# Hooks

- [Actions](#actions)
- [Filters](#filters)

## Actions

### `pre_trackback_post`

*Fires before the trackback is added to a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tb_id` | `int` | Post ID related to the trackback.
`$tb_url` | `string` | Trackback URL.
`$charset` | `string` | Character Set.
`$title` | `string` | Trackback Title.
`$excerpt` | `string` | Trackback Excerpt.
`$blog_name` | `string` | Blog Name.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-trackback.php](../../wordpress/wp-trackback.php), [line 98](../../wordpress/wp-trackback.php#L98-L110)

### `trackback_post`

*Fires after a trackback is added to a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$trackback_id` | `int` | Trackback ID.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-trackback.php](../../wordpress/wp-trackback.php), [line 143](../../wordpress/wp-trackback.php#L143-L150)

### `{$hook}`

*Fires scheduled events.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$v['args']` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-cron.php](../../wordpress/wp-cron.php), [line 129](../../wordpress/wp-cron.php#L129-L138)

### `activate_header`

*Fires before the Site Activation page is loaded.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-activate.php](../../wordpress/wp-activate.php), [line 74](../../wordpress/wp-activate.php#L74-L79)

### `activate_wp_head`

*Fires before the Site Activation page is loaded.*

Fires on the %1$s action.


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-activate.php](../../wordpress/wp-activate.php), [line 89](../../wordpress/wp-activate.php#L89-L96)

### `xmlrpc_rsd_apis`

*Add additional APIs to the Really Simple Discovery (RSD) endpoint.*


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/xmlrpc.php](../../wordpress/xmlrpc.php), [line 48](../../wordpress/xmlrpc.php#L48-L55)

### `opml_head`

*Fires in the OPML header.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-links-opml.php](../../wordpress/wp-links-opml.php), [line 38](../../wordpress/wp-links-opml.php#L38-L43)

### `wp-mail.php`

*Fires to allow a plugin to do a complete takeover of Post by Email.*


**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-mail.php](../../wordpress/wp-mail.php), [line 24](../../wordpress/wp-mail.php#L24-L29)

### `publish_phone`

*Fires after a post submitted by email is published.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-mail.php](../../wordpress/wp-mail.php), [line 235](../../wordpress/wp-mail.php#L235-L242)

### `mu_plugin_loaded`

*Fires once a single must-use plugin has loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mu_plugin` | `string` | Full path to the plugin's main file.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 324](../../wordpress/wp-settings.php#L324-L331)

### `network_plugin_loaded`

*Fires once a single network-activated plugin has loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$network_plugin` | `string` | Full path to the plugin's main file.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 341](../../wordpress/wp-settings.php#L341-L348)

### `muplugins_loaded`

*Fires once all must-use and network-activated plugins have loaded.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 353](../../wordpress/wp-settings.php#L353-L358)

### `plugin_loaded`

*Fires once a single activated plugin has loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin` | `string` | Full path to the plugin's main file.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 393](../../wordpress/wp-settings.php#L393-L400)

### `plugins_loaded`

*Fires once activated plugins have loaded.*

Pluggable functions are also available at this point in the loading order.


**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 416](../../wordpress/wp-settings.php#L416-L423)

### `sanitize_comment_cookies`

*Fires when comment cookies are sanitized.*


**Changelog**

Version | Description
------- | -----------
`2.0.11` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 431](../../wordpress/wp-settings.php#L431-L436)

### `setup_theme`

*Fires before the theme is loaded.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 487](../../wordpress/wp-settings.php#L487-L492)

### `after_setup_theme`

*Fires after the theme is loaded.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 533](../../wordpress/wp-settings.php#L533-L538)

### `init`

*Fires after WordPress has finished loading but before any headers are sent.*

Most of WP is loaded at this stage, and the user is authenticated. WP continues
to load on the %1$s hook that follows (e.g. widgets), and many plugins instantiate
themselves on it for all sorts of reasons (e.g. they need a user, a taxonomy, etc.).

If you wish to plug an action once WP is loaded, use the %2$s hook below.


**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 549](../../wordpress/wp-settings.php#L549-L560)

### `wp_loaded`

*This hook is fired once WP, all plugins, and the theme are fully loaded and instantiated.*

Ajax requests should use wp-admin/admin-ajax.php. admin-ajax.php can handle requests for
users not logged in.


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 572](../../wordpress/wp-settings.php#L572-L582)

### `set_comment_cookies`

*Perform other actions when comment cookies are set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` | `\WP_Comment` | Comment object.
`$user` | `\WP_User` | Comment author's user object. The user may not exist.
`$cookies_consent` | `bool` | Comment author's consent to store cookies.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | The `$cookies_consent` parameter was added.
`3.4.0` | 

Source: [wordpress/wp-comments-post.php](../../wordpress/wp-comments-post.php), [line 45](../../wordpress/wp-comments-post.php#L45-L55)

### `sidebar_admin_setup`

*Fires early before the Widgets administration screen loads,
after scripts are enqueued.*


**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-admin/widgets.php](../../wordpress/wp-admin/widgets.php), [line 41](../../wordpress/wp-admin/widgets.php#L41-L47)

### `delete_widget`

*Fires immediately after a widget has been marked for deletion.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$widget_id` | `string` | ID of the widget marked for deletion.
`$sidebar_id` | `string` | ID of the sidebar the widget was deleted from.
`$id_base` | `string` | ID base for the widget.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/widgets.php](../../wordpress/wp-admin/widgets.php), [line 176](../../wordpress/wp-admin/widgets.php#L176-L185)

### `widgets_admin_page`

*Fires before the Widgets administration page content loads.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/widgets.php](../../wordpress/wp-admin/widgets.php), [line 429](../../wordpress/wp-admin/widgets.php#L429-L434)

### `sidebar_admin_page`

*Fires after the available widgets and sidebars have loaded, before the admin footer.*


**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-admin/widgets.php](../../wordpress/wp-admin/widgets.php), [line 576](../../wordpress/wp-admin/widgets.php#L576-L581)

### `update-custom_{$action}`

*Fires when a custom plugin or theme update request is received.*

The dynamic portion of the hook name, `$action`, refers to the action
provided in the request for wp-admin/update.php. Can be used to
provide custom update functionality for themes and plugins.


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/update.php](../../wordpress/wp-admin/update.php), [line 343](../../wordpress/wp-admin/update.php#L343-L352)

### `admin_enqueue_scripts`

*Enqueue scripts for all admin pages.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hook_suffix` | `string` | The current admin page.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 95](../../wordpress/wp-admin/admin-header.php#L95-L102)

### `admin_print_styles-{$hook_suffix}`

*Fires when styles are printed for a specific admin page based on $hook_suffix.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 104](../../wordpress/wp-admin/admin-header.php#L104-L109)

### `admin_print_styles`

*Fires when styles are printed for all admin pages.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 111](../../wordpress/wp-admin/admin-header.php#L111-L116)

### `admin_print_scripts-{$hook_suffix}`

*Fires when scripts are printed for a specific admin page based on $hook_suffix.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 118](../../wordpress/wp-admin/admin-header.php#L118-L123)

### `admin_print_scripts`

*Fires when scripts are printed for all admin pages.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 125](../../wordpress/wp-admin/admin-header.php#L125-L130)

### `admin_head-{$hook_suffix}`

*Fires in head section for a specific admin page.*

The dynamic portion of the hook, `$hook_suffix`, refers to the hook suffix
for the admin page.


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 132](../../wordpress/wp-admin/admin-header.php#L132-L140)

### `admin_head`

*Fires in head section for all admin pages.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 142](../../wordpress/wp-admin/admin-header.php#L142-L147)

### `in_admin_header`

*Fires at the beginning of the content section in an admin page.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 247](../../wordpress/wp-admin/admin-header.php#L247-L252)

### `network_admin_notices`

*Prints network admin screen notices.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 269](../../wordpress/wp-admin/admin-header.php#L269-L274)

### `user_admin_notices`

*Prints user admin screen notices.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 276](../../wordpress/wp-admin/admin-header.php#L276-L281)

### `admin_notices`

*Prints admin screen notices.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 283](../../wordpress/wp-admin/admin-header.php#L283-L288)

### `all_admin_notices`

*Prints generic admin screen notices.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 291](../../wordpress/wp-admin/admin-header.php#L291-L296)

### `in_admin_footer`

*Fires after the opening tag for the admin footer.*


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/admin-footer.php](../../wordpress/wp-admin/admin-footer.php), [line 26](../../wordpress/wp-admin/admin-footer.php#L26-L31)

### `admin_footer`

*Prints scripts or data before the default footer scripts.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-admin/admin-footer.php](../../wordpress/wp-admin/admin-footer.php), [line 71](../../wordpress/wp-admin/admin-footer.php#L71-L78)

### `admin_print_footer_scripts-{$hook_suffix}`

*Prints scripts and data queued for the footer.*

The dynamic portion of the hook name, `$hook_suffix`,
refers to the global hook suffix of the current page.


**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-admin/admin-footer.php](../../wordpress/wp-admin/admin-footer.php), [line 80](../../wordpress/wp-admin/admin-footer.php#L80-L88)

### `admin_print_footer_scripts`

*Prints any scripts and data queued for the footer.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/admin-footer.php](../../wordpress/wp-admin/admin-footer.php), [line 90](../../wordpress/wp-admin/admin-footer.php#L90-L95)

### `admin_footer-{$hook_suffix}`

*Prints scripts or data after the default footer scripts.*

The dynamic portion of the hook name, `$hook_suffix`,
refers to the global hook suffix of the current page.


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/admin-footer.php](../../wordpress/wp-admin/admin-footer.php), [line 97](../../wordpress/wp-admin/admin-footer.php#L97-L105)

### `post_edit_form_tag`

*Fires inside the post editor form tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 456](../../wordpress/wp-admin/edit-form-advanced.php#L456-L463)

### `edit_form_top`

*Fires at the beginning of the edit form.*

At this point, the required hidden fields and nonces have already been output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 491](../../wordpress/wp-admin/edit-form-advanced.php#L491-L500)

### `edit_form_before_permalink`

*Fires before the permalink field in the edit form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 525](../../wordpress/wp-admin/edit-form-advanced.php#L525-L532)

### `edit_form_after_title`

*Fires after the title field.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 574](../../wordpress/wp-admin/edit-form-advanced.php#L574-L581)

### `edit_form_after_editor`

*Fires after the content editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 642](../../wordpress/wp-admin/edit-form-advanced.php#L642-L649)

### `submitpage_box`

*Fires before meta boxes with 'side' context are output for the 'page' post type.*

The submitpage box is a meta box with 'side' context, so this hook fires just before it is output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 657](../../wordpress/wp-admin/edit-form-advanced.php#L657-L666)

### `submitpost_box`

*Fires before meta boxes with 'side' context are output for all post types other than 'page'.*

The submitpost box is a meta box with 'side' context, so this hook fires just before it is output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 668](../../wordpress/wp-admin/edit-form-advanced.php#L668-L677)

### `edit_page_form`

*Fires after 'normal' context meta boxes have been output for the 'page' post type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 691](../../wordpress/wp-admin/edit-form-advanced.php#L691-L698)

### `edit_form_advanced`

*Fires after 'normal' context meta boxes have been output for all post types other than 'page'.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 700](../../wordpress/wp-admin/edit-form-advanced.php#L700-L707)

### `dbx_post_sidebar`

*Fires after all meta box sections have been output, before the closing #post-body div.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 716](../../wordpress/wp-admin/edit-form-advanced.php#L716-L723)

### `blog_privacy_selector`

*This action is documented in wp-admin/options-reading.php*


Source: [wordpress/wp-admin/install.php](../../wordpress/wp-admin/install.php), [line 195](../../wordpress/wp-admin/install.php#L195-L196)

### `welcome_panel`

*Add content to the welcome panel on the admin dashboard.*

To remove the default welcome panel, use remove_action():

remove_action( 'welcome_panel', 'wp_welcome_panel' );


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/index.php](../../wordpress/wp-admin/index.php), [line 166](../../wordpress/wp-admin/index.php#L166-L175)

### `wp_authorize_application_password_form_approved_no_js`

*Fires in the Authorize Application Password new password section in the no-JS version.*

In most cases, this should be used in combination with the %1$s
action to ensure that both the JS and no-JS variants are handled.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_password` | `string` | The newly generated application password.
`$request` | `array` | The array of request data. All arguments are optional and may be empty.
`$user` | `\WP_User` | The user authorizing the application.

**Changelog**

Version | Description
------- | -----------
`5.6.1` | Corrected action name and signature.
`5.6.0` | 

Source: [wordpress/wp-admin/authorize-application.php](../../wordpress/wp-admin/authorize-application.php), [line 202](../../wordpress/wp-admin/authorize-application.php#L202-L215)

### `wp_authorize_application_password_form`

*Fires in the Authorize Application Password form before the submit buttons.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$request` | `array` | {<br>    The array of request data. All arguments are optional and may be empty.<br><br>    @type string $app_name    The suggested name of the application.<br>    @type string $success_url The url the user will be redirected to after approving the application.<br>    @type string $reject_url  The url the user will be redirected to after rejecting the application.<br>}
`$user` | `\WP_User` | The user authorizing the application.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/authorize-application.php](../../wordpress/wp-admin/authorize-application.php), [line 231](../../wordpress/wp-admin/authorize-application.php#L231-L245)

### `post_action_{$action}`

*Fires for a given custom post action request.*

The dynamic portion of the hook name, `$action`, refers to the custom post action.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID sent with the request.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-admin/post.php](../../wordpress/wp-admin/post.php), [line 354](../../wordpress/wp-admin/post.php#L354-L363)

### `media_upload_{$type}`

*Fires inside specific upload-type views in the legacy (pre-3.5.0)
media popup based on the current tab.*

The dynamic portion of the hook name, `$type`, refers to the specific
media upload type. Possible values include 'image', 'audio', 'video',
'file', etc.

The hook only fires if the current `$tab` is 'type' (From Computer),
'type_url' (From URL), or, if the tab does not exist (i.e., has not
been registered via the %1$s filter.


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/media-upload.php](../../wordpress/wp-admin/media-upload.php), [line 85](../../wordpress/wp-admin/media-upload.php#L85-L99)

### `media_upload_{$tab}`

*Fires inside limited and specific upload-tab views in the legacy
(pre-3.5.0) media popup.*

The dynamic portion of the hook name, `$tab`, refers to the specific
media upload tab. Possible values include 'library' (Media Library),
or any custom tab registered via the %1$s filter.


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/media-upload.php](../../wordpress/wp-admin/media-upload.php), [line 101](../../wordpress/wp-admin/media-upload.php#L101-L111)

### `blog_privacy_selector`

*Enable the legacy 'Site visibility' privacy options.*

By default the privacy options form displays a single checkbox to 'discourage' search
engines from indexing the site. Hooking to this action serves a dual purpose:
1. Disable the single checkbox in favor of a multiple-choice list of radio buttons.
2. Open the door to adding additional radio button choices to the list.

Hooking to this action also converts the 'Search engine visibility' heading to the more
open-ended 'Site visibility' heading.


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/options-reading.php](../../wordpress/wp-admin/options-reading.php), [line 188](../../wordpress/wp-admin/options-reading.php#L188-L201)

### `export_filters`

*Fires at the end of the export filters form.*


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/export.php](../../wordpress/wp-admin/export.php), [line 312](../../wordpress/wp-admin/export.php#L312-L317)

### `wpmuadminedit`

*This action is documented in wp-admin/network/edit.php*


Source: [wordpress/wp-admin/network/sites.php](../../wordpress/wp-admin/network/sites.php), [line 59](../../wordpress/wp-admin/network/sites.php#L59-L60)

### `activate_blog`

*Fires after a network site is activated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `string` | The ID of the activated site.

Source: [wordpress/wp-admin/network/sites.php](../../wordpress/wp-admin/network/sites.php), [line 258](../../wordpress/wp-admin/network/sites.php#L258-L265)

### `deactivate_blog`

*Fires before a network site is deactivated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `string` | The ID of the site being deactivated.

Source: [wordpress/wp-admin/network/sites.php](../../wordpress/wp-admin/network/sites.php), [line 269](../../wordpress/wp-admin/network/sites.php#L269-L276)

### `wpmuadminedit`

*This action is documented in wp-admin/network/edit.php*


Source: [wordpress/wp-admin/network/settings.php](../../wordpress/wp-admin/network/settings.php), [line 68](../../wordpress/wp-admin/network/settings.php#L68-L69)

### `update_wpmu_options`

*Fires after the network options are updated.*


Source: [wordpress/wp-admin/network/settings.php](../../wordpress/wp-admin/network/settings.php), [line 127](../../wordpress/wp-admin/network/settings.php#L127-L132)

### `wpmu_options`

*Fires at the end of the Network Settings form, before the submit button.*


Source: [wordpress/wp-admin/network/settings.php](../../wordpress/wp-admin/network/settings.php), [line 495](../../wordpress/wp-admin/network/settings.php#L495-L500)

### `pre_network_site_new_created_user`

*Fires immediately before a new user is created via the network site-new.php page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email` | `string` | Email of the non-existent user.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-admin/network/site-new.php](../../wordpress/wp-admin/network/site-new.php), [line 110](../../wordpress/wp-admin/network/site-new.php#L110-L117)

### `network_site_new_created_user`

*Fires after a new user has been created via the network site-new.php page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the newly created user.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/network/site-new.php](../../wordpress/wp-admin/network/site-new.php), [line 129](../../wordpress/wp-admin/network/site-new.php#L129-L136)

### `network_site_new_form`

*Fires at the end of the new site form in network admin.*


**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-admin/network/site-new.php](../../wordpress/wp-admin/network/site-new.php), [line 268](../../wordpress/wp-admin/network/site-new.php#L268-L273)

### `after_mu_upgrade`

*Fires after the Multisite DB upgrade for each site is complete.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array\|\WP_Error` | The upgrade response array or WP_Error on failure.

Source: [wordpress/wp-admin/network/upgrade.php](../../wordpress/wp-admin/network/upgrade.php), [line 105](../../wordpress/wp-admin/network/upgrade.php#L105-L112)

### `wpmu_upgrade_site`

*Fires after each site has been upgraded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | The Site ID.

Source: [wordpress/wp-admin/network/upgrade.php](../../wordpress/wp-admin/network/upgrade.php), [line 114](../../wordpress/wp-admin/network/upgrade.php#L114-L121)

### `wpmu_upgrade_page`

*Fires before the footer on the network upgrade screen.*


Source: [wordpress/wp-admin/network/upgrade.php](../../wordpress/wp-admin/network/upgrade.php), [line 146](../../wordpress/wp-admin/network/upgrade.php#L146-L151)

### `wpmuadminedit`

*This action is documented in wp-admin/network/edit.php*


Source: [wordpress/wp-admin/network/users.php](../../wordpress/wp-admin/network/users.php), [line 18](../../wordpress/wp-admin/network/users.php#L18-L19)

### `wpmu_update_blog_options`

*Fires after the site options are updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | The ID of the site being updated.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added `$id` parameter.
`3.0.0` | 

Source: [wordpress/wp-admin/network/site-settings.php](../../wordpress/wp-admin/network/site-settings.php), [line 52](../../wordpress/wp-admin/network/site-settings.php#L52-L60)

### `wpmueditblogaction`

*Fires at the end of the Edit Site form, before the submit button.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | Site ID.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/network/site-settings.php](../../wordpress/wp-admin/network/site-settings.php), [line 166](../../wordpress/wp-admin/network/site-settings.php#L166-L173)

### `network_user_new_created_user`

*Fires after a new user has been created via the network user-new.php page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the newly created user.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/network/user-new.php](../../wordpress/wp-admin/network/user-new.php), [line 57](../../wordpress/wp-admin/network/user-new.php#L57-L64)

### `network_user_new_form`

*Fires at the end of the new user form in network admin.*


**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-admin/network/user-new.php](../../wordpress/wp-admin/network/user-new.php), [line 140](../../wordpress/wp-admin/network/user-new.php#L140-L145)

### `wpmuadminedit`

*Fires just before the action handler in several Network Admin screens.*

This hook fires on multiple screens in the Multisite Network Admin,
including Users, Network Settings, and Site Settings.


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/network/edit.php](../../wordpress/wp-admin/network/edit.php), [line 20](../../wordpress/wp-admin/network/edit.php#L20-L28)

### `network_admin_edit_{$action}`

*Fires the requested handler action.*

The dynamic portion of the hook name, `$action`, refers to the name
of the requested action derived from the `GET` request.


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/network/edit.php](../../wordpress/wp-admin/network/edit.php), [line 30](../../wordpress/wp-admin/network/edit.php#L30-L38)

### `network_site_info_form`

*Fires at the end of the site info form in network admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | The site ID.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/network/site-info.php](../../wordpress/wp-admin/network/site-info.php), [line 207](../../wordpress/wp-admin/network/site-info.php#L207-L214)

### `network_site_users_created_user`

*Fires after a user has been created via the network site-users.php page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the newly created user.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/network/site-users.php](../../wordpress/wp-admin/network/site-users.php), [line 81](../../wordpress/wp-admin/network/site-users.php#L81-L88)

### `network_site_users_after_list_table`

*Fires after the list table on the Users screen in the Multisite Network Admin.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/network/site-users.php](../../wordpress/wp-admin/network/site-users.php), [line 288](../../wordpress/wp-admin/network/site-users.php#L288-L293)

### `after_menu_locations_table`

*Fires after the menu locations table is displayed.*


**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/nav-menus.php](../../wordpress/wp-admin/nav-menus.php), [line 814](../../wordpress/wp-admin/nav-menus.php#L814-L819)

### `manage_{$screen->id}_custom_column`

*Fires for each custom column of a specific request type in the Requests list table.*

Custom columns are registered using the %1$s
and the %2$s filters.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | The name of the column to display.
`$item` | `\WP_User_Request` | The item being shown.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-privacy-requests-table.php](../../wordpress/wp-admin/includes/class-wp-privacy-requests-table.php), [line 493](../../wordpress/wp-admin/includes/class-wp-privacy-requests-table.php#L493-L504)

### `quick_edit_custom_box`

*This action is documented in wp-admin/includes/class-wp-posts-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` |  | 
`'edit-tags'` |  | 
`$this->screen->taxonomy` |  | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 680](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L680-L681)

### `restrict_manage_users`

*Fires just before the closing div containing the bulk role-change controls
in the Users list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$which` | `string` | The location of the extra table nav markup: 'top' or 'bottom'.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | The `$which` parameter was added.
`3.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-users-list-table.php), [line 309](../../wordpress/wp-admin/includes/class-wp-users-list-table.php#L309-L318)

### `manage_users_extra_tablenav`

*Fires immediately following the closing "actions" div in the tablenav for the users
list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$which` | `string` | The location of the extra table nav markup: 'top' or 'bottom'.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-admin/includes/class-wp-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-users-list-table.php), [line 322](../../wordpress/wp-admin/includes/class-wp-users-list-table.php#L322-L330)

### `delete_blog`

*This action is documented in wp-includes/ms-blogs.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($blog_id, false)` |  | 
`'5.1.0'` |  | 

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 99](../../wordpress/wp-admin/includes/ms.php#L99-L100)

### `deleted_blog`

*This action is documented in wp-includes/ms-blogs.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($blog_id, false)` |  | 
`'5.1.0'` |  | 

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 118](../../wordpress/wp-admin/includes/ms.php#L118-L119)

### `wpmu_delete_user`

*Fires before a user is deleted from the network.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | ID of the user about to be deleted from the network.
`$user` | `\WP_User` | WP_User object of the user about to be deleted from the network.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$user` parameter.

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 159](../../wordpress/wp-admin/includes/ms.php#L159-L168)

### `deleted_user`

*This action is documented in wp-admin/includes/user.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` |  | 
`null` |  | 
`$user` |  | 

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 204](../../wordpress/wp-admin/includes/ms.php#L204-L205)

### `delete_user_form`

*This action is documented in wp-admin/users.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$current_user` |  | 
`$allusers` |  | 

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 976](../../wordpress/wp-admin/includes/ms.php#L976-L977)

### `upgrader_overwrote_package`

*Fires when the upgrader has successfully overwritten a currently installed
plugin or theme with an uploaded zip package.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$package` | `string` | The package file.
`$this->new_plugin_data` |  | 
`'plugin'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-plugin-upgrader.php](../../wordpress/wp-admin/includes/class-plugin-upgrader.php), [line 159](../../wordpress/wp-admin/includes/class-plugin-upgrader.php#L159-L169)

### `upgrader_process_complete`

*This action is documented in wp-admin/includes/class-wp-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 
`array('action' => 'update', 'type' => 'plugin', 'bulk' => true, 'plugins' => $plugins)` |  | 

Source: [wordpress/wp-admin/includes/class-plugin-upgrader.php](../../wordpress/wp-admin/includes/class-plugin-upgrader.php), [line 363](../../wordpress/wp-admin/includes/class-plugin-upgrader.php#L363-L373)

### `in_plugin_update_message-{$file}`

*Fires at the end of the update message container in each
row of the plugins list table.*

The dynamic portion of the hook name, `$file`, refers to the path
of the plugin's primary file relative to the plugins directory.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin_data` | `array` | {<br>    An array of plugin metadata.<br><br>    @type string $name        The human-readable name of the plugin.<br>    @type string $plugin_uri  Plugin URI.<br>    @type string $version     Plugin version.<br>    @type string $description Plugin description.<br>    @type string $author      Plugin author.<br>    @type string $author_uri  Plugin author URI.<br>    @type string $text_domain Plugin text domain.<br>    @type string $domain_path Relative path to the plugin's .mo file(s).<br>    @type bool   $network     Whether the plugin can only be activated network wide.<br>    @type string $title       The human-readable title of the plugin.<br>    @type string $author_name Plugin author's name.<br>    @type bool   $update      Whether there's an available update. Default null.<br>}
`$response` | `array` | {<br>    An array of metadata about the available plugin update.<br><br>    @type int    $id          Plugin ID.<br>    @type string $slug        Plugin slug.<br>    @type string $new_version New plugin version.<br>    @type string $url         Plugin URL.<br>    @type string $package     Plugin update package URL.<br>}

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/update.php](../../wordpress/wp-admin/includes/update.php), [line 535](../../wordpress/wp-admin/includes/update.php#L535-L570)

### `in_theme_update_message-{$theme_key}`

*Fires at the end of the update message container in each
row of the themes list table.*

The dynamic portion of the hook name, `$theme_key`, refers to
the theme slug as found in the WordPress.org themes repository.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$theme` | `\WP_Theme` | The WP_Theme object.
`$response` | `array` | {<br>    An array of metadata about the available theme update.<br><br>    @type string $new_version New theme version.<br>    @type string $url         Theme URL.<br>    @type string $package     Theme update package URL.<br>}

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/update.php](../../wordpress/wp-admin/includes/update.php), [line 769](../../wordpress/wp-admin/includes/update.php#L769-L787)

### `install_themes_table_header`

*Fires in the Install Themes list table header.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-theme-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php), [line 202](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php#L202-L207)

### `wp_network_dashboard_setup`

*Fires after core widgets for the Network Admin dashboard have been registered.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 84](../../wordpress/wp-admin/includes/dashboard.php#L84-L89)

### `wp_user_dashboard_setup`

*Fires after core widgets for the User Admin dashboard have been registered.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 101](../../wordpress/wp-admin/includes/dashboard.php#L101-L106)

### `wp_dashboard_setup`

*Fires after core widgets for the admin dashboard have been registered.*


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 118](../../wordpress/wp-admin/includes/dashboard.php#L118-L123)

### `do_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$screen->id` |  | 
`'normal'` |  | 
`''` |  | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 149](../../wordpress/wp-admin/includes/dashboard.php#L149-L150)

### `do_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$screen->id` |  | 
`'side'` |  | 
`''` |  | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 152](../../wordpress/wp-admin/includes/dashboard.php#L152-L153)

### `rightnow_end`

*Fires at the end of the 'At a Glance' dashboard widget.*

Prior to 3.8.0, the widget was named 'Right Now'.


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 395](../../wordpress/wp-admin/includes/dashboard.php#L395-L402)

### `activity_box_end`

*Fires at the end of the 'At a Glance' dashboard widget.*

Prior to 3.8.0, the widget was named 'Right Now'.


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 404](../../wordpress/wp-admin/includes/dashboard.php#L404-L411)

### `wpmuadminresult`

*Fires in the Network Admin 'Right Now' dashboard widget
just before the user and site search form fields.*


Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 462](../../wordpress/wp-admin/includes/dashboard.php#L462-L468)

### `mu_rightnow_end`

*Fires at the end of the 'Right Now' widget in the Network Admin dashboard.*


Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 487](../../wordpress/wp-admin/includes/dashboard.php#L487-L492)

### `mu_activity_box_end`

*Fires at the end of the 'Right Now' widget in the Network Admin dashboard.*


Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 494](../../wordpress/wp-admin/includes/dashboard.php#L494-L499)

### `post_locked_dialog`

*Fires inside the post locked dialog before the buttons are displayed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.
`$user` | `\WP_User` | The user with the lock for the post.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | The $user parameter was added.
`3.6.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1752](../../wordpress/wp-admin/includes/post.php#L1752-L1761)

### `post_lock_lost_dialog`

*Fires inside the dialog displayed when a user has lost the post lock.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1791](../../wordpress/wp-admin/includes/post.php#L1791-L1798)

### `wp_creating_autosave`

*Fires before an autosave is stored.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_autosave` | `array` | Post array - the autosave that is about to be saved.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1858](../../wordpress/wp-admin/includes/post.php#L1858-L1865)

### `edit_form_after_title`

*This filter is documented in wp-admin/edit-form-advanced.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2432](../../wordpress/wp-admin/includes/post.php#L2432-L2433)

### `edit_form_advanced`

*This filter is documented in wp-admin/edit-form-advanced.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2434](../../wordpress/wp-admin/includes/post.php#L2434-L2435)

### `block_editor_meta_box_hidden_fields`

*Add hidden input fields to the meta box save form.*

Hook into this action to print `<input type="hidden" ... />` fields, which will be POSTed back to
the server when meta boxes are saved.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | The post that is being edited.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2467](../../wordpress/wp-admin/includes/post.php#L2467-L2477)

### `upgrader_process_complete`

*This action is documented in wp-admin/includes/class-wp-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 
`array('action' => 'update', 'type' => 'translation', 'bulk' => true, 'translations' => $language_updates_results)` |  | 

Source: [wordpress/wp-admin/includes/class-language-pack-upgrader.php](../../wordpress/wp-admin/includes/class-language-pack-upgrader.php), [line 279](../../wordpress/wp-admin/includes/class-language-pack-upgrader.php#L279-L289)

### `restrict_manage_sites`

*Fires before the Filter button on the MS sites list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$which` | `string` | The location of the extra table nav markup: 'top' or 'bottom'.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 327](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L327-L334)

### `manage_sites_extra_tablenav`

*Fires immediately following the closing "actions" div in the tablenav for the
MS sites list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$which` | `string` | The location of the extra table nav markup: 'top' or 'bottom'.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 346](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L346-L354)

### `wpmublogsaction`

*Fires inside the auxiliary 'Actions' column of the Sites list table.*

By default this column is hidden unless something is hooked to the action.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$blog['blog_id']` |  | 

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 546](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L546-L555)

### `manage_sites_custom_column`

*Fires for each registered custom column in the Sites list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | The name of the column to display.
`$blog['blog_id']` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 568](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L568-L576)

### `export_wp`

*Fires at the beginning of an export, before any headers are sent.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | An array of export arguments.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 70](../../wordpress/wp-admin/includes/export.php#L70-L77)

### `rss2_head`

*This action is documented in wp-includes/feed-rss2.php*


Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 522](../../wordpress/wp-admin/includes/export.php#L522-L523)

### `activate_plugin`

*Fires before a plugin is activated.*

If a plugin is silently activated (such as during an update),
this hook does not fire.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin` | `string` | Path to the plugin file relative to the plugins directory.
`$network_wide` | `bool` | Whether to enable the plugin for all sites in the network<br>or just the current site. Multisite only. Default false.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 674](../../wordpress/wp-admin/includes/plugin.php#L674-L686)

### `activate_{$plugin}`

*Fires as a specific plugin is being activated.*

This hook is the "activation" hook used internally by register_activation_hook().
The dynamic portion of the hook name, `$plugin`, refers to the plugin basename.

If a plugin is silently activated (such as during an update), this hook does not fire.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$network_wide` | `bool` | Whether to enable the plugin for all sites in the network<br>or just the current site. Multisite only. Default false.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 688](../../wordpress/wp-admin/includes/plugin.php#L688-L701)

### `activated_plugin`

*Fires after a plugin has been activated.*

If a plugin is silently activated (such as during an update),
this hook does not fire.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin` | `string` | Path to the plugin file relative to the plugins directory.
`$network_wide` | `bool` | Whether to enable the plugin for all sites in the network<br>or just the current site. Multisite only. Default false.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 716](../../wordpress/wp-admin/includes/plugin.php#L716-L728)

### `deactivate_plugin`

*Fires before a plugin is deactivated.*

If a plugin is silently deactivated (such as during an update),
this hook does not fire.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin` | `string` | Path to the plugin file relative to the plugins directory.
`$network_deactivating` | `bool` | Whether the plugin is deactivated for all sites in the network<br>or just the current site. Multisite only. Default false.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 772](../../wordpress/wp-admin/includes/plugin.php#L772-L784)

### `deactivate_{$plugin}`

*Fires as a specific plugin is being deactivated.*

This hook is the "deactivation" hook used internally by register_deactivation_hook().
The dynamic portion of the hook name, `$plugin`, refers to the plugin basename.

If a plugin is silently deactivated (such as during an update), this hook does not fire.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$network_deactivating` | `bool` | Whether the plugin is deactivated for all sites in the network<br>or just the current site. Multisite only. Default false.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 810](../../wordpress/wp-admin/includes/plugin.php#L810-L823)

### `deactivated_plugin`

*Fires after a plugin is deactivated.*

If a plugin is silently deactivated (such as during an update),
this hook does not fire.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin` | `string` | Path to the plugin file relative to the plugins directory.
`$network_deactivating` | `bool` | Whether the plugin is deactivated for all sites in the network<br>or just the current site. Multisite only. Default false.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 825](../../wordpress/wp-admin/includes/plugin.php#L825-L837)

### `delete_plugin`

*Fires immediately before a plugin deletion attempt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 970](../../wordpress/wp-admin/includes/plugin.php#L970-L977)

### `deleted_plugin`

*Fires immediately after a plugin deletion attempt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$deleted` | `bool` | Whether the plugin deletion was successful.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 989](../../wordpress/wp-admin/includes/plugin.php#L989-L997)

### `pre_uninstall_plugin`

*Fires in uninstall_plugin() immediately before the plugin is uninstalled.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin` | `string` | Path to the plugin file relative to the plugins directory.
`$uninstallable_plugins` | `array` | Uninstallable plugins.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 1242](../../wordpress/wp-admin/includes/plugin.php#L1242-L1250)

### `uninstall_{$file}`

*Fires in uninstall_plugin() once the plugin has been uninstalled.*

The action concatenates the 'uninstall_' prefix with the basename of the
plugin passed to uninstall_plugin() to create a dynamically-named action.


**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 1278](../../wordpress/wp-admin/includes/plugin.php#L1278-L1286)

### `manage_{$screen->id}_custom_column`

*Fires for each custom column in the Application Passwords list table.*

Custom columns are registered using the %1$s filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the custom column.
`$item` | `array` | The application password item.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/includes/class-wp-application-passwords-list-table.php](../../wordpress/wp-admin/includes/class-wp-application-passwords-list-table.php), [line 134](../../wordpress/wp-admin/includes/class-wp-application-passwords-list-table.php#L134-L144)

### `manage_{$screen->id}_custom_column_js_template`

*Fires in the JavaScript row template for each custom column in the Application Passwords list table.*

Custom columns are registered using the %1$s filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the custom column.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/includes/class-wp-application-passwords-list-table.php](../../wordpress/wp-admin/includes/class-wp-application-passwords-list-table.php), [line 245](../../wordpress/wp-admin/includes/class-wp-application-passwords-list-table.php#L245-L254)

### `wp_nav_menu_item_custom_fields`

*Fires just before the move buttons of a nav menu item in the menu editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$item_id` | `int` | Menu item ID.
`$item` | `\WP_Post` | Menu item data object.
`$depth` | `int` | Depth of menu item. Used for padding.
`$args` | `\stdClass` | An object of menu item arguments.
`$id` | `int` | Nav menu ID.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-admin/includes/class-walker-nav-menu-edit.php](../../wordpress/wp-admin/includes/class-walker-nav-menu-edit.php), [line 231](../../wordpress/wp-admin/includes/class-walker-nav-menu-edit.php#L231-L242)

### `check_passwords`

*Fires before the password and confirm password fields are checked for congruity.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($user->user_login, &$pass1, &$pass2)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 154](../../wordpress/wp-admin/includes/user.php#L154-L163)

### `user_profile_update_errors`

*Fires before user profile update errors are returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$errors, $update, &$user)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 211](../../wordpress/wp-admin/includes/user.php#L211-L220)

### `edit_user_created_user`

*Fires after a new user has been created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the newly created user.
`$notify` | `string` | Type of notification that should happen. See wp_send_new_user_notifications()<br>for more information on possible values.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 232](../../wordpress/wp-admin/includes/user.php#L232-L241)

### `delete_user`

*Fires immediately before a user is deleted from the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | ID of the user to delete.
`$reassign` | `int\|null` | ID of the user to reassign posts and links to.<br>Default null, for no reassignment.
`$user` | `\WP_User` | WP_User object of the user to delete.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$user` parameter.
`2.0.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 357](../../wordpress/wp-admin/includes/user.php#L357-L368)

### `deleted_user`

*Fires immediately after a user is deleted from the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | ID of the deleted user.
`$reassign` | `int\|null` | ID of the user to reassign posts and links to.<br>Default null, for no reassignment.
`$user` | `\WP_User` | WP_User object of the deleted user.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$user` parameter.
`2.9.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 436](../../wordpress/wp-admin/includes/user.php#L436-L447)

### `wp_authorize_application_password_request_errors`

*Fires before application password errors are returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$error` | `\WP_Error` | The error object.
`$request` | `array` | The array of request data.
`$user` | `\WP_User` | The user authorizing the application.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 646](../../wordpress/wp-admin/includes/user.php#L646-L655)

### `_core_updated_successfully`

*Fires after WordPress core has been successfully updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_version` | `string` | The current WordPress version.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/update-core.php](../../wordpress/wp-admin/includes/update-core.php), [line 1327](../../wordpress/wp-admin/includes/update-core.php#L1327-L1334)

### `pre_auto_update`

*Fires immediately prior to an auto-update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$type` | `string` | The type of update being checked: 'core', 'theme', 'plugin', or 'translation'.
`$item` | `object` | The update offer.
`$context` | `string` | The filesystem context (a path) against which filesystem access and status<br>should be checked.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 327](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L327-L337)

### `automatic_updates_complete`

*Fires after all automatic updates have run.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->update_results` |  | 

**Changelog**

Version | Description
------- | -----------
`3.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 542](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L542-L549)

### `wp_privacy_personal_data_export_file_created`

*Fires right after all personal data has been written to the export file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$archive_pathname` | `string` | The full path to the export file on the filesystem.
`$archive_url` | `string` | The URL of the archive file.
`$html_report_pathname` | `string` | The full path to the HTML personal data report on the filesystem.
`$request_id` | `int` | The export request ID.
`$json_report_pathname` | `string` | The full path to the JSON personal data report on the filesystem.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | Added the `$json_report_pathname` parameter.
`4.9.6` | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 529](../../wordpress/wp-admin/includes/privacy-tools.php#L529-L541)

### `wp_privacy_personal_data_export_file`

*Generate the export file from the collected, grouped personal data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$request_id` | `int` | The export request ID.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 837](../../wordpress/wp-admin/includes/privacy-tools.php#L837-L844)

### `wp_privacy_personal_data_erased`

*Fires immediately after a personal data erasure request has been marked completed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$request_id` | `int` | The privacy request post ID associated with this request.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 938](../../wordpress/wp-admin/includes/privacy-tools.php#L938-L945)

### `upgrader_process_complete`

*Fires when the upgrader process is complete.*

See also %1$s.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Upgrader` | WP_Upgrader instance. In other contexts, $this, might be a<br>Theme_Upgrader, Plugin_Upgrader, Core_Upgrade, or Language_Pack_Upgrader instance.
`$options['hook_extra']` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | `$translations` was added as a possible argument to `$hook_extra`.
`3.7.0` | Added to WP_Upgrader::run().
`3.6.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 827](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L827-L857)

### `post_submitbox_minor_actions`

*Fires before the post time/date setting in the Publish meta box.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | WP_Post object for the current post.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 89](../../wordpress/wp-admin/includes/meta-boxes.php#L89-L96)

### `post_submitbox_misc_actions`

*Fires after the post time/date setting in the Publish meta box.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | WP_Post object for the current post.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added the `$post` parameter.
`2.9.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 304](../../wordpress/wp-admin/includes/meta-boxes.php#L304-L312)

### `post_submitbox_start`

*Fires at the beginning of the publishing actions section of the Publish meta box.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post\|null` | WP_Post object for the current post on Edit Post screen,<br>null on Edit Link screen.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$post` parameter.
`2.7.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 320](../../wordpress/wp-admin/includes/meta-boxes.php#L320-L329)

### `attachment_submitbox_misc_actions`

*Fires after the 'Uploaded on' section of the Save meta box
in the attachment editing screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | WP_Post object for the current attachment.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$post` parameter.
`3.5.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 421](../../wordpress/wp-admin/includes/meta-boxes.php#L421-L430)

### `post_comment_status_meta_box-options`

*Fires at the end of the Discussion meta box on the post editing screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | WP_Post object of the current post.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 812](../../wordpress/wp-admin/includes/meta-boxes.php#L812-L819)

### `page_attributes_meta_box_template`

*Fires immediately after the label inside the 'Template' section
of the 'Page Attributes' meta box.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$template` | `string` | The template used for the current post.
`$post` | `\WP_Post` | The current post.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 978](../../wordpress/wp-admin/includes/meta-boxes.php#L978-L987)

### `page_attributes_misc_attributes`

*Fires before the help hint text in the 'Page Attributes' meta box.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | The current post.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1011](../../wordpress/wp-admin/includes/meta-boxes.php#L1011-L1018)

### `post_submitbox_start`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1068](../../wordpress/wp-admin/includes/meta-boxes.php#L1068-L1069)

### `submitlink_box`

*Fires at the end of the Publish box in the Link editing screen.*


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1095](../../wordpress/wp-admin/includes/meta-boxes.php#L1095-L1100)

### `dbx_post_advanced`

*Fires in the middle of built-in meta box registration.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($post)` |  | 
`'3.7.0'` |  | 
`'add_meta_boxes'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1532](../../wordpress/wp-admin/includes/meta-boxes.php#L1532-L1540)

### `add_meta_boxes`

*Fires after all built-in meta boxes have been added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type` | `string` | Post type.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1570](../../wordpress/wp-admin/includes/meta-boxes.php#L1570-L1578)

### `add_meta_boxes_{$post_type}`

*Fires after all built-in meta boxes have been added, contextually for the given post type.*

The dynamic portion of the hook, `$post_type`, refers to the post type of the post.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1580](../../wordpress/wp-admin/includes/meta-boxes.php#L1580-L1589)

### `do_meta_boxes`

*Fires after meta boxes have been added.*

Fires once for each of the default meta box contexts: normal, advanced, and side.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type` | `string` | Post type of the post on Edit Post screen, 'link' on Edit Link screen,<br>'dashboard' on Dashboard screen.
`'normal'` |  | 
`$post` | `\WP_Post\|object\|string` | Post object on Edit Post screen, link object on Edit Link screen,<br>an empty string on Dashboard screen.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1591](../../wordpress/wp-admin/includes/meta-boxes.php#L1591-L1604)

### `do_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type` |  | 
`'advanced'` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1605](../../wordpress/wp-admin/includes/meta-boxes.php#L1605-L1606)

### `do_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type` |  | 
`'side'` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 1607](../../wordpress/wp-admin/includes/meta-boxes.php#L1607-L1608)

### `wp_install`

*Fires after a site is fully installed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | The site owner.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-admin/includes/upgrade.php](../../wordpress/wp-admin/includes/upgrade.php), [line 121](../../wordpress/wp-admin/includes/upgrade.php#L121-L128)

### `wp_upgrade`

*Fires after a site is fully upgraded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_db_version` | `int` | The new $wp_db_version.
`$wp_current_db_version` | `int` | The old (current) $wp_db_version.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-admin/includes/upgrade.php](../../wordpress/wp-admin/includes/upgrade.php), [line 711](../../wordpress/wp-admin/includes/upgrade.php#L711-L719)

### `install_plugins_table_header`

*Fires before the Plugin Install table header pagination is displayed.*


**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php), [line 385](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php#L385-L390)

### `_network_admin_menu`

*Fires before the administration menu loads in the Network Admin.*

The hook fires before menus and sub-menus are removed based on user privileges.


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 11](../../wordpress/wp-admin/includes/menu.php#L11-L19)

### `_user_admin_menu`

*Fires before the administration menu loads in the User Admin.*

The hook fires before menus and sub-menus are removed based on user privileges.


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 22](../../wordpress/wp-admin/includes/menu.php#L22-L30)

### `_admin_menu`

*Fires before the administration menu loads in the admin.*

The hook fires before menus and sub-menus are removed based on user privileges.


**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 33](../../wordpress/wp-admin/includes/menu.php#L33-L41)

### `network_admin_menu`

*Fires before the administration menu loads in the Network Admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 128](../../wordpress/wp-admin/includes/menu.php#L128-L135)

### `user_admin_menu`

*Fires before the administration menu loads in the User Admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 138](../../wordpress/wp-admin/includes/menu.php#L138-L145)

### `admin_menu`

*Fires before the administration menu loads in the admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 148](../../wordpress/wp-admin/includes/menu.php#L148-L155)

### `admin_page_access_denied`

*Fires when access to an admin page is denied.*


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 343](../../wordpress/wp-admin/includes/menu.php#L343-L348)

### `heartbeat_nopriv_tick`

*Fires when Heartbeat ticks in no-privilege environments.*

Allows the transport to be easily replaced with long-polling.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The no-priv Heartbeat response.
`$screen_id` | `string` | The screen ID.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 56](../../wordpress/wp-admin/includes/ajax-actions.php#L56-L66)

### `load-widgets.php`

*Fires early when editing the widgets displayed in sidebars.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2282](../../wordpress/wp-admin/includes/ajax-actions.php#L2282-L2287)

### `widgets.php`

*Fires early when editing the widgets displayed in sidebars.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2289](../../wordpress/wp-admin/includes/ajax-actions.php#L2289-L2294)

### `sidebar_admin_setup`

*This action is documented in wp-admin/widgets.php*


Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2296](../../wordpress/wp-admin/includes/ajax-actions.php#L2296-L2297)

### `delete_widget`

*This action is documented in wp-admin/widgets.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$widget_id` |  | 
`$sidebar_id` |  | 
`$id_base` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2324](../../wordpress/wp-admin/includes/ajax-actions.php#L2324-L2325)

### `load-widgets.php`

*This action is documented in wp-admin/includes/ajax-actions.php*


Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2396](../../wordpress/wp-admin/includes/ajax-actions.php#L2396-L2397)

### `widgets.php`

*This action is documented in wp-admin/includes/ajax-actions.php*


Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2398](../../wordpress/wp-admin/includes/ajax-actions.php#L2398-L2399)

### `sidebar_admin_setup`

*This action is documented in wp-admin/widgets.php*


Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2400](../../wordpress/wp-admin/includes/ajax-actions.php#L2400-L2401)

### `heartbeat_tick`

*Fires when Heartbeat ticks in logged-in environments.*

Allows the transport to be easily replaced with long-polling.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The Heartbeat response.
`$screen_id` | `string` | The screen ID.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3411](../../wordpress/wp-admin/includes/ajax-actions.php#L3411-L3421)

### `wp_ajax_crop_image_pre_save`

*Fires before a cropped image is saved.*

Allows to add filters to modify the way a cropped image is saved.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$context` | `string` | The Customizer control requesting the cropped image.
`$attachment_id` | `int` | The attachment ID of the original image.
`$cropped` | `string` | Path to the cropped image file.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3910](../../wordpress/wp-admin/includes/ajax-actions.php#L3910-L3921)

### `delete_link`

*Fires before a link is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link_id` | `int` | ID of the link to delete.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/bookmark.php](../../wordpress/wp-admin/includes/bookmark.php), [line 92](../../wordpress/wp-admin/includes/bookmark.php#L92-L99)

### `deleted_link`

*Fires after a link has been deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link_id` | `int` | ID of the deleted link.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-admin/includes/bookmark.php](../../wordpress/wp-admin/includes/bookmark.php), [line 105](../../wordpress/wp-admin/includes/bookmark.php#L105-L112)

### `edit_link`

*Fires after a link was updated in the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link_id` | `int` | ID of the link that was updated.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/bookmark.php](../../wordpress/wp-admin/includes/bookmark.php), [line 248](../../wordpress/wp-admin/includes/bookmark.php#L248-L255)

### `add_link`

*Fires after a link was added to the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link_id` | `int` | ID of the link that was added.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/bookmark.php](../../wordpress/wp-admin/includes/bookmark.php), [line 257](../../wordpress/wp-admin/includes/bookmark.php#L257-L264)

### `upgrader_process_complete`

*This action is documented in wp-admin/includes/class-wp-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 
`array('action' => 'update', 'type' => 'core')` |  | 

Source: [wordpress/wp-admin/includes/class-core-upgrader.php](../../wordpress/wp-admin/includes/class-core-upgrader.php), [line 214](../../wordpress/wp-admin/includes/class-core-upgrader.php#L214-L222)

### `upgrader_overwrote_package`

*This action is documented in wp-admin/includes/class-plugin-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$package` |  | 
`$this->new_theme_data` |  | 
`'theme'` |  | 

Source: [wordpress/wp-admin/includes/class-theme-upgrader.php](../../wordpress/wp-admin/includes/class-theme-upgrader.php), [line 273](../../wordpress/wp-admin/includes/class-theme-upgrader.php#L273-L274)

### `upgrader_process_complete`

*This action is documented in wp-admin/includes/class-wp-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 
`array('action' => 'update', 'type' => 'theme', 'bulk' => true, 'themes' => $themes)` |  | 

Source: [wordpress/wp-admin/includes/class-theme-upgrader.php](../../wordpress/wp-admin/includes/class-theme-upgrader.php), [line 464](../../wordpress/wp-admin/includes/class-theme-upgrader.php#L464-L474)

### `manage_link_custom_column`

*Fires for each registered custom link column.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the custom column.
`$link->link_id` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-links-list-table.php](../../wordpress/wp-admin/includes/class-wp-links-list-table.php), [line 287](../../wordpress/wp-admin/includes/class-wp-links-list-table.php#L287-L295)

### `wp_update_nav_menu`

*This action is documented in wp-includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nav_menu_selected_id` |  | 

Source: [wordpress/wp-admin/includes/nav-menu.php](../../wordpress/wp-admin/includes/nav-menu.php), [line 1237](../../wordpress/wp-admin/includes/nav-menu.php#L1237-L1238)

### `custom_header_options`

*Fires just before the submit button in the custom header options form.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-custom-image-header.php](../../wordpress/wp-admin/includes/class-custom-image-header.php), [line 749](../../wordpress/wp-admin/includes/class-custom-image-header.php#L749-L754)

### `wp_create_file_in_uploads`

*Fires after the header image is set or an error is returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` | `string` | Path to the file.
`$attachment_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/includes/class-custom-image-header.php](../../wordpress/wp-admin/includes/class-custom-image-header.php), [line 823](../../wordpress/wp-admin/includes/class-custom-image-header.php#L823-L831)

### `restrict_manage_posts`

*Fires before the Filter button on the Posts and Pages list tables.*

The Filter button allows sorting by date and/or category on the
Posts list table, and sorting by date on the Pages list table.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->screen->post_type` |  | 
`$which` | `string` | The location of the extra table nav markup:<br>'top' or 'bottom' for WP_Posts_List_Table,<br>'bar' for WP_Media_List_Table.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | The `$which` parameter was added.
`4.4.0` | The `$post_type` parameter was added.
`2.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 543](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L543-L558)

### `manage_posts_extra_tablenav`

*Fires immediately following the closing "actions" div in the tablenav for the posts
list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$which` | `string` | The location of the extra table nav markup: 'top' or 'bottom'.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 574](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L574-L582)

### `manage_pages_custom_column`

*Fires in each custom column on the Posts list table.*

This hook only fires if the current post type is hierarchical,
such as pages.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | The name of the column to display.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1244](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1244-L1255)

### `manage_posts_custom_column`

*Fires in each custom column in the Posts list table.*

This hook only fires if the current post type is non-hierarchical,
such as posts.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | The name of the column to display.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1258](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1258-L1269)

### `manage_{$post->post_type}_posts_custom_column`

*Fires for each custom column of a specific post type in the Posts list table.*

The dynamic portion of the hook name, `$post->post_type`, refers to the post type.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | The name of the column to display.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1272](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1272-L1282)

### `bulk_edit_custom_box`

*Fires once for each column in Bulk Edit mode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the column to edit.
`$screen->post_type` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1914](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1914-L1922)

### `quick_edit_custom_box`

*Fires once for each column in Quick Edit mode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the column to edit.
`$screen->post_type` |  | 
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1925](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1925-L1934)

### `populate_options`

*Fires before creating WordPress options and populating their default values.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/schema.php](../../wordpress/wp-admin/includes/schema.php), [line 365](../../wordpress/wp-admin/includes/schema.php#L365-L370)

### `add_inline_data`

*Fires after outputting the fields for the inline editor for posts and pages.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | The current post object.
`$post_type_object` | `\WP_Post_Type` | The current post's post type object.

**Changelog**

Version | Description
------- | -----------
`4.9.8` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 379](../../wordpress/wp-admin/includes/template.php#L379-L387)

### `admin_enqueue_scripts`

*This action is documented in wp-admin/admin-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hook_suffix` |  | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2039](../../wordpress/wp-admin/includes/template.php#L2039-L2040)

### `admin_print_styles-{$hook_suffix}`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2042](../../wordpress/wp-admin/includes/template.php#L2042-L2043)

### `admin_print_styles`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2045](../../wordpress/wp-admin/includes/template.php#L2045-L2046)

### `admin_print_scripts-{$hook_suffix}`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2048](../../wordpress/wp-admin/includes/template.php#L2048-L2049)

### `admin_print_scripts`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2051](../../wordpress/wp-admin/includes/template.php#L2051-L2052)

### `admin_head-{$hook_suffix}`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2054](../../wordpress/wp-admin/includes/template.php#L2054-L2055)

### `admin_head`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2057](../../wordpress/wp-admin/includes/template.php#L2057-L2058)

### `admin_footer`

*This action is documented in wp-admin/admin-footer.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hook_suffix` |  | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2108](../../wordpress/wp-admin/includes/template.php#L2108-L2109)

### `admin_print_footer_scripts-{$hook_suffix}`

*This action is documented in wp-admin/admin-footer.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2111](../../wordpress/wp-admin/includes/template.php#L2111-L2112)

### `admin_print_footer_scripts`

*This action is documented in wp-admin/admin-footer.php*


Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2114](../../wordpress/wp-admin/includes/template.php#L2114-L2115)

### `admin_xml_ns`

*Fires inside the HTML tag in the admin header.*


**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2529](../../wordpress/wp-admin/includes/template.php#L2529-L2534)

### `restrict_manage_comments`

*Fires just before the Filter submit button for comment types.*


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 401](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L401-L406)

### `manage_comments_nav`

*Fires after the Filter submit button for comment types.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_status` | `string` | The comment status name. Default 'All'.
`$which` | `string` | The location of the extra table nav markup: 'top' or 'bottom'.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The `$which` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 422](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L422-L431)

### `manage_comments_custom_column`

*Fires when the default column output is displayed for a single row.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | The custom column's name.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 1023](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L1023-L1031)

### `manage_themes_custom_column`

*Fires inside each custom column of the Multisite themes list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the column.
`$stylesheet` | `string` | Directory name of the theme.
`$theme` | `\WP_Theme` | Current WP_Theme object.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 857](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L857-L866)

### `after_theme_row`

*Fires after each row in the Multisite themes list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet` | `string` | Directory name of the theme.
`$theme` | `\WP_Theme` | Current WP_Theme object.
`$status` | `string` | Status of the theme.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 982](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L982-L991)

### `after_theme_row_{$stylesheet}`

*Fires after each specific row in the Multisite themes list table.*

The dynamic portion of the hook name, `$stylesheet`, refers to the
directory name of the theme, most often synonymous with the template
name of the theme.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet` | `string` | Directory name of the theme.
`$theme` | `\WP_Theme` | Current WP_Theme object.
`$status` | `string` | Status of the theme.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 993](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L993-L1006)

### `admin_enqueue_scripts`

*This action is documented in wp-admin/admin-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'media-upload-popup'` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 541](../../wordpress/wp-admin/includes/media.php#L541-L542)

### `admin_print_styles-media-upload-popup`

*Fires when admin styles enqueued for the legacy (pre-3.5.0) media upload popup are printed.*


**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 544](../../wordpress/wp-admin/includes/media.php#L544-L549)

### `admin_print_styles`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 551](../../wordpress/wp-admin/includes/media.php#L551-L552)

### `admin_print_scripts-media-upload-popup`

*Fires when admin scripts enqueued for the legacy (pre-3.5.0) media upload popup are printed.*


**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 554](../../wordpress/wp-admin/includes/media.php#L554-L559)

### `admin_print_scripts`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 561](../../wordpress/wp-admin/includes/media.php#L561-L562)

### `admin_head-media-upload-popup`

*Fires when scripts enqueued for the admin header for the legacy (pre-3.5.0)
media upload popup are printed.*


**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 564](../../wordpress/wp-admin/includes/media.php#L564-L570)

### `admin_head`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 572](../../wordpress/wp-admin/includes/media.php#L572-L573)

### `admin_head_{$content_func}`

*Fires in the admin header for each specific form tab in the legacy
(pre-3.5.0) media upload popup.*

The dynamic portion of the hook, `$content_func`, refers to the form
callback for the media upload type. Possible values include
'media_upload_type_form', 'media_upload_type_url_form', and
'media_upload_library_form'.


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 576](../../wordpress/wp-admin/includes/media.php#L576-L587)

### `admin_print_footer_scripts`

*This action is documented in wp-admin/admin-footer.php*


Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 606](../../wordpress/wp-admin/includes/media.php#L606-L607)

### `upload_ui_over_quota`

*Fires when an upload will exceed the defined upload space quota for a network site.*


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2129](../../wordpress/wp-admin/includes/media.php#L2129-L2134)

### `pre-upload-ui`

*Fires just before the legacy (pre-3.5.0) upload interface is loaded.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2138](../../wordpress/wp-admin/includes/media.php#L2138-L2143)

### `pre-plupload-upload-ui`

*Fires before the upload interface loads.*


**Changelog**

Version | Description
------- | -----------
`3.3.0` | 
`2.6.0` | As 'pre-flash-upload-ui'

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2222](../../wordpress/wp-admin/includes/media.php#L2222-L2228)

### `post-plupload-upload-ui`

*Fires after the upload interface loads.*


**Changelog**

Version | Description
------- | -----------
`3.3.0` | 
`2.6.0` | As 'post-flash-upload-ui'

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2239](../../wordpress/wp-admin/includes/media.php#L2239-L2245)

### `pre-html-upload-ui`

*Fires before the upload button in the media upload interface.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2251](../../wordpress/wp-admin/includes/media.php#L2251-L2256)

### `post-html-upload-ui`

*Fires after the upload button in the media upload interface.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2267](../../wordpress/wp-admin/includes/media.php#L2267-L2272)

### `post-upload-ui`

*Fires on the post upload UI screen.*

Legacy (pre-3.5.0) media workflow hook.


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2285](../../wordpress/wp-admin/includes/media.php#L2285-L2292)

### `wp_edit_form_attachment_display`

*Fires when an attachment type can't be rendered in the edit form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | A post object.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 3195](../../wordpress/wp-admin/includes/media.php#L3195-L3202)

### `wp_media_attach_action`

*Fires when media is attached or detached from a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$action` | `string` | Attach/detach action. Accepts 'attach' or 'detach'.
`$attachment_id` | `int` | The attachment ID.
`$parent_id` | `int` | Attachment parent ID.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 3795](../../wordpress/wp-admin/includes/media.php#L3795-L3804)

### `manage_plugins_custom_column`

*Fires inside each custom column of the Plugins list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the column.
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 1176](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L1176-L1185)

### `after_plugin_row`

*Fires after each row in the Plugins list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data.
`$status` | `string` | Status filter currently applied to the plugin list. Possible<br>values are: 'all', 'active', 'inactive', 'recently_activated',<br>'upgrade', 'mustuse', 'dropins', 'search', 'paused',<br>'auto-update-enabled', 'auto-update-disabled'.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added 'auto-update-enabled' and 'auto-update-disabled' to possible values for `$status`.
`2.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 1193](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L1193-L1206)

### `after_plugin_row_{$plugin_file}`

*Fires after each specific row in the Plugins list table.*

The dynamic portion of the hook name, `$plugin_file`, refers to the path
to the plugin file, relative to the plugins directory.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data.
`$status` | `string` | Status filter currently applied to the plugin list. Possible<br>values are: 'all', 'active', 'inactive', 'recently_activated',<br>'upgrade', 'mustuse', 'dropins', 'search', 'paused',<br>'auto-update-enabled', 'auto-update-disabled'.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added 'auto-update-enabled' and 'auto-update-disabled' to possible values for `$status`.
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 1208](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L1208-L1224)

### `restrict_manage_posts`

*This action is documented in wp-admin/includes/class-wp-posts-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->screen->post_type` |  | 
`$which` |  | 

Source: [wordpress/wp-admin/includes/class-wp-media-list-table.php](../../wordpress/wp-admin/includes/class-wp-media-list-table.php), [line 206](../../wordpress/wp-admin/includes/class-wp-media-list-table.php#L206-L207)

### `manage_media_custom_column`

*Fires for each custom column in the Media list table.*

Custom columns are registered using the %1$s filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$column_name` | `string` | Name of the custom column.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-media-list-table.php](../../wordpress/wp-admin/includes/class-wp-media-list-table.php), [line 623](../../wordpress/wp-admin/includes/class-wp-media-list-table.php#L623-L633)

### `current_screen`

*Fires after the current screen has been set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$current_screen` | `\WP_Screen` | Current WP_Screen object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 414](../../wordpress/wp-admin/includes/class-wp-screen.php#L414-L421)

### `pre_user_search`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

Source: [wordpress/wp-admin/includes/deprecated.php](../../wordpress/wp-admin/includes/deprecated.php), [line 557](../../wordpress/wp-admin/includes/deprecated.php#L557-L557)

### `wp_create_file_in_uploads`

*This action is documented in wp-admin/includes/class-custom-image-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` |  | 
`$id` |  | 

Source: [wordpress/wp-admin/includes/class-custom-background.php](../../wordpress/wp-admin/includes/class-custom-background.php), [line 527](../../wordpress/wp-admin/includes/class-custom-background.php#L527-L528)

### `add_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'link'` |  | 
`$link` |  | 

Source: [wordpress/wp-admin/edit-link-form.php](../../wordpress/wp-admin/edit-link-form.php), [line 36](../../wordpress/wp-admin/edit-link-form.php#L36-L37)

### `add_meta_boxes_link`

*Fires when link-specific meta boxes are added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `object` | Link object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-link-form.php](../../wordpress/wp-admin/edit-link-form.php), [line 39](../../wordpress/wp-admin/edit-link-form.php#L39-L46)

### `do_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'link'` |  | 
`'normal'` |  | 
`$link` |  | 

Source: [wordpress/wp-admin/edit-link-form.php](../../wordpress/wp-admin/edit-link-form.php), [line 48](../../wordpress/wp-admin/edit-link-form.php#L48-L49)

### `do_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'link'` |  | 
`'advanced'` |  | 
`$link` |  | 

Source: [wordpress/wp-admin/edit-link-form.php](../../wordpress/wp-admin/edit-link-form.php), [line 50](../../wordpress/wp-admin/edit-link-form.php#L50-L51)

### `do_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'link'` |  | 
`'side'` |  | 
`$link` |  | 

Source: [wordpress/wp-admin/edit-link-form.php](../../wordpress/wp-admin/edit-link-form.php), [line 52](../../wordpress/wp-admin/edit-link-form.php#L52-L53)

### `submitlink_box`

*This action is documented in wp-admin/includes/meta-boxes.php*


Source: [wordpress/wp-admin/edit-link-form.php](../../wordpress/wp-admin/edit-link-form.php), [line 141](../../wordpress/wp-admin/edit-link-form.php#L141-L142)

### `adminmenu`

*Fires after the admin menu has been output.*


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/menu-header.php](../../wordpress/wp-admin/menu-header.php), [line 296](../../wordpress/wp-admin/menu-header.php#L296-L301)

### `after_core_auto_updates_settings`

*Fires after the major core auto-update settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$auto_update_settings` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/update-core.php](../../wordpress/wp-admin/update-core.php), [line 412](../../wordpress/wp-admin/update-core.php#L412-L417)

### `core_upgrade_preamble`

*Fires after the core, plugin, and theme update tables.*


**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/update-core.php](../../wordpress/wp-admin/update-core.php), [line 1029](../../wordpress/wp-admin/update-core.php#L1029-L1034)

### `update-core-custom_{$action}`

*Fires for each custom update action on the WordPress Updates screen.*

The dynamic portion of the hook name, `$action`, refers to the
passed update action. The hook fires in lieu of all available
default update actions.


**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/update-core.php](../../wordpress/wp-admin/update-core.php), [line 1215](../../wordpress/wp-admin/update-core.php#L1215-L1224)

### `add_meta_boxes`

*This action is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'comment'` |  | 
`$comment` |  | 

Source: [wordpress/wp-admin/edit-form-comment.php](../../wordpress/wp-admin/edit-form-comment.php), [line 219](../../wordpress/wp-admin/edit-form-comment.php#L219-L220)

### `add_meta_boxes_comment`

*Fires when comment-specific meta boxes are added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` | `\WP_Comment` | Comment object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-form-comment.php](../../wordpress/wp-admin/edit-form-comment.php), [line 222](../../wordpress/wp-admin/edit-form-comment.php#L222-L229)

### `activate_{$plugin}`

*This action is documented in wp-admin/includes/plugin.php*


Source: [wordpress/wp-admin/plugins.php](../../wordpress/wp-admin/plugins.php), [line 192](../../wordpress/wp-admin/plugins.php#L192-L193)

### `pre_current_active_plugins`

*Fires before the plugins list table is rendered.*

This hook also fires before the plugins list table is rendered in the Network Admin.

Please note: The 'active' portion of the hook name does not refer to whether the current
view is for active plugins, but rather all plugins actively-installed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugins['all']` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/plugins.php](../../wordpress/wp-admin/plugins.php), [line 745](../../wordpress/wp-admin/plugins.php#L745-L757)

### `add_category_form_pre`

*Fires before the Add Category form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array((object) array('parent' => 0))` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_pre_add_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 381](../../wordpress/wp-admin/edit-tags.php#L381-L389)

### `add_link_category_form_pre`

*Fires before the link category form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array((object) array('parent' => 0))` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_pre_add_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 391](../../wordpress/wp-admin/edit-tags.php#L391-L399)

### `add_tag_form_pre`

*Fires before the Add Tag form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($taxonomy)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_pre_add_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 401](../../wordpress/wp-admin/edit-tags.php#L401-L409)

### `{$taxonomy}_pre_add_form`

*Fires before the Add Term form for all taxonomies.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | The taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 412](../../wordpress/wp-admin/edit-tags.php#L412-L421)

### `{$taxonomy}_term_new_form_tag`

*Fires inside the Add Tag form tag.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.


**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 428](../../wordpress/wp-admin/edit-tags.php#L428-L435)

### `add_tag_form_fields`

*Fires after the Add Tag form fields for non-hierarchical taxonomies.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | The taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 510](../../wordpress/wp-admin/edit-tags.php#L510-L517)

### `{$taxonomy}_add_form_fields`

*Fires after the Add Term form fields.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | The taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 520](../../wordpress/wp-admin/edit-tags.php#L520-L529)

### `edit_category_form`

*Fires at the end of the Edit Category form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array((object) array('parent' => 0))` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_add_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 537](../../wordpress/wp-admin/edit-tags.php#L537-L545)

### `edit_link_category_form`

*Fires at the end of the Edit Link form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array((object) array('parent' => 0))` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_add_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 547](../../wordpress/wp-admin/edit-tags.php#L547-L555)

### `add_tag_form`

*Fires at the end of the Add Tag form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($taxonomy)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_add_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 557](../../wordpress/wp-admin/edit-tags.php#L557-L565)

### `{$taxonomy}_add_form`

*Fires at the end of the Add Term form for all taxonomies.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | The taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 568](../../wordpress/wp-admin/edit-tags.php#L568-L577)

### `after-{$taxonomy}-table`

*Fires after the taxonomy list table.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | The taxonomy name.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 636](../../wordpress/wp-admin/edit-tags.php#L636-L645)

### `tool_box`

*Fires at the end of the Tools Administration screen.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/tools.php](../../wordpress/wp-admin/tools.php), [line 87](../../wordpress/wp-admin/tools.php#L87-L92)

### `delete_user_form`

*Fires at the end of the delete users form prior to the confirm button.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$current_user` | `\WP_User` | WP_User object for the current user.
`$userids` | `int[]` | Array of IDs for users being deleted.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | The `$userids` parameter was added.
`4.0.0` | 

Source: [wordpress/wp-admin/users.php](../../wordpress/wp-admin/users.php), [line 377](../../wordpress/wp-admin/users.php#L377-L386)

### `install_themes_pre_{$tab}`

*Fires before each of the tabs are rendered on the Install Themes page.*

The dynamic portion of the hook name, `$tab`, refers to the current
theme installation tab. Possible values are 'dashboard', 'search', 'upload',
'featured', 'new', or 'updated'.


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/theme-install.php](../../wordpress/wp-admin/theme-install.php), [line 83](../../wordpress/wp-admin/theme-install.php#L83-L92)

### `install_themes_{$tab}`

*Fires at the top of each of the tabs on the Install Themes page.*

The dynamic portion of the hook name, `$tab`, refers to the current
theme installation tab. Possible values are 'dashboard', 'search', 'upload',
'featured', 'new', or 'updated'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$paged` | `int` | Number of the current page of results being viewed.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/theme-install.php](../../wordpress/wp-admin/theme-install.php), [line 250](../../wordpress/wp-admin/theme-install.php#L250-L261)

### `customize_controls_init`

*Fires when Customizer controls are initialized, before scripts are enqueued.*


**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/customize.php](../../wordpress/wp-admin/customize.php), [line 107](../../wordpress/wp-admin/customize.php#L107-L112)

### `customize_controls_enqueue_scripts`

*Enqueue Customizer control scripts.*


**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/customize.php](../../wordpress/wp-admin/customize.php), [line 118](../../wordpress/wp-admin/customize.php#L118-L123)

### `customize_controls_print_styles`

*Fires when Customizer control styles are printed.*


**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/customize.php](../../wordpress/wp-admin/customize.php), [line 158](../../wordpress/wp-admin/customize.php#L158-L163)

### `customize_controls_print_scripts`

*Fires when Customizer control scripts are printed.*


**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/customize.php](../../wordpress/wp-admin/customize.php), [line 165](../../wordpress/wp-admin/customize.php#L165-L170)

### `customize_controls_head`

*Fires in head section of Customizer controls.*


**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/customize.php](../../wordpress/wp-admin/customize.php), [line 172](../../wordpress/wp-admin/customize.php#L172-L177)

### `customize_controls_print_footer_scripts`

*Prints templates, control scripts, and settings in the footer.*


**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/customize.php](../../wordpress/wp-admin/customize.php), [line 276](../../wordpress/wp-admin/customize.php#L276-L281)

### `install_plugins_pre_{$tab}`

*Fires before each tab on the Install Plugins screen is loaded.*

The dynamic portion of the action hook, `$tab`, allows for targeting
individual tabs, for instance 'install_plugins_pre_plugin-information'.


**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/plugin-install.php](../../wordpress/wp-admin/plugin-install.php), [line 62](../../wordpress/wp-admin/plugin-install.php#L62-L70)

### `install_plugins_pre_upload`

*This action is documented in wp-admin/plugin-install.php*


Source: [wordpress/wp-admin/plugin-install.php](../../wordpress/wp-admin/plugin-install.php), [line 77](../../wordpress/wp-admin/plugin-install.php#L77-L78)

### `install_plugins_upload`

*This action is documented in wp-admin/plugin-install.php*


Source: [wordpress/wp-admin/plugin-install.php](../../wordpress/wp-admin/plugin-install.php), [line 155](../../wordpress/wp-admin/plugin-install.php#L155-L156)

### `install_plugins_{$tab}`

*Fires after the plugins list table in each tab of the Install Plugins screen.*

The dynamic portion of the action hook, `$tab`, allows for targeting
individual tabs, for instance 'install_plugins_plugin-information'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$paged` | `int` | The current page number of the plugins list table.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/plugin-install.php](../../wordpress/wp-admin/plugin-install.php), [line 163](../../wordpress/wp-admin/plugin-install.php#L163-L173)

### `invite_user`

*Fires immediately after an existing user is invited to join the site, but before the notification is sent.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | The invited user's ID.
`$role` | `array` | Array containing role information for the invited user.
`$newuser_key` | `string` | The key of the invitation.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 102](../../wordpress/wp-admin/user-new.php#L102-L111)

### `user_new_form_tag`

*Fires inside the adduser form tag.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 425](../../wordpress/wp-admin/user-new.php#L425-L430)

### `user_new_form`

*Fires at the end of the new user form.*

Passes a contextual string to make both types of new user forms
uniquely targetable. Contexts are 'add-existing-user' (Multisite),
and 'add-new-user' (single site and network admin).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'add-existing-user'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 459](../../wordpress/wp-admin/user-new.php#L459-L470)

### `user_new_form_tag`

*This action is documented in wp-admin/user-new.php*


Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 485](../../wordpress/wp-admin/user-new.php#L485-L486)

### `user_new_form`

*This action is documented in wp-admin/user-new.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'add-new-user'` |  | 

Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 627](../../wordpress/wp-admin/user-new.php#L627-L628)

### `edit_category_form_pre`

*Fires before the Edit Category form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_pre_edit_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 16](../../wordpress/wp-admin/edit-tag-form.php#L16-L24)

### `edit_link_category_form_pre`

*Fires before the Edit Link Category form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_pre_edit_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 26](../../wordpress/wp-admin/edit-tag-form.php#L26-L34)

### `edit_tag_form_pre`

*Fires before the Edit Tag form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_pre_edit_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 36](../../wordpress/wp-admin/edit-tag-form.php#L36-L44)

### `{$taxonomy}_pre_edit_form`

*Fires before the Edit Term form for all taxonomies.*

The dynamic portion of the hook name, `$taxonomy`, refers to
the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag` | `\WP_Term` | Current taxonomy term object.
`$taxonomy` | `string` | Current $taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 57](../../wordpress/wp-admin/edit-tag-form.php#L57-L68)

### `{$taxonomy}_term_edit_form_tag`

*Fires inside the Edit Term form tag.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.


**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 94](../../wordpress/wp-admin/edit-tag-form.php#L94-L101)

### `{$taxonomy}_term_edit_form_top`

*Fires at the beginning of the Edit Term form.*

At this point, the required hidden fields and nonces have already been output.

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag` | `\WP_Term` | Current taxonomy term object.
`$taxonomy` | `string` | Current $taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 111](../../wordpress/wp-admin/edit-tag-form.php#L111-L123)

### `edit_category_form_fields`

*Fires after the Edit Category form fields are displayed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_edit_form_fields'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 196](../../wordpress/wp-admin/edit-tag-form.php#L196-L204)

### `edit_link_category_form_fields`

*Fires after the Edit Link Category form fields are displayed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_edit_form_fields'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 206](../../wordpress/wp-admin/edit-tag-form.php#L206-L214)

### `edit_tag_form_fields`

*Fires after the Edit Tag form fields are displayed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_edit_form_fields'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 216](../../wordpress/wp-admin/edit-tag-form.php#L216-L224)

### `{$taxonomy}_edit_form_fields`

*Fires after the Edit Term form fields are displayed.*

The dynamic portion of the hook name, `$taxonomy`, refers to
the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag` | `\WP_Term` | Current taxonomy term object.
`$taxonomy` | `string` | Current taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 226](../../wordpress/wp-admin/edit-tag-form.php#L226-L237)

### `edit_category_form`

*This action is documented in wp-admin/edit-tags.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_add_form'` |  | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 243](../../wordpress/wp-admin/edit-tag-form.php#L243-L244)

### `edit_link_category_form`

*This action is documented in wp-admin/edit-tags.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_add_form'` |  | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 246](../../wordpress/wp-admin/edit-tag-form.php#L246-L247)

### `edit_tag_form`

*Fires at the end of the Edit Term form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tag)` |  | 
`'3.0.0'` |  | 
`'{$taxonomy}_edit_form'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 249](../../wordpress/wp-admin/edit-tag-form.php#L249-L257)

### `{$taxonomy}_edit_form`

*Fires at the end of the Edit Term form for all taxonomies.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag` | `\WP_Term` | Current taxonomy term object.
`$taxonomy` | `string` | Current taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 259](../../wordpress/wp-admin/edit-tag-form.php#L259-L269)

### `admin_init`

*This action is documented in wp-admin/admin.php*


Source: [wordpress/wp-admin/admin-post.php](../../wordpress/wp-admin/admin-post.php), [line 29](../../wordpress/wp-admin/admin-post.php#L29-L30)

### `admin_post_nopriv`

*Fires on a non-authenticated admin post request where no action is supplied.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/admin-post.php](../../wordpress/wp-admin/admin-post.php), [line 36](../../wordpress/wp-admin/admin-post.php#L36-L41)

### `admin_post_nopriv_{$action}`

*Fires on a non-authenticated admin post request for the given action.*

The dynamic portion of the hook name, `$action`, refers to the given
request action.


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/admin-post.php](../../wordpress/wp-admin/admin-post.php), [line 43](../../wordpress/wp-admin/admin-post.php#L43-L51)

### `admin_post`

*Fires on an authenticated admin post request where no action is supplied.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/admin-post.php](../../wordpress/wp-admin/admin-post.php), [line 55](../../wordpress/wp-admin/admin-post.php#L55-L60)

### `admin_post_{$action}`

*Fires on an authenticated admin post request for the given action.*

The dynamic portion of the hook name, `$action`, refers to the given
request action.


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/admin-post.php](../../wordpress/wp-admin/admin-post.php), [line 62](../../wordpress/wp-admin/admin-post.php#L62-L70)

### `admin_init`

*This action is documented in wp-admin/admin.php*


Source: [wordpress/wp-admin/admin-ajax.php](../../wordpress/wp-admin/admin-ajax.php), [line 44](../../wordpress/wp-admin/admin-ajax.php#L44-L45)

### `wp_ajax_{$action}`

*Fires authenticated Ajax actions for logged-in users.*

The dynamic portion of the hook name, `$action`, refers
to the name of the Ajax action callback being fired.


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/admin-ajax.php](../../wordpress/wp-admin/admin-ajax.php), [line 179](../../wordpress/wp-admin/admin-ajax.php#L179-L187)

### `wp_ajax_nopriv_{$action}`

*Fires non-authenticated Ajax actions for logged-out users.*

The dynamic portion of the hook name, `$action`, refers
to the name of the Ajax action callback being fired.


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/admin-ajax.php](../../wordpress/wp-admin/admin-ajax.php), [line 194](../../wordpress/wp-admin/admin-ajax.php#L194-L202)

### `after_db_upgrade`

*Fires on the next page load after a successful DB upgrade.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 43](../../wordpress/wp-admin/admin.php#L43-L48)

### `after_mu_upgrade`

*This action is documented in wp-admin/network/upgrade.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` |  | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 89](../../wordpress/wp-admin/admin.php#L89-L90)

### `admin_init`

*Fires as an admin screen or script is being initialized.*

Note, this does not just run on user-facing admin screens.
It runs on admin-ajax.php and admin-post.php as well.

This is roughly analogous to the more general %1$s hook, which fires earlier.


**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 165](../../wordpress/wp-admin/admin.php#L165-L175)

### `load-{$page_hook}`

*Fires before a particular screen is loaded.*

The load-* hook fires in a number of contexts. This hook is for plugin screens
where a callback is provided when the screen is registered.

The dynamic portion of the hook name, `$page_hook`, refers to a mixture of plugin
page information including:
1. The page type. If the plugin page is registered as a submenu page, such as for
   Settings, the page type would be 'settings'. Otherwise the type is 'toplevel'.
2. A separator of '_page_'.
3. The plugin basename minus the file extension.

Together, the three parts form the `$page_hook`. Citing the example above,
the hook name used would be 'load-settings_page_pluginbasename'.


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 217](../../wordpress/wp-admin/admin.php#L217-L237)

### `{$page_hook}`

*Used to call the registered callback for a plugin screen.*

This hook uses a dynamic hook name, `$page_hook`, which refers to a mixture of plugin
page information including:
1. The page type. If the plugin page is registered as a submenu page, such as for
   Settings, the page type would be 'settings'. Otherwise the type is 'toplevel'.
2. A separator of '_page_'.
3. The plugin basename minus the file extension.

Together, the three parts form the `$page_hook`. Citing the example above,
the hook name used would be 'settings_page_pluginbasename'.


**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 242](../../wordpress/wp-admin/admin.php#L242-L259)

### `load-{$plugin_page}`

*Fires before a particular screen is loaded.*

The load-* hook fires in a number of contexts. This hook is for plugin screens
where the file to load is directly included, rather than the use of a function.

The dynamic portion of the hook name, `$plugin_page`, refers to the plugin basename.


**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 272](../../wordpress/wp-admin/admin.php#L272-L284)

### `load-importer-{$importer}`

*Fires before an importer screen is loaded.*

The dynamic portion of the hook name, `$importer`, refers to the importer slug.


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 318](../../wordpress/wp-admin/admin.php#L318-L325)

### `load-{$pagenow}`

*Fires before a particular screen is loaded.*

The load-* hook fires in a number of contexts. This hook is for core screens.

The dynamic portion of the hook name, `$pagenow`, is a global variable
referring to the filename of the current page, such as 'admin.php',
'post-new.php' etc. A complete hook for the latter would be
'load-post-new.php'.


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 362](../../wordpress/wp-admin/admin.php#L362-L374)

### `load-page-new.php`


Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 382](../../wordpress/wp-admin/admin.php#L382-L382)

### `load-page.php`


Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 384](../../wordpress/wp-admin/admin.php#L384-L384)

### `load-categories.php`


Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 388](../../wordpress/wp-admin/admin.php#L388-L388)

### `load-edit-link-categories.php`


Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 390](../../wordpress/wp-admin/admin.php#L390-L390)

### `load-edit-tags.php`


Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 393](../../wordpress/wp-admin/admin.php#L393-L393)

### `admin_action_{$action}`

*Fires when an 'action' request variable is sent.*

The dynamic portion of the hook name, `$action`, refers to
the action derived from the `GET` or `POST` request.


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 400](../../wordpress/wp-admin/admin.php#L400-L408)

### `enqueue_block_editor_assets`

*Fires after block assets have been enqueued for the editing interface.*

Call `add_action` on any hook before 'admin_enqueue_scripts'.

In the function call you supply, simply use `wp_enqueue_script` and
`wp_enqueue_style` to add your functionality to the block editor.


**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 399](../../wordpress/wp-admin/edit-form-blocks.php#L399-L409)

### `personal_options_update`

*Fires before the page loads on the 'Profile' editing screen.*

The action only fires if the current user is editing their own profile.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | The user ID.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 133](../../wordpress/wp-admin/user-edit.php#L133-L142)

### `edit_user_profile_update`

*Fires before the page loads on the 'Edit User' screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | The user ID.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 144](../../wordpress/wp-admin/user-edit.php#L144-L151)

### `user_edit_form_tag`

*Fires inside the your-profile form tag on the user editing screen.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 243](../../wordpress/wp-admin/user-edit.php#L243-L248)

### `admin_color_scheme_picker`

*Fires in the 'Admin Color Scheme' section of the user editing screen.*

The section is only enabled if a callback is hooked to the action,
and if there is more than one defined color scheme for the admin.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | The user ID.

**Changelog**

Version | Description
------- | -----------
`3.8.1` | Added `$user_id` parameter.
`3.0.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 302](../../wordpress/wp-admin/user-edit.php#L302-L313)

### `personal_options`

*Fires at the end of the 'Personal Options' settings table on the user editing screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$profileuser` | `\WP_User` | The current WP_User object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 379](../../wordpress/wp-admin/user-edit.php#L379-L386)

### `profile_personal_options`

*Fires after the 'Personal Options' settings table on the 'Profile' editing screen.*

The action only fires if the current user is editing their own profile.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$profileuser` | `\WP_User` | The current WP_User object.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 392](../../wordpress/wp-admin/user-edit.php#L392-L401)

### `wp_create_application_password_form`

*Fires in the create Application Passwords form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$profileuser` | `\WP_User` | The current WP_User object.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 773](../../wordpress/wp-admin/user-edit.php#L773-L780)

### `show_user_profile`

*Fires after the 'About Yourself' settings table on the 'Profile' editing screen.*

The action only fires if the current user is editing their own profile.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$profileuser` | `\WP_User` | The current WP_User object.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 803](../../wordpress/wp-admin/user-edit.php#L803-L812)

### `edit_user_profile`

*Fires after the 'About the User' settings table on the 'Edit User' screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$profileuser` | `\WP_User` | The current WP_User object.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 814](../../wordpress/wp-admin/user-edit.php#L814-L821)

### `myblogs_allblogs_options`

*Fires before the sites list on the My Sites screen.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/my-sites.php](../../wordpress/wp-admin/my-sites.php), [line 87](../../wordpress/wp-admin/my-sites.php#L87-L92)

### `do_feed_{$feed}`

*Fires once the given feed is loaded.*

The dynamic portion of the hook name, `$feed`, refers to the feed template name.
Possible values include: 'rdf', 'rss', 'rss2', and 'atom'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_query->is_comment_feed` |  | 
`$feed` | `string` | The feed name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$feed` parameter was added.
`2.1.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 1567](../../wordpress/wp-includes/functions.php#L1567-L1579)

### `do_robotstxt`

*Fires when displaying the robots.txt file.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 1649](../../wordpress/wp-includes/functions.php#L1649-L1654)

### `do_faviconico`

*Fires when serving the favicon.ico file.*


**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 1681](../../wordpress/wp-includes/functions.php#L1681-L1686)

### `deprecated_function_run`

*Fires when a deprecated function is called.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$function` | `string` | The function that was called.
`$replacement` | `string` | The function that should have been called.
`$version` | `string` | The version of WordPress that deprecated the function.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 4832](../../wordpress/wp-includes/functions.php#L4832-L4841)

### `deprecated_constructor_run`

*Fires when a deprecated constructor is called.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$class` | `string` | The class containing the deprecated constructor.
`$version` | `string` | The version of WordPress that deprecated the function.
`$parent_class` | `string` | The parent class calling the deprecated constructor.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Added the `$parent_class` parameter.
`4.3.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 4921](../../wordpress/wp-includes/functions.php#L4921-L4931)

### `deprecated_file_included`

*Fires when a deprecated file is called.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` | `string` | The file that was called.
`$replacement` | `string` | The file that should have been included based on ABSPATH.
`$version` | `string` | The version of WordPress that deprecated the file.
`$message` | `string` | A message regarding the change.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5019](../../wordpress/wp-includes/functions.php#L5019-L5029)

### `deprecated_argument_run`

*Fires when a deprecated argument is called.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$function` | `string` | The function that was called.
`$message` | `string` | A message regarding the change.
`$version` | `string` | The version of WordPress that deprecated the argument used.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5116](../../wordpress/wp-includes/functions.php#L5116-L5125)

### `deprecated_hook_run`

*Fires when a deprecated hook is called.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hook` | `string` | The hook that was called.
`$replacement` | `string` | The hook that should be used as a replacement.
`$version` | `string` | The version of WordPress that deprecated the argument used.
`$message` | `string` | A message regarding the change.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5204](../../wordpress/wp-includes/functions.php#L5204-L5214)

### `doing_it_wrong_run`

*Fires when the given function is being used incorrectly.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$function` | `string` | The function that was called.
`$message` | `string` | A message explaining what has been done incorrectly.
`$version` | `string` | The version of WordPress where the message was added.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5270](../../wordpress/wp-includes/functions.php#L5270-L5279)

### `load_feed_engine`

*Fires before MagpieRSS is loaded, to optionally replace it.*


**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/rss.php](../../wordpress/wp-includes/rss.php), [line 21](../../wordpress/wp-includes/rss.php#L21-L27)

### `customize_preview_{$this->id}`

*Fires when the WP_Customize_Setting::preview() method is called for settings
not handled as theme_mods or options.*

The dynamic portion of the hook name, `$this->id`, refers to the setting ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Setting` | WP_Customize_Setting instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 389](../../wordpress/wp-includes/class-wp-customize-setting.php#L389-L399)

### `customize_preview_{$this->type}`

*Fires when the WP_Customize_Setting::preview() method is called for settings
not handled as theme_mods or options.*

The dynamic portion of the hook name, `$this->type`, refers to the setting type.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Setting` | WP_Customize_Setting instance.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 401](../../wordpress/wp-includes/class-wp-customize-setting.php#L401-L411)

### `customize_save_{$id_base}`

*Fires when the WP_Customize_Setting::save() method is called.*

The dynamic portion of the hook name, `$id_base` refers to
the base slug of the setting name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Setting` | WP_Customize_Setting instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 528](../../wordpress/wp-includes/class-wp-customize-setting.php#L528-L538)

### `customize_update_{$this->type}`

*Fires when the WP_Customize_Setting::update() method is called for settings
not handled as theme_mods or options.*

The dynamic portion of the hook name, `$this->type`, refers to the type of setting.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the setting.
`$this` | `\WP_Customize_Setting` | WP_Customize_Setting instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 692](../../wordpress/wp-includes/class-wp-customize-setting.php#L692-L703)

### `register_sidebar`

*Fires once a sidebar has been registered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sidebar` | `array` | Parsed arguments for the registered sidebar.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 306](../../wordpress/wp-includes/widgets.php#L306-L313)

### `wp_register_sidebar_widget`

*Fires once for each registered widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$widget` | `array` | An array of default widget arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 408](../../wordpress/wp-includes/widgets.php#L408-L415)

### `wp_unregister_sidebar_widget`

*Fires just before a widget is removed from a sidebar.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | The widget ID.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 480](../../wordpress/wp-includes/widgets.php#L480-L487)

### `dynamic_sidebar_before`

*This action is documented in wp-includes/widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$index` |  | 
`false` |  | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 697](../../wordpress/wp-includes/widgets.php#L697-L698)

### `dynamic_sidebar_after`

*This action is documented in wp-includes/widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$index` |  | 
`false` |  | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 699](../../wordpress/wp-includes/widgets.php#L699-L700)

### `dynamic_sidebar_before`

*Fires before widgets are rendered in a dynamic sidebar.*

Note: The action also fires for empty sidebars, and on both the front end
and back end, including the Inactive Widgets sidebar on the Widgets screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$index` | `int\|string` | Index, name, or ID of the dynamic sidebar.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 709](../../wordpress/wp-includes/widgets.php#L709-L721)

### `dynamic_sidebar`

*Fires before a widget's display callback is called.*

Note: The action fires on both the front end and back end, including
for widgets in the Inactive Widgets sidebar on the Widgets screen.

The action is not fired for empty sidebars.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_registered_widgets[$id]` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 795](../../wordpress/wp-includes/widgets.php#L795-L820)

### `dynamic_sidebar_after`

*Fires after widgets are rendered in a dynamic sidebar.*

Note: The action also fires for empty sidebars, and on both the front end
and back end, including the Inactive Widgets sidebar on the Widgets screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$index` | `int\|string` | Index, name, or ID of the dynamic sidebar.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 832](../../wordpress/wp-includes/widgets.php#L832-L844)

### `the_widget`

*Fires before rendering the requested widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$widget` | `string` | The widget's class name.
`$instance` | `array` | The current widget instance's settings.
`$args` | `array` | An array of the widget's sidebar arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 1204](../../wordpress/wp-includes/widgets.php#L1204-L1213)

### `widgets_init`

*Fires after all default WordPress widgets have been registered.*


**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 1794](../../wordpress/wp-includes/widgets.php#L1794-L1799)

### `comment_form_comments_closed`

*Fires after the comment form if comments are closed.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2328](../../wordpress/wp-includes/comment-template.php#L2328-L2333)

### `comment_form_before`

*Fires before the comment form.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2514](../../wordpress/wp-includes/comment-template.php#L2514-L2519)

### `comment_form_must_log_in_after`

*Fires after the HTML-formatted 'must log in after' message in the comment form.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2538](../../wordpress/wp-includes/comment-template.php#L2538-L2543)

### `comment_form_top`

*Fires at the top of the comment form, inside the form tag.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2555](../../wordpress/wp-includes/comment-template.php#L2555-L2560)

### `comment_form_logged_in_after`

*Fires after the is_user_logged_in() check in the comment form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commenter` | `array` | An array containing the comment author's<br>username, email, and URL.
`$user_identity` | `string` | If the commenter is a registered user,<br>the display name, blank otherwise.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2577](../../wordpress/wp-includes/comment-template.php#L2577-L2587)

### `comment_form_before_fields`

*Fires before the comment fields in the comment form, excluding the textarea.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2632](../../wordpress/wp-includes/comment-template.php#L2632-L2637)

### `comment_form_after_fields`

*Fires after the comment fields in the comment form, excluding the textarea.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2653](../../wordpress/wp-includes/comment-template.php#L2653-L2658)

### `comment_form`

*Fires at the bottom of the comment form, inside the closing form tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2700](../../wordpress/wp-includes/comment-template.php#L2700-L2707)

### `comment_form_after`

*Fires after the comment form.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2716](../../wordpress/wp-includes/comment-template.php#L2716-L2721)

### `_wp_put_post_revision`

*Fires once a revision has been saved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$revision_id` | `int` | Post revision ID.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/revision.php](../../wordpress/wp-includes/revision.php), [line 340](../../wordpress/wp-includes/revision.php#L340-L347)

### `wp_restore_post_revision`

*Fires after a post revision has been restored.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$revision['ID']` |  | 

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/revision.php](../../wordpress/wp-includes/revision.php), [line 429](../../wordpress/wp-includes/revision.php#L429-L437)

### `wp_delete_post_revision`

*Fires once a post revision has been deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$revision->ID` |  | 
`$revision` | `\WP_Post` | Post revision object.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/revision.php](../../wordpress/wp-includes/revision.php), [line 460](../../wordpress/wp-includes/revision.php#L460-L468)

### `registered_taxonomy`

*Fires after a taxonomy is registered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | Taxonomy slug.
`$object_type` | `array\|string` | Object type or array of object types.
`(array) $taxonomy_object` |  | 

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 469](../../wordpress/wp-includes/taxonomy.php#L469-L478)

### `unregistered_taxonomy`

*Fires after a taxonomy is unregistered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | Taxonomy name.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 521](../../wordpress/wp-includes/taxonomy.php#L521-L528)

### `registered_taxonomy_for_object_type`

*Fires after a taxonomy is registered for an object type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | Taxonomy name.
`$object_type` | `string` | Name of the object type.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 673](../../wordpress/wp-includes/taxonomy.php#L673-L681)

### `unregistered_taxonomy_for_object_type`

*Fires after a taxonomy is unregistered for an object type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | Taxonomy name.
`$object_type` | `string` | Name of the object type.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 715](../../wordpress/wp-includes/taxonomy.php#L715-L723)

### `pre_delete_term`

*Fires when deleting a term, before any modifications are made to posts or terms.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` | `int` | Term ID.
`$taxonomy` | `string` | Taxonomy Name.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1894](../../wordpress/wp-includes/taxonomy.php#L1894-L1902)

### `edit_term_taxonomies`

*Fires immediately before a term to delete's children are reassigned a parent.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$edit_tt_ids` | `array` | An array of term taxonomy IDs for the given term.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1915](../../wordpress/wp-includes/taxonomy.php#L1915-L1922)

### `edited_term_taxonomies`

*Fires immediately after a term to delete's children are reassigned a parent.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$edit_tt_ids` | `array` | An array of term taxonomy IDs for the given term.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1930](../../wordpress/wp-includes/taxonomy.php#L1930-L1937)

### `delete_term_taxonomy`

*Fires immediately before a term taxonomy ID is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tt_id` | `int` | Term taxonomy ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1984](../../wordpress/wp-includes/taxonomy.php#L1984-L1991)

### `deleted_term_taxonomy`

*Fires immediately after a term taxonomy ID is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tt_id` | `int` | Term taxonomy ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1995](../../wordpress/wp-includes/taxonomy.php#L1995-L2002)

### `delete_term`

*Fires after a term is deleted from the database and the cache is cleaned.*

The %1$s hook is also available for targeting a specific
taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.
`$deleted_term` | `\WP_Term` | Copy of the already-deleted term.
`$object_ids` | `array` | List of term object IDs.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Introduced the `$object_ids` argument.
`2.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2011](../../wordpress/wp-includes/taxonomy.php#L2011-L2026)

### `delete_{$taxonomy}`

*Fires after a term in a specific taxonomy is deleted.*

The dynamic portion of the hook name, `$taxonomy`, refers to the specific
taxonomy the term belonged to.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`$deleted_term` | `\WP_Term` | Copy of the already-deleted term.
`$object_ids` | `array` | List of term object IDs.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Introduced the `$object_ids` argument.
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2028](../../wordpress/wp-includes/taxonomy.php#L2028-L2042)

### `edit_terms`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` |  | 
`$taxonomy` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2394](../../wordpress/wp-includes/taxonomy.php#L2394-L2395)

### `edited_terms`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` |  | 
`$taxonomy` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2398](../../wordpress/wp-includes/taxonomy.php#L2398-L2399)

### `create_term`

*Fires immediately after a new term is created, before the term cache is cleaned.*

The %1$s hook is also available for targeting a specific
taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2457](../../wordpress/wp-includes/taxonomy.php#L2457-L2469)

### `create_{$taxonomy}`

*Fires after a new term is created for a specific taxonomy.*

The dynamic portion of the hook name, `$taxonomy`, refers
to the slug of the taxonomy the term was created for.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2471](../../wordpress/wp-includes/taxonomy.php#L2471-L2482)

### `created_term`

*Fires after a new term is created, and after the term cache has been cleaned.*

The %1$s hook is also available for targeting a specific
taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2496](../../wordpress/wp-includes/taxonomy.php#L2496-L2508)

### `created_{$taxonomy}`

*Fires after a new term in a specific taxonomy is created, and after the term
cache has been cleaned.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2510](../../wordpress/wp-includes/taxonomy.php#L2510-L2521)

### `saved_term`

*Fires after a term has been saved, and the term cache has been cleared.*

The %1$s hook is also available for targeting a specific
taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2523](../../wordpress/wp-includes/taxonomy.php#L2523-L2536)

### `saved_{$taxonomy}`

*Fires after a term in a specific taxonomy has been saved, and the term
cache has been cleared.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2538](../../wordpress/wp-includes/taxonomy.php#L2538-L2550)

### `add_term_relationship`

*Fires immediately before an object-term relationship is added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_id` | `int` | Object ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Added the `$taxonomy` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2640](../../wordpress/wp-includes/taxonomy.php#L2640-L2650)

### `added_term_relationship`

*Fires immediately after an object-term relationship is added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_id` | `int` | Object ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Added the `$taxonomy` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2660](../../wordpress/wp-includes/taxonomy.php#L2660-L2670)

### `set_object_terms`

*Fires after an object's terms have been set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_id` | `int` | Object ID.
`$terms` | `array` | An array of object terms.
`$tt_ids` | `array` | An array of term taxonomy IDs.
`$taxonomy` | `string` | Taxonomy slug.
`$append` | `bool` | Whether to append new terms to the old terms.
`$old_tt_ids` | `array` | Old array of term taxonomy IDs.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2725](../../wordpress/wp-includes/taxonomy.php#L2725-L2737)

### `delete_term_relationships`

*Fires immediately before an object-term relationship is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_id` | `int` | Object ID.
`$tt_ids` | `array` | An array of term taxonomy IDs.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Added the `$taxonomy` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2806](../../wordpress/wp-includes/taxonomy.php#L2806-L2816)

### `deleted_term_relationships`

*Fires immediately after an object-term relationship is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_id` | `int` | Object ID.
`$tt_ids` | `array` | An array of term taxonomy IDs.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Added the `$taxonomy` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2823](../../wordpress/wp-includes/taxonomy.php#L2823-L2833)

### `edit_terms`

*Fires immediately before the given terms are edited.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3105](../../wordpress/wp-includes/taxonomy.php#L3105-L3113)

### `edited_terms`

*Fires immediately after a term is updated in the database, but before its
term-taxonomy relationship is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3136](../../wordpress/wp-includes/taxonomy.php#L3136-L3145)

### `edit_term_taxonomy`

*Fires immediate before a term-taxonomy relationship is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3147](../../wordpress/wp-includes/taxonomy.php#L3147-L3155)

### `edited_term_taxonomy`

*Fires immediately after a term-taxonomy relationship is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3159](../../wordpress/wp-includes/taxonomy.php#L3159-L3167)

### `edit_term`

*Fires after a term has been updated, but before the term cache has been cleaned.*

The %1$s hook is also available for targeting a specific
taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3169](../../wordpress/wp-includes/taxonomy.php#L3169-L3181)

### `edit_{$taxonomy}`

*Fires after a term in a specific taxonomy has been updated, but before the term
cache has been cleaned.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3183](../../wordpress/wp-includes/taxonomy.php#L3183-L3194)

### `edited_term`

*Fires after a term has been updated, and the term cache has been cleaned.*

The %1$s hook is also available for targeting a specific
taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3201](../../wordpress/wp-includes/taxonomy.php#L3201-L3213)

### `edited_{$taxonomy}`

*Fires after a term for a specific taxonomy has been updated, and the term
cache has been cleaned.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3215](../../wordpress/wp-includes/taxonomy.php#L3215-L3226)

### `saved_term`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` |  | 
`$tt_id` |  | 
`$taxonomy` |  | 
`true` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3228](../../wordpress/wp-includes/taxonomy.php#L3228-L3229)

### `saved_{$taxonomy}`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` |  | 
`$tt_id` |  | 
`true` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3231](../../wordpress/wp-includes/taxonomy.php#L3231-L3232)

### `clean_object_term_cache`

*Fires after the object term cache has been cleaned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_ids` | `array` | An array of object IDs.
`$object_type` | `string` | Object type.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3383](../../wordpress/wp-includes/taxonomy.php#L3383-L3391)

### `clean_term_cache`

*Fires once after each taxonomy's term cache has been cleaned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ids` | `array` | An array of term IDs.
`$taxonomy` | `string` | Taxonomy slug.
`$clean_taxonomy` | `bool` | Whether or not to clean taxonomy-wide caches

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Added the `$clean_taxonomy` parameter.
`2.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3449](../../wordpress/wp-includes/taxonomy.php#L3449-L3459)

### `clean_taxonomy_cache`

*Fires after a taxonomy's caches have been cleaned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3480](../../wordpress/wp-includes/taxonomy.php#L3480-L3487)

### `edit_term_taxonomy`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` |  | 
`$taxonomy->name` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3927](../../wordpress/wp-includes/taxonomy.php#L3927-L3928)

### `edited_term_taxonomy`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` |  | 
`$taxonomy->name` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3931](../../wordpress/wp-includes/taxonomy.php#L3931-L3932)

### `edit_term_taxonomy`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` |  | 
`$taxonomy->name` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3954](../../wordpress/wp-includes/taxonomy.php#L3954-L3955)

### `edited_term_taxonomy`

*This action is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` |  | 
`$taxonomy->name` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3958](../../wordpress/wp-includes/taxonomy.php#L3958-L3959)

### `split_shared_term`

*Fires after a previously shared taxonomy term is split into two separate terms.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | ID of the formerly shared term.
`$new_term_id` | `int` | ID of the new term created for the $term_taxonomy_id.
`$term_taxonomy_id` | `int` | ID for the term_taxonomy row affected by the split.
`$term_taxonomy->taxonomy` |  | 

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 4098](../../wordpress/wp-includes/taxonomy.php#L4098-L4108)

### `parse_comment_query`

*Fires after the comment query vars have been parsed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/class-wp-comment-query.php](../../wordpress/wp-includes/class-wp-comment-query.php), [line 322](../../wordpress/wp-includes/class-wp-comment-query.php#L322-L329)

### `pre_get_comments`

*Fires before comments are retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-comment-query.php](../../wordpress/wp-includes/class-wp-comment-query.php), [line 368](../../wordpress/wp-includes/class-wp-comment-query.php#L368-L375)

### `wp_feed_options`

*Fires just before processing the SimplePie feed object.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$feed, $url)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 819](../../wordpress/wp-includes/feed.php#L819-L827)

### `wp_maybe_auto_update`

*Fires during wp_cron, starting the auto-update process.*


**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/update.php](../../wordpress/wp-includes/update.php), [line 251](../../wordpress/wp-includes/update.php#L251-L256)

### `shutdown`

*Fires just before PHP shuts down execution.*


**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1067](../../wordpress/wp-includes/load.php#L1067-L1072)

### `is_wp_error_instance`

*Fires when `is_wp_error()` is called and its parameter is an instance of `WP_Error`.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$thing` | `\WP_Error` | The error object passed to `is_wp_error()`.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1527](../../wordpress/wp-includes/load.php#L1527-L1534)

### `media_buttons`

*Fires after the default media button(s) are displayed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 228](../../wordpress/wp-includes/class-wp-editor.php#L228-L235)

### `wp_enqueue_editor`

*Fires when scripts and styles are enqueued for the editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('tinymce' => $default_scripts || self::$has_tinymce, 'quicktags' => $default_scripts || self::$has_quicktags)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 874](../../wordpress/wp-includes/class-wp-editor.php#L874-L888)

### `print_default_editor_scripts`

*Fires when the editor scripts are loaded for later initialization,
after all scripts and settings are printed.*


**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 1006](../../wordpress/wp-includes/class-wp-editor.php#L1006-L1012)

### `before_wp_tiny_mce`

*Fires immediately before the TinyMCE settings are printed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::$mce_settings` |  | 

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 1603](../../wordpress/wp-includes/class-wp-editor.php#L1603-L1610)

### `wp_tiny_mce_init`

*Fires after tinymce.js is loaded, but before any TinyMCE editor
instances are created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::$mce_settings` |  | 

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 1641](../../wordpress/wp-includes/class-wp-editor.php#L1641-L1649)

### `after_wp_tiny_mce`

*Fires after any core TinyMCE editor instances are created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::$mce_settings` |  | 

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 1705](../../wordpress/wp-includes/class-wp-editor.php#L1705-L1712)

### `wp_default_scripts`

*Fires when the WP_Scripts instance is initialized.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/class.wp-scripts.php](../../wordpress/wp-includes/class.wp-scripts.php), [line 160](../../wordpress/wp-includes/class.wp-scripts.php#L160-L167)

### `wp_roles_init`

*After the roles have been initialized, allow plugins to add their own roles.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Roles` | A reference to the WP_Roles object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/class-wp-roles.php](../../wordpress/wp-includes/class-wp-roles.php), [line 294](../../wordpress/wp-includes/class-wp-roles.php#L294-L301)

### `rss_tag_pre`

*This action is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'atom'` |  | 

Source: [wordpress/wp-includes/feed-atom.php](../../wordpress/wp-includes/feed-atom.php), [line 13](../../wordpress/wp-includes/feed-atom.php#L13-L14)

### `atom_ns`

*Fires at end of the Atom feed root to add namespaces.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-atom.php](../../wordpress/wp-includes/feed-atom.php), [line 22](../../wordpress/wp-includes/feed-atom.php#L22-L27)

### `atom_head`

*Fires just before the first Atom feed entry.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-atom.php](../../wordpress/wp-includes/feed-atom.php), [line 40](../../wordpress/wp-includes/feed-atom.php#L40-L45)

### `atom_author`

*Fires at the end of each Atom feed author entry.*


**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-includes/feed-atom.php](../../wordpress/wp-includes/feed-atom.php), [line 61](../../wordpress/wp-includes/feed-atom.php#L61-L66)

### `atom_entry`

*Fires at the end of each Atom feed item.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-atom.php](../../wordpress/wp-includes/feed-atom.php), [line 87](../../wordpress/wp-includes/feed-atom.php#L87-L92)

### `add_user_to_blog`

*Fires immediately after a user is added to a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | User ID.
`$role` | `string` | User role.
`$blog_id` | `int` | Blog ID.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 208](../../wordpress/wp-includes/ms-functions.php#L208-L217)

### `remove_user_from_blog`

*Fires before a user is removed from a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user being removed.
`$blog_id` | `int` | ID of the blog the user is being removed from.
`$reassign` | `int` | ID of the user to whom to reassign posts.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | Added the `$reassign` parameter.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 251](../../wordpress/wp-includes/ms-functions.php#L251-L261)

### `after_signup_site`

*Fires after site signup information has been written to the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$domain` | `string` | The requested domain.
`$path` | `string` | The requested path.
`$title` | `string` | The requested site title.
`$user` | `string` | The user's requested login name.
`$user_email` | `string` | The user's email address.
`$key` | `string` | The user's activation key.
`$meta` | `array` | Signup meta data. By default, contains the requested privacy setting and lang_id.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 821](../../wordpress/wp-includes/ms-functions.php#L821-L834)

### `after_signup_user`

*Fires after a user's signup information has been written to the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `string` | The user's requested login name.
`$user_email` | `string` | The user's email address.
`$key` | `string` | The user's activation key.
`$meta` | `array` | Signup meta data. Default empty array.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 887](../../wordpress/wp-includes/ms-functions.php#L887-L897)

### `wpmu_activate_user`

*Fires immediately after a new user is activated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | User ID.
`$password` | `string` | User password.
`$meta` | `array` | Signup meta data.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1210](../../wordpress/wp-includes/ms-functions.php#L1210-L1219)

### `wpmu_activate_blog`

*Fires immediately after a site is activated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$blog_id` | `int` | Blog ID.
`$user_id` | `int` | User ID.
`$password` | `int` | User password.
`$signup->title` |  | 
`$meta` | `array` | Signup meta data. By default, contains the requested privacy setting and lang_id.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1260](../../wordpress/wp-includes/ms-functions.php#L1260-L1271)

### `wpmu_new_user`

*Fires immediately after a new user is created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | User ID.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1324](../../wordpress/wp-includes/ms-functions.php#L1324-L1331)

### `added_existing_user`

*Fires immediately after an existing user is added to a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$details['user_id']` |  | 
`$result` | `true\|\WP_Error` | True on success or a WP_Error object if the user doesn't exist<br>or could not be added.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2315](../../wordpress/wp-includes/ms-functions.php#L2315-L2324)

### `parse_request`

*Fires once all query variables for the current request have been parsed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 381](../../wordpress/wp-includes/class-wp.php#L381-L388)

### `send_headers`

*Fires once the requested HTTP headers for caching, content type, etc. have been sent.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 520](../../wordpress/wp-includes/class-wp.php#L520-L527)

### `wp`

*Fires once the WordPress environment has been set up.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 756](../../wordpress/wp-includes/class-wp.php#L756-L763)

### `parse_site_query`

*Fires after the site query vars have been parsed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-site-query.php](../../wordpress/wp-includes/class-wp-site-query.php), [line 232](../../wordpress/wp-includes/class-wp-site-query.php#L232-L239)

### `pre_get_sites`

*Fires before sites are retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-site-query.php](../../wordpress/wp-includes/class-wp-site-query.php), [line 276](../../wordpress/wp-includes/class-wp-site-query.php#L276-L283)

### `customize_render_panel`

*Fires before rendering a Customizer panel.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Panel` | WP_Customize_Panel instance.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-customize-panel.php](../../wordpress/wp-includes/class-wp-customize-panel.php), [line 273](../../wordpress/wp-includes/class-wp-customize-panel.php#L273-L280)

### `customize_render_panel_{$this->id}`

*Fires before rendering a specific Customizer panel.*

The dynamic portion of the hook name, `$this->id`, refers to
the ID of the specific Customizer panel to be rendered.


**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-customize-panel.php](../../wordpress/wp-includes/class-wp-customize-panel.php), [line 282](../../wordpress/wp-includes/class-wp-customize-panel.php#L282-L290)

### `registered_post_type`

*Fires after a post type is registered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type` | `string` | Post type.
`$post_type_object` | `\WP_Post_Type` | Arguments used to register the post type.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Converted the `$post_type` parameter to accept a `WP_Post_Type` object.
`3.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 1474](../../wordpress/wp-includes/post.php#L1474-L1483)

### `unregistered_post_type`

*Fires after a post type was unregistered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type` | `string` | Post type key.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 1522](../../wordpress/wp-includes/post.php#L1522-L1529)

### `post_stuck`

*Fires once a post has been added to the sticky list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | ID of the post that was stuck.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2643](../../wordpress/wp-includes/post.php#L2643-L2650)

### `post_unstuck`

*Fires once a post has been removed from the sticky list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | ID of the post that was unstuck.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2687](../../wordpress/wp-includes/post.php#L2687-L2694)

### `before_delete_post`

*Fires before a post is deleted, at the start of wp_delete_post().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$postid` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$post` parameter.
`3.2.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3114](../../wordpress/wp-includes/post.php#L3114-L3125)

### `delete_post`

*Fires immediately before a post is deleted from the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$postid` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$post` parameter.
`1.2.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3168](../../wordpress/wp-includes/post.php#L3168-L3177)

### `deleted_post`

*Fires immediately after a post is deleted from the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$postid` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$post` parameter.
`2.2.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3184](../../wordpress/wp-includes/post.php#L3184-L3193)

### `after_delete_post`

*Fires after a post is deleted, at the conclusion of wp_delete_post().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$postid` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$post` parameter.
`3.2.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3205](../../wordpress/wp-includes/post.php#L3205-L3216)

### `wp_trash_post`

*Fires before a post is sent to the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3294](../../wordpress/wp-includes/post.php#L3294-L3301)

### `trashed_post`

*Fires after a post is sent to the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3319](../../wordpress/wp-includes/post.php#L3319-L3326)

### `untrash_post`

*Fires before a post is restored from the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$previous_status` | `string` | The status of the post at the point where it was trashed.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The `$previous_status` parameter was added.
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3371](../../wordpress/wp-includes/post.php#L3371-L3380)

### `untrashed_post`

*Fires after a post is restored from the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$previous_status` | `string` | The status of the post at the point where it was trashed.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The `$previous_status` parameter was added.
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3417](../../wordpress/wp-includes/post.php#L3417-L3426)

### `trash_post_comments`

*Fires before comments are sent to the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3452](../../wordpress/wp-includes/post.php#L3452-L3459)

### `trashed_post_comments`

*Fires after comments are sent to the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$statuses` | `array` | Array of comment statuses.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3479](../../wordpress/wp-includes/post.php#L3479-L3487)

### `untrash_post_comments`

*Fires before comments are restored for a post from the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3519](../../wordpress/wp-includes/post.php#L3519-L3526)

### `untrashed_post_comments`

*Fires after comments are restored for a post from the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3547](../../wordpress/wp-includes/post.php#L3547-L3554)

### `pre_post_update`

*Fires immediately before an existing post is updated in the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$data` | `array` | Array of unslashed post data.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4102](../../wordpress/wp-includes/post.php#L4102-L4110)

### `edit_attachment`

*Fires once an existing attachment has been updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4287](../../wordpress/wp-includes/post.php#L4287-L4294)

### `attachment_updated`

*Fires once an existing attachment has been updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$post_after` | `\WP_Post` | Post object following the update.
`$post_before` | `\WP_Post` | Post object before the update.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4298](../../wordpress/wp-includes/post.php#L4298-L4307)

### `add_attachment`

*Fires once an attachment has been added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4310](../../wordpress/wp-includes/post.php#L4310-L4317)

### `edit_post_{$post->post_type}`

*Fires once an existing post has been updated.*

The dynamic portion of the hook name, `$post->post_type`, refers to
the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4324](../../wordpress/wp-includes/post.php#L4324-L4335)

### `edit_post`

*Fires once an existing post has been updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4337](../../wordpress/wp-includes/post.php#L4337-L4345)

### `post_updated`

*Fires once an existing post has been updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$post_after` | `\WP_Post` | Post object following the update.
`$post_before` | `\WP_Post` | Post object before the update.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4349](../../wordpress/wp-includes/post.php#L4349-L4358)

### `save_post_{$post->post_type}`

*Fires once a post has been saved.*

The dynamic portion of the hook name, `$post->post_type`, refers to
the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.
`$update` | `bool` | Whether this is an existing post being updated.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4361](../../wordpress/wp-includes/post.php#L4361-L4373)

### `save_post`

*Fires once a post has been saved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.
`$update` | `bool` | Whether this is an existing post being updated.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4375](../../wordpress/wp-includes/post.php#L4375-L4384)

### `wp_insert_post`

*Fires once a post has been saved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.
`$update` | `bool` | Whether this is an existing post being updated.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4386](../../wordpress/wp-includes/post.php#L4386-L4395)

### `edit_post_{$post->post_type}`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4548](../../wordpress/wp-includes/post.php#L4548-L4549)

### `edit_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4551](../../wordpress/wp-includes/post.php#L4551-L4552)

### `save_post_{$post->post_type}`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 
`true` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4554](../../wordpress/wp-includes/post.php#L4554-L4555)

### `save_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 
`true` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4557](../../wordpress/wp-includes/post.php#L4557-L4558)

### `wp_insert_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 
`true` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4560](../../wordpress/wp-includes/post.php#L4560-L4561)

### `transition_post_status`

*Fires when a post is transitioned from one status to another.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_status` | `string` | New post status.
`$old_status` | `string` | Old post status.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5005](../../wordpress/wp-includes/post.php#L5005-L5014)

### `{$old_status}_to_{$new_status}`

*Fires when a post is transitioned from one status to another.*

The dynamic portions of the hook name, `$new_status` and `$old_status`,
refer to the old and new post statuses, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5016](../../wordpress/wp-includes/post.php#L5016-L5026)

### `{$new_status}_{$post->post_type}`

*Fires when a post is transitioned from one status to another.*

The dynamic portions of the hook name, `$new_status` and `$post->post_type`,
refer to the new post status and post type, respectively.

Please note: When this action is hooked using a particular post status (like
'publish', as `publish_{$post->post_type}`), it will fire both when a post is
first transitioned to that status from something else, as well as upon
subsequent post updates (old and new status are both the same).

Therefore, if you are looking to only fire a callback when a post is first
transitioned to a status, use the %1$s hook instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5028](../../wordpress/wp-includes/post.php#L5028-L5047)

### `wp_after_insert_post`

*Fires once a post, its terms and meta data has been saved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$post` | `\WP_Post` | Post object.
`$update` | `bool` | Whether this is an existing post being updated.
`$post_before` | `null\|\WP_Post` | Null for new posts, the WP_Post object prior<br>to the update for updated posts.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5068](../../wordpress/wp-includes/post.php#L5068-L5079)

### `delete_attachment`

*Fires before an attachment is deleted, at the start of wp_delete_attachment().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Attachment ID.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$post` parameter.
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6045](../../wordpress/wp-includes/post.php#L6045-L6054)

### `delete_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6076](../../wordpress/wp-includes/post.php#L6076-L6077)

### `deleted_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6082](../../wordpress/wp-includes/post.php#L6082-L6083)

### `clean_post_cache`

*Fires immediately after the given post's cache is cleaned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 7072](../../wordpress/wp-includes/post.php#L7072-L7080)

### `clean_page_cache`

*Fires immediately after the given page's cache is cleaned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 7085](../../wordpress/wp-includes/post.php#L7085-L7092)

### `clean_attachment_cache`

*Fires after the given attachment's cache is cleaned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 7196](../../wordpress/wp-includes/post.php#L7196-L7203)

### `private_to_published`

*Fires when a post's status is transitioned from private to published.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($post->ID)` |  | 
`'2.3.0'` |  | 
`'private_to_publish'` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 7232](../../wordpress/wp-includes/post.php#L7232-L7240)

### `xmlrpc_publish_post`

*Fires when _publish_post_hook() is called during an XML-RPC request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 7291](../../wordpress/wp-includes/post.php#L7291-L7298)

### `parse_term_query`

*Fires after term query vars have been parsed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Term_Query` | Current instance of WP_Term_Query.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 277](../../wordpress/wp-includes/class-wp-term-query.php#L277-L284)

### `pre_get_terms`

*Fires before terms are retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 351](../../wordpress/wp-includes/class-wp-term-query.php#L351-L358)

### `switch_locale`

*Fires when the locale is switched.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$locale` | `string` | The new locale.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/class-wp-locale-switcher.php](../../wordpress/wp-includes/class-wp-locale-switcher.php), [line 85](../../wordpress/wp-includes/class-wp-locale-switcher.php#L85-L92)

### `restore_previous_locale`

*Fires when the locale is restored to the previous one.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$locale` | `string` | The new locale.
`$previous_locale` | `string` | The previous locale.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/class-wp-locale-switcher.php](../../wordpress/wp-includes/class-wp-locale-switcher.php), [line 121](../../wordpress/wp-includes/class-wp-locale-switcher.php#L121-L129)

### `change_locale`

*Fires when the locale is switched to or restored.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$locale` | `string` | The new locale.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/class-wp-locale-switcher.php](../../wordpress/wp-includes/class-wp-locale-switcher.php), [line 228](../../wordpress/wp-includes/class-wp-locale-switcher.php#L228-L235)

### `rest_api_init`

*Fires when preparing to serve a REST API request.*

Endpoint objects should be created and register their hooks on this action rather
than another action to ensure they're only loaded when needed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_rest_server` | `\WP_REST_Server` | Server object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 511](../../wordpress/wp-includes/rest-api.php#L511-L521)

### `generate_rewrite_rules`

*Fires after the rewrite rules are generated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1446](../../wordpress/wp-includes/class-wp-rewrite.php#L1446-L1453)

### `permalink_structure_changed`

*Fires after the permalink structure is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$old_permalink_structure` | `string` | The previous permalink structure.
`$permalink_structure` | `string` | The new permalink structure.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1935](../../wordpress/wp-includes/class-wp-rewrite.php#L1935-L1943)

### `start_previewing_theme`

*Fires once the Customizer theme preview has started.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 689](../../wordpress/wp-includes/class-wp-customize-manager.php#L689-L696)

### `stop_previewing_theme`

*Fires once the Customizer theme preview has stopped.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 727](../../wordpress/wp-includes/class-wp-customize-manager.php#L727-L734)

### `customize_register`

*Fires once WordPress has loaded, allowing scripts and styles to be initialized.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 926](../../wordpress/wp-includes/class-wp-customize-manager.php#L926-L933)

### `customize_post_value_set_{$setting_id}`

*Announce when a specific setting's unsanitized post value has been set.*

Fires when the WP_Customize_Manager::set_post_value() method is called.

The dynamic portion of the hook name, `$setting_id`, refers to the setting ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Unsanitized setting post value.
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 1853](../../wordpress/wp-includes/class-wp-customize-manager.php#L1853-L1865)

### `customize_post_value_set`

*Announce when any setting's unsanitized post value has been set.*

Fires when the WP_Customize_Manager::set_post_value() method is called.

This is useful for `WP_Customize_Setting` instances to watch
in order to update a cached previewed value.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$setting_id` | `string` | Setting ID.
`$value` | `mixed` | Unsanitized setting post value.
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 1867](../../wordpress/wp-includes/class-wp-customize-manager.php#L1867-L1881)

### `customize_preview_init`

*Fires once the Customizer preview has initialized and JavaScript
settings have been printed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 1934](../../wordpress/wp-includes/class-wp-customize-manager.php#L1934-L1942)

### `customize_save_validation_before`

*Fires before save validation happens.*

Plugins can add just-in-time %1$s'} filters
at this point to catch any settings registered after `customize_register`.
The dynamic portion of the hook name, `$this->ID` refers to the setting ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 2754](../../wordpress/wp-includes/class-wp-customize-manager.php#L2754-L2765)

### `wp_trash_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3079](../../wordpress/wp-includes/class-wp-customize-manager.php#L3079-L3080)

### `edit_post_{$post->post_type}`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3093](../../wordpress/wp-includes/class-wp-customize-manager.php#L3093-L3094)

### `edit_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3096](../../wordpress/wp-includes/class-wp-customize-manager.php#L3096-L3097)

### `save_post_{$post->post_type}`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 
`true` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3099](../../wordpress/wp-includes/class-wp-customize-manager.php#L3099-L3100)

### `save_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 
`true` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3102](../../wordpress/wp-includes/class-wp-customize-manager.php#L3102-L3103)

### `wp_insert_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post` |  | 
`true` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3105](../../wordpress/wp-includes/class-wp-customize-manager.php#L3105-L3106)

### `trashed_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3112](../../wordpress/wp-includes/class-wp-customize-manager.php#L3112-L3113)

### `customize_save`

*Fires once the theme has switched in the Customizer, but before settings
have been saved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3516](../../wordpress/wp-includes/class-wp-customize-manager.php#L3516-L3524)

### `customize_save_after`

*Fires after Customize settings have been saved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3570](../../wordpress/wp-includes/class-wp-customize-manager.php#L3570-L3577)

### `rss_tag_pre`

*This action is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'rdf'` |  | 

Source: [wordpress/wp-includes/feed-rdf.php](../../wordpress/wp-includes/feed-rdf.php), [line 13](../../wordpress/wp-includes/feed-rdf.php#L13-L14)

### `rdf_ns`

*Fires at the end of the feed root to add namespaces.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rdf.php](../../wordpress/wp-includes/feed-rdf.php), [line 24](../../wordpress/wp-includes/feed-rdf.php#L24-L29)

### `rdf_header`

*Fires at the end of the RDF feed header.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rdf.php](../../wordpress/wp-includes/feed-rdf.php), [line 51](../../wordpress/wp-includes/feed-rdf.php#L51-L56)

### `rdf_item`

*Fires at the end of each RDF feed item.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rdf.php](../../wordpress/wp-includes/feed-rdf.php), [line 90](../../wordpress/wp-includes/feed-rdf.php#L90-L95)

### `update_option`

*Fires immediately before an option value is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the option to update.
`$old_value` | `mixed` | The old option value.
`$value` | `mixed` | The new option value.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 422](../../wordpress/wp-includes/option.php#L422-L431)

### `update_option_{$option}`

*Fires after the value of a specific option has been successfully updated.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$old_value` | `mixed` | The old option value.
`$value` | `mixed` | The new option value.
`$option` | `string` | Option name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$option` parameter was added.
`2.0.1` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 463](../../wordpress/wp-includes/option.php#L463-L475)

### `updated_option`

*Fires after the value of an option has been successfully updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the updated option.
`$old_value` | `mixed` | The old option value.
`$value` | `mixed` | The new option value.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 477](../../wordpress/wp-includes/option.php#L477-L486)

### `add_option`

*Fires before an option is added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the option to add.
`$value` | `mixed` | Value of the option.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 572](../../wordpress/wp-includes/option.php#L572-L580)

### `add_option_{$option}`

*Fires after a specific option has been added.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the option to add.
`$value` | `mixed` | Value of the option.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 
`2.5.0` | As "add_option_{$name}"

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 605](../../wordpress/wp-includes/option.php#L605-L616)

### `added_option`

*Fires after an option has been added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the added option.
`$value` | `mixed` | Value of the option.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 618](../../wordpress/wp-includes/option.php#L618-L626)

### `delete_option`

*Fires immediately before an option is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the option to delete.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 657](../../wordpress/wp-includes/option.php#L657-L664)

### `delete_option_{$option}`

*Fires after a specific option has been deleted.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the deleted option.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 682](../../wordpress/wp-includes/option.php#L682-L691)

### `deleted_option`

*Fires after an option has been deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the deleted option.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 693](../../wordpress/wp-includes/option.php#L693-L700)

### `delete_transient_{$transient}`

*Fires immediately before a specific transient is deleted.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 718](../../wordpress/wp-includes/option.php#L718-L727)

### `deleted_transient`

*Fires after a transient is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$transient` | `string` | Deleted transient name.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 743](../../wordpress/wp-includes/option.php#L743-L750)

### `set_transient_{$transient}`

*Fires after the value for a specific transient has been set.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Transient value.
`$expiration` | `int` | Time until expiration in seconds.
`$transient` | `string` | The name of the transient.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added.
`3.6.0` | The `$value` and `$expiration` parameters were added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 912](../../wordpress/wp-includes/option.php#L912-L925)

### `setted_transient`

*Fires after the value for a transient has been set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$transient` | `string` | The name of the transient.
`$value` | `mixed` | Transient value.
`$expiration` | `int` | Time until expiration in seconds.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | The `$value` and `$expiration` parameters were added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 927](../../wordpress/wp-includes/option.php#L927-L937)

### `add_site_option_{$option}`

*Fires after a specific network option has been successfully added.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the network option.
`$value` | `mixed` | Value of the network option.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`3.0.0` | 
`2.9.0` | As "add_site_option_{$key}"

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1524](../../wordpress/wp-includes/option.php#L1524-L1537)

### `add_site_option`

*Fires after a network option has been successfully added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the network option.
`$value` | `mixed` | Value of the network option.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1539](../../wordpress/wp-includes/option.php#L1539-L1549)

### `pre_delete_site_option_{$option}`

*Fires immediately before a specific network option is deleted.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Option name.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`4.4.0` | The `$option` parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1584](../../wordpress/wp-includes/option.php#L1584-L1596)

### `delete_site_option_{$option}`

*Fires after a specific network option has been deleted.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the network option.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`3.0.0` | 
`2.9.0` | As "delete_site_option_{$key}"

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1619](../../wordpress/wp-includes/option.php#L1619-L1631)

### `delete_site_option`

*Fires after a network option has been deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the network option.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1633](../../wordpress/wp-includes/option.php#L1633-L1642)

### `update_site_option_{$option}`

*Fires after the value of a specific network option has been successfully updated.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the network option.
`$value` | `mixed` | Current value of the network option.
`$old_value` | `mixed` | Old value of the network option.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`3.0.0` | 
`2.9.0` | As "update_site_option_{$key}"

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1747](../../wordpress/wp-includes/option.php#L1747-L1761)

### `update_site_option`

*Fires after the value of a network option has been successfully updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option` | `string` | Name of the network option.
`$value` | `mixed` | Current value of the network option.
`$old_value` | `mixed` | Old value of the network option.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1763](../../wordpress/wp-includes/option.php#L1763-L1774)

### `delete_site_transient_{$transient}`

*Fires immediately before a specific site transient is deleted.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1792](../../wordpress/wp-includes/option.php#L1792-L1801)

### `deleted_site_transient`

*Fires after a transient is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$transient` | `string` | Deleted transient name.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1817](../../wordpress/wp-includes/option.php#L1817-L1824)

### `set_site_transient_{$transient}`

*Fires after the value for a specific site transient has been set.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Site transient value.
`$expiration` | `int` | Time until expiration in seconds.
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1969](../../wordpress/wp-includes/option.php#L1969-L1981)

### `setted_site_transient`

*Fires after the value for a site transient has been set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$transient` | `string` | The name of the site transient.
`$value` | `mixed` | Site transient value.
`$expiration` | `int` | Time until expiration in seconds.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1983](../../wordpress/wp-includes/option.php#L1983-L1992)

### `register_setting`

*Fires immediately before the setting is registered but after its filters are in place.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option_group` | `string` | Setting group.
`$option_name` | `string` | Setting name.
`$args` | `array` | Array of setting registration arguments.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 2301](../../wordpress/wp-includes/option.php#L2301-L2310)

### `unregister_setting`

*Fires immediately before the setting is unregistered and after its filters have been removed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$option_group` | `string` | Setting group.
`$option_name` | `string` | Setting name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 2396](../../wordpress/wp-includes/option.php#L2396-L2404)

### `{$tag}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 

Source: [wordpress/wp-includes/plugin.php](../../wordpress/wp-includes/plugin.php), [line 667](../../wordpress/wp-includes/plugin.php#L667-L667)

### `begin_fetch_post_thumbnail_html`

*Fires before fetching the post thumbnail HTML.*

Provides "just in time" filtering of all filters in wp_get_attachment_image().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post_thumbnail_id` | `int` | The post thumbnail ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post-thumbnail-template.php](../../wordpress/wp-includes/post-thumbnail-template.php), [line 161](../../wordpress/wp-includes/post-thumbnail-template.php#L161-L173)

### `end_fetch_post_thumbnail_html`

*Fires after fetching the post thumbnail HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->ID` |  | 
`$post_thumbnail_id` | `int` | The post thumbnail ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post-thumbnail-template.php](../../wordpress/wp-includes/post-thumbnail-template.php), [line 181](../../wordpress/wp-includes/post-thumbnail-template.php#L181-L191)

### `xmlrpc_call`

*Fires after the XML-RPC user has been authenticated but before the rest of
the method logic begins.*

All built-in XML-RPC methods use the action xmlrpc_call, with a parameter
equal to the method's name, e.g., wp.getUsersBlogs, wp.newPost, etc.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getUsersBlogs'` |  | 
`$args` | `array\|string` | The escaped arguments passed to the method.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`5.7.0` | Added the `$args` and `$server` parameters.
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 676](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L676-L690)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.newPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1299](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1299-L1300)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.editPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1692](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1692-L1693)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.deletePost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1775](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1775-L1776)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1875](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1875-L1876)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPosts'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1936](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1936-L1937)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.newTerm'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2035](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2035-L2036)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.editTerm'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2140](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2140-L2141)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.deleteTerm'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2256](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2256-L2257)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getTerm'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2335](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2335-L2336)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getTerms'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2400](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2400-L2401)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getTaxonomy'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2506](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2506-L2507)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getTaxonomies'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2564](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2564-L2565)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getUser'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2650](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2650-L2651)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getUsers'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2713](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2713-L2714)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getProfile'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2793](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2793-L2794)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.editProfile'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2843](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2843-L2844)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPage'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2932](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2932-L2933)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPages'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2975](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2975-L2976)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.newPage'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3030](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3030-L3031)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.deletePage'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3067](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3067-L3068)

### `xmlrpc_call_success_wp_deletePage`

*Fires after a page has been successfully deleted via XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$page_id` | `int` | ID of the deleted page.
`$args` | `array` | An array of arguments to delete the page.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3088](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3088-L3096)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.editPage'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3134](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3134-L3135)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPageList'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3197](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3197-L3198)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getAuthors'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3258](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3258-L3259)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getKeywords'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3302](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3302-L3303)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.newCategory'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3352](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3352-L3353)

### `xmlrpc_call_success_wp_newCategory`

*Fires after a new category has been successfully created via XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cat_id` | `int` | ID of the new category.
`$args` | `array` | An array of new category arguments.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3395](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3395-L3403)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.deleteCategory'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3435](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3435-L3436)

### `xmlrpc_call_success_wp_deleteCategory`

*Fires after a category has been successfully deleted via XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$category_id` | `int` | ID of the deleted category.
`$args` | `array` | An array of arguments to delete the category.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3445](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3445-L3453)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.suggestCategories'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3492](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3492-L3493)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getComment'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3538](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3538-L3539)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getComments'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3591](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3591-L3592)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.deleteComment'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3686](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3686-L3687)

### `xmlrpc_call_success_wp_deleteComment`

*Fires after a comment has been successfully deleted via XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_ID` | `int` | ID of the deleted comment.
`$args` | `array` | An array of arguments to delete the comment.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3692](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3692-L3700)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.editComment'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3754](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3754-L3755)

### `xmlrpc_call_success_wp_editComment`

*Fires after a comment has been successfully updated via XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_ID` | `int` | ID of the updated comment.
`$args` | `array` | An array of arguments to update the comment.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3804](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3804-L3812)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.newComment'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3947](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3947-L3948)

### `xmlrpc_call_success_wp_newComment`

*Fires after a new comment has been successfully created via XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_ID` | `int` | ID of the new comment.
`$args` | `array` | An array of new comment arguments.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3959](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3959-L3967)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getCommentStatusList'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4001](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4001-L4002)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getCommentCount'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4043](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4043-L4044)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPostStatusList'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4085](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4085-L4086)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPageStatusList'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4120](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4120-L4121)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getMediaItem'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4313](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4313-L4314)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getMediaLibrary'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4366](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4366-L4367)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPostFormats'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4422](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4422-L4423)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPostType'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4502](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4502-L4503)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getPostTypes'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4559](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4559-L4560)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.getRevisions'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4629](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4629-L4630)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp.restoreRevision'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4703](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4703-L4704)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'blogger.getUsersBlogs'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4774](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4774-L4775)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'blogger.getUserInfo'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4860](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4860-L4861)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'blogger.getPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4910](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4910-L4911)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'blogger.getRecentPosts'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4967](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4967-L4968)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'blogger.newPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5057](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5057-L5058)

### `xmlrpc_call_success_blogger_newPost`

*Fires after a new post has been successfully created via the XML-RPC Blogger API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | ID of the new post.
`$args` | `array` | An array of new post arguments.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5089](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5089-L5097)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'blogger.editPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5134](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5134-L5135)

### `xmlrpc_call_success_blogger_editPost`

*Fires after a post has been successfully updated via the XML-RPC Blogger API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | ID of the updated post.
`$args` | `array` | An array of arguments for the post to edit.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5168](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5168-L5176)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'blogger.deletePost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5208](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5208-L5209)

### `xmlrpc_call_success_blogger_deletePost`

*Fires after a post has been successfully deleted via the XML-RPC Blogger API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | ID of the deleted post.
`$args` | `array` | An array of arguments to delete the post.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5227](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5227-L5235)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'metaWeblog.newPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5296](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5296-L5297)

### `xmlrpc_call_success_mw_newPost`

*Fires after a new post has been successfully created via the XML-RPC MovableType API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | ID of the new post.
`$args` | `array` | An array of arguments to create the new post.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5580](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5580-L5588)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'metaWeblog.editPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5675](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5675-L5676)

### `xmlrpc_call_success_mw_editPost`

*Fires after a post has been successfully updated via the XML-RPC MovableType API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_ID` | `int` | ID of the updated post.
`$args` | `array` | An array of arguments to update the post.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 5964](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L5964-L5972)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'metaWeblog.getPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6013](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6013-L6014)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'metaWeblog.getRecentPosts'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6154](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6154-L6155)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'metaWeblog.getCategories'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6275](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6275-L6276)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'metaWeblog.newMediaObject'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6336](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6336-L6337)

### `xmlrpc_call_success_mw_newMediaObject`

*Fires after a new attachment has been added via the XML-RPC MovableType API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | ID of the new attachment.
`$args` | `array` | An array of arguments to add the attachment.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6399](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6399-L6407)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.getRecentPostTitles'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6455](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6455-L6456)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.getCategoryList'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6517](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6517-L6518)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.getPostCategories'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6575](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6575-L6576)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.setPostCategories'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6622](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6622-L6623)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.supportedMethods'` |  | 
`array()` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6651](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6651-L6652)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.supportedTextFilters'` |  | 
`array()` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6663](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6663-L6664)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.getTrackbackPings'` |  | 
`$post_ID` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6689](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6689-L6690)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mt.publishPost'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6746](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6746-L6747)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'pingback.ping'` |  | 
`$args` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6788](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6788-L6789)

### `pingback_post`

*Fires after a post pingback has been sent.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_ID` | `int` | Comment ID.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6999](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6999-L7006)

### `xmlrpc_call`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'pingback.extensions.getPingbacks'` |  | 
`$url` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 7027](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L7027-L7028)

### `switch_theme`

*Fires after the theme is switched.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_name` | `string` | Name of the new theme.
`$new_theme` | `\WP_Theme` | WP_Theme instance of the new theme.
`$old_theme` | `\WP_Theme` | WP_Theme instance of the old theme.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Introduced the `$old_theme` parameter.
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 819](../../wordpress/wp-includes/theme.php#L819-L829)

### `after_switch_theme`

*Fires on the first WP load after a theme switch if the old theme still exists.*

This action fires multiple times and the parameters differs
according to the context, if the old theme exists or not.
If the old theme is missing, the parameter will be the slug
of the old theme.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$old_theme->get('Name')` |  | 
`$old_theme` | `\WP_Theme` | WP_Theme instance of the old theme.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 3289](../../wordpress/wp-includes/theme.php#L3289-L3302)

### `after_switch_theme`

*This action is documented in wp-includes/theme.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet` |  | 
`$old_theme` |  | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 3304](../../wordpress/wp-includes/theme.php#L3304-L3305)

### `customize_register`

*This filter is documented in /wp-includes/class-wp-customize-manager.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_customize` |  | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 3460](../../wordpress/wp-includes/theme.php#L3460-L3461)

### `wp_authenticate`

*Fires before the user is authenticated.*

The variables passed to the callbacks are passed by reference,
and can be modified by callback functions.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$credentials['user_login'], &$credentials['user_password'])` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 54](../../wordpress/wp-includes/user.php#L54-L67)

### `wp_login`

*Fires after the user has successfully logged in.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user->user_login` |  | 
`$user` | `\WP_User` | WP_User object of the logged-in user.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 102](../../wordpress/wp-includes/user.php#L102-L110)

### `application_password_failed_authentication`

*Fires when an application password failed to authenticate the user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$error` | `\WP_Error` | The authentication error.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 371](../../wordpress/wp-includes/user.php#L371-L378)

### `wp_authenticate_application_password_errors`

*Fires when an application password has been successfully checked as valid.*

This allows for plugins to add additional constraints to prevent an application password from being used.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$error` | `\WP_Error` | The error object.
`$user` | `\WP_User` | The user authenticating.
`$item` | `array` | The details about the application password.
`$password` | `string` | The raw supplied password.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 400](../../wordpress/wp-includes/user.php#L400-L412)

### `application_password_failed_authentication`

*This action is documented in wp-includes/user.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$error` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 415](../../wordpress/wp-includes/user.php#L415-L416)

### `application_password_did_authenticate`

*Fires after an application password was used for authentication.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | The user who was authenticated.
`$item` | `array` | The application password used.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 423](../../wordpress/wp-includes/user.php#L423-L431)

### `application_password_failed_authentication`

*This action is documented in wp-includes/user.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$error` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 441](../../wordpress/wp-includes/user.php#L441-L442)

### `clean_user_cache`

*Fires immediately after the given user's cache is cleaned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user->ID` |  | 
`$user` | `\WP_User` | User object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1579](../../wordpress/wp-includes/user.php#L1579-L1587)

### `profile_update`

*Fires immediately after an existing user is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | User ID.
`$old_user_data` | `\WP_User` | Object containing user's data prior to update.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2080](../../wordpress/wp-includes/user.php#L2080-L2088)

### `make_spam_user`

*Fires after the user is marked as a SPAM user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user marked as SPAM.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2092](../../wordpress/wp-includes/user.php#L2092-L2099)

### `make_ham_user`

*Fires after the user is marked as a HAM user. Opposite of SPAM.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user marked as HAM.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2101](../../wordpress/wp-includes/user.php#L2101-L2108)

### `user_register`

*Fires immediately after a new user is registered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | User ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2112](../../wordpress/wp-includes/user.php#L2112-L2119)

### `retreive_password`

*Fires before a new password is retrieved.*

Use the %1$s hook instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($user->user_login)` |  | 
`'1.5.1'` |  | 
`'retrieve_password'` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2489](../../wordpress/wp-includes/user.php#L2489-L2499)

### `retrieve_password`

*Fires before a new password is retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user->user_login` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2501](../../wordpress/wp-includes/user.php#L2501-L2508)

### `retrieve_password_key`

*Fires when a password reset key is generated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user->user_login` |  | 
`$key` | `string` | The generated password reset key.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2534](../../wordpress/wp-includes/user.php#L2534-L2542)

### `lostpassword_post`

*Fires before errors are returned from a password reset request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | A WP_Error object containing any errors generated<br>by using invalid credentials.
`$user_data` | `\WP_User\|false` | WP_User object if found, false if the user does not exist.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | Added the `$user_data` parameter.
`4.4.0` | Added the `$errors` parameter.
`2.1.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2704](../../wordpress/wp-includes/user.php#L2704-L2715)

### `password_reset`

*Fires before the user's password is reset.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | The user.
`$new_pass` | `string` | New user password.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2845](../../wordpress/wp-includes/user.php#L2845-L2853)

### `after_password_reset`

*Fires after the user's password is reset.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | The user.
`$new_pass` | `string` | New user password.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2858](../../wordpress/wp-includes/user.php#L2858-L2866)

### `register_post`

*Fires when submitting registration form data, before the user is created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sanitized_user_login` | `string` | The submitted username after being sanitized.
`$user_email` | `string` | The submitted email.
`$errors` | `\WP_Error` | Contains any errors with submitted username and email,<br>e.g., an empty field, an invalid username or email,<br>or an existing username or email.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2918](../../wordpress/wp-includes/user.php#L2918-L2929)

### `register_new_user`

*Fires after a new user registration has been recorded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the newly registered user.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2969](../../wordpress/wp-includes/user.php#L2969-L2976)

### `http_api_curl`

*This action is documented in wp-includes/class-wp-http-curl.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$parameters[0], $this->request, $this->url)` |  | 

Source: [wordpress/wp-includes/class-wp-http-requests-hooks.php](../../wordpress/wp-includes/class-wp-http-requests-hooks.php), [line 56](../../wordpress/wp-includes/class-wp-http-requests-hooks.php#L56-L57)

### `requests-{$hook}`

*Transforms a native Request hook to a WordPress action.*

This action maps Requests internal hook to a native WordPress action.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parameters` | `array` | Parameters from Requests internal hook.
`$this->request` |  | 
`$this->url` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/class-wp-http-requests-hooks.php](../../wordpress/wp-includes/class-wp-http-requests-hooks.php), [line 61](../../wordpress/wp-includes/class-wp-http-requests-hooks.php#L61-L74)

### `add_{$meta_type}_meta`

*Fires immediately before meta of a specific type is added.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$_meta_value` | `mixed` | Metadata value. Serialized if non-scalar.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 89](../../wordpress/wp-includes/meta.php#L89-L101)

### `added_{$meta_type}_meta`

*Fires immediately after meta of a specific type is added.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mid` | `int` | The meta ID after successful update.
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$_meta_value` | `mixed` | Metadata value. Serialized if non-scalar.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 120](../../wordpress/wp-includes/meta.php#L120-L133)

### `update_{$meta_type}_meta`

*Fires immediately before updating metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` | `int` | ID of the metadata entry to update.
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$_meta_value` | `mixed` | Metadata value. Serialized if non-scalar.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 240](../../wordpress/wp-includes/meta.php#L240-L253)

### `update_postmeta`

*Fires immediately before updating a post's metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` | `int` | ID of metadata entry to update.
`$object_id` | `int` | Post ID.
`$meta_key` | `string` | Metadata key.
`$meta_value` | `mixed` | Metadata value. This will be a PHP-serialized string representation of the value<br>if the value is an array, an object, or itself a PHP-serialized string.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 256](../../wordpress/wp-includes/meta.php#L256-L267)

### `updated_{$meta_type}_meta`

*Fires immediately after updating metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` | `int` | ID of updated metadata entry.
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$_meta_value` | `mixed` | Metadata value. Serialized if non-scalar.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 279](../../wordpress/wp-includes/meta.php#L279-L292)

### `updated_postmeta`

*Fires immediately after updating a post's metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` | `int` | ID of updated metadata entry.
`$object_id` | `int` | Post ID.
`$meta_key` | `string` | Metadata key.
`$meta_value` | `mixed` | Metadata value. This will be a PHP-serialized string representation of the value<br>if the value is an array, an object, or itself a PHP-serialized string.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 295](../../wordpress/wp-includes/meta.php#L295-L306)

### `delete_{$meta_type}_meta`

*Fires immediately before deleting metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_ids` | `string[]` | An array of metadata entry IDs to delete.
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$_meta_value` | `mixed` | Metadata value. Serialized if non-scalar.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 407](../../wordpress/wp-includes/meta.php#L407-L420)

### `delete_postmeta`

*Fires immediately before deleting metadata for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_ids` | `string[]` | An array of metadata entry IDs to delete.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 424](../../wordpress/wp-includes/meta.php#L424-L431)

### `deleted_{$meta_type}_meta`

*Fires immediately after deleting metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_ids` | `string[]` | An array of metadata entry IDs to delete.
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$_meta_value` | `mixed` | Metadata value. Serialized if non-scalar.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 450](../../wordpress/wp-includes/meta.php#L450-L463)

### `deleted_postmeta`

*Fires immediately after deleting metadata for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_ids` | `string[]` | An array of metadata entry IDs to delete.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 467](../../wordpress/wp-includes/meta.php#L467-L474)

### `update_{$meta_type}_meta`

*This action is documented in wp-includes/meta.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` |  | 
`$object_id` |  | 
`$meta_key` |  | 
`$_meta_value` |  | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 852](../../wordpress/wp-includes/meta.php#L852-L853)

### `update_postmeta`

*This action is documented in wp-includes/meta.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` |  | 
`$object_id` |  | 
`$meta_key` |  | 
`$meta_value` |  | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 856](../../wordpress/wp-includes/meta.php#L856-L857)

### `updated_{$meta_type}_meta`

*This action is documented in wp-includes/meta.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` |  | 
`$object_id` |  | 
`$meta_key` |  | 
`$_meta_value` |  | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 869](../../wordpress/wp-includes/meta.php#L869-L870)

### `updated_postmeta`

*This action is documented in wp-includes/meta.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` |  | 
`$object_id` |  | 
`$meta_key` |  | 
`$meta_value` |  | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 873](../../wordpress/wp-includes/meta.php#L873-L874)

### `delete_{$meta_type}_meta`

*This action is documented in wp-includes/meta.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`(array) $meta_id` |  | 
`$object_id` |  | 
`$meta->meta_key` |  | 
`$meta->meta_value` |  | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 940](../../wordpress/wp-includes/meta.php#L940-L941)

### `delete_{$meta_type}meta`

*Fires immediately before deleting post or comment metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta
object type (post or comment).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` | `int` | ID of the metadata entry to delete.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 945](../../wordpress/wp-includes/meta.php#L945-L955)

### `deleted_{$meta_type}_meta`

*This action is documented in wp-includes/meta.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`(array) $meta_id` |  | 
`$object_id` |  | 
`$meta->meta_key` |  | 
`$meta->meta_value` |  | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 964](../../wordpress/wp-includes/meta.php#L964-L965)

### `deleted_{$meta_type}meta`

*Fires immediately after deleting post or comment metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta
object type (post or comment).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_id` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 969](../../wordpress/wp-includes/meta.php#L969-L979)

### `http_api_debug`

*This action is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` |  | 
`'response'` |  | 
`'Requests'` |  | 
`$parsed_args` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 276](../../wordpress/wp-includes/class-http.php#L276-L277)

### `http_api_debug`

*This action is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` |  | 
`'response'` |  | 
`'Requests'` |  | 
`$parsed_args` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 283](../../wordpress/wp-includes/class-http.php#L283-L284)

### `http_api_debug`

*This action is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` |  | 
`'response'` |  | 
`'Requests'` |  | 
`$parsed_args` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 300](../../wordpress/wp-includes/class-http.php#L300-L301)

### `http_api_debug`

*Fires after an HTTP API response is received and before the response is returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array\|\WP_Error` | HTTP response or WP_Error object.
`'response'` |  | 
`'Requests'` |  | 
`$parsed_args` | `array` | HTTP request arguments.
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 408](../../wordpress/wp-includes/class-http.php#L408-L419)

### `http_api_debug`

*This action is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` |  | 
`'response'` |  | 
`$class` |  | 
`$args` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 582](../../wordpress/wp-includes/class-http.php#L582-L583)

### `wp_insert_site`

*Fires once a site has been inserted into the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_site` | `\WP_Site` | New site object.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 82](../../wordpress/wp-includes/ms-site.php#L82-L89)

### `wp_initialize_site`

*Fires when a site's initialization routine should be executed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_site` | `\WP_Site` | New site object.
`$args` | `array` | Arguments for the initialization.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 97](../../wordpress/wp-includes/ms-site.php#L97-L105)

### `wpmu_new_blog`

*Fires immediately after a new site is created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($new_site->id, $user_id, $new_site->domain, $new_site->path, $new_site->network_id, $meta)` |  | 
`'5.1.0'` |  | 
`'wp_insert_site'` |  | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 122](../../wordpress/wp-includes/ms-site.php#L122-L140)

### `wp_update_site`

*Fires once a site has been updated in the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_site` | `\WP_Site` | New site object.
`$old_site` | `\WP_Site` | Old site object.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 187](../../wordpress/wp-includes/ms-site.php#L187-L195)

### `wp_validate_site_deletion`

*Fires before a site should be deleted from the database.*

Plugins should amend the `$errors` object via its `WP_Error::add()` method. If any errors
are present, the site will not be deleted.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | Error object to add validation errors to.
`$old_site` | `\WP_Site` | The site object to be deleted.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 224](../../wordpress/wp-includes/ms-site.php#L224-L235)

### `delete_blog`

*Fires before a site is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($old_site->id, true)` |  | 
`'5.1.0'` |  | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 241](../../wordpress/wp-includes/ms-site.php#L241-L250)

### `wp_uninitialize_site`

*Fires when a site's uninitialization routine should be executed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$old_site` | `\WP_Site` | Deleted site object.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 252](../../wordpress/wp-includes/ms-site.php#L252-L259)

### `wp_delete_site`

*Fires once a site has been deleted from the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$old_site` | `\WP_Site` | Deleted site object.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 274](../../wordpress/wp-includes/ms-site.php#L274-L281)

### `deleted_blog`

*Fires after the site is deleted from the network.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($old_site->id, true)` |  | 
`'5.1.0'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 283](../../wordpress/wp-includes/ms-site.php#L283-L292)

### `wp_validate_site_data`

*Fires when data should be validated for a site prior to inserting or updating in the database.*

Plugins should amend the `$errors` object via its `WP_Error::add()` method.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | Error object to add validation errors to.
`$data` | `array` | Associative array of complete site data. See {@see \wp_insert_site()}<br>for the included data.
`$old_site` | `\WP_Site\|null` | The old site object if the data belongs to a site being updated,<br>or null if it is a new site being inserted.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 505](../../wordpress/wp-includes/ms-site.php#L505-L518)

### `clean_site_cache`

*Fires immediately after a site has been removed from the object cache.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$blog_id` |  | 
`$blog` | `\WP_Site` | Site object.
`$domain_path_key` | `string` | md5 hash of domain and path.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1018](../../wordpress/wp-includes/ms-site.php#L1018-L1027)

### `refresh_blog_details`

*Fires after the blog details cache is cleared.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($blog_id)` |  | 
`'4.9.0'` |  | 
`'clean_site_cache'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1031](../../wordpress/wp-includes/ms-site.php#L1031-L1039)

### `make_spam_blog`

*Fires when the 'spam' status is added to a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1173](../../wordpress/wp-includes/ms-site.php#L1173-L1180)

### `make_ham_blog`

*Fires when the 'spam' status is removed from a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1183](../../wordpress/wp-includes/ms-site.php#L1183-L1190)

### `mature_blog`

*Fires when the 'mature' status is added to a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1197](../../wordpress/wp-includes/ms-site.php#L1197-L1204)

### `unmature_blog`

*Fires when the 'mature' status is removed from a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1207](../../wordpress/wp-includes/ms-site.php#L1207-L1214)

### `archive_blog`

*Fires when the 'archived' status is added to a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1221](../../wordpress/wp-includes/ms-site.php#L1221-L1228)

### `unarchive_blog`

*Fires when the 'archived' status is removed from a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1231](../../wordpress/wp-includes/ms-site.php#L1231-L1238)

### `make_delete_blog`

*Fires when the 'deleted' status is added to a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1245](../../wordpress/wp-includes/ms-site.php#L1245-L1252)

### `make_undelete_blog`

*Fires when the 'deleted' status is removed from a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1255](../../wordpress/wp-includes/ms-site.php#L1255-L1262)

### `update_blog_public`

*Fires after the current blog's 'public' setting is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` | `int` | Site ID.
`$new_site->public` |  | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 1268](../../wordpress/wp-includes/ms-site.php#L1268-L1276)

### `wpmu_blog_updated`

*Fires after the blog details are updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_id` |  | 

Source: [wordpress/wp-includes/ms-blogs.php](../../wordpress/wp-includes/ms-blogs.php), [line 23](../../wordpress/wp-includes/ms-blogs.php#L23-L30)

### `switch_blog`

*Fires when the blog is switched.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_blog_id` | `int` | New blog ID.
`$prev_blog_id` | `int` | Previous blog ID.
`'switch'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.4.0` | The `$context` parameter was added.

Source: [wordpress/wp-includes/ms-blogs.php](../../wordpress/wp-includes/ms-blogs.php), [line 516](../../wordpress/wp-includes/ms-blogs.php#L516-L527)

### `switch_blog`

*This filter is documented in wp-includes/ms-blogs.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_blog_id` |  | 
`$prev_blog_id` |  | 
`'switch'` |  | 

Source: [wordpress/wp-includes/ms-blogs.php](../../wordpress/wp-includes/ms-blogs.php), [line 562](../../wordpress/wp-includes/ms-blogs.php#L562-L563)

### `switch_blog`

*This filter is documented in wp-includes/ms-blogs.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_blog_id` |  | 
`$prev_blog_id` |  | 
`'restore'` |  | 

Source: [wordpress/wp-includes/ms-blogs.php](../../wordpress/wp-includes/ms-blogs.php), [line 596](../../wordpress/wp-includes/ms-blogs.php#L596-L597)

### `switch_blog`

*This filter is documented in wp-includes/ms-blogs.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_blog_id` |  | 
`$prev_blog_id` |  | 
`'restore'` |  | 

Source: [wordpress/wp-includes/ms-blogs.php](../../wordpress/wp-includes/ms-blogs.php), [line 633](../../wordpress/wp-includes/ms-blogs.php#L633-L634)

### `rss_tag_pre`

*This action is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'atom-comments'` |  | 

Source: [wordpress/wp-includes/feed-atom-comments.php](../../wordpress/wp-includes/feed-atom-comments.php), [line 11](../../wordpress/wp-includes/feed-atom-comments.php#L11-L12)

### `atom_ns`

*This action is documented in wp-includes/feed-atom.php*


Source: [wordpress/wp-includes/feed-atom-comments.php](../../wordpress/wp-includes/feed-atom-comments.php), [line 19](../../wordpress/wp-includes/feed-atom-comments.php#L19-L20)

### `atom_comments_ns`

*Fires inside the feed tag in the Atom comment feed.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/feed-atom-comments.php](../../wordpress/wp-includes/feed-atom-comments.php), [line 22](../../wordpress/wp-includes/feed-atom-comments.php#L22-L27)

### `comments_atom_head`

*Fires at the end of the Atom comment feed header.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/feed-atom-comments.php](../../wordpress/wp-includes/feed-atom-comments.php), [line 62](../../wordpress/wp-includes/feed-atom-comments.php#L62-L67)

### `comment_atom_entry`

*Fires at the end of each Atom comment feed item.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment_post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/feed-atom-comments.php](../../wordpress/wp-includes/feed-atom-comments.php), [line 129](../../wordpress/wp-includes/feed-atom-comments.php#L129-L137)

### `embed_content`

*Prints additional content after the embed excerpt.*


**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/theme-compat/embed-content.php](../../wordpress/wp-includes/theme-compat/embed-content.php), [line 104](../../wordpress/wp-includes/theme-compat/embed-content.php#L104-L109)

### `embed_content_meta`

*Prints additional meta content in the embed template.*


**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/theme-compat/embed-content.php](../../wordpress/wp-includes/theme-compat/embed-content.php), [line 117](../../wordpress/wp-includes/theme-compat/embed-content.php#L117-L122)

### `embed_footer`

*Prints scripts or data before the closing body tag in the embed template.*


**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/theme-compat/footer-embed.php](../../wordpress/wp-includes/theme-compat/footer-embed.php), [line 13](../../wordpress/wp-includes/theme-compat/footer-embed.php#L13-L18)

### `embed_head`

*Prints scripts or data in the embed template head tag.*


**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/theme-compat/header-embed.php](../../wordpress/wp-includes/theme-compat/header-embed.php), [line 24](../../wordpress/wp-includes/theme-compat/header-embed.php#L24-L29)

### `embed_content`

*This filter is documented in wp-includes/theme-compat/embed-content.php*


Source: [wordpress/wp-includes/theme-compat/embed-404.php](../../wordpress/wp-includes/theme-compat/embed-404.php), [line 29](../../wordpress/wp-includes/theme-compat/embed-404.php#L29-L30)

### `make_spam_user`

*This filter is documented in wp-includes/user.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` |  | 

Source: [wordpress/wp-includes/ms-deprecated.php](../../wordpress/wp-includes/ms-deprecated.php), [line 723](../../wordpress/wp-includes/ms-deprecated.php#L723-L724)

### `make_ham_user`

*This filter is documented in wp-includes/user.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` |  | 

Source: [wordpress/wp-includes/ms-deprecated.php](../../wordpress/wp-includes/ms-deprecated.php), [line 726](../../wordpress/wp-includes/ms-deprecated.php#L726-L727)

### `wp_print_scripts`

*Fires before scripts in the $handles queue are printed.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/functions.wp-scripts.php](../../wordpress/wp-includes/functions.wp-scripts.php), [line 90](../../wordpress/wp-includes/functions.wp-scripts.php#L90-L95)

### `clean_network_cache`

*Fires immediately after a network has been removed from the object cache.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | Network ID.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/ms-network.php](../../wordpress/wp-includes/ms-network.php), [line 88](../../wordpress/wp-includes/ms-network.php#L88-L95)

### `grant_super_admin`

*Fires before the user is granted Super Admin privileges.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user that is about to be granted Super Admin privileges.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 943](../../wordpress/wp-includes/capabilities.php#L943-L950)

### `granted_super_admin`

*Fires after the user is granted Super Admin privileges.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user that was granted Super Admin privileges.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 960](../../wordpress/wp-includes/capabilities.php#L960-L967)

### `revoke_super_admin`

*Fires before the user's Super Admin privileges are revoked.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user Super Admin privileges are being revoked from.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 990](../../wordpress/wp-includes/capabilities.php#L990-L997)

### `revoked_super_admin`

*Fires after the user's Super Admin privileges are revoked.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user Super Admin privileges were revoked from.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 1009](../../wordpress/wp-includes/capabilities.php#L1009-L1016)

### `rss_tag_pre`

*This action is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'rss2-comments'` |  | 

Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 12](../../wordpress/wp-includes/feed-rss2-comments.php#L12-L13)

### `rss2_ns`

*This action is documented in wp-includes/feed-rss2.php*


Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 21](../../wordpress/wp-includes/feed-rss2-comments.php#L21-L22)

### `rss2_comments_ns`

*Fires at the end of the RSS root to add namespaces.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 26](../../wordpress/wp-includes/feed-rss2-comments.php#L26-L31)

### `commentsrss2_head`

*Fires at the end of the RSS2 comment feed header.*


**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 66](../../wordpress/wp-includes/feed-rss2-comments.php#L66-L71)

### `commentrss2_item`

*Fires at the end of each RSS2 comment feed item.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment_post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 108](../../wordpress/wp-includes/feed-rss2-comments.php#L108-L116)

### `ms_network_not_found`

*Fires when a network cannot be found based on the requested domain and path.*

At the time of this action, the only recourse is to redirect somewhere
and exit. If you want to declare a particular network, do so earlier.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$domain` | `string` | The domain used to search for a network.
`$path` | `string` | The path used to search for a path.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/ms-load.php](../../wordpress/wp-includes/ms-load.php), [line 344](../../wordpress/wp-includes/ms-load.php#L344-L355)

### `ms_network_not_found`

*This action is documented in wp-includes/ms-settings.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$domain` |  | 
`$path` |  | 

Source: [wordpress/wp-includes/ms-load.php](../../wordpress/wp-includes/ms-load.php), [line 382](../../wordpress/wp-includes/ms-load.php#L382-L383)

### `ms_site_not_found`

*Fires when a network can be determined but a site cannot.*

At the time of this action, the only recourse is to redirect somewhere
and exit. If you want to declare a particular site, do so earlier.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$current_site` | `\WP_Network` | The network that had been determined.
`$domain` | `string` | The domain used to search for a site.
`$path` | `string` | The path used to search for a site.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/ms-load.php](../../wordpress/wp-includes/ms-load.php), [line 402](../../wordpress/wp-includes/ms-load.php#L402-L414)

### `wp_create_application_password`

*Fires when an application password is created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | The user ID.
`$new_item` | `array` | The details about the created password.
`$new_password` | `string` | The unhashed generated app password.
`$args` | `array` | Information used to create the application password.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/class-wp-application-passwords.php](../../wordpress/wp-includes/class-wp-application-passwords.php), [line 107](../../wordpress/wp-includes/class-wp-application-passwords.php#L107-L117)

### `wp_update_application_password`

*Fires when an application password is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | The user ID.
`$item` | `array` | The updated app password details.
`$update` | `array` | The information to update.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/class-wp-application-passwords.php](../../wordpress/wp-includes/class-wp-application-passwords.php), [line 232](../../wordpress/wp-includes/class-wp-application-passwords.php#L232-L241)

### `wp_delete_application_password`

*Fires when an application password is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | The user ID.
`$item` | `array` | The data about the application password.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/class-wp-application-passwords.php](../../wordpress/wp-includes/class-wp-application-passwords.php), [line 308](../../wordpress/wp-includes/class-wp-application-passwords.php#L308-L316)

### `wp_delete_application_password`

*This action is documented in wp-includes/class-wp-application-passwords.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` |  | 
`$item` |  | 

Source: [wordpress/wp-includes/class-wp-application-passwords.php](../../wordpress/wp-includes/class-wp-application-passwords.php), [line 344](../../wordpress/wp-includes/class-wp-application-passwords.php#L344-L345)

### `rss_head`

*Fires at the end of the RSS Feed Header.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rss.php](../../wordpress/wp-includes/feed-rss.php), [line 21](../../wordpress/wp-includes/feed-rss.php#L21-L26)

### `rss_item`

*Fires at the end of each RSS feed item.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rss.php](../../wordpress/wp-includes/feed-rss.php), [line 38](../../wordpress/wp-includes/feed-rss.php#L38-L43)

### `admin_bar_init`

*Fires after WP_Admin_Bar is initialized.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-admin-bar.php](../../wordpress/wp-includes/class-wp-admin-bar.php), [line 76](../../wordpress/wp-includes/class-wp-admin-bar.php#L76-L81)

### `add_admin_bar_menus`

*Fires after menus are added to the menu bar.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-admin-bar.php](../../wordpress/wp-includes/class-wp-admin-bar.php), [line 624](../../wordpress/wp-includes/class-wp-admin-bar.php#L624-L629)

### `template_redirect`

*Fires before determining which template to load.*


**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/template-loader.php](../../wordpress/wp-includes/template-loader.php), [line 8](../../wordpress/wp-includes/template-loader.php#L8-L13)

### `do_robots`

*Fired when the template loader determines a robots.txt request.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/template-loader.php](../../wordpress/wp-includes/template-loader.php), [line 32](../../wordpress/wp-includes/template-loader.php#L32-L37)

### `do_favicon`

*Fired when the template loader determines a favicon.ico request.*


**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/template-loader.php](../../wordpress/wp-includes/template-loader.php), [line 40](../../wordpress/wp-includes/template-loader.php#L40-L45)

### `generate_recovery_mode_key`

*Fires when a recovery mode key is generated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$token` | `string` | The recovery data token.
`$key` | `string` | The recovery mode key.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode-key-service.php](../../wordpress/wp-includes/class-wp-recovery-mode-key-service.php), [line 67](../../wordpress/wp-includes/class-wp-recovery-mode-key-service.php#L67-L75)

### `enqueue_embed_scripts`

*Fires when scripts and styles are enqueued for the embed iframe.*


**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 1022](../../wordpress/wp-includes/embed.php#L1022-L1027)

### `wp_error_added`

*Fires when an error is added to a WP_Error object.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$code` | `string\|int` | Error code.
`$message` | `string` | Error message.
`$data` | `mixed` | Error data. Might be empty.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/class-wp-error.php](../../wordpress/wp-includes/class-wp-error.php), [line 196](../../wordpress/wp-includes/class-wp-error.php#L196-L206)

### `customize_render_section`

*Fires before rendering a Customizer section.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Section` | WP_Customize_Section instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-section.php](../../wordpress/wp-includes/class-wp-customize-section.php), [line 296](../../wordpress/wp-includes/class-wp-customize-section.php#L296-L303)

### `customize_render_section_{$this->id}`

*Fires before rendering a specific Customizer section.*

The dynamic portion of the hook name, `$this->id`, refers to the ID
of the specific Customizer section to be rendered.


**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-section.php](../../wordpress/wp-includes/class-wp-customize-section.php), [line 304](../../wordpress/wp-includes/class-wp-customize-section.php#L304-L312)

### `admin_bar_menu`

*Load all necessary admin bar items.*

This is the hook used to add, remove, or manipulate admin bar items.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$wp_admin_bar)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/admin-bar.php](../../wordpress/wp-includes/admin-bar.php), [line 86](../../wordpress/wp-includes/admin-bar.php#L86-L95)

### `wp_before_admin_bar_render`

*Fires before the admin bar is rendered.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/admin-bar.php](../../wordpress/wp-includes/admin-bar.php), [line 97](../../wordpress/wp-includes/admin-bar.php#L97-L102)

### `wp_after_admin_bar_render`

*Fires after the admin bar is rendered.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/admin-bar.php](../../wordpress/wp-includes/admin-bar.php), [line 106](../../wordpress/wp-includes/admin-bar.php#L106-L111)

### `customize_render_control`

*Fires just before the current Customizer control is rendered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Control` | WP_Customize_Control instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-control.php](../../wordpress/wp-includes/class-wp-customize-control.php), [line 395](../../wordpress/wp-includes/class-wp-customize-control.php#L395-L402)

### `customize_render_control_{$this->id}`

*Fires just before a specific Customizer control is rendered.*

The dynamic portion of the hook name, `$this->id`, refers to
the control ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Control` | WP_Customize_Control instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-control.php](../../wordpress/wp-includes/class-wp-customize-control.php), [line 404](../../wordpress/wp-includes/class-wp-customize-control.php#L404-L414)

### `wp_sitemaps_init`

*Fires when initializing the Sitemaps object.*

Additional sitemaps should be registered on this hook.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_sitemaps` | `\WP_Sitemaps` | Sitemaps object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps.php](../../wordpress/wp-includes/sitemaps.php), [line 30](../../wordpress/wp-includes/sitemaps.php#L30-L39)

### `comment_duplicate_trigger`

*Fires immediately after a duplicate comment is detected.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata` | `array` | Comment data.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 712](../../wordpress/wp-includes/comment.php#L712-L719)

### `check_comment_flood`

*Fires immediately before a comment is marked approved.*

Allows checking for comment flooding.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['comment_author_IP']` |  | 
`$commentdata['comment_author_email']` |  | 
`$commentdata['comment_date_gmt']` |  | 
`$wp_error` | `bool` | Whether to return a WP_Error object instead of executing<br>wp_die() or die() if a comment flood is occurring.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$avoid_die` parameter was renamed to `$wp_error`.
`4.7.0` | The `$avoid_die` parameter was added.
`2.3.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 741](../../wordpress/wp-includes/comment.php#L741-L762)

### `comment_flood_trigger`

*Fires before the comment flood message is triggered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$time_lastcomment` | `int` | Timestamp of when the last comment was posted.
`$time_newcomment` | `int` | Timestamp of when the new comment was posted.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 931](../../wordpress/wp-includes/comment.php#L931-L939)

### `wp_blacklist_check`

*Fires before the comment is tested for disallowed characters or words.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($author, $email, $url, $comment, $user_ip, $user_agent)` |  | 
`'5.5.0'` |  | 
`'wp_check_comment_disallowed_list'` |  | 
`__('Please consider writing more inclusive code.')` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1326](../../wordpress/wp-includes/comment.php#L1326-L1345)

### `wp_check_comment_disallowed_list`

*Fires before the comment is tested for disallowed characters or words.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$author` | `string` | Comment author.
`$email` | `string` | Comment author's email.
`$url` | `string` | Comment author's URL.
`$comment` | `string` | Comment content.
`$user_ip` | `string` | Comment author's IP address.
`$user_agent` | `string` | Comment author's browser user agent.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1347](../../wordpress/wp-includes/comment.php#L1347-L1359)

### `delete_comment`

*Fires immediately before a comment is deleted from the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment to be deleted.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`1.2.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1480](../../wordpress/wp-includes/comment.php#L1480-L1489)

### `deleted_comment`

*Fires immediately after a comment is deleted from the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The deleted comment.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1508](../../wordpress/wp-includes/comment.php#L1508-L1517)

### `wp_set_comment_status`

*This action is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`'delete'` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1526](../../wordpress/wp-includes/comment.php#L1526-L1527)

### `trash_comment`

*Fires immediately before a comment is sent to the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment to be trashed.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1554](../../wordpress/wp-includes/comment.php#L1554-L1563)

### `trashed_comment`

*Fires immediately after a comment is sent to Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The trashed comment.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1571](../../wordpress/wp-includes/comment.php#L1571-L1580)

### `untrash_comment`

*Fires immediately before a comment is restored from the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment to be untrashed.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1602](../../wordpress/wp-includes/comment.php#L1602-L1611)

### `untrashed_comment`

*Fires immediately after a comment is restored from the Trash.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The untrashed comment.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1622](../../wordpress/wp-includes/comment.php#L1622-L1631)

### `spam_comment`

*Fires immediately before a comment is marked as Spam.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment to be marked as spam.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1653](../../wordpress/wp-includes/comment.php#L1653-L1662)

### `spammed_comment`

*Fires immediately after a comment is marked as Spam.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment marked as spam.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1670](../../wordpress/wp-includes/comment.php#L1670-L1679)

### `unspam_comment`

*Fires immediately before a comment is unmarked as Spam.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment to be unmarked as spam.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1701](../../wordpress/wp-includes/comment.php#L1701-L1710)

### `unspammed_comment`

*Fires immediately after a comment is unmarked as Spam.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment unmarked as spam.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$comment` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1721](../../wordpress/wp-includes/comment.php#L1721-L1730)

### `transition_comment_status`

*Fires when the comment status is in transition.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_status` | `int\|string` | The new comment status.
`$old_status` | `int\|string` | The old comment status.
`$comment` | `\WP_Comment` | Comment object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1808](../../wordpress/wp-includes/comment.php#L1808-L1817)

### `comment_{$old_status}_to_{$new_status}`

*Fires when the comment status is in transition from one specific status to another.*

The dynamic portions of the hook name, `$old_status`, and `$new_status`,
refer to the old and new comment statuses, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` | `\WP_Comment` | Comment object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1818](../../wordpress/wp-includes/comment.php#L1818-L1828)

### `comment_{$new_status}_{$comment->comment_type}`

*Fires when the status of a specific comment type is in transition.*

The dynamic portions of the hook name, `$new_status`, and `$comment->comment_type`,
refer to the new comment status, and the type of comment, respectively.

Typical comment types include an empty string (standard comment), 'pingback',
or 'trackback'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | Comment object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1830](../../wordpress/wp-includes/comment.php#L1830-L1844)

### `wp_insert_comment`

*Fires immediately after a comment is inserted into the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | The comment ID.
`$comment` | `\WP_Comment` | Comment object.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2039](../../wordpress/wp-includes/comment.php#L2039-L2047)

### `comment_post`

*Fires immediately after a comment is inserted into the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_ID` | `int` | The comment ID.
`$commentdata['comment_approved']` |  | 
`$commentdata` | `array` | Comment data.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | The `$commentdata` parameter was added.
`1.2.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2271](../../wordpress/wp-includes/comment.php#L2271-L2281)

### `wp_set_comment_status`

*Fires immediately after transitioning a comment's status from one to another in the database
and removing the comment from the object cache, but prior to all status transition hooks.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment_status` | `string` | Current comment status. Possible values include<br>'hold', '0', 'approve', '1', 'spam', and 'trash'.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2405](../../wordpress/wp-includes/comment.php#L2405-L2415)

### `edit_comment`

*Fires immediately after a comment is updated in the database.*

The hook also fires immediately before comment status transition hooks are fired.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_ID` | `int` | The comment ID.
`$data` | `array` | Comment data.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Added the `$data` parameter.
`1.2.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2546](../../wordpress/wp-includes/comment.php#L2546-L2557)

### `wp_update_comment_count`

*Fires immediately after a post's comment count is updated in the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$new` | `int` | The new comment count.
`$old` | `int` | The old comment count.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2687](../../wordpress/wp-includes/comment.php#L2687-L2696)

### `edit_post_{$post->post_type}`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2698](../../wordpress/wp-includes/comment.php#L2698-L2699)

### `edit_post`

*This action is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2701](../../wordpress/wp-includes/comment.php#L2701-L2702)

### `do_all_pings`

*Fires immediately after the `do_pings` event to hook services individually.*


**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2808](../../wordpress/wp-includes/comment.php#L2808-L2813)

### `pre_ping`

*Fires just before pinging back links found in a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$post_links, &$pung, $post->ID)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3025](../../wordpress/wp-includes/comment.php#L3025-L3034)

### `clean_comment_cache`

*Fires immediately after a comment has been removed from the object cache.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | Comment ID.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3201](../../wordpress/wp-includes/comment.php#L3201-L3208)

### `comment_id_not_found`

*Fires when a comment is attempted on a post that does not exist.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3407](../../wordpress/wp-includes/comment.php#L3407-L3414)

### `comment_closed`

*Fires when a comment is attempted on a post that has comments closed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3431](../../wordpress/wp-includes/comment.php#L3431-L3438)

### `comment_on_trash`

*Fires when a comment is attempted on a trashed post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3444](../../wordpress/wp-includes/comment.php#L3444-L3451)

### `comment_on_draft`

*Fires when a comment is attempted on a post in draft mode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3457](../../wordpress/wp-includes/comment.php#L3457-L3464)

### `comment_on_password_protected`

*Fires when a comment is attempted on a password-protected post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3473](../../wordpress/wp-includes/comment.php#L3473-L3480)

### `pre_comment_on_post`

*Fires before a comment is posted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3486](../../wordpress/wp-includes/comment.php#L3486-L3493)

### `wp_delete_nav_menu`

*Fires after a navigation menu has been successfully deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu->term_id` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 291](../../wordpress/wp-includes/nav-menu.php#L291-L298)

### `wp_create_nav_menu`

*Fires after a navigation menu is successfully created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_menu['term_id']` |  | 
`$menu_data` | `array` | An array of menu data.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 367](../../wordpress/wp-includes/nav-menu.php#L367-L375)

### `wp_update_nav_menu`

*Fires after a navigation menu has been successfully updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_id` | `int` | ID of the updated menu.
`$menu_data` | `array` | An array of menu data.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 394](../../wordpress/wp-includes/nav-menu.php#L394-L402)

### `wp_add_nav_menu_item`

*Fires immediately after a new navigation menu item has been added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_id` | `int` | ID of the updated menu.
`$menu_item_db_id` | `int` | ID of the new menu item.
`$args` | `array` | An array of arguments used to update/add the menu item.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 534](../../wordpress/wp-includes/nav-menu.php#L534-L545)

### `wp_update_nav_menu_item`

*Fires after a navigation menu item has been updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_id` | `int` | ID of the updated menu.
`$menu_item_db_id` | `int` | ID of the updated menu item.
`$args` | `array` | An array of arguments used to update a menu item.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 586](../../wordpress/wp-includes/nav-menu.php#L586-L597)

### `upload_ui_over_quota`

*This action is documented in wp-admin/includes/media.php*


Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 247](../../wordpress/wp-includes/media-template.php#L247-L248)

### `pre-upload-ui`

*This action is documented in wp-admin/includes/media.php*


Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 262](../../wordpress/wp-includes/media-template.php#L262-L263)

### `pre-plupload-upload-ui`

*This action is documented in wp-admin/includes/media.php*


Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 264](../../wordpress/wp-includes/media-template.php#L264-L265)

### `post-plupload-upload-ui`

*This action is documented in wp-admin/includes/media.php*


Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 268](../../wordpress/wp-includes/media-template.php#L268-L269)

### `post-plupload-upload-ui`

*This action is documented in wp-admin/includes/media.php*


Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 272](../../wordpress/wp-includes/media-template.php#L272-L273)

### `post-upload-ui`

*This action is documented in wp-admin/includes/media.php*


Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 302](../../wordpress/wp-includes/media-template.php#L302-L303)

### `print_media_templates`

*Fires when the custom Backbone media templates are printed.*


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 1507](../../wordpress/wp-includes/media-template.php#L1507-L1512)

### `parse_network_query`

*Fires after the network query vars have been parsed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-network-query.php](../../wordpress/wp-includes/class-wp-network-query.php), [line 156](../../wordpress/wp-includes/class-wp-network-query.php#L156-L163)

### `pre_get_networks`

*Fires before networks are retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-network-query.php](../../wordpress/wp-includes/class-wp-network-query.php), [line 191](../../wordpress/wp-includes/class-wp-network-query.php#L191-L198)

### `in_widget_form`

*Fires at the end of the widget control form.*

Use this hook to add extra fields to the widget form. The hook
is only fired if the value passed to the 'widget_form_callback'
hook is not false.

Note: If the widget has no form, the text echoed from the default
form method can be hidden using CSS.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this, &$return, $instance)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-widget.php](../../wordpress/wp-includes/class-wp-widget.php), [line 521](../../wordpress/wp-includes/class-wp-widget.php#L521-L537)

### `set_current_user`

*Fires after the current user is set.*


**Changelog**

Version | Description
------- | -----------
`2.0.1` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 43](../../wordpress/wp-includes/pluggable.php#L43-L48)

### `wp_mail_failed`

*This filter is documented in wp-includes/pluggable.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`new WP_Error('wp_mail_failed', $e->getMessage(), $mail_error_data)` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 402](../../wordpress/wp-includes/pluggable.php#L402-L403)

### `phpmailer_init`

*Fires after PHPMailer is initialized.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$phpmailer)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 520](../../wordpress/wp-includes/pluggable.php#L520-L527)

### `wp_mail_failed`

*Fires after a PHPMailer\PHPMailer\Exception is caught.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`new WP_Error('wp_mail_failed', $e->getMessage(), $mail_error_data)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 537](../../wordpress/wp-includes/pluggable.php#L537-L545)

### `wp_login_failed`

*Fires after a user login has failed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$username` | `string` | Username or email address.
`$error` | `\WP_Error` | A WP_Error object with the authentication failure details.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | The `$error` parameter was added.
`4.5.0` | The value of `$username` can now be an email address.
`2.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 595](../../wordpress/wp-includes/pluggable.php#L595-L605)

### `wp_logout`

*Fires after a user is logged out.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | ID of the user that was logged out.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$user_id` parameter.
`1.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 625](../../wordpress/wp-includes/pluggable.php#L625-L633)

### `auth_cookie_malformed`

*Fires if an authentication cookie is malformed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cookie` | `string` | Malformed auth cookie.
`$scheme` | `string` | Authentication scheme. Values include 'auth', 'secure_auth',<br>or 'logged_in'.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 658](../../wordpress/wp-includes/pluggable.php#L658-L667)

### `auth_cookie_expired`

*Fires once an authentication cookie has expired.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cookie_elements` | `string[]` | An array of data for the authentication cookie.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 685](../../wordpress/wp-includes/pluggable.php#L685-L692)

### `auth_cookie_bad_username`

*Fires if a bad username is entered in the user authentication process.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cookie_elements` | `string[]` | An array of data for the authentication cookie.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 698](../../wordpress/wp-includes/pluggable.php#L698-L705)

### `auth_cookie_bad_hash`

*Fires if a bad authentication cookie hash is encountered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cookie_elements` | `string[]` | An array of data for the authentication cookie.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 718](../../wordpress/wp-includes/pluggable.php#L718-L725)

### `auth_cookie_bad_session_token`

*Fires if a bad session token is encountered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cookie_elements` | `string[]` | An array of data for the authentication cookie.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 731](../../wordpress/wp-includes/pluggable.php#L731-L738)

### `auth_cookie_valid`

*Fires once an authentication cookie has been validated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cookie_elements` | `string[]` | An array of data for the authentication cookie.
`$user` | `\WP_User` | User object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 747](../../wordpress/wp-includes/pluggable.php#L747-L755)

### `set_auth_cookie`

*Fires immediately before the authentication cookie is set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$auth_cookie` | `string` | Authentication cookie value.
`$expire` | `int` | The time the login grace period expires as a UNIX timestamp.<br>Default is 12 hours past the cookie's expiration time.
`$expiration` | `int` | The time when the authentication cookie expires as a UNIX timestamp.<br>Default is 14 days from now.
`$user_id` | `int` | User ID.
`$scheme` | `string` | Authentication scheme. Values include 'auth' or 'secure_auth'.
`$token` | `string` | User's session token to use for this cookie.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `$token` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 946](../../wordpress/wp-includes/pluggable.php#L946-L961)

### `set_logged_in_cookie`

*Fires immediately before the logged-in authentication cookie is set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$logged_in_cookie` | `string` | The logged-in cookie value.
`$expire` | `int` | The time the login grace period expires as a UNIX timestamp.<br>Default is 12 hours past the cookie's expiration time.
`$expiration` | `int` | The time when the logged-in authentication cookie expires as a UNIX timestamp.<br>Default is 14 days from now.
`$user_id` | `int` | User ID.
`'logged_in'` |  | 
`$token` | `string` | User's session token to use for this cookie.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `$token` parameter was added.
`2.6.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 963](../../wordpress/wp-includes/pluggable.php#L963-L978)

### `clear_auth_cookie`

*Fires just before the authentication cookies are cleared.*


**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1007](../../wordpress/wp-includes/pluggable.php#L1007-L1012)

### `auth_redirect`

*Fires before the authentication redirect.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int` | User ID.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1112](../../wordpress/wp-includes/pluggable.php#L1112-L1119)

### `check_admin_referer`

*Fires once the admin request has been validated or not.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$action` | `string` | The nonce action.
`$result` | `false\|int` | False if the nonce is invalid, 1 if the nonce is valid and generated between<br>0-12 hours ago, 2 if the nonce is valid and generated between 12-24 hours ago.

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1175](../../wordpress/wp-includes/pluggable.php#L1175-L1184)

### `check_ajax_referer`

*Fires once the Ajax request has been validated or not.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$action` | `string` | The Ajax nonce action.
`$result` | `false\|int` | False if the nonce is invalid, 1 if the nonce is valid and generated between<br>0-12 hours ago, 2 if the nonce is valid and generated between 12-24 hours ago.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1228](../../wordpress/wp-includes/pluggable.php#L1228-L1237)

### `wp_verify_nonce_failed`

*Fires when nonce verification fails.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nonce` | `string` | The invalid nonce.
`$action` | `string\|int` | The nonce action.
`$user` | `\WP_User` | The current user object.
`$token` | `string` | The user's session token.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2202](../../wordpress/wp-includes/pluggable.php#L2202-L2212)

### `metadata_lazyloader_queued_objects`

*Fires after objects are added to the metadata lazy-load queue.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_ids` | `array` | Array of object IDs.
`$object_type` | `string` | Type of object being queued.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/class-wp-metadata-lazyloader.php](../../wordpress/wp-includes/class-wp-metadata-lazyloader.php), [line 95](../../wordpress/wp-includes/class-wp-metadata-lazyloader.php#L95-L104)

### `http_api_curl`

*Fires before the cURL request is executed.*

Cookies are not currently handled by the HTTP API. This action allows
plugins to handle cookies themselves.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$handle, $parsed_args, $url)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-http-curl.php](../../wordpress/wp-includes/class-wp-http-curl.php), [line 218](../../wordpress/wp-includes/class-wp-http-curl.php#L218-L230)

### `parse_query`

*Fires after the main query vars have been parsed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 1076](../../wordpress/wp-includes/class-wp-query.php#L1076-L1083)

### `parse_tax_query`

*Fires after taxonomy-related query vars have been parsed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 1317](../../wordpress/wp-includes/class-wp-query.php#L1317-L1324)

### `set_404`

*Fires after a 404 is triggered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 1716](../../wordpress/wp-includes/class-wp-query.php#L1716-L1723)

### `pre_get_posts`

*Fires after the query variable object is created, but before the actual query is run.*

Note: If using conditional tags, use the method versions within the passed instance
(e.g. $this->is_main_query() instead of is_main_query()). This is because the functions
like is_main_query() test against the global $wp_query instance, not the passed one.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 1773](../../wordpress/wp-includes/class-wp-query.php#L1773-L1784)

### `posts_selection`

*Fires to announce the query's current selection parameters.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$where . $groupby . $orderby . $limits . $join` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2790](../../wordpress/wp-includes/class-wp-query.php#L2790-L2799)

### `loop_start`

*Fires once the loop is started.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3319](../../wordpress/wp-includes/class-wp-query.php#L3319-L3326)

### `loop_end`

*Fires once the loop has ended.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3346](../../wordpress/wp-includes/class-wp-query.php#L3346-L3353)

### `loop_no_results`

*Fires if no results are found in a post query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3357](../../wordpress/wp-includes/class-wp-query.php#L3357-L3364)

### `comment_loop_start`

*Fires once the comment loop is started.*


**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3411](../../wordpress/wp-includes/class-wp-query.php#L3411-L3416)

### `the_post`

*Fires once the post data has been set up.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$post, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | Introduced `$query` parameter.
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 4313](../../wordpress/wp-includes/class-wp-query.php#L4313-L4322)

### `load_textdomain`

*Fires before the MO translation file is loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.
`$mofile` | `string` | Path to the .mo file.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 721](../../wordpress/wp-includes/l10n.php#L721-L729)

### `unload_textdomain`

*Fires before the text domain is unloaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 793](../../wordpress/wp-includes/l10n.php#L793-L800)

### `wp_default_styles`

*Fires when the WP_Styles instance is initialized.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/class.wp-styles.php](../../wordpress/wp-includes/class.wp-styles.php), [line 128](../../wordpress/wp-includes/class.wp-styles.php#L128-L135)

### `wp_playlist_scripts`

*Prints and enqueues playlist scripts, styles, and JavaScript templates.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$atts['type']` |  | 
`$atts['style']` |  | 

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2782](../../wordpress/wp-includes/media.php#L2782-L2790)

### `wp_enqueue_media`

*Fires at the conclusion of wp_enqueue_media().*


**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4526](../../wordpress/wp-includes/media.php#L4526-L4531)

### `load-widgets.php`

*This action is documented in wp-admin/includes/ajax-actions.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 333](../../wordpress/wp-includes/class-wp-customize-widgets.php#L333-L334)

### `widgets.php`

*This action is documented in wp-admin/includes/ajax-actions.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 336](../../wordpress/wp-includes/class-wp-customize-widgets.php#L336-L337)

### `sidebar_admin_setup`

*This action is documented in wp-admin/widgets.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 339](../../wordpress/wp-includes/class-wp-customize-widgets.php#L339-L340)

### `admin_print_styles-widgets.php`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 643](../../wordpress/wp-includes/class-wp-customize-widgets.php#L643-L644)

### `admin_print_styles`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 646](../../wordpress/wp-includes/class-wp-customize-widgets.php#L646-L647)

### `admin_print_scripts-widgets.php`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 657](../../wordpress/wp-includes/class-wp-customize-widgets.php#L657-L658)

### `admin_print_scripts`

*This action is documented in wp-admin/admin-header.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 660](../../wordpress/wp-includes/class-wp-customize-widgets.php#L660-L661)

### `admin_enqueue_scripts`

*This action is documented in wp-admin/admin-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'widgets.php'` |  | 

Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 679](../../wordpress/wp-includes/class-wp-customize-widgets.php#L679-L680)

### `admin_print_footer_scripts-widgets.php`

*This action is documented in wp-admin/admin-footer.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 860](../../wordpress/wp-includes/class-wp-customize-widgets.php#L860-L861)

### `admin_print_footer_scripts`

*This action is documented in wp-admin/admin-footer.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 863](../../wordpress/wp-includes/class-wp-customize-widgets.php#L863-L864)

### `admin_footer-widgets.php`

*This action is documented in wp-admin/admin-footer.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 866](../../wordpress/wp-includes/class-wp-customize-widgets.php#L866-L867)

### `load-widgets.php`

*This action is documented in wp-admin/includes/ajax-actions.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 1544](../../wordpress/wp-includes/class-wp-customize-widgets.php#L1544-L1545)

### `widgets.php`

*This action is documented in wp-admin/includes/ajax-actions.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 1547](../../wordpress/wp-includes/class-wp-customize-widgets.php#L1547-L1548)

### `sidebar_admin_setup`

*This action is documented in wp-admin/widgets.php*


Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 1550](../../wordpress/wp-includes/class-wp-customize-widgets.php#L1550-L1551)

### `rss_tag_pre`

*Fires between the xml and rss tags in a feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'rss2'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/feed-rss2.php](../../wordpress/wp-includes/feed-rss2.php), [line 13](../../wordpress/wp-includes/feed-rss2.php#L13-L21)

### `rss2_ns`

*Fires at the end of the RSS root to add namespaces.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rss2.php](../../wordpress/wp-includes/feed-rss2.php), [line 31](../../wordpress/wp-includes/feed-rss2.php#L31-L36)

### `rss2_head`

*Fires at the end of the RSS2 Feed Header.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rss2.php](../../wordpress/wp-includes/feed-rss2.php), [line 78](../../wordpress/wp-includes/feed-rss2.php#L78-L83)

### `rss2_item`

*Fires at the end of each RSS2 feed item.*


**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/feed-rss2.php](../../wordpress/wp-includes/feed-rss2.php), [line 120](../../wordpress/wp-includes/feed-rss2.php#L120-L125)

### `add_user_role`

*Fires immediately after the user has been given a new role.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->ID` |  | 
`$role` | `string` | The new role.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/class-wp-user.php](../../wordpress/wp-includes/class-wp-user.php), [line 546](../../wordpress/wp-includes/class-wp-user.php#L546-L554)

### `remove_user_role`

*Fires immediately after a role as been removed from a user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->ID` |  | 
`$role` | `string` | The removed role.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/class-wp-user.php](../../wordpress/wp-includes/class-wp-user.php), [line 573](../../wordpress/wp-includes/class-wp-user.php#L573-L581)

### `set_user_role`

*Fires after the user's role has changed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->ID` |  | 
`$role` | `string` | The new role.
`$old_roles` | `string[]` | An array of the user's previous roles.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | Added $old_roles to include an array of the user's previous roles.
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-user.php](../../wordpress/wp-includes/class-wp-user.php), [line 615](../../wordpress/wp-includes/class-wp-user.php#L615-L625)

### `ms_loaded`

*Fires after the current site and network have been detected and loaded
in multisite's bootstrap.*


**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/ms-settings.php](../../wordpress/wp-includes/ms-settings.php), [line 117](../../wordpress/wp-includes/ms-settings.php#L117-L123)

### `wp_print_styles`

*Fires before styles in the $handles queue are printed.*


**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/functions.wp-styles.php](../../wordpress/wp-includes/functions.wp-styles.php), [line 52](../../wordpress/wp-includes/functions.wp-styles.php#L52-L57)

### `rest_insert_{$this->post_type}`

*Fires after a single post is created or updated via the REST API.*

The dynamic portion of the hook name, `$this->post_type`, refers to the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Inserted or updated post object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 608](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L608-L619)

### `rest_after_insert_{$this->post_type}`

*Fires after a single post is completely created or updated via the REST API.*

The dynamic portion of the hook name, `$this->post_type`, refers to the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | Inserted or updated post object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 666](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L666-L677)

### `rest_insert_{$this->post_type}`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 776](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L776-L777)

### `rest_after_insert_{$this->post_type}`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 830](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L830-L831)

### `rest_delete_{$this->post_type}`

*Fires immediately after a single post is deleted or trashed via the REST API.*

They dynamic portion of the hook name, `$this->post_type`, refers to the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `\WP_Post` | The deleted or trashed post.
`$response` | `\WP_REST_Response` | The response data.
`$request` | `\WP_REST_Request` | The request sent to the API.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 958](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L958-L969)

### `rest_after_insert_application_password`

*Fires after a single application password is completely created or updated via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$item` | `array` | Inserted or updated password item.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php), [line 264](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php#L264-L273)

### `rest_after_insert_application_password`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$item` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php), [line 351](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php#L351-L352)

### `rest_after_insert_attachment`

*Fires after a single attachment is completely created or updated via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attachment` | `\WP_Post` | Inserted or updated attachment object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 183](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L183-L192)

### `rest_insert_attachment`

*Fires after a single attachment is created or updated via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attachment` | `\WP_Post` | Inserted or updated attachment<br>object.
`$request` | `\WP_REST_Request` | The request sent to the API.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 289](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L289-L299)

### `rest_after_insert_attachment`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attachment` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 348](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L348-L349)

### `rest_delete_revision`

*Fires after a revision is deleted via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `\WP_Post\|false\|null` | The revision object (if it was deleted or moved to the Trash successfully)<br>or false or null (failure). If the revision was moved to the Trash, $result represents<br>its new state; if it was deleted, $result represents its state before deletion.
`$request` | `\WP_REST_Request` | The request sent to the API.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php), [line 469](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php#L469-L479)

### `rest_insert_user`

*Fires immediately after a user is created or updated via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | Inserted or updated user object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 593](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L593-L602)

### `rest_after_insert_user`

*Fires after a user is completely created or updated via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | Inserted or updated user object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 625](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L625-L634)

### `rest_insert_user`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 759](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L759-L760)

### `rest_after_insert_user`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 785](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L785-L786)

### `rest_delete_user`

*Fires immediately after a user is deleted via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | The user data.
`$response` | `\WP_REST_Response` | The response returned from the API.
`$request` | `\WP_REST_Request` | The request sent to the API.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 920](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L920-L929)

### `rest_insert_{$this->taxonomy}`

*Fires after a single term is created or updated via the REST API.*

The dynamic portion of the hook name, `$this->taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` | `\WP_Term` | Inserted or updated term object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 473](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L473-L484)

### `rest_after_insert_{$this->taxonomy}`

*Fires after a single term is completely created or updated via the REST API.*

The dynamic portion of the hook name, `$this->taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` | `\WP_Term` | Inserted or updated term object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 503](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L503-L514)

### `rest_insert_{$this->taxonomy}`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 598](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L598-L599)

### `rest_after_insert_{$this->taxonomy}`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 618](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L618-L619)

### `rest_delete_{$this->taxonomy}`

*Fires after a single term is deleted via the REST API.*

The dynamic portion of the hook name, `$this->taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` | `\WP_Term` | The deleted term.
`$response` | `\WP_REST_Response` | The response data.
`$request` | `\WP_REST_Request` | The request sent to the API.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 700](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L700-L711)

### `rest_insert_comment`

*Fires after a comment is created or updated via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` | `\WP_Comment` | Inserted or updated comment object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 715](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L715-L725)

### `rest_after_insert_comment`

*Fires completely after a comment is created or updated via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` | `\WP_Comment` | Inserted or updated comment object.
`$request` | `\WP_REST_Request` | Request object.
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 746](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L746-L756)

### `rest_insert_comment`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 888](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L888-L889)

### `rest_after_insert_comment`

*This action is documented in wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` |  | 
`$request` |  | 
`false` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 909](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L909-L910)

### `rest_delete_comment`

*Fires after a comment is deleted via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` | `\WP_Comment` | The deleted comment data.
`$response` | `\WP_REST_Response` | The response returned from the API.
`$request` | `\WP_REST_Request` | The request sent to the API.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 1013](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L1013-L1022)

### `wp_creating_autosave`

*This filter is documented in wp-admin/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_autosave` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-autosaves-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-autosaves-controller.php), [line 384](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-autosaves-controller.php#L384-L385)

### `pre_get_users`

*Fires before the WP_User_Query has been parsed.*

The passed WP_User_Query object contains the query variables,
not yet passed into SQL.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-user-query.php](../../wordpress/wp-includes/class-wp-user-query.php), [line 219](../../wordpress/wp-includes/class-wp-user-query.php#L219-L229)

### `pre_user_query`

*Fires after the WP_User_Query has been parsed, and before
the query is executed.*

The passed WP_User_Query object contains SQL parts formed
from parsing the given query.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(&$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-user-query.php](../../wordpress/wp-includes/class-wp-user-query.php), [line 569](../../wordpress/wp-includes/class-wp-user-query.php#L569-L580)

### `wp_print_scripts`

*This action is documented in wp-includes/functions.wp-scripts.php*


Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 1859](../../wordpress/wp-includes/script-loader.php#L1859-L1860)

### `wp_print_scripts`

*This action is documented in wp-includes/functions.wp-scripts.php*


Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 1977](../../wordpress/wp-includes/script-loader.php#L1977-L1978)

### `wp_print_footer_scripts`

*Fires when footer scripts are printed.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2005](../../wordpress/wp-includes/script-loader.php#L2005-L2010)

### `wp_enqueue_scripts`

*Fires when scripts and styles are enqueued.*


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2022](../../wordpress/wp-includes/script-loader.php#L2022-L2027)

### `enqueue_block_assets`

*Fires after enqueuing block assets for both editor and front-end.*

Call `add_action` on any hook before 'wp_enqueue_scripts'.

In the function call you supply, simply use `wp_enqueue_script` and
`wp_enqueue_style` to add your functionality to the Gutenberg editor.


**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2201](../../wordpress/wp-includes/script-loader.php#L2201-L2211)

### `get_header`

*Fires before the header template file is loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$name` | `string\|null` | Name of the specific header file to use. Null for the default header.
`$args` | `array` | Additional arguments passed to the header template.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`2.8.0` | The `$name` parameter was added.
`2.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 28](../../wordpress/wp-includes/general-template.php#L28-L38)

### `get_footer`

*Fires before the footer template file is loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$name` | `string\|null` | Name of the specific footer file to use. Null for the default footer.
`$args` | `array` | Additional arguments passed to the footer template.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`2.8.0` | The `$name` parameter was added.
`2.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 72](../../wordpress/wp-includes/general-template.php#L72-L82)

### `get_sidebar`

*Fires before the sidebar template file is loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$name` | `string\|null` | Name of the specific sidebar file to use. Null for the default sidebar.
`$args` | `array` | Additional arguments passed to the sidebar template.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`2.8.0` | The `$name` parameter was added.
`2.2.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 116](../../wordpress/wp-includes/general-template.php#L116-L126)

### `get_template_part_{$slug}`

*Fires before the specified template part file is loaded.*

The dynamic portion of the hook name, `$slug`, refers to the slug name
for the generic template part.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$slug` | `string` | The slug name for the generic template.
`$name` | `string\|null` | The name of the specialized template.
`$args` | `array` | Additional arguments passed to the template.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 168](../../wordpress/wp-includes/general-template.php#L168-L181)

### `get_template_part`

*Fires before a template part is loaded.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$slug` | `string` | The slug name for the generic template.
`$name` | `string` | The name of the specialized template.
`$templates` | `string[]` | Array of template files to search for, in order.
`$args` | `array` | Additional arguments passed to the template.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`5.2.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 191](../../wordpress/wp-includes/general-template.php#L191-L202)

### `pre_get_search_form`

*Fires before the search form is retrieved, at the start of get_search_form().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | The array of arguments for building the search form.<br>See get_search_form() for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`3.6.0` | 
`2.7.0` | as 'get_search_form' action.

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 240](../../wordpress/wp-includes/general-template.php#L240-L252)

### `wp_meta`

*Fires before displaying echoed content in the sidebar.*


**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 700](../../wordpress/wp-includes/general-template.php#L700-L705)

### `wp_head`

*Prints scripts or data in the head tag on the front end.*


**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3004](../../wordpress/wp-includes/general-template.php#L3004-L3009)

### `wp_footer`

*Prints scripts or data before the closing body tag on the front end.*


**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3020](../../wordpress/wp-includes/general-template.php#L3020-L3025)

### `wp_body_open`

*Triggered after the opening body tag.*


**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3036](../../wordpress/wp-includes/general-template.php#L3036-L3041)

### `wp_enqueue_code_editor`

*Fires when scripts and styles are enqueued for the code editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$settings` | `array` | Settings for the enqueued code editor.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3599](../../wordpress/wp-includes/general-template.php#L3599-L3606)

### `wp_nav_menu_item_custom_fields_customize_template`

*Fires at the end of the form field template for nav menu items in the customizer.*

Additional fields can be rendered here and managed in JavaScript.


**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-control.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-control.php), [line 138](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-control.php#L138-L145)

### `customize_render_partials_before`

*Fires immediately before partials are rendered.*

Plugins may do things like call wp_enqueue_scripts() and gather a list of the scripts
and styles which may get enqueued in the response.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Selective_Refresh` | Selective refresh component.
`$partials` | `array` | Placements' context data for the partials rendered in the request.<br>The array is keyed by partial ID, with each item being an array of<br>the placements' context data.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php), [line 330](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php#L330-L343)

### `customize_render_partials_after`

*Fires immediately after partials are rendered.*

Plugins may do things like call wp_footer() to scrape scripts output and return them
via the %1$s filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this` | `\WP_Customize_Selective_Refresh` | Selective refresh component.
`$partials` | `array` | Placements' context data for the partials rendered in the request.<br>The array is keyed by partial ID, with each item being an array of<br>the placements' context data.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php), [line 379](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php#L379-L392)

### `delete_usermeta`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cur->umeta_id` |  | 
`$user_id` |  | 
`$meta_key` |  | 
`$meta_value` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2255](../../wordpress/wp-includes/deprecated.php#L2255-L2255)

### `deleted_usermeta`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cur->umeta_id` |  | 
`$user_id` |  | 
`$meta_key` |  | 
`$meta_value` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2266](../../wordpress/wp-includes/deprecated.php#L2266-L2266)

### `update_usermeta`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cur->umeta_id` |  | 
`$user_id` |  | 
`$meta_key` |  | 
`$meta_value` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2359](../../wordpress/wp-includes/deprecated.php#L2359-L2359)

### `added_usermeta`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wpdb->insert_id` |  | 
`$user_id` |  | 
`$meta_key` |  | 
`$meta_value` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2372](../../wordpress/wp-includes/deprecated.php#L2372-L2372)

### `updated_usermeta`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cur->umeta_id` |  | 
`$user_id` |  | 
`$meta_key` |  | 
`$meta_value` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2374](../../wordpress/wp-includes/deprecated.php#L2374-L2374)

### `login_enqueue_scripts`

*Enqueue scripts and styles for the login page.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 109](../../wordpress/wp-login.php#L109-L114)

### `login_head`

*Fires in the login page header after scripts are enqueued.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 116](../../wordpress/wp-login.php#L116-L121)

### `login_header`

*Fires in the login page header after the body tag is opened.*


**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 200](../../wordpress/wp-login.php#L200-L205)

### `login_footer`

*Fires in the login page footer.*


**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 325](../../wordpress/wp-login.php#L325-L330)

### `login_init`

*Fires when the login form is initialized.*


**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 422](../../wordpress/wp-login.php#L422-L427)

### `login_form_{$action}`

*Fires before a specified login form action.*

The dynamic portion of the hook name, `$action`, refers to the action
that brought the visitor to the login form. Actions include 'postpass',
'logout', 'lostpassword', etc.


**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 429](../../wordpress/wp-login.php#L429-L438)

### `admin_email_confirm`

*Fires before the admin email confirm form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | A `WP_Error` object containing any errors generated by using invalid<br>credentials. Note that the error object may not contain any errors.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 531](../../wordpress/wp-login.php#L531-L539)

### `admin_email_confirm_form`

*Fires inside the admin-email-confirm-form form tags, before the hidden fields.*


**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 545](../../wordpress/wp-login.php#L545-L550)

### `lost_password`

*Fires before the lost password form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | A `WP_Error` object containing any errors generated by using invalid<br>credentials. Note that the error object may not contain any errors.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | Added the `$errors` parameter.
`1.5.1` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 729](../../wordpress/wp-login.php#L729-L738)

### `lostpassword_form`

*Fires inside the lostpassword form tags, before the hidden fields.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 757](../../wordpress/wp-login.php#L757-L762)

### `validate_password_reset`

*Fires before the password reset procedure is validated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | WP Error object.
`$user` | `\WP_User\|\WP_Error` | WP_User object if the login and reset key match. WP_Error object otherwise.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 834](../../wordpress/wp-login.php#L834-L842)

### `resetpass_form`

*Fires following the 'Strength indicator' meter in the user password reset form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User` | User object of the user whose password is being reset.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 890](../../wordpress/wp-login.php#L890-L897)

### `register_form`

*Fires following the 'Email' field in the user registration form.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 991](../../wordpress/wp-login.php#L991-L996)

### `user_request_action_confirmed`

*Fires an action hook when the account action has been confirmed by the user.*

Using this you can assume the user has agreed to perform the action by
clicking on the link in the confirmation email.

After firing this action hook the page will redirect to wp-login a callback
redirects or exits first.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$request_id` | `int` | Request ID.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1069](../../wordpress/wp-login.php#L1069-L1082)

### `login_footer`

*This action is documented in wp-login.php*


Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1176](../../wordpress/wp-login.php#L1176-L1177)

### `login_form`

*Fires following the 'Password' field in the login form.*


**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1319](../../wordpress/wp-login.php#L1319-L1324)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentyseventeen/inc/template-tags.php](../../wordpress/wp-content/themes/twentyseventeen/inc/template-tags.php), [line 219](../../wordpress/wp-content/themes/twentyseventeen/inc/template-tags.php#L219-L224)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentysixteen/inc/template-tags.php](../../wordpress/wp-content/themes/twentysixteen/inc/template-tags.php), [line 279](../../wordpress/wp-content/themes/twentysixteen/inc/template-tags.php#L279-L284)

### `twentysixteen_credits`

*Fires before the twentysixteen footer text for footer customization.*


Source: [wordpress/wp-content/themes/twentysixteen/footer.php](../../wordpress/wp-content/themes/twentysixteen/footer.php), [line 47](../../wordpress/wp-content/themes/twentysixteen/footer.php#L47-L52)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentyeleven/functions.php](../../wordpress/wp-content/themes/twentyeleven/functions.php), [line 908](../../wordpress/wp-content/themes/twentyeleven/functions.php#L908-L913)

### `twentyeleven_enqueue_color_scheme`

*Fires after the styles for the Twenty Eleven color scheme are enqueued.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$color_scheme` | `string` | The color scheme.

Source: [wordpress/wp-content/themes/twentyeleven/inc/theme-options.php](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php), [line 425](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php#L425-L432)

### `twentyeleven_credits`


Source: [wordpress/wp-content/themes/twentyeleven/footer.php](../../wordpress/wp-content/themes/twentyeleven/footer.php), [line 28](../../wordpress/wp-content/themes/twentyeleven/footer.php#L28-L28)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentythirteen/functions.php](../../wordpress/wp-content/themes/twentythirteen/functions.php), [line 823](../../wordpress/wp-content/themes/twentythirteen/functions.php#L823-L828)

### `twentythirteen_credits`


Source: [wordpress/wp-content/themes/twentythirteen/footer.php](../../wordpress/wp-content/themes/twentythirteen/footer.php), [line 18](../../wordpress/wp-content/themes/twentythirteen/footer.php#L18-L18)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentynineteen/inc/template-tags.php](../../wordpress/wp-content/themes/twentynineteen/inc/template-tags.php), [line 251](../../wordpress/wp-content/themes/twentynineteen/inc/template-tags.php#L251-L256)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentyfifteen/inc/template-tags.php](../../wordpress/wp-content/themes/twentyfifteen/inc/template-tags.php), [line 283](../../wordpress/wp-content/themes/twentyfifteen/inc/template-tags.php#L283-L288)

### `twentyfifteen_credits`

*Fires before the Twenty Fifteen footer text for footer customization.*


Source: [wordpress/wp-content/themes/twentyfifteen/footer.php](../../wordpress/wp-content/themes/twentyfifteen/footer.php), [line 18](../../wordpress/wp-content/themes/twentyfifteen/footer.php#L18-L23)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentyfourteen/inc/template-tags.php](../../wordpress/wp-content/themes/twentyfourteen/inc/template-tags.php), [line 246](../../wordpress/wp-content/themes/twentyfourteen/inc/template-tags.php#L246-L251)

### `twentyfourteen_featured_posts_before`

*Fires before the Twenty Fourteen featured content.*


Source: [wordpress/wp-content/themes/twentyfourteen/featured-content.php](../../wordpress/wp-content/themes/twentyfourteen/featured-content.php), [line 14](../../wordpress/wp-content/themes/twentyfourteen/featured-content.php#L14-L19)

### `twentyfourteen_featured_posts_after`

*Fires after the Twenty Fourteen featured content.*


Source: [wordpress/wp-content/themes/twentyfourteen/featured-content.php](../../wordpress/wp-content/themes/twentyfourteen/featured-content.php), [line 29](../../wordpress/wp-content/themes/twentyfourteen/featured-content.php#L29-L34)

### `twentyfourteen_credits`


Source: [wordpress/wp-content/themes/twentyfourteen/footer.php](../../wordpress/wp-content/themes/twentyfourteen/footer.php), [line 20](../../wordpress/wp-content/themes/twentyfourteen/footer.php#L20-L20)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentytwelve/functions.php](../../wordpress/wp-content/themes/twentytwelve/functions.php), [line 716](../../wordpress/wp-content/themes/twentytwelve/functions.php#L716-L721)

### `twentytwelve_credits`


Source: [wordpress/wp-content/themes/twentytwelve/footer.php](../../wordpress/wp-content/themes/twentytwelve/footer.php), [line 15](../../wordpress/wp-content/themes/twentytwelve/footer.php#L15-L15)

### `wp_body_open`

*Triggered after the opening <body> tag.*


Source: [wordpress/wp-content/themes/twentyten/functions.php](../../wordpress/wp-content/themes/twentyten/functions.php), [line 751](../../wordpress/wp-content/themes/twentyten/functions.php#L751-L756)

### `twentyten_credits`

*Fires before the Twenty Ten credits in the footer.*


Source: [wordpress/wp-content/themes/twentyten/footer.php](../../wordpress/wp-content/themes/twentyten/footer.php), [line 39](../../wordpress/wp-content/themes/twentyten/footer.php#L39-L44)

### `wp_body_open`


Source: [wordpress/wp-content/themes/twentytwenty/functions.php](../../wordpress/wp-content/themes/twentytwenty/functions.php), [line 336](../../wordpress/wp-content/themes/twentytwenty/functions.php#L336-L336)

### `twentytwenty_start_of_post_meta_list`

*Fires before post meta HTML display.*

Allow output of additional post meta info to be added by child themes and plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$post_meta` | `array` | An array of post meta information.
`$location` | `string` | The location where the meta is shown.<br>Accepts 'single-top' or 'single-bottom'.

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 328](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L328-L341)

### `twentytwenty_end_of_post_meta_list`

*Fires after post meta HTML display.*

Allow output of additional post meta info to be added by child themes and plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | Post ID.
`$post_meta` | `array` | An array of post meta information.
`$location` | `string` | The location where the meta is shown.<br>Accepts 'single-top' or 'single-bottom'.

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 455](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L455-L468)

### `signup_header`

*Fires within the head section of the site sign-up screen.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 23](../../wordpress/wp-signup.php#L23-L28)

### `before_signup_header`

*Fires before the Site Signup page is loaded.*


**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 45](../../wordpress/wp-signup.php#L45-L50)

### `before_signup_form`

*Fires before the site sign-up form.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 81](../../wordpress/wp-signup.php#L81-L86)

### `signup_blogform`

*Fires after the site sign-up form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | A WP_Error object possibly containing 'blogname' or 'blog_title' errors.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 216](../../wordpress/wp-signup.php#L216-L223)

### `signup_extra_fields`

*Fires at the end of the new user account registration form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | A WP_Error object containing 'user_name' or 'user_email' errors.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 279](../../wordpress/wp-signup.php#L279-L286)

### `signup_hidden_fields`

*Hidden sign-up form fields output when creating another site or user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'create-another-site'` |  | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 378](../../wordpress/wp-signup.php#L378-L386)

### `signup_finished`

*Fires when the site or user sign-up process is complete.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 541](../../wordpress/wp-signup.php#L541-L546)

### `signup_hidden_fields`

*This action is documented in wp-signup.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'validate-user'` |  | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 602](../../wordpress/wp-signup.php#L602-L603)

### `signup_finished`

*This action is documented in wp-signup.php*


Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 681](../../wordpress/wp-signup.php#L681-L682)

### `signup_hidden_fields`

*This action is documented in wp-signup.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'validate-site'` |  | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 741](../../wordpress/wp-signup.php#L741-L742)

### `signup_finished`

*This action is documented in wp-signup.php*


Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 853](../../wordpress/wp-signup.php#L853-L854)

### `preprocess_signup_form`

*Fires when the site sign-up form is sent.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 965](../../wordpress/wp-signup.php#L965-L970)

### `after_signup_form`

*Fires after the sign-up forms, before wp_footer.*


**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 1005](../../wordpress/wp-signup.php#L1005-L1010)

## Filters

### `wp_xmlrpc_server_class`

*Filters the class used for handling XML-RPC requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp_xmlrpc_server'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/xmlrpc.php](../../wordpress/xmlrpc.php), [line 76](../../wordpress/xmlrpc.php#L76-L83)

### `link_category`

*This filter is documented in wp-includes/bookmark-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cat->name` |  | 

Source: [wordpress/wp-links-opml.php](../../wordpress/wp-links-opml.php), [line 66](../../wordpress/wp-links-opml.php#L66-L67)

### `link_title`

*Filters the OPML outline link title text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$bookmark->link_name` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-links-opml.php](../../wordpress/wp-links-opml.php), [line 74](../../wordpress/wp-links-opml.php#L74-L81)

### `enable_post_by_email_configuration`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-mail.php](../../wordpress/wp-mail.php), [line 14](../../wordpress/wp-mail.php#L14-L14)

### `wp_mail_original_content`

*Filters the original content of the email.*

Give Post-By-Email extending plugins full access to the content, either
the raw content, or the content of the last quoted-printable section.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | The original email content.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-mail.php](../../wordpress/wp-mail.php), [line 179](../../wordpress/wp-mail.php#L179-L189)

### `phone_content`

*Filters the content of the post submitted by email before saving.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | The email content.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-mail.php](../../wordpress/wp-mail.php), [line 205](../../wordpress/wp-mail.php#L205-L212)

### `enable_loading_advanced_cache_dropin`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-settings.php](../../wordpress/wp-settings.php), [line 93](../../wordpress/wp-settings.php#L93-L93)

### `comment_post_redirect`

*Filters the location URI to send the commenter after posting.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` | `string` | The 'redirect_to' URI sent via $_POST.
`$comment` | `\WP_Comment` | Comment object.

**Changelog**

Version | Description
------- | -----------
`2.0.5` | 

Source: [wordpress/wp-comments-post.php](../../wordpress/wp-comments-post.php), [line 70](../../wordpress/wp-comments-post.php#L70-L78)

### `available_permalink_structure_tags`

*Filters the list of available permalink structure tags on the Permalinks settings page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$available_tags` | `string[]` | An array of key => value pairs of available permalink structure tags.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-admin/options-permalink.php](../../wordpress/wp-admin/options-permalink.php), [line 289](../../wordpress/wp-admin/options-permalink.php#L289-L296)

### `replace_editor`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/post-new.php](../../wordpress/wp-admin/post-new.php), [line 70](../../wordpress/wp-admin/post-new.php#L70-L70)

### `admin_title`

*Filters the title tag content for an admin page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$admin_title` | `string` | The page title, with extra context added.
`$title` | `string` | The original page title.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 60](../../wordpress/wp-admin/admin-header.php#L60-L68)

### `admin_body_class`

*Filters the CSS classes for the body tag in the admin.*

This filter differs from the %1$s and %2$s filters
in two important ways:

1. `$classes` is a space-separated string of class names instead of an array.
2. Not all core admin classes are filterable, notably: wp-admin, wp-core-ui,
   and no-js cannot be removed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/admin-header.php](../../wordpress/wp-admin/admin-header.php), [line 213](../../wordpress/wp-admin/admin-header.php#L213-L227)

### `handle_bulk_actions-{$screen}`

*This action is documented in wp-admin/edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_to` |  | 
`$doaction` |  | 
`$comment_ids` |  | 

Source: [wordpress/wp-admin/edit-comments.php](../../wordpress/wp-admin/edit-comments.php), [line 95](../../wordpress/wp-admin/edit-comments.php#L95-L96)

### `admin_footer_text`

*Filters the "Thank you" text displayed in the admin footer.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'<span id="footer-thankyou">' . $text . '</span>'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/admin-footer.php](../../wordpress/wp-admin/admin-footer.php), [line 41](../../wordpress/wp-admin/admin-footer.php#L41-L48)

### `update_footer`

*Filters the version/update text displayed in the admin footer.*

WordPress prints the current version and update information,
using core_update_footer() at priority 10.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/admin-footer.php](../../wordpress/wp-admin/admin-footer.php), [line 53](../../wordpress/wp-admin/admin-footer.php#L53-L65)

### `wp_editor_expand`

*Filters whether to enable the 'expand' functionality in the post editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post_type` | `string` | Post type.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | Added the `$post_type` parameter.
`4.0.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 51](../../wordpress/wp-admin/edit-form-advanced.php#L51-L60)

### `post_updated_messages`

*Filters the post updated messages.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$messages` | `array[]` | Post updated messages. For defaults see `$messages` declarations above.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 212](../../wordpress/wp-admin/edit-form-advanced.php#L212-L219)

### `enter_title_here`

*Filters the title field placeholder text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Add title')` |  | 
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/edit-form-advanced.php](../../wordpress/wp-admin/edit-form-advanced.php), [line 511](../../wordpress/wp-admin/edit-form-advanced.php#L511-L519)

### `admin_email_remind_interval`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`3 * DAY_IN_SECONDS` |  | 

Source: [wordpress/wp-admin/index.php](../../wordpress/wp-admin/index.php), [line 124](../../wordpress/wp-admin/index.php#L124-L124)

### `theme_auto_update_setting_template`

*Filters the JavaScript template used to display the auto-update setting for a theme (in the overlay).*

See %1$s for the properties of the `data` object.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$template` | `string` | The template for displaying the auto-update setting link.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/themes.php](../../wordpress/wp-admin/themes.php), [line 705](../../wordpress/wp-admin/themes.php#L705-L714)

### `replace_editor`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/post.php](../../wordpress/wp-admin/post.php), [line 182](../../wordpress/wp-admin/post.php#L182-L182)

### `media_upload_default_type`

*Filters the default media upload type in the legacy (pre-3.5.0) media popup.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'file'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/media-upload.php](../../wordpress/wp-admin/media-upload.php), [line 56](../../wordpress/wp-admin/media-upload.php#L56-L64)

### `media_upload_default_tab`

*Filters the default tab in the legacy (pre-3.5.0) media popup.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'type'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/media-upload.php](../../wordpress/wp-admin/media-upload.php), [line 71](../../wordpress/wp-admin/media-upload.php#L71-L78)

### `export_args`

*Filters the export args.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | The arguments to send to the exporter.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/export.php](../../wordpress/wp-admin/export.php), [line 112](../../wordpress/wp-admin/export.php#L112-L119)

### `date_formats`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(__('F j, Y'), 'Y-m-d', 'm/d/Y', 'd/m/Y')` |  | 

Source: [wordpress/wp-admin/options-general.php](../../wordpress/wp-admin/options-general.php), [line 318](../../wordpress/wp-admin/options-general.php#L318-L318)

### `time_formats`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(__('g:i a'), 'g:i A', 'H:i')` |  | 

Source: [wordpress/wp-admin/options-general.php](../../wordpress/wp-admin/options-general.php), [line 355](../../wordpress/wp-admin/options-general.php#L355-L355)

### `handle_network_bulk_actions-{$get_current_screen->id}`

*This action is documented in wp-admin/network/site-themes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_to` |  | 
`$doaction` |  | 
`$blogs` |  | 
`$id` |  | 

Source: [wordpress/wp-admin/network/sites.php](../../wordpress/wp-admin/network/sites.php), [line 231](../../wordpress/wp-admin/network/sites.php#L231-L232)

### `network_sites_updated_message_{$action}`

*Filters a specific, non-default, site-updated message in the Network admin.*

The dynamic portion of the hook name, `$action`, refers to the non-default
site update action.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Settings saved.')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/network/sites.php](../../wordpress/wp-admin/network/sites.php), [line 341](../../wordpress/wp-admin/network/sites.php#L341-L351)

### `mu_menu_items`

*Filters available network-wide administration menu options.*

Options returned to this filter are output as individual checkboxes that, when selected,
enable site administrator access to the specified administration menu in certain contexts.

Adding options for specific menus here hinges on the appropriate checks and capabilities
being in place in the site dashboard on the other side. For instance, when the single
default option, 'plugins' is enabled, site administrators are granted access to the Plugins
screen in their individual sites' dashboards.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('plugins' => __('Plugins'))` |  | 

Source: [wordpress/wp-admin/network/settings.php](../../wordpress/wp-admin/network/settings.php), [line 454](../../wordpress/wp-admin/network/settings.php#L454-L469)

### `handle_network_bulk_actions-{$get_current_screen->id}`

*This action is documented in wp-admin/network/site-themes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$referer` |  | 
`$action` |  | 
`$themes` |  | 

Source: [wordpress/wp-admin/network/themes.php](../../wordpress/wp-admin/network/themes.php), [line 280](../../wordpress/wp-admin/network/themes.php#L280-L281)

### `handle_network_bulk_actions-{$get_current_screen->id}`

*This action is documented in wp-admin/network/site-themes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sendback` |  | 
`$doaction` |  | 
`$user_ids` |  | 

Source: [wordpress/wp-admin/network/users.php](../../wordpress/wp-admin/network/users.php), [line 121](../../wordpress/wp-admin/network/users.php#L121-L122)

### `handle_network_bulk_actions-{$screen}`

*Fires when a custom bulk action should be handled.*

The redirect link should be modified with success or failure feedback
from the action to be used to display feedback to the user.

The dynamic portion of the hook name, `$screen`, refers to the current screen ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$referer` |  | 
`$action` | `string` | The action being taken.
`$themes` |  | 
`$id` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-admin/network/site-themes.php](../../wordpress/wp-admin/network/site-themes.php), [line 124](../../wordpress/wp-admin/network/site-themes.php#L124-L139)

### `handle_network_bulk_actions-{$get_current_screen->id}`

*This action is documented in wp-admin/network/site-themes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$referer` |  | 
`$action` |  | 
`$userids` |  | 
`$id` |  | 

Source: [wordpress/wp-admin/network/site-users.php](../../wordpress/wp-admin/network/site-users.php), [line 178](../../wordpress/wp-admin/network/site-users.php#L178-L179)

### `show_network_site_users_add_existing_form`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/network/site-users.php](../../wordpress/wp-admin/network/site-users.php), [line 211](../../wordpress/wp-admin/network/site-users.php#L211-L211)

### `show_network_site_users_add_existing_form`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/network/site-users.php](../../wordpress/wp-admin/network/site-users.php), [line 296](../../wordpress/wp-admin/network/site-users.php#L296-L296)

### `show_network_site_users_add_new_form`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/network/site-users.php](../../wordpress/wp-admin/network/site-users.php), [line 330](../../wordpress/wp-admin/network/site-users.php#L330-L330)

### `redirect_network_admin_request`

*Filters whether to redirect the request to the Network Admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_network_admin_request` | `bool` | Whether the request should be redirected.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/network/admin.php](../../wordpress/wp-admin/network/admin.php), [line 22](../../wordpress/wp-admin/network/admin.php#L22-L29)

### `wp_nav_locations_listed_per_menu`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`3` |  | 

Source: [wordpress/wp-admin/nav-menus.php](../../wordpress/wp-admin/nav-menus.php), [line 876](../../wordpress/wp-admin/nav-menus.php#L876-L876)

### `wp_privacy_personal_data_exporters`

*This filter is documented in wp-admin/includes/ajax-actions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/class-wp-privacy-data-export-requests-list-table.php](../../wordpress/wp-admin/includes/class-wp-privacy-data-export-requests-list-table.php), [line 47](../../wordpress/wp-admin/includes/class-wp-privacy-data-export-requests-list-table.php#L47-L48)

### `wp_privacy_personal_data_exporters`

*This filter is documented in wp-admin/includes/ajax-actions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/class-wp-privacy-data-export-requests-list-table.php](../../wordpress/wp-admin/includes/class-wp-privacy-data-export-requests-list-table.php), [line 119](../../wordpress/wp-admin/includes/class-wp-privacy-data-export-requests-list-table.php#L119-L120)

### `edit_tags_per_page`

*Filters the number of terms displayed per page for the Tags list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags_per_page` | `int` | Number of tags to be displayed. Default 20.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 83](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L83-L90)

### `tagsperpage`

*Filters the number of terms displayed per page for the Tags list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($tags_per_page)` |  | 
`'2.8.0'` |  | 
`'edit_tags_per_page'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 92](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L92-L100)

### `edit_categories_per_page`

*Filters the number of terms displayed per page for the Categories list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags_per_page` | `int` | Number of categories to be displayed. Default 20.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 102](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L102-L109)

### `term_name`

*Filters display of the term name in the terms list table.*

The default output may include padding due to the term's
current level in the term hierarchy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pad . ' ' . $tag->name` |  | 
`$tag` | `\WP_Term` | Term object.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 388](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L388-L401)

### `editable_slug`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$qe_data->slug` |  | 
`$qe_data` |  | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 433](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L433-L433)

### `tag_row_actions`

*Filters the action links displayed for each term in the Tags list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of action links to be displayed. Default<br>'Edit', 'Quick Edit', 'Delete', and 'View'.
`$tag` | `\WP_Term` | Term object.

**Changelog**

Version | Description
------- | -----------
`5.4.2` | Restored (un-deprecated).
`3.0.0` | Deprecated in favor of {@see '{$taxonomy}_row_actions'} filter.
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 511](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L511-L522)

### `{$taxonomy}_row_actions`

*Filters the action links displayed for each term in the terms list table.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of action links to be displayed. Default<br>'Edit', 'Quick Edit', 'Delete', and 'View'.
`$tag` | `\WP_Term` | Term object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 524](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L524-L535)

### `editable_slug`

*This filter is documented in wp-admin/edit-tag-form.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag->slug` |  | 
`$tag` |  | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 557](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L557-L558)

### `manage_{$screen->taxonomy}_custom_column`

*Filters the displayed columns in the terms list table.*

The dynamic portion of the hook name, `$this->screen->taxonomy`,
refers to the slug of the current taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$column_name` | `string` | Name of the column.
`$tag->term_id` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-terms-list-table.php](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php), [line 613](../../wordpress/wp-admin/includes/class-wp-terms-list-table.php#L613-L625)

### `users_list_table_query_args`

*Filters the query arguments used to retrieve users for the current users list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Arguments passed to WP_User_Query to retrieve items for the current<br>users list table.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-users-list-table.php), [line 130](../../wordpress/wp-admin/includes/class-wp-users-list-table.php#L130-L138)

### `user_row_actions`

*Filters the action links displayed under each user in the Users list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of action links to be displayed.<br>Default 'Edit', 'Delete' for single site, and<br>'Edit', 'Remove' for Multisite.
`$user_object` | `\WP_User` | WP_User object for the currently listed user.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-users-list-table.php), [line 483](../../wordpress/wp-admin/includes/class-wp-users-list-table.php#L483-L493)

### `manage_users_custom_column`

*Filters the display output of custom columns in the Users list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$column_name` | `string` | Column name.
`$user_object->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-users-list-table.php), [line 583](../../wordpress/wp-admin/includes/class-wp-users-list-table.php#L583-L592)

### `get_role_list`

*Filters the returned array of roles for a user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$role_list` | `string[]` | An array of user roles.
`$user_object` | `\WP_User` | A WP_User object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-users-list-table.php), [line 640](../../wordpress/wp-admin/includes/class-wp-users-list-table.php#L640-L648)

### `lang_codes`

*Filters the language codes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$lang_codes` | `string[]` | Array of key/value pairs of language codes where key is the short version.
`$code` | `string` | A two-letter designation of the language.

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 528](../../wordpress/wp-admin/includes/ms.php#L528-L536)

### `mu_dropdown_languages`

*Filters the languages available in the dropdown.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string[]` | Array of HTML output for the dropdown.
`$lang_files` | `string[]` | Array of available language files.
`$current` | `string` | The current language code.

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 670](../../wordpress/wp-admin/includes/ms.php#L670-L679)

### `can_edit_network`

*Filters whether this network can be edited from this page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `bool` | Whether the network can be edited from this page.
`$network_id` | `int` | The network ID to check.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 824](../../wordpress/wp-admin/includes/ms.php#L824-L832)

### `network_edit_site_nav_links`

*Filters the links that appear on site-editing network pages.*

Default links: 'site-info', 'site-users', 'site-themes', and 'site-settings'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('site-info' => array('label' => __('Info'), 'url' => 'site-info.php', 'cap' => 'manage_sites'), 'site-users' => array('label' => __('Users'), 'url' => 'site-users.php', 'cap' => 'manage_sites'), 'site-themes' => array('label' => __('Themes'), 'url' => 'site-themes.php', 'cap' => 'manage_sites'), 'site-settings' => array('label' => __('Settings'), 'url' => 'site-settings.php', 'cap' => 'manage_sites'))` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-admin/includes/ms.php](../../wordpress/wp-admin/includes/ms.php), [line 1033](../../wordpress/wp-admin/includes/ms.php#L1033-L1076)

### `_wp_post_revision_field_{$field}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$compare_from->{$field}` |  | 
`$field` |  | 
`$compare_from` |  | 
`'from'` |  | 

Source: [wordpress/wp-admin/includes/revision.php](../../wordpress/wp-admin/includes/revision.php), [line 82](../../wordpress/wp-admin/includes/revision.php#L82-L82)

### `_wp_post_revision_field_{$field}`

*This filter is documented in wp-admin/includes/revision.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$compare_to->{$field}` |  | 
`$field` |  | 
`$compare_to` |  | 
`'to'` |  | 

Source: [wordpress/wp-admin/includes/revision.php](../../wordpress/wp-admin/includes/revision.php), [line 84](../../wordpress/wp-admin/includes/revision.php#L84-L85)

### `revision_text_diff_options`

*Filters revisions text diff options.*

Filters the options passed to wp_text_diff() when viewing a post revision.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | {<br>    Associative array of options to pass to wp_text_diff().<br><br>    @type bool $show_split_view True for split view (two columns), false for<br>                                un-split view (single column). Default true.<br>}
`$field` | `string` | The current revision field.
`$compare_from` | `\WP_Post` | The revision post to compare from.
`$compare_to` | `\WP_Post` | The revision post to compare to.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-admin/includes/revision.php](../../wordpress/wp-admin/includes/revision.php), [line 93](../../wordpress/wp-admin/includes/revision.php#L93-L110)

### `wp_get_revision_ui_diff`

*Filters the fields displayed in the post revision diff UI.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `array[]` | Array of revision UI fields. Each item is an array of id, name, and diff.
`$compare_from` | `\WP_Post` | The revision post to compare from.
`$compare_to` | `\WP_Post` | The revision post to compare to.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-admin/includes/revision.php](../../wordpress/wp-admin/includes/revision.php), [line 144](../../wordpress/wp-admin/includes/revision.php#L144-L153)

### `wp_prepare_revision_for_js`

*Filters the array of revisions used on the revisions screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$revisions_data` | `array` | {<br>    The bootstrapped data for the revisions screen.<br><br>    @type int        $id         Revision ID.<br>    @type string     $title      Title for the revision's parent WP_Post object.<br>    @type int        $author     Revision post author ID.<br>    @type string     $date       Date the revision was modified.<br>    @type string     $dateShort  Short-form version of the date the revision was modified.<br>    @type string     $timeAgo    GMT-aware amount of time ago the revision was modified.<br>    @type bool       $autosave   Whether the revision is an autosave.<br>    @type bool       $current    Whether the revision is both not an autosave and the post<br>                                 modified date matches the revision modified date (GMT-aware).<br>    @type bool\|false $restoreUrl URL if the revision can be restored, false otherwise.<br>}
`$revision` | `\WP_Post` | The revision's WP_Post object.
`$post` | `\WP_Post` | The revision's parent WP_Post object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/revision.php](../../wordpress/wp-admin/includes/revision.php), [line 251](../../wordpress/wp-admin/includes/revision.php#L251-L273)

### `terms_to_edit`

*Filters the comma-separated list of terms available to edit.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$terms_to_edit` | `string` | A comma-separated list of term names.
`$taxonomy` | `string` | The taxonomy name for which to retrieve terms.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/taxonomy.php](../../wordpress/wp-admin/includes/taxonomy.php), [line 283](../../wordpress/wp-admin/includes/taxonomy.php#L283-L293)

### `wp_get_default_privacy_policy_content`

*Filters the default content suggested for inclusion in a privacy policy.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($content, $strings, $description, $blocks)` |  | 
`'5.7.0'` |  | 
`'wp_add_privacy_policy_content()'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | Added the `$strings`, `$description`, and `$blocks` parameters.
`4.9.6` | 

Source: [wordpress/wp-admin/includes/class-wp-privacy-policy-content.php](../../wordpress/wp-admin/includes/class-wp-privacy-policy-content.php), [line 667](../../wordpress/wp-admin/includes/class-wp-privacy-policy-content.php#L667-L684)

### `update_bulk_plugins_complete_actions`

*Filters the list of action links available following bulk plugin updates.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_actions` | `string[]` | Array of plugin action links.
`$this->plugin_info` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-bulk-plugin-upgrader-skin.php](../../wordpress/wp-admin/includes/class-bulk-plugin-upgrader-skin.php), [line 64](../../wordpress/wp-admin/includes/class-bulk-plugin-upgrader-skin.php#L64-L72)

### `update_right_now_text`

*Filters the text displayed in the 'At a Glance' dashboard widget.*

Prior to 3.8.0, the widget was named 'Right Now'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | Default text.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/update.php](../../wordpress/wp-admin/includes/update.php), [line 356](../../wordpress/wp-admin/includes/update.php#L356-L365)

### `plugins_auto_update_enabled`

*Filters whether plugins auto-update is enabled.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$enabled` | `bool` | True if plugins auto-update is enabled, false otherwise.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/update.php](../../wordpress/wp-admin/includes/update.php), [line 1028](../../wordpress/wp-admin/includes/update.php#L1028-L1035)

### `themes_auto_update_enabled`

*Filters whether themes auto-update is enabled.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$enabled` | `bool` | True if themes auto-update is enabled, false otherwise.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/update.php](../../wordpress/wp-admin/includes/update.php), [line 1037](../../wordpress/wp-admin/includes/update.php#L1037-L1044)

### `auto_update_{$type}`

*This filter is documented in wp-admin/includes/class-wp-automatic-updater.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update` |  | 
`$item` |  | 

Source: [wordpress/wp-admin/includes/update.php](../../wordpress/wp-admin/includes/update.php), [line 1062](../../wordpress/wp-admin/includes/update.php#L1062-L1063)

### `install_themes_tabs`

*This filter is documented in wp-admin/theme-install.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tabs` |  | 

Source: [wordpress/wp-admin/includes/class-wp-theme-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php), [line 71](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php#L71-L72)

### `install_themes_nonmenu_tabs`

*Filters tabs not associated with a menu item on the Install Themes screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nonmenu_tabs` | `string[]` | The tabs that don't have a menu item on<br>the Install Themes screen.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-theme-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php), [line 74](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php#L74-L82)

### `install_themes_table_api_args_{$tab}`

*Filters API request arguments for each Install Themes screen tab.*

The dynamic portion of the hook name, `$tab`, refers to the theme install
tabs. Default tabs are 'dashboard', 'search', 'upload', 'featured',
'new', and 'updated'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array\|false` | Theme install API arguments.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-theme-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php), [line 131](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php#L131-L142)

### `theme_install_actions`

*Filters the install action links for a theme in the Install Themes list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of theme action links. Defaults are<br>links to Install Now, Preview, and Details.
`$theme` | `\WP_Theme` | Theme object.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-theme-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php), [line 340](../../wordpress/wp-admin/includes/class-wp-theme-install-list-table.php#L340-L349)

### `wp_network_dashboard_widgets`

*Filters the list of widgets to load for the Network Admin dashboard.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 91](../../wordpress/wp-admin/includes/dashboard.php#L91-L98)

### `wp_user_dashboard_widgets`

*Filters the list of widgets to load for the User Admin dashboard.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 108](../../wordpress/wp-admin/includes/dashboard.php#L108-L115)

### `wp_dashboard_widgets`

*Filters the list of widgets to load for the admin dashboard.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 125](../../wordpress/wp-admin/includes/dashboard.php#L125-L132)

### `dashboard_glance_items`

*Filters the array of extra elements to list in the 'At a Glance'
dashboard widget.*

Prior to 3.8.0, the widget was named 'Right Now'. Each element
is wrapped in list-item tags on output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`3.8.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 333](../../wordpress/wp-admin/includes/dashboard.php#L333-L344)

### `privacy_on_link_title`

*Filters the link title attribute for the 'Search engines discouraged'
message displayed in the 'At a Glance' dashboard widget.*

Prior to 3.8.0, the widget was named 'Right Now'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`4.5.0` | The default for `$title` was updated to an empty string.
`3.0.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 358](../../wordpress/wp-admin/includes/dashboard.php#L358-L369)

### `privacy_on_link_text`

*Filters the link label for the 'Search engines discouraged' message
displayed in the 'At a Glance' dashboard widget.*

Prior to 3.8.0, the widget was named 'Right Now'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Search engines discouraged')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 371](../../wordpress/wp-admin/includes/dashboard.php#L371-L381)

### `enter_title_here`

*This filter is documented in wp-admin/edit-form-advanced.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Title')` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 549](../../wordpress/wp-admin/includes/dashboard.php#L549-L550)

### `dashboard_recent_drafts_query_args`

*Filters the post query arguments for the 'Recent Drafts' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_args` | `array` | The query arguments for the 'Recent Drafts' dashboard widget.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 593](../../wordpress/wp-admin/includes/dashboard.php#L593-L600)

### `comment_row_actions`

*Filters the action links displayed for each comment in the 'Recent Comments'
dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array_filter($actions)` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 755](../../wordpress/wp-admin/includes/dashboard.php#L755-L766)

### `dashboard_recent_posts_query_args`

*Filters the query arguments used for the Recent Posts widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_args` | `array` | The arguments passed to WP_Query to produce the list of posts.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 947](../../wordpress/wp-admin/includes/dashboard.php#L947-L954)

### `dashboard_primary_link`

*Filters the primary link URL for the 'WordPress Events and News' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('https://wordpress.org/news/')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1452](../../wordpress/wp-admin/includes/dashboard.php#L1452-L1459)

### `dashboard_primary_feed`

*Filters the primary feed URL for the 'WordPress Events and News' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('https://wordpress.org/news/feed/')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1461](../../wordpress/wp-admin/includes/dashboard.php#L1461-L1468)

### `dashboard_primary_title`

*Filters the primary link title for the 'WordPress Events and News' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('WordPress Blog')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1470](../../wordpress/wp-admin/includes/dashboard.php#L1470-L1477)

### `dashboard_secondary_link`

*Filters the secondary link URL for the 'WordPress Events and News' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('https://planet.wordpress.org/')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1485](../../wordpress/wp-admin/includes/dashboard.php#L1485-L1492)

### `dashboard_secondary_feed`

*Filters the secondary feed URL for the 'WordPress Events and News' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('https://planet.wordpress.org/feed/')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1494](../../wordpress/wp-admin/includes/dashboard.php#L1494-L1501)

### `dashboard_secondary_title`

*Filters the secondary link title for the 'WordPress Events and News' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Other WordPress News')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1503](../../wordpress/wp-admin/includes/dashboard.php#L1503-L1510)

### `dashboard_secondary_items`

*Filters the number of secondary link items for the 'WordPress Events and News' dashboard widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`3` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1512](../../wordpress/wp-admin/includes/dashboard.php#L1512-L1519)

### `browse-happy-notice`

*Filters the notice output for the 'Browse Happy' nag meta box.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$notice` | `string` | The notice content.
`$response` | `array` | An array containing web browser information. See `wp_check_browser_version()`.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/includes/dashboard.php](../../wordpress/wp-admin/includes/dashboard.php), [line 1662](../../wordpress/wp-admin/includes/dashboard.php#L1662-L1670)

### `attachment_fields_to_save`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translated` |  | 
`$attachment_data` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 400](../../wordpress/wp-admin/includes/post.php#L400-L401)

### `default_content`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_content` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 732](../../wordpress/wp-admin/includes/post.php#L732-L732)

### `default_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_title` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 742](../../wordpress/wp-admin/includes/post.php#L742-L742)

### `default_excerpt`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_excerpt` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 752](../../wordpress/wp-admin/includes/post.php#L752-L752)

### `edit_{$post_type}_per_page`

*Filters the number of items per page to show for a specific 'per_page' type.*

The dynamic portion of the hook name, `$post_type`, refers to the post type.

Some examples of filter hooks generated here include: 'edit_attachment_per_page',
'edit_post_per_page', 'edit_page_per_page', etc.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$posts_per_page` | `int` | Number of posts to display per page for the given post<br>type. Default 20.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1166](../../wordpress/wp-admin/includes/post.php#L1166-L1179)

### `edit_posts_per_page`

*Filters the number of posts displayed per page when specifically listing "posts".*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$posts_per_page` | `int` | Number of posts to be displayed. Default 20.
`$post_type` | `string` | The post type.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1181](../../wordpress/wp-admin/includes/post.php#L1181-L1189)

### `upload_per_page`

*Filters the number of items to list per page when listing media items.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$media_per_page` | `int` | Number of media to list. Default 20.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1241](../../wordpress/wp-admin/includes/post.php#L1241-L1248)

### `postbox_classes_{$screen_id}_{$box_id}`

*Filters the postbox classes for a specific screen and box ID combo.*

The dynamic portions of the hook name, `$screen_id` and `$box_id`, refer to
the screen ID and meta box ID, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classes` | `string[]` | An array of postbox classes.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1319](../../wordpress/wp-admin/includes/post.php#L1319-L1329)

### `editable_slug`

*This filter is documented in wp-admin/edit-tag-form.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$uri` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1390](../../wordpress/wp-admin/includes/post.php#L1390-L1391)

### `editable_slug`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_name` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1399](../../wordpress/wp-admin/includes/post.php#L1399-L1399)

### `get_sample_permalink`

*Filters the sample permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$permalink` | `array` | {<br>    Array containing the sample permalink with placeholder for the post name, and the post name.<br><br>    @type string $0 The permalink with placeholder for the post name.<br>    @type string $1 The post name.<br>}
`$post->ID` |  | 
`$title` | `string` | Post title.
`$name` | `string` | Post name (slug).
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1405](../../wordpress/wp-admin/includes/post.php#L1405-L1421)

### `get_sample_permalink_html`

*Filters the sample permalink HTML markup.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `string` | Sample permalink HTML markup.
`$post->ID` |  | 
`$new_title` | `string` | New sample permalink title.
`$new_slug` | `string` | New sample permalink slug.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added `$post` parameter.
`2.9.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1493](../../wordpress/wp-admin/includes/post.php#L1493-L1505)

### `admin_post_thumbnail_size`

*Filters the size used to display the post thumbnail image in the 'Featured image' meta box.*

Note: When a theme adds 'post-thumbnail' support, a special 'post-thumbnail'
image size is registered, which differs from the 'thumbnail' image size
managed via the Settings > Media screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$thumbnail_id` | `int` | Post thumbnail attachment ID.
`$post` | `\WP_Post` | The post object associated with the thumbnail.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1537](../../wordpress/wp-admin/includes/post.php#L1537-L1551)

### `admin_post_thumbnail_html`

*Filters the admin post thumbnail HTML markup to return.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | Admin post thumbnail HTML markup.
`$post->ID` |  | 
`$thumbnail_id` | `int\|null` | Thumbnail attachment ID, or null if there isn't one.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Added the `$thumbnail_id` parameter.
`3.5.0` | Added the `$post_id` parameter.
`2.9.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1569](../../wordpress/wp-admin/includes/post.php#L1569-L1580)

### `wp_check_post_lock_window`

*This filter is documented in wp-admin/includes/ajax-actions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`150` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1611](../../wordpress/wp-admin/includes/post.php#L1611-L1612)

### `show_post_locked_dialog`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post` |  | 
`$user` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1678](../../wordpress/wp-admin/includes/post.php#L1678-L1678)

### `override_post_lock`

*Filters whether to allow the post lock to be overridden.*

Returning false from the filter will disable the ability
to override the post lock.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post` | `\WP_Post` | Post object.
`$user` | `\WP_User` | The user with the lock for the post.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 1722](../../wordpress/wp-admin/includes/post.php#L1722-L1734)

### `redirect_post_location`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` |  | 
`$post_id` |  | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2034](../../wordpress/wp-admin/includes/post.php#L2034-L2034)

### `use_block_editor_for_post`

*Filters whether a post is able to be edited in the block editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$use_block_editor` | `bool` | Whether the post can be edited or not.
`$post` | `\WP_Post` | The post being checked.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2129](../../wordpress/wp-admin/includes/post.php#L2129-L2137)

### `use_block_editor_for_post_type`

*Filters whether a post is able to be edited in the block editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post_type` | `string` | The post type being checked.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2165](../../wordpress/wp-admin/includes/post.php#L2165-L2173)

### `block_categories`

*Filters the default array of block categories.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_categories` | `array[]` | Array of block categories.
`$post` | `\WP_Post` | Post being loaded.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2218](../../wordpress/wp-admin/includes/post.php#L2218-L2226)

### `filter_block_editor_meta_boxes`

*Fires right before the meta boxes are rendered.*

This allows for the filtering of meta box data, that should already be
present by this point. Do not use as a means of adding meta box data.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_meta_boxes` | `array` | Global meta box state.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/includes/post.php](../../wordpress/wp-admin/includes/post.php), [line 2287](../../wordpress/wp-admin/includes/post.php#L2287-L2297)

### `update_translations_complete_actions`

*Filters the list of action links available following a translations update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_actions` | `string[]` | Array of translations update links.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-language-pack-upgrader-skin.php](../../wordpress/wp-admin/includes/class-language-pack-upgrader-skin.php), [line 82](../../wordpress/wp-admin/includes/class-language-pack-upgrader-skin.php#L82-L89)

### `async_update_translation`

*Filters whether to asynchronously update translation for core, a plugin, or a theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update` | `bool` | Whether to update.
`$language_update` | `object` | The update offer.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-admin/includes/class-language-pack-upgrader.php](../../wordpress/wp-admin/includes/class-language-pack-upgrader.php), [line 73](../../wordpress/wp-admin/includes/class-language-pack-upgrader.php#L73-L81)

### `install_plugin_complete_actions`

*Filters the list of action links available following a single plugin installation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$install_actions` | `string[]` | Array of plugin action links.
`$this->api` |  | 
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-plugin-installer-skin.php](../../wordpress/wp-admin/includes/class-plugin-installer-skin.php), [line 161](../../wordpress/wp-admin/includes/class-plugin-installer-skin.php#L161-L172)

### `install_plugin_overwrite_comparison`

*Filters the compare table output for overwriting a plugin package on upload.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$table` | `string` | The output table with Name, Version, Author, RequiresWP, and RequiresPHP info.
`$current_plugin_data` | `array` | Array with current plugin data.
`$new_plugin_data` | `array` | Array with uploaded plugin data.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-plugin-installer-skin.php](../../wordpress/wp-admin/includes/class-plugin-installer-skin.php), [line 245](../../wordpress/wp-admin/includes/class-plugin-installer-skin.php#L245-L254)

### `install_plugin_overwrite_actions`

*Filters the list of action links available following a single plugin installation failure
when overwriting is allowed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$install_actions` | `string[]` | Array of plugin action links.
`$this->api` |  | 
`$new_plugin_data` | `array` | Array with uploaded plugin data.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-plugin-installer-skin.php](../../wordpress/wp-admin/includes/class-plugin-installer-skin.php), [line 327](../../wordpress/wp-admin/includes/class-plugin-installer-skin.php#L327-L337)

### `editable_extensions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_types` |  | 
`$plugin` |  | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 233](../../wordpress/wp-admin/includes/file.php#L233-L233)

### `wp_theme_editor_filetypes`

*Filters the list of file types allowed for editing in the theme editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_types` | `string[]` | An array of editable theme file extensions.
`$theme` | `\WP_Theme` | The current theme object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 283](../../wordpress/wp-admin/includes/file.php#L283-L291)

### `https_local_ssl_verify`

*This filter is documented in wp-includes/class-wp-http-streams.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 526](../../wordpress/wp-admin/includes/file.php#L526-L527)

### `{$action}_prefilter`

*Filters the data for a file before it is uploaded to WordPress.*

The dynamic portion of the hook name, `$action`, refers to the post action.
Possible filter names include:

 - `wp_handle_sideload_prefilter`
 - `wp_handle_upload_prefilter`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` | `string[]` | An array of data for the file. Reference to a single element of `$_FILES`.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | Converted to a dynamic hook with `$action`.
`2.9.0` | as 'wp_handle_upload_prefilter'.

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 756](../../wordpress/wp-admin/includes/file.php#L756-L770)

### `{$action}_overrides`

*Filters the override parameters for a file before it is uploaded to WordPress.*

The dynamic portion of the hook name, `$action`, refers to the post action.
Possible filter names include:

 - `wp_handle_sideload_overrides`
 - `wp_handle_upload_overrides`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$overrides` | `array\|false` | An array of override parameters for this file. Boolean false if none are<br>provided. @see _wp_handle_upload().
`$file` | `string[]` | An array of data for the file. Reference to a single element of `$_FILES`.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 772](../../wordpress/wp-admin/includes/file.php#L772-L787)

### `pre_move_uploaded_file`

*Filters whether to short-circuit moving the uploaded file after passing all checks.*

If a non-null value is returned from the filter, moving the file and any related
error reporting will be completely skipped.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$file` | `string[]` | An array of data for a single file.
`$new_file` | `string` | Filename of the newly-uploaded file.
`$type` | `string` | Mime type of the newly-uploaded file.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 913](../../wordpress/wp-admin/includes/file.php#L913-L926)

### `wp_handle_upload`

*Filters the data array for the uploaded file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('file' => $new_file, 'url' => $url, 'type' => $type)` |  | 
`'wp_handle_sideload' === $action ? 'sideload' : 'upload'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 967](../../wordpress/wp-admin/includes/file.php#L967-L989)

### `download_url_error_max_body_size`

*Filters the maximum error response body size in `download_url()`.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`KB_IN_BYTES` |  | 

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 1106](../../wordpress/wp-admin/includes/file.php#L1106-L1115)

### `wp_signature_hosts`

*Filters the list of hosts which should have Signature Verification attempted on.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('wordpress.org', 'downloads.wordpress.org', 's.w.org')` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 1135](../../wordpress/wp-admin/includes/file.php#L1135-L1142)

### `wp_signature_url`

*Filters the URL where the signature for a file is located.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$signature_url` | `false\|string` | The URL where signatures can be found for a file, or false if none are known.
`$url` | `string` | The URL being verified.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 1160](../../wordpress/wp-admin/includes/file.php#L1160-L1168)

### `wp_signature_softfail`

*Filters whether Signature Verification failures should be allowed to soft fail.*

WARNING: This may be removed from a future release.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$url` | `string` | The url being accessed.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 1190](../../wordpress/wp-admin/includes/file.php#L1190-L1200)

### `wp_trusted_keys`

*Filters the valid signing keys used to verify the contents of files.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$trusted_keys` | `string[]` | The trusted keys that may sign packages.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 1429](../../wordpress/wp-admin/includes/file.php#L1429-L1436)

### `unzip_file_use_ziparchive`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 1498](../../wordpress/wp-admin/includes/file.php#L1498-L1498)

### `filesystem_method_file`

*Filters the path for a specific filesystem method class file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`ABSPATH . 'wp-admin/includes/class-wp-filesystem-' . $method . '.php'` |  | 
`$method` | `string` | The filesystem method to use.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 1861](../../wordpress/wp-admin/includes/file.php#L1861-L1871)

### `filesystem_method`

*Filters the filesystem method to use.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$method` | `string` | Filesystem method to return.
`$args` | `array` | An array of connection details for the method.
`$context` | `string` | Full path to the directory that is tested for being writable.
`$allow_relaxed_file_ownership` | `bool` | Whether to allow Group/World writable.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 2000](../../wordpress/wp-admin/includes/file.php#L2000-L2010)

### `request_filesystem_credentials`

*Filters the filesystem credentials.*

Returning anything other than an empty string will effectively short-circuit
output of the filesystem credentials form, returning that value instead.

A filter should return true if no filesystem credentials are required, false if they are required but have not been
provided, or an array of credentials if they are required and have been provided.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$form_post` | `string` | The URL to post the form to.
`$type` | `string` | Chosen type of filesystem.
`$error` | `bool\|\WP_Error` | Whether the current request has failed to connect,<br>or an error object.
`$context` | `string` | Full path to the directory that is tested for<br>being writable.
`$extra_fields` | `array` | Extra POST fields.
`$allow_relaxed_file_ownership` | `bool` | Whether to allow Group/World writable.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | The `$context` parameter default changed from `false` to an empty string.
`2.5.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 2046](../../wordpress/wp-admin/includes/file.php#L2046-L2068)

### `fs_ftp_connection_types`

*Filters the connection types to output to the filesystem credentials form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$types` | `string[]` | Types of connections.
`$credentials` | `array` | Credentials to connect with.
`$type` | `string` | Chosen filesystem method.
`$error` | `bool\|\WP_Error` | Whether the current request has failed to connect,<br>or an error object.
`$context` | `string` | Full path to the directory that is tested for being writable.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | The `$context` parameter default changed from `false` to an empty string.
`2.9.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 2182](../../wordpress/wp-admin/includes/file.php#L2182-L2195)

### `wp_opcache_invalidate_file`

*Filters whether to invalidate a file from the opcode cache.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$filepath` | `string` | The path to the PHP file to invalidate.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/file.php](../../wordpress/wp-admin/includes/file.php), [line 2398](../../wordpress/wp-admin/includes/file.php#L2398-L2406)

### `theme_action_links`

*This filter is documented in wp-admin/includes/class-wp-ms-themes-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` |  | 
`$theme` |  | 
`'all'` |  | 

Source: [wordpress/wp-admin/includes/class-wp-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-themes-list-table.php), [line 237](../../wordpress/wp-admin/includes/class-wp-themes-list-table.php#L237-L238)

### `theme_action_links_{$stylesheet}`

*This filter is documented in wp-admin/includes/class-wp-ms-themes-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` |  | 
`$theme` |  | 
`'all'` |  | 

Source: [wordpress/wp-admin/includes/class-wp-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-themes-list-table.php), [line 240](../../wordpress/wp-admin/includes/class-wp-themes-list-table.php#L240-L241)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$item->post_title` |  | 
`$item->ID` |  | 

Source: [wordpress/wp-admin/includes/class-walker-nav-menu-checklist.php](../../wordpress/wp-admin/includes/class-walker-nav-menu-checklist.php), [line 96](../../wordpress/wp-admin/includes/class-walker-nav-menu-checklist.php#L96-L97)

### `ms_sites_list_table_query_args`

*Filters the arguments for the site query in the sites list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | An array of get_sites() arguments.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 169](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L169-L176)

### `wpmu_blogs_columns`

*Filters the displayed site columns in Sites list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sites_columns` | `string[]` | An array of displayed site columns. Default 'cb',<br>'blogname', 'lastupdated', 'registered', 'users'.

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 373](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L373-L381)

### `display_site_states`

*Filters the default site display states for items in the Sites list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_states` | `array` | An array of site states. Default 'Main',<br>'Archived', 'Mature', 'Spam', 'Deleted'.
`$_site` |  | 

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 628](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L628-L637)

### `manage_sites_action_links`

*Filters the action links displayed for each site in the Sites list table.*

The 'Edit', 'Dashboard', 'Delete', and 'Visit' links are displayed by
default for each site. The site's status determines whether to show the
'Activate' or 'Deactivate' link, 'Unarchive' or 'Archive' links, and
'Not Spam' or 'Spam' link for each site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array_filter($actions)` |  | 
`$blog['blog_id']` |  | 
`$blogname` | `string` | Site path, formatted depending on whether it is a sub-domain<br>or subdirectory multisite installation.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php), [line 722](../../wordpress/wp-admin/includes/class-wp-ms-sites-list-table.php#L722-L737)

### `export_wp_filename`

*Filters the export filename.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_filename` | `string` | The name of the file for download.
`$sitename` | `string` | The site name.
`$date` | `string` | Today's date, formatted.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 85](../../wordpress/wp-admin/includes/export.php#L85-L94)

### `wxr_export_skip_termmeta`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$meta->meta_key` |  | 
`$meta` |  | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 341](../../wordpress/wp-admin/includes/export.php#L341-L341)

### `the_title_export`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_title` |  | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 552](../../wordpress/wp-admin/includes/export.php#L552-L552)

### `the_content_export`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_content` |  | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 561](../../wordpress/wp-admin/includes/export.php#L561-L561)

### `the_excerpt_export`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_excerpt` |  | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 570](../../wordpress/wp-admin/includes/export.php#L570-L570)

### `wxr_export_skip_postmeta`

*Filters whether to selectively skip post meta used for WXR exports.*

Returning a truthy value from the filter will skip the current meta
object from being exported.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$meta->meta_key` |  | 
`$meta` | `object` | Current meta object.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 604](../../wordpress/wp-admin/includes/export.php#L604-L616)

### `wxr_export_skip_commentmeta`

*Filters whether to selectively skip comment meta used for WXR exports.*

Returning a truthy value from the filter will skip the current meta
object from being exported.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$meta->meta_key` |  | 
`$meta` | `object` | Current meta object.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-admin/includes/export.php](../../wordpress/wp-admin/includes/export.php), [line 647](../../wordpress/wp-admin/includes/export.php#L647-L659)

### `plugin_files_exclusions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('CVS', 'node_modules', 'vendor', 'bower_components')` |  | 

Source: [wordpress/wp-admin/includes/plugin.php](../../wordpress/wp-admin/includes/plugin.php), [line 246](../../wordpress/wp-admin/includes/plugin.php#L246-L246)

### `themes_api_args`

*Filters arguments used to query for installer pages from the WordPress.org Themes API.*

Important: An object MUST be returned to this filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `object` | Arguments used to query for installer pages from the WordPress.org Themes API.
`$action` | `string` | Requested action. Likely values are 'theme_information',<br>'feature_list', or 'query_themes'.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/theme.php](../../wordpress/wp-admin/includes/theme.php), [line 487](../../wordpress/wp-admin/includes/theme.php#L487-L498)

### `themes_api`

*Filters whether to override the WordPress.org Themes API.*

Passing a non-false value will effectively short-circuit the WordPress.org API request.

If `$action` is 'query_themes', 'theme_information', or 'feature_list', an object MUST
be passed. If `$action` is 'hot_tags', an array should be passed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$action` | `string` | Requested action. Likely values are 'theme_information',<br>'feature_list', or 'query_themes'.
`$args` | `object` | Arguments used to query for installer pages from the Themes API.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/theme.php](../../wordpress/wp-admin/includes/theme.php), [line 500](../../wordpress/wp-admin/includes/theme.php#L500-L515)

### `themes_api_result`

*Filters the returned WordPress.org Themes API response.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$res` | `array\|object\|\WP_Error` | WordPress.org Themes API response.
`$action` | `string` | Requested action. Likely values are 'theme_information',<br>'feature_list', or 'query_themes'.
`$args` | `object` | Arguments used to query for installer pages from the WordPress.org Themes API.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/theme.php](../../wordpress/wp-admin/includes/theme.php), [line 596](../../wordpress/wp-admin/includes/theme.php#L596-L606)

### `pre_prepare_themes_for_js`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$themes` |  | 
`$current_theme` |  | 

Source: [wordpress/wp-admin/includes/theme.php](../../wordpress/wp-admin/includes/theme.php), [line 634](../../wordpress/wp-admin/includes/theme.php#L634-L634)

### `wp_prepare_themes_for_js`

*Filters the themes prepared for JavaScript, for themes.php.*

Could be useful for changing the order, which is by name by default.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_themes` | `array` | Array of theme data.

**Changelog**

Version | Description
------- | -----------
`3.8.0` | 

Source: [wordpress/wp-admin/includes/theme.php](../../wordpress/wp-admin/includes/theme.php), [line 762](../../wordpress/wp-admin/includes/theme.php#L762-L771)

### `illegal_user_logins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 193](../../wordpress/wp-admin/includes/user.php#L193-L193)

### `editable_roles`

*Filters the list of editable roles.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$all_roles` | `array[]` | Array of arrays containing role information.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 265](../../wordpress/wp-admin/includes/user.php#L265-L272)

### `get_users_drafts`

*Filters the user's drafts query string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query` | `string` | The user's drafts query string.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 309](../../wordpress/wp-admin/includes/user.php#L309-L316)

### `post_types_to_delete_with_user`

*Filters the list of post types to delete with a user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_types_to_delete` | `string[]` | Array of post types to delete.
`$id` | `int` | User ID.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/includes/user.php](../../wordpress/wp-admin/includes/user.php), [line 380](../../wordpress/wp-admin/includes/user.php#L380-L388)

### `update_feedback`

*Filters feedback messages displayed during the core update process.*

The filter is first evaluated after the zip file for the latest version
has been downloaded and unzipped. It is evaluated five more times during
the process:

1. Before WordPress begins the core upgrade process.
2. Before Maintenance Mode is enabled.
3. Before WordPress begins copying over the necessary files.
4. Before Maintenance Mode is disabled.
5. Before the database is upgraded.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Verifying the unpacked files&#8230;')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/update-core.php](../../wordpress/wp-admin/includes/update-core.php), [line 905](../../wordpress/wp-admin/includes/update-core.php#L905-L922)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Preparing to install the latest version&#8230;')` |  | 

Source: [wordpress/wp-admin/includes/update-core.php](../../wordpress/wp-admin/includes/update-core.php), [line 1046](../../wordpress/wp-admin/includes/update-core.php#L1046-L1047)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Enabling Maintenance mode&#8230;')` |  | 

Source: [wordpress/wp-admin/includes/update-core.php](../../wordpress/wp-admin/includes/update-core.php), [line 1108](../../wordpress/wp-admin/includes/update-core.php#L1108-L1109)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Copying the required files&#8230;')` |  | 

Source: [wordpress/wp-admin/includes/update-core.php](../../wordpress/wp-admin/includes/update-core.php), [line 1116](../../wordpress/wp-admin/includes/update-core.php#L1116-L1117)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Disabling Maintenance mode&#8230;')` |  | 

Source: [wordpress/wp-admin/includes/update-core.php](../../wordpress/wp-admin/includes/update-core.php), [line 1213](../../wordpress/wp-admin/includes/update-core.php#L1213-L1214)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Upgrading database&#8230;')` |  | 

Source: [wordpress/wp-admin/includes/update-core.php](../../wordpress/wp-admin/includes/update-core.php), [line 1307](../../wordpress/wp-admin/includes/update-core.php#L1307-L1308)

### `automatic_updater_disabled`

*Filters whether to entirely disable background updates.*

There are more fine-grained filters and controls for selective disabling.
This filter parallels the AUTOMATIC_UPDATER_DISABLED constant in name.

This also disables update notification emails. That may change in the future.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$disabled` | `bool` | Whether the updater should be disabled.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 43](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L43-L55)

### `automatic_updates_is_vcs_checkout`

*Filters whether the automatic updater should consider a filesystem
location to be potentially managed by a version control system.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$checkout` | `bool` | Whether a VCS checkout was discovered at `$context`<br>or ABSPATH, or anywhere higher.
`$context` | `string` | The filesystem context (a path) against which<br>filesystem status should be checked.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 111](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L111-L122)

### `auto_update_{$type}`

*Filters whether to automatically update core, a plugin, a theme, or a language.*

The dynamic portion of the hook name, `$type`, refers to the type of update
being checked. Potential hook names include:

 - `auto_update_core`
 - `auto_update_plugin`
 - `auto_update_theme`
 - `auto_update_translation`

Generally speaking, plugins, themes, and major core versions are not updated
by default, while translations and minor and development versions for core
are updated by default.

See the %1$s, %2$s,
and %3$s filters for a more straightforward way to
adjust core updates.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update` | `bool\|null` | Whether to update. The value of null is internally used<br>to detect whether nothing has hooked into this filter.
`$item` | `object` | The update offer.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$update` parameter accepts the value of null.
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 181](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L181-L207)

### `send_core_update_notification_email`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$notify` |  | 
`$item` |  | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 281](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L281-L281)

### `automatic_updates_send_debug_email`

*Filters whether to send a debugging email for each automatic background update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$development_version` | `bool` | By default, emails are sent if the<br>install is a development version.<br>Return false to avoid the email.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 523](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L523-L532)

### `auto_core_update_send_email`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$type` |  | 
`$core_update` |  | 
`$result` |  | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 688](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L688-L688)

### `auto_core_update_email`

*Filters the email sent following an automatic background core update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email` | `array` | {<br>    Array of email arguments that will be passed to wp_mail().<br><br>    @type string $to      The email recipient. An array of emails<br>                           can be returned, as handled by wp_mail().<br>    @type string $subject The email's subject.<br>    @type string $body    The email message body.<br>    @type string $headers Any email headers, defaults to no headers.<br>}
`$type` | `string` | The type of email being sent. Can be one of<br>'success', 'fail', 'manual', 'critical'.
`$core_update` | `object` | The update offer that was attempted.
`$result` | `mixed` | The result for the core update. Can be WP_Error.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 869](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L869-L888)

### `auto_plugin_update_send_email`

*Filters whether to send an email following an automatic background plugin update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$update_results['plugin']` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.1` | Added the `$update_results` parameter.
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 906](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L906-L915)

### `auto_theme_update_send_email`

*Filters whether to send an email following an automatic background theme update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$update_results['theme']` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.1` | Added the `$update_results` parameter.
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 929](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L929-L938)

### `auto_plugin_theme_update_email`

*Filters the email sent following an automatic background update for plugins and themes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email` | `array` | {<br>    Array of email arguments that will be passed to wp_mail().<br><br>    @type string $to      The email recipient. An array of emails<br>                          can be returned, as handled by wp_mail().<br>    @type string $subject The email's subject.<br>    @type string $body    The email message body.<br>    @type string $headers Any email headers, defaults to no headers.<br>}
`$type` | `string` | The type of email being sent. Can be one of 'success', 'fail', 'mixed'.
`$successful_updates` | `array` | A list of updates that succeeded.
`$failed_updates` | `array` | A list of updates that failed.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 1226](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L1226-L1244)

### `automatic_updates_debug_email`

*Filters the debug email that can be sent following an automatic
background core update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email` | `array` | {<br>    Array of email arguments that will be passed to wp_mail().<br><br>    @type string $to      The email recipient. An array of emails<br>                          can be returned, as handled by wp_mail().<br>    @type string $subject Email subject.<br>    @type string $body    Email message body.<br>    @type string $headers Any email headers. Default empty.<br>}
`$failures` | `int` | The number of failures encountered while upgrading.
`$this->update_results` |  | 

**Changelog**

Version | Description
------- | -----------
`3.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-automatic-updater.php](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php), [line 1401](../../wordpress/wp-admin/includes/class-wp-automatic-updater.php#L1401-L1419)

### `update_plugin_complete_actions`

*Filters the list of action links available following a single plugin update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_actions` | `string[]` | Array of plugin action links.
`$this->plugin` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-plugin-upgrader-skin.php](../../wordpress/wp-admin/includes/class-plugin-upgrader-skin.php), [line 109](../../wordpress/wp-admin/includes/class-plugin-upgrader-skin.php#L109-L117)

### `site_status_test_result`

*Filters the output of a finished Site Health test.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`call_user_func($callback)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-site-health.php](../../wordpress/wp-admin/includes/class-wp-site-health.php), [line 156](../../wordpress/wp-admin/includes/class-wp-site-health.php#L156-L177)

### `site_status_test_php_modules`

*An array representing all the modules we wish to test for.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$modules` | `array` | {<br>    An associative array of modules to test for.<br><br>    @type array ...$0 {<br>        An associative array of module properties used during testing.<br>        One of either `$function` or `$extension` must be provided, or they will fail by default.<br><br>        @type string $function     Optional. A function name to test for the existence of.<br>        @type string $extension    Optional. An extension to check if is loaded in PHP.<br>        @type string $constant     Optional. A constant name to check for to verify an extension exists.<br>        @type string $class        Optional. A class name to check for to verify an extension exists.<br>        @type bool   $required     Is this a required feature or not.<br>        @type string $fallback_for Optional. The module this module replaces as a fallback.<br>    }<br>}

**Changelog**

Version | Description
------- | -----------
`5.3.0` | The `$constant` and `$class` parameters were added.
`5.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-site-health.php](../../wordpress/wp-admin/includes/class-wp-site-health.php), [line 951](../../wordpress/wp-admin/includes/class-wp-site-health.php#L951-L973)

### `https_local_ssl_verify`

*This filter is documented in wp-includes/class-wp-http-streams.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-admin/includes/class-wp-site-health.php](../../wordpress/wp-admin/includes/class-wp-site-health.php), [line 2043](../../wordpress/wp-admin/includes/class-wp-site-health.php#L2043-L2044)

### `site_status_tests`

*Add or modify which site status tests are run on a site.*

The site health is determined by a set of tests based on best practices from
both the WordPress Hosting Team, but also web standards in general.

Some sites may not have the same requirements, for example the automatic update
checks may be handled by a host, and are therefore disabled in core.
Or maybe you want to introduce a new test, is caching enabled/disabled/stale for example.

Tests may be added either as direct, or asynchronous ones. Any test that may require some time
to complete should run asynchronously, to avoid extended loading periods within wp-admin.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tests` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | Added the `async_direct_test` array key.
Added the `skip_cron` array key.
`5.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-site-health.php](../../wordpress/wp-admin/includes/class-wp-site-health.php), [line 2384](../../wordpress/wp-admin/includes/class-wp-site-health.php#L2384-L2421)

### `https_local_ssl_verify`

*This filter is documented in wp-includes/class-wp-http-streams.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-admin/includes/class-wp-site-health.php](../../wordpress/wp-admin/includes/class-wp-site-health.php), [line 2656](../../wordpress/wp-admin/includes/class-wp-site-health.php#L2656-L2657)

### `update_bulk_theme_complete_actions`

*Filters the list of action links available following bulk theme updates.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_actions` | `string[]` | Array of theme action links.
`$this->theme_info` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-bulk-theme-upgrader-skin.php](../../wordpress/wp-admin/includes/class-bulk-theme-upgrader-skin.php), [line 64](../../wordpress/wp-admin/includes/class-bulk-theme-upgrader-skin.php#L64-L72)

### `install_theme_complete_actions`

*Filters the list of action links available following a single theme installation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$install_actions` | `string[]` | Array of theme action links.
`$this->api` |  | 
`$stylesheet` | `string` | Theme directory name.
`$theme_info` | `\WP_Theme` | Theme object.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-theme-installer-skin.php](../../wordpress/wp-admin/includes/class-theme-installer-skin.php), [line 174](../../wordpress/wp-admin/includes/class-theme-installer-skin.php#L174-L184)

### `install_theme_overwrite_comparison`

*Filters the compare table output for overwriting a theme package on upload.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$table` | `string` | The output table with Name, Version, Author, RequiresWP, and RequiresPHP info.
`$current_theme_data` | `array` | Array with current theme data.
`$new_theme_data` | `array` | Array with uploaded theme data.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-theme-installer-skin.php](../../wordpress/wp-admin/includes/class-theme-installer-skin.php), [line 280](../../wordpress/wp-admin/includes/class-theme-installer-skin.php#L280-L289)

### `install_theme_overwrite_actions`

*Filters the list of action links available following a single theme installation failure
when overwriting is allowed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$install_actions` | `string[]` | Array of theme action links.
`$this->api` |  | 
`$new_theme_data` | `array` | Array with uploaded theme data.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-theme-installer-skin.php](../../wordpress/wp-admin/includes/class-theme-installer-skin.php), [line 362](../../wordpress/wp-admin/includes/class-theme-installer-skin.php#L362-L372)

### `the_category`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$category->name` |  | 
`''` |  | 
`''` |  | 

Source: [wordpress/wp-admin/includes/class-walker-category-checklist.php](../../wordpress/wp-admin/includes/class-walker-category-checklist.php), [line 103](../../wordpress/wp-admin/includes/class-walker-category-checklist.php#L103-L103)

### `the_category`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$category->name` |  | 
`''` |  | 
`''` |  | 

Source: [wordpress/wp-admin/includes/class-walker-category-checklist.php](../../wordpress/wp-admin/includes/class-walker-category-checklist.php), [line 113](../../wordpress/wp-admin/includes/class-walker-category-checklist.php#L113-L113)

### `user_request_key_expiration`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`DAY_IN_SECONDS` |  | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 197](../../wordpress/wp-admin/includes/privacy-tools.php#L197-L197)

### `wp_privacy_export_expiration`

*This filter is documented in wp-includes/functions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`3 * DAY_IN_SECONDS` |  | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 583](../../wordpress/wp-admin/includes/privacy-tools.php#L583-L584)

### `wp_privacy_personal_data_email_to`

*Filters the recipient of the personal data export email notification.*

Should be used with great caution to avoid sending the data export link to wrong emails.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$request->email` |  | 
`$request` | `\WP_User_Request` | The request that is initiating the notification.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 594](../../wordpress/wp-admin/includes/privacy-tools.php#L594-L603)

### `wp_privacy_personal_data_email_subject`

*Filters the subject of the email sent when an export request is completed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$subject` | `string` | The email subject.
`$site_name` |  | 
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request           User request object.<br>    @type int             $expiration        The time in seconds until the export file expires.<br>    @type string          $expiration_date   The localized date and time when the export file expires.<br>    @type string          $message_recipient The address that the email will be sent to. Defaults<br>                                             to the value of `$request->email`, but can be changed<br>                                             by the `wp_privacy_personal_data_email_to` filter.<br>    @type string          $export_file_url   The export file URL.<br>    @type string          $sitename          The site name sending the mail.<br>    @type string          $siteurl           The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 618](../../wordpress/wp-admin/includes/privacy-tools.php#L618-L639)

### `wp_privacy_personal_data_email_content`

*Filters the text of the email sent with a personal data export file.*

The following strings have a special meaning and will get replaced dynamically:
###EXPIRATION###         The date when the URL will be automatically deleted.
###LINK###               URL of the personal data export file for the user.
###SITENAME###           The name of the site.
###SITEURL###            The URL to the site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_text` | `string` | Text in the email.
`$request_id` | `int` | The request ID for this personal data export.
`$email_data` | `array` | {<br>Data relating to the account action email.<br><br>@type WP_User_Request $request           User request object.<br>@type int             $expiration        The time in seconds until the export file expires.<br>@type string          $expiration_date   The localized date and time when the export file expires.<br>@type string          $message_recipient The address that the email will be sent to. Defaults<br>                                         to the value of `$request->email`, but can be changed<br>                                         by the `wp_privacy_personal_data_email_to` filter.<br>@type string          $export_file_url   The export file URL.<br>@type string          $sitename          The site name sending the mail.<br>@type string          $siteurl           The site URL sending the mail.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | Introduced the `$email_data` array.
`4.9.6` | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 657](../../wordpress/wp-admin/includes/privacy-tools.php#L657-L684)

### `wp_privacy_personal_data_email_headers`

*Filters the headers of the email sent with a personal data export file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$headers` | `string\|array` | The email headers.
`$subject` | `string` | The email subject.
`$content` | `string` | The email content.
`$request_id` | `int` | The request ID.
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request           User request object.<br>    @type int             $expiration        The time in seconds until the export file expires.<br>    @type string          $expiration_date   The localized date and time when the export file expires.<br>    @type string          $message_recipient The address that the email will be sent to. Defaults<br>                                             to the value of `$request->email`, but can be changed<br>                                             by the `wp_privacy_personal_data_email_to` filter.<br>    @type string          $export_file_url   The export file URL.<br>    @type string          $sitename          The site name sending the mail.<br>    @type string          $siteurl           The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 694](../../wordpress/wp-admin/includes/privacy-tools.php#L694-L717)

### `wp_privacy_personal_data_exporters`

*This filter is documented in wp-admin/includes/ajax-actions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 794](../../wordpress/wp-admin/includes/privacy-tools.php#L794-L795)

### `wp_privacy_personal_data_erasers`

*This filter is documented in wp-admin/includes/ajax-actions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/privacy-tools.php](../../wordpress/wp-admin/includes/privacy-tools.php), [line 927](../../wordpress/wp-admin/includes/privacy-tools.php#L927-L928)

### `upgrader_pre_download`

*Filters whether to return the package.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$package` | `string` | The package file name.
`$this` |  | 
`$hook_extra` | `array` | Extra arguments passed to hooked filters.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$hook_extra` parameter.
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 256](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L256-L268)

### `upgrader_pre_install`

*Filters the install response before the installation has started.*

Returning a truthy value, or one that could be evaluated as a WP_Error
will effectively short-circuit the installation, returning that value
instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$args['hook_extra']` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 478](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L478-L490)

### `upgrader_source_selection`

*Filters the source file location for the upgrade package.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$source` | `string` | File source location.
`$remote_source` | `string` | Remote file source location.
`$this` |  | 
`$args['hook_extra']` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The $hook_extra parameter became available.
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 516](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L516-L527)

### `upgrader_clear_destination`

*Filters whether the upgrader cleared the destination.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$removed` | `true\|\WP_Error` | Whether the destination was cleared. true upon success, WP_Error on failure.
`$local_destination` | `string` | The local package destination.
`$remote_destination` | `string` | The remote package destination.
`$args['hook_extra']` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 562](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L562-L572)

### `upgrader_post_install`

*Filters the installation response after the installation has finished.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$args['hook_extra']` |  | 
`$this->result` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 615](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L615-L624)

### `upgrader_package_options`

*Filters the package options before running an update.*

See also %1$s.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$options` | `array` | {<br>    Options used by the upgrader.<br><br>    @type string $package                     Package for update.<br>    @type string $destination                 Update location.<br>    @type bool   $clear_destination           Clear the destination resource.<br>    @type bool   $clear_working               Clear the working resource.<br>    @type bool   $abort_if_destination_exists Abort if the Destination directory exists.<br>    @type bool   $is_multi                    Whether the upgrader is running multiple times.<br>    @type array  $hook_extra {<br>        Extra hook arguments.<br><br>        @type string $action               Type of action. Default 'update'.<br>        @type string $type                 Type of update process. Accepts 'plugin', 'theme', or 'core'.<br>        @type bool   $bulk                 Whether the update process is a bulk update. Default true.<br>        @type string $plugin               Path to the plugin file relative to the plugins directory.<br>        @type string $theme                The stylesheet or template name of the theme.<br>        @type string $language_update_type The language pack update type. Accepts 'plugin', 'theme',<br>                                           or 'core'.<br>        @type object $language_update      The language pack update offer.<br>    }<br>}

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 682](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L682-L712)

### `upgrader_install_package_result`

*Filters the result of WP_Upgrader::install_package().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `array\|\WP_Error` | Result from WP_Upgrader::install_package().
`$options['hook_extra']` |  | 

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-upgrader.php](../../wordpress/wp-admin/includes/class-wp-upgrader.php), [line 801](../../wordpress/wp-admin/includes/class-wp-upgrader.php#L801-L809)

### `post_edit_category_parent_dropdown_args`

*Filters the arguments for the taxonomy parent dropdown on the Post Edit page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parent_dropdown_args` | `array` | {<br>    Optional. Array of arguments to generate parent dropdown.<br><br>    @type string   $taxonomy         Name of the taxonomy to retrieve.<br>    @type bool     $hide_if_empty    True to skip generating markup if no<br>                                     categories are found. Default 0.<br>    @type string   $name             Value for the 'name' attribute<br>                                     of the select element.<br>                                     Default "new{$tax_name}_parent".<br>    @type string   $orderby          Which column to use for ordering<br>                                     terms. Default 'name'.<br>    @type bool\|int $hierarchical     Whether to traverse the taxonomy<br>                                     hierarchy. Default 1.<br>    @type string   $show_option_none Text to display for the "none" option.<br>                                     Default "&mdash; {$parent} &mdash;",<br>                                     where `$parent` is 'parent_item'<br>                                     taxonomy label.<br>}

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 655](../../wordpress/wp-admin/includes/meta-boxes.php#L655-L679)

### `editable_slug`

*This filter is documented in wp-admin/edit-tag-form.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_name` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 887](../../wordpress/wp-admin/includes/meta-boxes.php#L887-L888)

### `page_attributes_dropdown_pages_args`

*Filters the arguments used to generate a Pages drop-down element.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$dropdown_args` | `array` | Array of arguments used to generate the pages drop-down.
`$post` | `\WP_Post` | The current post.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 953](../../wordpress/wp-admin/includes/meta-boxes.php#L953-L963)

### `default_page_template_title`

*Filters the title of the default page template displayed in the drop-down.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Default template')` |  | 
`'meta-box'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-admin/includes/meta-boxes.php](../../wordpress/wp-admin/includes/meta-boxes.php), [line 992](../../wordpress/wp-admin/includes/meta-boxes.php#L992-L1001)

### `wp_installed_email`

*Filters the contents of the email sent to the site administrator when WordPress is installed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$installed_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The email address of the recipient.<br>    @type string $subject The subject of the email.<br>    @type string $message The content of the email.<br>    @type string $headers Headers.<br>}
`$user` | `\WP_User` | The site administrator user object.
`$blog_title` | `string` | The site title.
`$blog_url` | `string` | The site URL.
`$password` | `string` | The site administrator's password. Note that a placeholder message<br>is usually passed instead of the user's actual password.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/includes/upgrade.php](../../wordpress/wp-admin/includes/upgrade.php), [line 640](../../wordpress/wp-admin/includes/upgrade.php#L640-L659)

### `dbdelta_queries`

*Filters the dbDelta SQL queries.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$queries` | `string[]` | An array of dbDelta SQL queries.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/upgrade.php](../../wordpress/wp-admin/includes/upgrade.php), [line 2731](../../wordpress/wp-admin/includes/upgrade.php#L2731-L2738)

### `dbdelta_create_queries`

*Filters the dbDelta SQL queries for creating tables and/or databases.*

Queries filterable via this hook contain "CREATE TABLE" or "CREATE DATABASE".

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cqueries` | `string[]` | An array of dbDelta create SQL queries.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/upgrade.php](../../wordpress/wp-admin/includes/upgrade.php), [line 2760](../../wordpress/wp-admin/includes/upgrade.php#L2760-L2769)

### `dbdelta_insert_queries`

*Filters the dbDelta SQL queries for inserting or updating.*

Queries filterable via this hook contain "INSERT INTO" or "UPDATE".

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$iqueries` | `string[]` | An array of dbDelta insert or update SQL queries.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/upgrade.php](../../wordpress/wp-admin/includes/upgrade.php), [line 2771](../../wordpress/wp-admin/includes/upgrade.php#L2771-L2780)

### `wp_should_upgrade_global_tables`

*Filters if upgrade routines should be run on global tables.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$should_upgrade` | `bool` | Whether to run the upgrade routines on global tables.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/upgrade.php](../../wordpress/wp-admin/includes/upgrade.php), [line 3548](../../wordpress/wp-admin/includes/upgrade.php#L3548-L3555)

### `manage_{$screen->id}_columns`

*Filters the column headers for a list table on a specific screen.*

The dynamic portion of the hook name, `$screen->id`, refers to the
ID of a specific screen. For example, the screen ID for the Posts
list table is edit-post, so the filter for that screen would be
manage_edit-post_columns.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/screen.php](../../wordpress/wp-admin/includes/screen.php), [line 25](../../wordpress/wp-admin/includes/screen.php#L25-L37)

### `default_hidden_columns`

*Filters the default list of hidden columns.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hidden` | `string[]` | Array of IDs of columns hidden by default.
`$screen` | `\WP_Screen` | WP_Screen object of the current screen.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/screen.php](../../wordpress/wp-admin/includes/screen.php), [line 63](../../wordpress/wp-admin/includes/screen.php#L63-L71)

### `hidden_columns`

*Filters the list of hidden columns.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hidden` | `string[]` | Array of IDs of hidden columns.
`$screen` | `\WP_Screen` | WP_Screen object of the current screen.
`$use_defaults` | `bool` | Whether to show the default columns.

**Changelog**

Version | Description
------- | -----------
`4.4.1` | Added the `use_defaults` parameter.
`4.4.0` | 

Source: [wordpress/wp-admin/includes/screen.php](../../wordpress/wp-admin/includes/screen.php), [line 74](../../wordpress/wp-admin/includes/screen.php#L74-L84)

### `default_hidden_meta_boxes`

*Filters the default list of hidden meta boxes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hidden` | `string[]` | An array of IDs of meta boxes hidden by default.
`$screen` | `\WP_Screen` | WP_Screen object of the current screen.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/screen.php](../../wordpress/wp-admin/includes/screen.php), [line 170](../../wordpress/wp-admin/includes/screen.php#L170-L178)

### `hidden_meta_boxes`

*Filters the list of hidden meta boxes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hidden` | `string[]` | An array of IDs of hidden meta boxes.
`$screen` | `\WP_Screen` | WP_Screen object of the current screen.
`$use_defaults` | `bool` | Whether to show the default meta boxes.<br>Default true.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/screen.php](../../wordpress/wp-admin/includes/screen.php), [line 181](../../wordpress/wp-admin/includes/screen.php#L181-L191)

### `install_plugins_tabs`

*Filters the tabs shown on the Add Plugins screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tabs` | `string[]` | The tabs shown on the Add Plugins screen. Defaults include<br>'featured', 'popular', 'recommended', 'favorites', and 'upload'.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php), [line 122](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php#L122-L130)

### `install_plugins_nonmenu_tabs`

*Filters tabs not associated with a menu item on the Add Plugins screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nonmenu_tabs` | `string[]` | The tabs that don't have a menu item on the Add Plugins screen.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php), [line 132](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php#L132-L139)

### `install_plugins_table_api_args_{$tab}`

*Filters API request arguments for each Add Plugins screen tab.*

The dynamic portion of the hook name, `$tab`, refers to the plugin install tabs.
Default tabs include 'featured', 'popular', 'recommended', 'favorites', and 'upload'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array\|false` | Plugin install API arguments.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php), [line 212](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php#L212-L222)

### `views_{$screen->id}`

*This filter is documented in wp-admin/inclues/class-wp-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$views` |  | 

Source: [wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php), [line 316](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php#L316-L317)

### `plugin_install_action_links`

*Filters the install action links for a plugin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$action_links` | `string[]` | An array of plugin action links. Defaults are links to Details and Install Now.
`$plugin` | `array` | The plugin currently being listed.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php), [line 637](../../wordpress/wp-admin/includes/class-wp-plugin-install-list-table.php#L637-L645)

### `add_menu_classes`

*Filters administration menus array with classes added for top-level items.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu` | `array` | Associative array of administration menu items.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 238](../../wordpress/wp-admin/includes/menu.php#L238-L245)

### `custom_menu_order`

*Filters whether to enable custom ordering of the administration menu.*

See the %1$s filter for reordering menu items.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 250](../../wordpress/wp-admin/includes/menu.php#L250-L259)

### `menu_order`

*Filters the order of administration menu items.*

A truthy value must first be passed to the %1$s filter
for this filter to work. Use the following to enable custom menu ordering:

    add_filter( 'custom_menu_order', '__return_true' );

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_order` | `array` | An ordered array of menu items.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/menu.php](../../wordpress/wp-admin/includes/menu.php), [line 267](../../wordpress/wp-admin/includes/menu.php#L267-L279)

### `heartbeat_nopriv_received`

*Filters Heartbeat Ajax response in no-privilege environments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The no-priv Heartbeat response.
`$data` | `array` | The $_POST data sent.
`$screen_id` | `string` | The screen ID.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 34](../../wordpress/wp-admin/includes/ajax-actions.php#L34-L43)

### `heartbeat_nopriv_send`

*Filters Heartbeat Ajax response in no-privilege environments when no data is passed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The no-priv Heartbeat response.
`$screen_id` | `string` | The screen ID.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 46](../../wordpress/wp-admin/includes/ajax-actions.php#L46-L54)

### `term_search_min_chars`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`2` |  | 
`$tax` |  | 
`$s` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 145](../../wordpress/wp-admin/includes/ajax-actions.php#L145-L145)

### `autocomplete_users_for_site_admins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 268](../../wordpress/wp-admin/includes/ajax-actions.php#L268-L268)

### `wp_edit_nav_menu_walker`

*This filter is documented in wp-admin/includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'Walker_Nav_Menu_Edit'` |  | 
`$_POST['menu']` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 1512](../../wordpress/wp-admin/includes/ajax-actions.php#L1512-L1513)

### `nav_menu_meta_box_object`

*This filter is documented in wp-admin/includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menus_meta_box_object` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 1814](../../wordpress/wp-admin/includes/ajax-actions.php#L1814-L1815)

### `quick_edit_show_taxonomy`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tax_object->show_in_quick_edit` |  | 
`$taxonomy` |  | 
`$post['post_type']` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2056](../../wordpress/wp-admin/includes/ajax-actions.php#L2056-L2056)

### `wp_check_post_lock_window`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`150` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2858](../../wordpress/wp-admin/includes/ajax-actions.php#L2858-L2858)

### `ajax_query_attachments_args`

*Filters the arguments passed to WP_Query during an Ajax
call for querying attachments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query` | `array` | An array of query variables.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 2980](../../wordpress/wp-admin/includes/ajax-actions.php#L2980-L2990)

### `attachment_fields_to_save`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` |  | 
`$attachment_data` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3118](../../wordpress/wp-admin/includes/ajax-actions.php#L3118-L3119)

### `media_send_to_editor`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` |  | 
`$id` |  | 
`$attachment` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3264](../../wordpress/wp-admin/includes/ajax-actions.php#L3264-L3265)

### `{$type}_send_to_editor_url`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` |  | 
`$src` |  | 
`$link_text` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3336](../../wordpress/wp-admin/includes/ajax-actions.php#L3336-L3337)

### `wp_refresh_nonces`

*Filters the nonces to send to the New/Edit Post screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The Heartbeat response.
`$data` | `array` | The $_POST data sent.
`$screen_id` | `string` | The screen ID.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3370](../../wordpress/wp-admin/includes/ajax-actions.php#L3370-L3379)

### `heartbeat_received`

*Filters the Heartbeat response received.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The Heartbeat response.
`$data` | `array` | The $_POST data sent.
`$screen_id` | `string` | The screen ID.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3389](../../wordpress/wp-admin/includes/ajax-actions.php#L3389-L3398)

### `heartbeat_send`

*Filters the Heartbeat response sent.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The Heartbeat response.
`$screen_id` | `string` | The screen ID.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3401](../../wordpress/wp-admin/includes/ajax-actions.php#L3401-L3409)

### `install_themes_table_api_args_{$old_filter}`

*This filter is documented in wp-admin/includes/class-wp-theme-install-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3533](../../wordpress/wp-admin/includes/ajax-actions.php#L3533-L3534)

### `wp_create_file_in_uploads`

*This filter is documented in wp-admin/includes/class-custom-image-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cropped` |  | 
`$attachment_id` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3895](../../wordpress/wp-admin/includes/ajax-actions.php#L3895-L3896)

### `wp_create_file_in_uploads`

*This filter is documented in wp-admin/includes/class-custom-image-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cropped` |  | 
`$attachment_id` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3923](../../wordpress/wp-admin/includes/ajax-actions.php#L3923-L3924)

### `wp_ajax_cropped_attachment_metadata`

*Filters the cropped image attachment metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$metadata` | `array` | Attachment metadata.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3943](../../wordpress/wp-admin/includes/ajax-actions.php#L3943-L3952)

### `wp_ajax_cropped_attachment_id`

*Filters the attachment ID for a cropped image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attachment_id` | `int` | The attachment ID of the cropped image.
`$context` | `string` | The Customizer control requesting the cropped image.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 3955](../../wordpress/wp-admin/includes/ajax-actions.php#L3955-L3963)

### `wp_privacy_personal_data_exporters`

*Filters the array of exporter callbacks.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 4779](../../wordpress/wp-admin/includes/ajax-actions.php#L4779-L4798)

### `wp_privacy_personal_data_export_page`

*Filters a page of personal data exporter data. Used to build the export report.*

Allows the export response to be consumed by destinations in addition to Ajax.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The personal data for the given exporter and page.
`$exporter_index` | `int` | The index of the exporter that provided this data.
`$email_address` | `string` | The email address associated with this personal data.
`$page` | `int` | The page for this response.
`$request_id` | `int` | The privacy request post ID associated with this request.
`$send_as_email` | `bool` | Whether the final results of the export should be emailed to the user.
`$exporter_key` | `string` | The key (slug) of the exporter that provided this data.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 4896](../../wordpress/wp-admin/includes/ajax-actions.php#L4896-L4911)

### `wp_privacy_personal_data_erasers`

*Filters the array of personal data eraser callbacks.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 4969](../../wordpress/wp-admin/includes/ajax-actions.php#L4969-L4989)

### `wp_privacy_personal_data_erasure_page`

*Filters a page of personal data eraser data.*

Allows the erasure response to be consumed by destinations in addition to Ajax.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | The personal data for the given exporter and page.
`$eraser_index` | `int` | The index of the eraser that provided this data.
`$email_address` | `string` | The email address associated with this personal data.
`$page` | `int` | The page for this response.
`$request_id` | `int` | The privacy request post ID associated with this request.
`$eraser_key` | `string` | The key (slug) of the eraser that provided this data.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 5126](../../wordpress/wp-admin/includes/ajax-actions.php#L5126-L5140)

### `all_plugins`

*This filter is documented in wp-admin/includes/class-wp-plugins-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_plugins()` |  | 

Source: [wordpress/wp-admin/includes/ajax-actions.php](../../wordpress/wp-admin/includes/ajax-actions.php), [line 5372](../../wordpress/wp-admin/includes/ajax-actions.php#L5372-L5373)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$download->get_error_message()` |  | 

Source: [wordpress/wp-admin/includes/class-core-upgrader.php](../../wordpress/wp-admin/includes/class-core-upgrader.php), [line 130](../../wordpress/wp-admin/includes/class-core-upgrader.php#L130-L131)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` |  | 

Source: [wordpress/wp-admin/includes/class-core-upgrader.php](../../wordpress/wp-admin/includes/class-core-upgrader.php), [line 194](../../wordpress/wp-admin/includes/class-core-upgrader.php#L194-L195)

### `update_feedback`

*This filter is documented in wp-admin/includes/update-core.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->strings['start_rollback']` |  | 

Source: [wordpress/wp-admin/includes/class-core-upgrader.php](../../wordpress/wp-admin/includes/class-core-upgrader.php), [line 197](../../wordpress/wp-admin/includes/class-core-upgrader.php#L197-L198)

### `allow_dev_auto_core_updates`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$upgrade_dev` |  | 

Source: [wordpress/wp-admin/includes/class-core-upgrader.php](../../wordpress/wp-admin/includes/class-core-upgrader.php), [line 351](../../wordpress/wp-admin/includes/class-core-upgrader.php#L351-L351)

### `allow_minor_auto_core_updates`

*Filters whether to enable minor automatic core updates.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$upgrade_minor` | `bool` | Whether to enable minor automatic core updates.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-core-upgrader.php](../../wordpress/wp-admin/includes/class-core-upgrader.php), [line 360](../../wordpress/wp-admin/includes/class-core-upgrader.php#L360-L367)

### `allow_major_auto_core_updates`

*Filters whether to enable major automatic core updates.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$upgrade_major` | `bool` | Whether to enable major automatic core updates.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-core-upgrader.php](../../wordpress/wp-admin/includes/class-core-upgrader.php), [line 373](../../wordpress/wp-admin/includes/class-core-upgrader.php#L373-L380)

### `plugins_api_args`

*Filters the WordPress.org Plugin Installation API arguments.*

Important: An object MUST be returned to this filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `object` | Plugin API arguments.
`$action` | `string` | The type of information being requested from the Plugin Installation API.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/plugin-install.php](../../wordpress/wp-admin/includes/plugin-install.php), [line 124](../../wordpress/wp-admin/includes/plugin-install.php#L124-L134)

### `plugins_api`

*Filters the response for the current WordPress.org Plugin Installation API request.*

Passing a non-false value will effectively short-circuit the WordPress.org API request.

If `$action` is 'query_plugins' or 'plugin_information', an object MUST be passed.
If `$action` is 'hot_tags' or 'hot_categories', an array should be passed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$action` | `string` | The type of information being requested from the Plugin Installation API.
`$args` | `object` | Plugin API arguments.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/plugin-install.php](../../wordpress/wp-admin/includes/plugin-install.php), [line 136](../../wordpress/wp-admin/includes/plugin-install.php#L136-L150)

### `plugins_api_result`

*Filters the Plugin Installation API response results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$res` | `object\|\WP_Error` | Response object or WP_Error.
`$action` | `string` | The type of information being requested from the Plugin Installation API.
`$args` | `object` | Plugin API arguments.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/plugin-install.php](../../wordpress/wp-admin/includes/plugin-install.php), [line 225](../../wordpress/wp-admin/includes/plugin-install.php#L225-L234)

### `users_list_table_query_args`

*This filter is documented in wp-admin/includes/class-wp-users-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 

Source: [wordpress/wp-admin/includes/class-wp-ms-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php), [line 93](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php#L93-L94)

### `wpmu_users_columns`

*Filters the columns displayed in the Network Admin Users list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$users_columns` | `string[]` | An array of user columns. Default 'cb', 'username',<br>'name', 'email', 'registered', 'blogs'.

Source: [wordpress/wp-admin/includes/class-wp-ms-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php), [line 203](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php#L203-L211)

### `ms_user_list_site_class`

*Filters the span class for a site listing on the mulisite user list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_classes` | `string[]` | Array of class names used within the span tag. Default "site-#" with the site's network ID.
`$val->userblog_id` |  | 
`$val->site_id` |  | 
`$user` | `\WP_User` | WP_User object.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php), [line 376](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php#L376-L386)

### `ms_user_list_site_actions`

*Filters the action links displayed next the sites a user belongs to
in the Network Admin Users list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of action links to be displayed. Default 'Edit', 'View'.
`$val->userblog_id` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php), [line 414](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php#L414-L423)

### `manage_users_custom_column`

*This filter is documented in wp-admin/includes/class-wp-users-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$column_name` |  | 
`$user->ID` |  | 

Source: [wordpress/wp-admin/includes/class-wp-ms-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php), [line 450](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php#L450-L451)

### `ms_user_row_actions`

*Filters the action links displayed under each user in the Network Admin Users list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of action links to be displayed. Default 'Edit', 'Delete'.
`$user` | `\WP_User` | WP_User object.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-users-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php), [line 517](../../wordpress/wp-admin/includes/class-wp-ms-users-list-table.php#L517-L525)

### `comment_edit_pre`

*Filters the comment content before editing.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_content` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-admin/includes/comment.php](../../wordpress/wp-admin/includes/comment.php), [line 120](../../wordpress/wp-admin/includes/comment.php#L120-L127)

### `nav_menu_meta_box_object`

*Filters whether a menu items meta box will be added for the current
object type.*

If a falsey value is returned instead of an object, the menu items
meta box for the current meta box object will not be added.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type` | `\WP_Post_Type\|false` | The current object to add a menu items<br>meta box for.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/nav-menu.php](../../wordpress/wp-admin/includes/nav-menu.php), [line 218](../../wordpress/wp-admin/includes/nav-menu.php#L218-L230)

### `nav_menu_meta_box_object`

*This filter is documented in wp-admin/includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tax` |  | 

Source: [wordpress/wp-admin/includes/nav-menu.php](../../wordpress/wp-admin/includes/nav-menu.php), [line 253](../../wordpress/wp-admin/includes/nav-menu.php#L253-L254)

### `nav_menu_items_{$post_type_name}_recent`

*Filters the posts displayed in the 'Most Recent' tab of the current
post type's menu items meta box.*

The dynamic portion of the hook name, `$post_type_name`, refers to the post type name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$most_recent` | `\WP_Post[]` | An array of post objects being listed.
`$args` | `array` | An array of `WP_Query` arguments for the meta box.
`$box` | `array` | Arguments passed to `wp_nav_menu_item_post_type_meta_box()`.
`$recent_args` | `array` | An array of `WP_Query` arguments for 'Most Recent' tab.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$recent_args` parameter.
`4.3.0` | 

Source: [wordpress/wp-admin/includes/nav-menu.php](../../wordpress/wp-admin/includes/nav-menu.php), [line 542](../../wordpress/wp-admin/includes/nav-menu.php#L542-L556)

### `nav_menu_items_{$post_type_name}`

*Filters the posts displayed in the 'View All' tab of the current
post type's menu items meta box.*

The dynamic portion of the hook name, `$post_type_name`, refers
to the slug of the current post type.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$posts` | `object[]` | The posts for the current post type. Mostly `WP_Post` objects, but<br>can also contain "fake" post objects to represent other menu items.
`$args` | `array` | An array of `WP_Query` arguments.
`$post_type` | `\WP_Post_Type` | The current post type object for this menu item meta box.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Converted the `$post_type` parameter to accept a WP_Post_Type object.
`3.2.0` | 

Source: [wordpress/wp-admin/includes/nav-menu.php](../../wordpress/wp-admin/includes/nav-menu.php), [line 629](../../wordpress/wp-admin/includes/nav-menu.php#L629-L646)

### `wp_edit_nav_menu_walker`

*Filters the Walker class used when adding nav menu items.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'Walker_Nav_Menu_Edit'` |  | 
`$menu_id` | `int` | ID of the menu being rendered.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/nav-menu.php](../../wordpress/wp-admin/includes/nav-menu.php), [line 1042](../../wordpress/wp-admin/includes/nav-menu.php#L1042-L1050)

### `translations_api`

*Allows a plugin to override the WordPress.org Translation Installation API entirely.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$type` | `string` | The type of translations being requested.
`$args` | `object` | Translation API arguments.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-admin/includes/translation-install.php](../../wordpress/wp-admin/includes/translation-install.php), [line 27](../../wordpress/wp-admin/includes/translation-install.php#L27-L36)

### `translations_api_result`

*Filters the Translation Installation API response results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$res` | `object\|\WP_Error` | Response object or WP_Error.
`$type` | `string` | The type of translations being requested.
`$args` | `object` | Translation API arguments.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-admin/includes/translation-install.php](../../wordpress/wp-admin/includes/translation-install.php), [line 100](../../wordpress/wp-admin/includes/translation-install.php#L100-L109)

### `wp_create_file_in_uploads`

*This filter is documented in wp-admin/includes/class-custom-image-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image` |  | 
`$attachment_id` |  | 

Source: [wordpress/wp-admin/includes/class-custom-image-header.php](../../wordpress/wp-admin/includes/class-custom-image-header.php), [line 841](../../wordpress/wp-admin/includes/class-custom-image-header.php#L841-L842)

### `wp_create_file_in_uploads`

*This filter is documented in wp-admin/includes/class-custom-image-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cropped` |  | 
`$attachment_id` |  | 

Source: [wordpress/wp-admin/includes/class-custom-image-header.php](../../wordpress/wp-admin/includes/class-custom-image-header.php), [line 984](../../wordpress/wp-admin/includes/class-custom-image-header.php#L984-L985)

### `wp_header_image_attachment_metadata`

*Filters the header image attachment metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$metadata` | `array` | Attachment metadata.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-admin/includes/class-custom-image-header.php](../../wordpress/wp-admin/includes/class-custom-image-header.php), [line 1262](../../wordpress/wp-admin/includes/class-custom-image-header.php#L1262-L1271)

### `wp_create_file_in_uploads`

*This filter is documented in wp-admin/includes/class-custom-image-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cropped` |  | 
`$attachment_id` |  | 

Source: [wordpress/wp-admin/includes/class-custom-image-header.php](../../wordpress/wp-admin/includes/class-custom-image-header.php), [line 1320](../../wordpress/wp-admin/includes/class-custom-image-header.php#L1320-L1321)

### `edit_posts_per_page`

*This filter is documented in wp-admin/includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$per_page` |  | 
`$post_type` |  | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 159](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L159-L160)

### `disable_categories_dropdown`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post_type` |  | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 445](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L445-L445)

### `disable_formats_dropdown`

*Filters whether to remove the 'Formats' drop-down from the post list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post_type` | `string` | Post type slug.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$post_type` parameter was added.
`5.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 474](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L474-L483)

### `manage_taxonomies_for_{$post_type}_columns`

*Filters the taxonomy columns in the Posts list table.*

The dynamic portion of the hook name, `$post_type`, refers to the post
type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomies` | `string[]` | Array of taxonomy names to show columns for.
`$post_type` | `string` | The post type.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 629](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L629-L640)

### `manage_pages_columns`

*Filters the columns displayed in the Pages list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$posts_columns` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 664](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L664-L671)

### `manage_posts_columns`

*Filters the columns displayed in the Posts list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$posts_columns` |  | 
`$post_type` | `string` | The post type slug.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 674](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L674-L682)

### `manage_{$post_type}_posts_columns`

*Filters the columns displayed in the Posts list table for a specific post type.*

The dynamic portion of the hook name, `$post_type`, refers to the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$posts_columns` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 685](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L685-L694)

### `wp_list_table_show_post_checkbox`

*Filters whether to show the bulk edit checkbox for a post in its list table.*

By default the checkbox is only shown if the current user can edit the post.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$show` | `bool` | Whether to show the checkbox.
`$post` | `\WP_Post` | The current WP_Post object.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 931](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L931-L941)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parent->post_title` |  | 
`$parent->ID` |  | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1008](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1008-L1009)

### `post_date_column_status`

*Filters the status text of the post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$status` | `string` | The status text.
`$post` | `\WP_Post` | Post object.
`'date'` |  | 
`$mode` | `string` | The list display mode ('excerpt' or 'list').

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1117](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1117-L1127)

### `post_date_column_time`

*Filters the published time of the post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$t_time` | `string` | The published time.
`$post` | `\WP_Post` | Post object.
`'date'` |  | 
`$mode` | `string` | The list display mode ('excerpt' or 'list').

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Removed the difference between 'excerpt' and 'list' modes.
The published time and date are both displayed now,
which is equivalent to the previous 'excerpt' mode.
`2.5.1` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1133](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1133-L1146)

### `post_column_taxonomy_links`

*Filters the links in `$taxonomy` column of edit.php.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_links` | `string[]` | Array of term editing links.
`$taxonomy` | `string` | Taxonomy name.
`$terms` | `\WP_Term[]` | Array of term objects appearing in the post row.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1223](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1223-L1232)

### `page_row_actions`

*Filters the array of row action links on the Pages list table.*

The filter is evaluated only for hierarchical post types.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of row action links. Defaults are<br>'Edit', 'Quick Edit', 'Restore', 'Trash',<br>'Delete Permanently', 'Preview', and 'View'.
`$post` | `\WP_Post` | The post object.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1436](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1436-L1448)

### `post_row_actions`

*Filters the array of row action links on the Posts list table.*

The filter is evaluated only for non-hierarchical post types.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of row action links. Defaults are<br>'Edit', 'Quick Edit', 'Restore', 'Trash',<br>'Delete Permanently', 'Preview', and 'View'.
`$post` | `\WP_Post` | The post object.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1451](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1451-L1463)

### `quick_edit_show_taxonomy`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$show_in_quick_edit` |  | 
`$taxonomy_name` |  | 
`$screen->post_type` |  | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1503](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1503-L1503)

### `quick_edit_dropdown_authors_args`

*Filters the arguments used to generate the Quick Edit authors drop-down.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$users_opt` | `array` | An array of arguments passed to wp_dropdown_users().
`$bulk` | `bool` | A flag to denote if it's a bulk action.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1603](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1603-L1613)

### `quick_edit_dropdown_pages_args`

*Filters the arguments used to generate the Quick Edit page-parent drop-down.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$dropdown_args` | `array` | An array of arguments passed to wp_dropdown_pages().
`$bulk` | `bool` | A flag to denote if it's a bulk action.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The `$bulk` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1706](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1706-L1717)

### `default_page_template_title`

*This filter is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Default template')` |  | 
`'quick-edit'` |  | 

Source: [wordpress/wp-admin/includes/class-wp-posts-list-table.php](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php), [line 1745](../../wordpress/wp-admin/includes/class-wp-posts-list-table.php#L1745-L1746)

### `populate_network_meta`

*Filters meta for a network on creation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemeta` | `array` | Associative array of network meta keys and values to be inserted.
`$network_id` | `int` | ID of network to populate.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/schema.php](../../wordpress/wp-admin/includes/schema.php), [line 1276](../../wordpress/wp-admin/includes/schema.php#L1276-L1284)

### `populate_site_meta`

*Filters meta for a site on creation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta` | `array` | Associative array of site meta keys and values to be inserted.
`$site_id` | `int` | ID of site to populate.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/schema.php](../../wordpress/wp-admin/includes/schema.php), [line 1322](../../wordpress/wp-admin/includes/schema.php#L1322-L1330)

### `term_updated_messages`

*Filters the messages displayed when a tag is updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$messages` | `array` | The messages to be displayed.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/edit-tag-messages.php](../../wordpress/wp-admin/includes/edit-tag-messages.php), [line 42](../../wordpress/wp-admin/includes/edit-tag-messages.php#L42-L49)

### `wp_privacy_personal_data_erasers`

*This filter is documented in wp-admin/includes/ajax-actions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/class-wp-privacy-data-removal-requests-list-table.php](../../wordpress/wp-admin/includes/class-wp-privacy-data-removal-requests-list-table.php), [line 54](../../wordpress/wp-admin/includes/class-wp-privacy-data-removal-requests-list-table.php#L54-L55)

### `wp_privacy_personal_data_erasers`

*This filter is documented in wp-admin/includes/ajax-actions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/class-wp-privacy-data-removal-requests-list-table.php](../../wordpress/wp-admin/includes/class-wp-privacy-data-removal-requests-list-table.php), [line 125](../../wordpress/wp-admin/includes/class-wp-privacy-data-removal-requests-list-table.php#L125-L126)

### `allow_subdirectory_install`

*Filters whether to enable the subdirectory installation feature in Multisite.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/network.php](../../wordpress/wp-admin/includes/network.php), [line 56](../../wordpress/wp-admin/includes/network.php#L56-L64)

### `image_editor_save_pre`

*Filters the WP_Image_Editor instance for the image to be streamed to the browser.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image` | `\WP_Image_Editor` | The image editor instance.
`$attachment_id` | `int` | The attachment post ID.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 269](../../wordpress/wp-admin/includes/image-edit.php#L269-L277)

### `image_save_pre`

*Filters the GD image resource to be streamed to the browser.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($image, $attachment_id)` |  | 
`'3.5.0'` |  | 
`'image_editor_save_pre'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 288](../../wordpress/wp-admin/includes/image-edit.php#L288-L297)

### `image_editor_save_pre`

*This filter is documented in wp-admin/includes/image-edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image` |  | 
`$post_id` |  | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 329](../../wordpress/wp-admin/includes/image-edit.php#L329-L330)

### `wp_save_image_editor_file`

*Filters whether to skip saving the image file.*

Returning a non-null value will short-circuit the save method,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$filename` | `string` | Name of the file to be saved.
`$image` | `\WP_Image_Editor` | The image editor instance.
`$mime_type` | `string` | The mime type of the image.
`$post_id` | `int` | Attachment post ID.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 332](../../wordpress/wp-admin/includes/image-edit.php#L332-L346)

### `image_save_pre`

*This filter is documented in wp-admin/includes/image-edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($image, $post_id)` |  | 
`'3.5.0'` |  | 
`'image_editor_save_pre'` |  | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 357](../../wordpress/wp-admin/includes/image-edit.php#L357-L358)

### `wp_save_image_file`

*Filters whether to skip saving the image file.*

Returning a non-null value will short-circuit the save method,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(null, $filename, $image, $mime_type, $post_id)` |  | 
`'3.5.0'` |  | 
`'wp_save_image_editor_file'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 360](../../wordpress/wp-admin/includes/image-edit.php#L360-L380)

### `jpeg_quality`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`90` |  | 
`'edit_image'` |  | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 389](../../wordpress/wp-admin/includes/image-edit.php#L389-L389)

### `wp_image_editor_before_change`

*Filters the WP_Image_Editor instance before applying changes to the image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image` | `\WP_Image_Editor` | WP_Image_Editor instance.
`$changes` | `array` | Array of change operations.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 568](../../wordpress/wp-admin/includes/image-edit.php#L568-L576)

### `image_edit_before_change`

*Filters the GD image resource before applying changes to the image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($image, $changes)` |  | 
`'3.5.0'` |  | 
`'wp_image_editor_before_change'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/image-edit.php](../../wordpress/wp-admin/includes/image-edit.php), [line 579](../../wordpress/wp-admin/includes/image-edit.php#L579-L588)

### `wp_terms_checklist_args`

*Filters the taxonomy terms checklist arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | An array of arguments.
`$post_id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 92](../../wordpress/wp-admin/includes/template.php#L92-L102)

### `the_category`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term->name` |  | 
`''` |  | 
`''` |  | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 246](../../wordpress/wp-admin/includes/template.php#L246-L246)

### `the_category`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$category->name` |  | 
`''` |  | 
`''` |  | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 294](../../wordpress/wp-admin/includes/template.php#L294-L294)

### `editable_slug`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_name` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 319](../../wordpress/wp-admin/includes/template.php#L319-L319)

### `wp_comment_reply`

*Filters the in-line comment reply-to form output in the Comments
list table.*

Returning a non-empty value here will short-circuit display
of the in-line comment-reply form in the Comments list table,
echoing the returned value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`array('position' => $position, 'checkbox' => $checkbox, 'mode' => $mode)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 406](../../wordpress/wp-admin/includes/template.php#L406-L429)

### `postmeta_form_keys`

*Filters values for the meta key dropdown in the Custom Fields meta box.*

Returning a non-null value will effectively short-circuit and avoid a
potentially expensive query against postmeta.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post` | `\WP_Post` | The current post object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 669](../../wordpress/wp-admin/includes/template.php#L669-L680)

### `postmeta_form_limit`

*Filters the number of custom fields to retrieve for the drop-down
in the Custom Fields meta box.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`30` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 683](../../wordpress/wp-admin/includes/template.php#L683-L691)

### `import_upload_size_limit`

*Filters the maximum allowed upload size for import files.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_max_upload_size()` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 959](../../wordpress/wp-admin/includes/template.php#L959-L968)

### `admin_body_class`

*This filter is documented in wp-admin/admin-header.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2074](../../wordpress/wp-admin/includes/template.php#L2074-L2075)

### `display_post_states`

*Filters the default post display states used in the posts list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_states` | `string[]` | An array of post display states.
`$post` | `\WP_Post` | The current post object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Also applied in the Customizer context. If any admin functions
are used within the filter, their existence should be checked
with `function_exists()` before being used.
`3.6.0` | Added the `$post` parameter.
`2.8.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2221](../../wordpress/wp-admin/includes/template.php#L2221-L2233)

### `display_media_states`

*Filters the default media display states for items in the Media list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$media_states` | `string[]` | An array of media states. Default 'Header Image',<br>'Background Image', 'Site Icon', 'Logo'.
`$post` | `\WP_Post` | The current attachment object.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | Added the `$post` parameter.
`3.2.0` | 

Source: [wordpress/wp-admin/includes/template.php](../../wordpress/wp-admin/includes/template.php), [line 2338](../../wordpress/wp-admin/includes/template.php#L2338-L2348)

### `comments_list_table_query_args`

*Filters the arguments for the comment query in the comments list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | An array of get_comments() arguments.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 155](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L155-L162)

### `comments_per_page`

*Filters the number of comments listed per page in the comments list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comments_per_page` | `int` | The number of comments to list per page.
`$comment_status` | `string` | The comment status name. Default 'All'.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 201](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L201-L209)

### `comment_status_links`

*Filters the comment status links.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$status_links` | `string[]` | An associative array of fully-formed comment status links. Includes 'All', 'Mine',<br>'Pending', 'Approved', 'Spam', and 'Trash'.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The 'Mine' link was added.
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 334](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L334-L343)

### `admin_comment_types_dropdown`

*Filters the comment types shown in the drop-down menu on the Comments list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('comment' => __('Comments'), 'pings' => __('Pings'))` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 483](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L483-L496)

### `comment_row_actions`

*This filter is documented in wp-admin/includes/dashboard.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array_filter($actions)` |  | 
`$comment` |  | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 803](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L803-L804)

### `comment_edit_pre`

*This filter is documented in wp-admin/includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_content` |  | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 888](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L888-L889)

### `comment_email`

*This filter is documented in wp-includes/comment-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_author_email` |  | 
`$comment` |  | 

Source: [wordpress/wp-admin/includes/class-wp-comments-list-table.php](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php), [line 926](../../wordpress/wp-admin/includes/class-wp-comments-list-table.php#L926-L927)

### `all_themes`

*Filters the full array of WP_Theme objects to list in the Multisite
themes list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_get_themes()` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 106](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L106-L114)

### `theme_action_links`

*Filters the action links displayed for each theme in the Multisite
themes list table.*

The action links displayed are determined by the theme's status, and
which Multisite themes list table is being displayed - the Network
themes list table (themes.php), which displays all installed themes,
or the Site themes list table (site-themes.php), which displays the
non-network enabled themes when editing a site in the Network admin.

The default action links for the Network themes list table include
'Network Enable', 'Network Disable', and 'Delete'.

The default action links for the Site themes list table include
'Enable', and 'Disable'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array_filter($actions)` |  | 
`$theme` | `\WP_Theme` | The current WP_Theme object.
`$context` | `string` | Status of the theme, one of 'all', 'enabled', or 'disabled'.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 633](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L633-L655)

### `theme_action_links_{$stylesheet}`

*Filters the action links of a specific theme in the Multisite themes
list table.*

The dynamic portion of the hook name, `$stylesheet`, refers to the
directory name of the theme, which in most cases is synonymous
with the template name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of action links.
`$theme` | `\WP_Theme` | The current WP_Theme object.
`$context` | `string` | Status of the theme, one of 'all', 'enabled', or 'disabled'.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 657](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L657-L671)

### `theme_row_meta`

*Filters the array of row meta for each theme in the Multisite themes
list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$theme_meta` | `string[]` | An array of the theme's metadata, including<br>the version, author, and theme URI.
`$stylesheet` | `string` | Directory name of the theme.
`$theme` | `\WP_Theme` | WP_Theme object.
`$status` | `string` | Status of the theme.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 731](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L731-L743)

### `theme_auto_update_setting_html`

*Filters the HTML of the auto-updates setting for each theme in the Themes list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | The HTML for theme's auto-update setting, including<br>toggle auto-update action link and time to next update.
`$stylesheet` | `string` | Directory name of the theme.
`$theme` | `\WP_Theme` | WP_Theme object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php), [line 831](../../wordpress/wp-admin/includes/class-wp-ms-themes-list-table.php#L831-L841)

### `media_upload_tabs`

*Filters the available tabs in the legacy (pre-3.5.0) media popup.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_default_tabs` | `string[]` | An array of media tabs.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 24](../../wordpress/wp-admin/includes/media.php#L24-L31)

### `media_upload_default_tab`

*This filter is documented in wp-admin/media-upload.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 89](../../wordpress/wp-admin/includes/media.php#L89-L90)

### `image_send_to_editor`

*Filters the image HTML markup to send to the editor when inserting an image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | The image HTML markup to send.
`$id` | `int` | The attachment ID.
`$caption` | `string` | The image caption.
`$title` | `string` | The image title.
`$align` | `string` | The image alignment.
`$url` | `string` | The image source URL.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$alt` | `string` | The image alternative, or alt, text.
`$rel` | `string` | The image rel attribute.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The `$rel` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 151](../../wordpress/wp-admin/includes/media.php#L151-L168)

### `image_add_caption_text`

*Filters the caption text.*

Note: If the caption text is empty, the caption shortcode will not be appended
to the image HTML when inserted into the editor.

Passing an empty value also prevents the %1$s
Filters from being evaluated at the end of image_add_caption().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$caption` | `string` | The original caption text.
`$id` | `int` | The attachment ID.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 190](../../wordpress/wp-admin/includes/media.php#L190-L204)

### `disable_captions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 216](../../wordpress/wp-admin/includes/media.php#L216-L216)

### `image_add_caption_shortcode`

*Filters the image HTML markup including the caption shortcode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$shcode` | `string` | The image HTML markup with caption shortcode.
`$html` | `string` | The image HTML markup.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 241](../../wordpress/wp-admin/includes/media.php#L241-L249)

### `media_buttons_context`

*Filters the legacy (pre-3.5.0) media buttons.*

Use %1$s action instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('')` |  | 
`'3.5.0'` |  | 
`'media_buttons'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 648](../../wordpress/wp-admin/includes/media.php#L648-L658)

### `{$type}_upload_iframe_src`

*Filters the upload iframe source URL for a specific media type.*

The dynamic portion of the hook name, `$type`, refers to the type
of media uploaded.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$upload_iframe_src` | `string` | The upload iframe source URL by type.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 693](../../wordpress/wp-admin/includes/media.php#L693-L703)

### `attachment_fields_to_save`

*Filters the attachment fields to be saved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` | `array` | An array of post data.
`$attachment` | `array` | An array of attachment metadata.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 756](../../wordpress/wp-admin/includes/media.php#L756-L766)

### `media_send_to_editor`

*Filters the HTML markup for a media item sent to the editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | HTML markup for a media item sent to the editor.
`$send_id` | `int` | The first key from the $_POST['send'] data.
`$attachment` | `array` | Array of attachment metadata.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 821](../../wordpress/wp-admin/includes/media.php#L821-L832)

### `{$type}_send_to_editor_url`

*Filters the URL sent to the editor for a specific media type.*

The dynamic portion of the hook name, `$type`, refers to the type
of media being sent.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | HTML markup sent to the editor.
`esc_url_raw($src)` |  | 
`$title` | `string` | Media title.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 890](../../wordpress/wp-admin/includes/media.php#L890-L902)

### `image_send_to_editor_url`

*Filters the image URL sent to the editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | HTML markup sent to the editor for an image.
`esc_url_raw($src)` |  | 
`$alt` | `string` | Image alternate, or alt, text.
`$align` | `string` | The image alignment. Default 'alignnone'. Possible values include<br>'alignleft', 'aligncenter', 'alignright', 'alignnone'.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 916](../../wordpress/wp-admin/includes/media.php#L916-L927)

### `image_sideload_extensions`

*Filters the list of allowed file extensions when sideloading an image from a URL.*

The default allowed extensions are:

- `jpg`
- `jpeg`
- `jpe`
- `png`
- `gif`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_extensions` | `string[]` | Array of allowed file extensions.
`$file` | `string` | The URL of the image to download.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 987](../../wordpress/wp-admin/includes/media.php#L987-L1003)

### `image_size_names_choose`

*Filters the names and labels of the default image sizes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('thumbnail' => __('Thumbnail'), 'medium' => __('Medium'), 'large' => __('Large'), 'full' => __('Full Size'))` |  | 

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 1157](../../wordpress/wp-admin/includes/media.php#L1157-L1173)

### `attachment_fields_to_edit`

*Filters the attachment fields to edit.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$form_fields` | `array` | An array of attachment form fields.
`$post` | `\WP_Post` | The WP_Post attachment object.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 1491](../../wordpress/wp-admin/includes/media.php#L1491-L1499)

### `get_media_item_args`

*Filters the arguments used to retrieve an image for the edit image form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_args` | `array` | An array of arguments.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 1599](../../wordpress/wp-admin/includes/media.php#L1599-L1608)

### `media_meta`

*Filters the media metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$media_dims` | `string` | The HTML markup containing the media dimensions.
`$post` | `\WP_Post` | The WP_Post attachment object.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 1660](../../wordpress/wp-admin/includes/media.php#L1660-L1668)

### `get_media_item_args`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 1876](../../wordpress/wp-admin/includes/media.php#L1876-L1877)

### `attachment_fields_to_edit`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$form_fields` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 1924](../../wordpress/wp-admin/includes/media.php#L1924-L1925)

### `media_meta`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 1939](../../wordpress/wp-admin/includes/media.php#L1939-L1940)

### `upload_post_params`

*Filters the media upload post parameters.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_params` | `array` | An array of media upload parameters used by Plupload.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 
`3.1.0` | As 'swfupload_post_params'

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2153](../../wordpress/wp-admin/includes/media.php#L2153-L2161)

### `plupload_init`

*Filters the default Plupload settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plupload_init` | `array` | An array of default settings used by Plupload.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2190](../../wordpress/wp-admin/includes/media.php#L2190-L2197)

### `media_upload_form_url`

*Filters the media upload form action URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$form_action_url` | `string` | The media upload form action URL.
`$type` | `string` | The type of media. Default 'file'.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2312](../../wordpress/wp-admin/includes/media.php#L2312-L2320)

### `media_upload_form_url`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$form_action_url` |  | 
`$type` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2388](../../wordpress/wp-admin/includes/media.php#L2388-L2389)

### `disable_captions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2421](../../wordpress/wp-admin/includes/media.php#L2421-L2421)

### `type_url_form_media`

*Filters the insert media from URL form HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_media_insert_url_form($type)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2500](../../wordpress/wp-admin/includes/media.php#L2500-L2507)

### `media_upload_form_url`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$form_action_url` |  | 
`$type` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2535](../../wordpress/wp-admin/includes/media.php#L2535-L2536)

### `media_upload_form_url`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$form_action_url` |  | 
`$type` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2699](../../wordpress/wp-admin/includes/media.php#L2699-L2700)

### `media_upload_mime_type_links`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$type_links` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2796](../../wordpress/wp-admin/includes/media.php#L2796-L2796)

### `disable_captions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 2902](../../wordpress/wp-admin/includes/media.php#L2902-L2902)

### `media_meta`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$media_dims` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 3288](../../wordpress/wp-admin/includes/media.php#L3288-L3289)

### `media_submitbox_misc_sections`

*Filters the audio and video metadata fields to be shown in the publish meta box.*

The key for each item in the array should correspond to an attachment
metadata key, and the value should be the desired label.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$fields` | `array` | An array of the attachment metadata keys and labels.
`$post` | `\WP_Post` | WP_Post object for the current attachment.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$post` parameter.
`3.7.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 3386](../../wordpress/wp-admin/includes/media.php#L3386-L3398)

### `audio_submitbox_misc_sections`

*Filters the audio attachment metadata fields to be shown in the publish meta box.*

The key for each item in the array should correspond to an attachment
metadata key, and the value should be the desired label.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$fields` | `array` | An array of the attachment metadata keys and labels.
`$post` | `\WP_Post` | WP_Post object for the current attachment.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$post` parameter.
`3.7.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 3434](../../wordpress/wp-admin/includes/media.php#L3434-L3446)

### `wp_read_video_metadata`

*Filters the array of metadata retrieved from a video.*

In core, usually this selection is what is stored.
More complete data can be parsed from the `$data` parameter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$metadata` | `array` | Filtered Video metadata.
`$file` | `string` | Path to video file.
`$file_format` | `string` | File format of video, as analyzed by getID3.
`$data` | `string` | Raw metadata from getID3.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-admin/includes/media.php](../../wordpress/wp-admin/includes/media.php), [line 3621](../../wordpress/wp-admin/includes/media.php#L3621-L3634)

### `automatic_updater_disabled`

*This filter is documented in wp-admin/includes/class-wp-automatic-updater.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php), [line 115](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php#L115-L116)

### `automatic_updates_is_vcs_checkout`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`ABSPATH` |  | 

Source: [wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php), [line 237](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php#L237-L237)

### `allow_dev_auto_core_updates`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_version` |  | 

Source: [wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php), [line 413](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php#L413-L413)

### `allow_minor_auto_core_updates`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php), [line 445](../../wordpress/wp-admin/includes/class-wp-site-health-auto-updates.php#L445-L445)

### `views_{$screen->id}`

*Filters the list of available list table views.*

The dynamic portion of the hook name, `$this->screen->id`, refers
to the ID of the current screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$views` | `string[]` | An array of available list table views.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 395](../../wordpress/wp-admin/includes/class-wp-list-table.php#L395-L405)

### `bulk_actions-{$screen->id}`

*Filters the items in the bulk actions menu of the list table.*

The dynamic portion of the hook name, `$this->screen->id`, refers
to the ID of the current screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->_actions` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | A bulk action can now contain an array of options in order to create an optgroup.
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 464](../../wordpress/wp-admin/includes/class-wp-list-table.php#L464-L475)

### `disable_months_dropdown`

*Filters whether to remove the 'Months' drop-down from the post list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post_type` | `string` | The post type.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 586](../../wordpress/wp-admin/includes/class-wp-list-table.php#L586-L594)

### `pre_months_dropdown_query`

*Filters to short-circuit performing the months dropdown query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post_type` | `string` | The post type.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 598](../../wordpress/wp-admin/includes/class-wp-list-table.php#L598-L606)

### `months_dropdown_results`

*Filters the 'Months' drop-down results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$months` | `object[]` | Array of the months drop-down query results.
`$post_type` | `string` | The post type.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 630](../../wordpress/wp-admin/includes/class-wp-list-table.php#L630-L638)

### `{$option}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$per_page` |  | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 856](../../wordpress/wp-admin/includes/class-wp-list-table.php#L856-L856)

### `list_table_primary_column`

*Filters the name of the primary column for the current list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` | `string` | Column name default for the specific list table, e.g. 'name'.
`$this->screen->id` |  | 

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 1087](../../wordpress/wp-admin/includes/class-wp-list-table.php#L1087-L1095)

### `manage_{$screen->id}_sortable_columns`

*Filters the list table sortable columns for a specific screen.*

The dynamic portion of the hook name, `$this->screen->id`, refers
to the ID of the current screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sortable_columns` | `array` | An array of sortable columns.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-list-table.php](../../wordpress/wp-admin/includes/class-wp-list-table.php), [line 1128](../../wordpress/wp-admin/includes/class-wp-list-table.php#L1128-L1138)

### `got_rewrite`

*Filters whether Apache and mod_rewrite are present.*

This filter was previously used to force URL rewriting for other servers,
like nginx. Use the %1$s filter in got_url_rewrite() instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$got_rewrite` | `bool` | Whether Apache and mod_rewrite are present.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 19](../../wordpress/wp-admin/includes/misc.php#L19-L31)

### `got_url_rewrite`

*Filters whether URL rewriting is available.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$got_url_rewrite` | `bool` | Whether URL rewriting is available.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 48](../../wordpress/wp-admin/includes/misc.php#L48-L55)

### `insert_with_markers_inline_instructions`

*Filters the inline instructions inserted before the dynamically generated content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instructions` | `string[]` | Array of lines with inline instructions.
`$marker` | `string` | The marker being inserted.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 149](../../wordpress/wp-admin/includes/misc.php#L149-L157)

### `documentation_ignore_functions`

*Filters the list of functions and classes to be ignored from the documentation lookup.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ignore_functions` | `string[]` | Array of names of functions and classes to be ignored.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 615](../../wordpress/wp-admin/includes/misc.php#L615-L622)

### `set-screen-option`

*Filters a screen option value before it is set.*

The filter can also be used to modify non-standard [items]_per_page
settings. See the parent function for a full list of standard options.

Returning false from the filter will skip saving the current option.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$screen_option` | `mixed` | The value to save instead of the option value.<br>Default false (to skip saving the current option).
`$option` | `string` | The option name.
`$value` | `int` | The option value.

**Changelog**

Version | Description
------- | -----------
`5.4.2` | Only applied to options ending with '_page',
or the 'layout_columns' option.
`2.8.0` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 694](../../wordpress/wp-admin/includes/misc.php#L694-L713)

### `set_screen_option_{$option}`

*Filters a screen option value before it is set.*

The dynamic portion of the hook, `$option`, refers to the option name.

Returning false from the filter will skip saving the current option.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$screen_option` | `mixed` | The value to save instead of the option value.<br>Default false (to skip saving the current option).
`$option` | `string` | The option name.
`$value` | `int` | The option value.

**Changelog**

Version | Description
------- | -----------
`5.4.2` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 716](../../wordpress/wp-admin/includes/misc.php#L716-L732)

### `admin_viewport_meta`

*Filters the viewport meta in the admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'width=device-width,initial-scale=1.0'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 1022](../../wordpress/wp-admin/includes/misc.php#L1022-L1029)

### `admin_referrer_policy`

*Filters the admin referrer policy header value.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$policy` | `string` | The admin referrer policy header value. Default 'strict-origin-when-cross-origin'.

**Changelog**

Version | Description
------- | -----------
`4.9.5` | The default value was changed to 'strict-origin-when-cross-origin'.
`4.9.0` | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 1298](../../wordpress/wp-admin/includes/misc.php#L1298-L1308)

### `new_admin_email_content`

*Filters the text of the email sent when a change of site admin email address is attempted.*

The following strings have a special meaning and will get replaced dynamically:
###USERNAME###  The current user's username.
###ADMIN_URL### The link to click on to confirm the email change.
###EMAIL###     The proposed new site admin email address.
###SITENAME###  The name of the site.
###SITEURL###   The URL to the site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_text` | `string` | Text in the email.
`$new_admin_email` | `array` | {<br>    Data relating to the new site admin email address.<br><br>    @type string $hash     The secure hash used in the confirmation link URL.<br>    @type string $newemail The proposed new site admin email address.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.0` | This filter is no longer Multisite specific.

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 1376](../../wordpress/wp-admin/includes/misc.php#L1376-L1397)

### `wp_is_php_version_acceptable`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$version` |  | 

Source: [wordpress/wp-admin/includes/misc.php](../../wordpress/wp-admin/includes/misc.php), [line 1498](../../wordpress/wp-admin/includes/misc.php#L1498-L1498)

### `all_plugins`

*Filters the full array of plugins to list in the Plugins list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_plugins()` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 97](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L97-L106)

### `show_advanced_plugins`

*Filters whether to display the advanced plugins list table.*

There are two types of advanced plugins - must-use and drop-ins -
which can be used in a single site or Multisite network.

The $type parameter allows you to differentiate between the type of advanced
plugins to filter the display of. Contexts include 'mustuse' and 'dropins'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`'mustuse'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 130](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L130-L145)

### `show_advanced_plugins`

*This action is documented in wp-admin/includes/class-wp-plugins-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`'dropins'` |  | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 149](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L149-L150)

### `show_network_active_plugins`

*Filters whether to display network-active plugins alongside plugins active for the current site.*

This also controls the display of inactive network-only plugins (plugins with
"Network: true" in the plugin header).

Plugins cannot be network-activated or network-deactivated from this screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$show` | `bool` | Whether to show network-active plugins. Default is whether the current<br>user can manage network plugins (ie. a Super Admin).

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 167](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L167-L180)

### `network_admin_plugin_action_links`

*Filters the action links displayed for each plugin in the Network Admin Plugins list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of plugin action links. By default this can include 'activate',<br>'deactivate', and 'delete'.
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data. See `get_plugin_data()`.
`$context` | `string` | The plugin context. By default this can include 'all', 'active', 'inactive',<br>'recently_activated', 'upgrade', 'mustuse', 'dropins', and 'search'.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 877](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L877-L889)

### `network_admin_plugin_action_links_{$plugin_file}`

*Filters the list of action links displayed for a specific plugin in the Network Admin Plugins list table.*

The dynamic portion of the hook name, `$plugin_file`, refers to the path
to the plugin file, relative to the plugins directory.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of plugin action links. By default this can include 'activate',<br>'deactivate', and 'delete'.
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data. See `get_plugin_data()`.
`$context` | `string` | The plugin context. By default this can include 'all', 'active', 'inactive',<br>'recently_activated', 'upgrade', 'mustuse', 'dropins', and 'search'.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 891](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L891-L906)

### `plugin_action_links`

*Filters the action links displayed for each plugin in the Plugins list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of plugin action links. By default this can include 'activate',<br>'deactivate', and 'delete'. With Multisite active this can also include<br>'network_active' and 'network_only' items.
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data. See `get_plugin_data()`.
`$context` | `string` | The plugin context. By default this can include 'all', 'active', 'inactive',<br>'recently_activated', 'upgrade', 'mustuse', 'dropins', and 'search'.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The 'Edit' link was removed from the list of action links.
`2.6.0` | The `$context` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 910](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L910-L925)

### `plugin_action_links_{$plugin_file}`

*Filters the list of action links displayed for a specific plugin in the Plugins list table.*

The dynamic portion of the hook name, `$plugin_file`, refers to the path
to the plugin file, relative to the plugins directory.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of plugin action links. By default this can include 'activate',<br>'deactivate', and 'delete'. With Multisite active this can also include<br>'network_active' and 'network_only' items.
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data. See `get_plugin_data()`.
`$context` | `string` | The plugin context. By default this can include 'all', 'active', 'inactive',<br>'recently_activated', 'upgrade', 'mustuse', 'dropins', and 'search'.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The 'Edit' link was removed from the list of action links.
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 927](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L927-L944)

### `plugin_row_meta`

*Filters the array of row meta for each plugin in the Plugins list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugin_meta` | `string[]` | An array of the plugin's metadata, including<br>the version, author, author URI, and plugin URI.
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data.
`$status` | `string` | Status filter currently applied to the plugin list. Possible<br>values are: 'all', 'active', 'inactive', 'recently_activated',<br>'upgrade', 'mustuse', 'dropins', 'search', 'paused',<br>'auto-update-enabled', 'auto-update-disabled'.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 1056](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L1056-L1070)

### `plugin_auto_update_setting_html`

*Filters the HTML of the auto-updates setting for each plugin in the Plugins list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | The HTML of the plugin's auto-update column content, including<br>toggle auto-update action links and time to next update.
`$plugin_file` | `string` | Path to the plugin file relative to the plugins directory.
`$plugin_data` | `array` | An array of plugin data.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-plugins-list-table.php](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php), [line 1155](../../wordpress/wp-admin/includes/class-wp-plugins-list-table.php#L1155-L1165)

### `views_{$screen->id}`

*This filter is documented in wp-admin/inclues/class-wp-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/includes/class-wp-media-list-table.php](../../wordpress/wp-admin/includes/class-wp-media-list-table.php), [line 285](../../wordpress/wp-admin/includes/class-wp-media-list-table.php#L285-L286)

### `manage_taxonomies_for_attachment_columns`

*Filters the taxonomy columns for attachments in the Media list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomies` | `string[]` | An array of registered taxonomy names to show for attachments.
`'attachment'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-media-list-table.php](../../wordpress/wp-admin/includes/class-wp-media-list-table.php), [line 320](../../wordpress/wp-admin/includes/class-wp-media-list-table.php#L320-L328)

### `manage_media_columns`

*Filters the Media list table columns.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$posts_columns` | `string[]` | An array of columns displayed in the Media list table.
`$this->detached` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-media-list-table.php](../../wordpress/wp-admin/includes/class-wp-media-list-table.php), [line 351](../../wordpress/wp-admin/includes/class-wp-media-list-table.php#L351-L360)

### `media_row_actions`

*Filters the action links for each attachment in the Media list table.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string[]` | An array of action links for each attachment.<br>Default 'Edit', 'Delete Permanently', 'View'.
`$post` | `\WP_Post` | WP_Post object for the current attachment.
`$this->detached` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-media-list-table.php](../../wordpress/wp-admin/includes/class-wp-media-list-table.php), [line 783](../../wordpress/wp-admin/includes/class-wp-media-list-table.php#L783-L794)

### `site_icon_attachment_metadata`

*Filters the site icon attachment metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$metadata` | `array` | Attachment metadata.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-site-icon.php](../../wordpress/wp-admin/includes/class-wp-site-icon.php), [line 118](../../wordpress/wp-admin/includes/class-wp-site-icon.php#L118-L127)

### `site_icon_image_sizes`

*Filters the different dimensions that a site icon is saved in.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->site_icon_sizes` |  | 

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/includes/class-wp-site-icon.php](../../wordpress/wp-admin/includes/class-wp-site-icon.php), [line 144](../../wordpress/wp-admin/includes/class-wp-site-icon.php#L144-L151)

### `site_icon_image_sizes`

*This filter is documented in wp-admin/includes/class-wp-site-icon.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->site_icon_sizes` |  | 

Source: [wordpress/wp-admin/includes/class-wp-site-icon.php](../../wordpress/wp-admin/includes/class-wp-site-icon.php), [line 186](../../wordpress/wp-admin/includes/class-wp-site-icon.php#L186-L187)

### `update_theme_complete_actions`

*Filters the list of action links available following a single theme update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_actions` | `string[]` | Array of theme action links.
`$this->theme` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-theme-upgrader-skin.php](../../wordpress/wp-admin/includes/class-theme-upgrader-skin.php), [line 130](../../wordpress/wp-admin/includes/class-theme-upgrader-skin.php#L130-L138)

### `wp_get_missing_image_subsizes`

*Filters the array of missing image sub-sizes for an uploaded image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$missing_sizes` | `array` | Array with the missing image sub-sizes.
`$image_meta` | `array` | The image meta data.
`$attachment_id` | `int` | The image attachment post ID.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 129](../../wordpress/wp-admin/includes/image.php#L129-L138)

### `wp_generate_attachment_metadata`

*This filter is documented in wp-admin/includes/image.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image_meta` |  | 
`$attachment_id` |  | 
`'update'` |  | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 174](../../wordpress/wp-admin/includes/image.php#L174-L175)

### `big_image_size_threshold`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`2560` |  | 
`$imagesize` |  | 
`$file` |  | 
`$attachment_id` |  | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 273](../../wordpress/wp-admin/includes/image.php#L273-L273)

### `intermediate_image_sizes_advanced`

*Filters the image sizes automatically generated when uploading an image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_sizes` | `array` | Associative array of image sizes to be created.
`$image_meta` | `array` | The image meta data: width, height, file, sizes, etc.
`$attachment_id` | `int` | The attachment post ID for the image.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | Added the `$attachment_id` argument.
`4.4.0` | Added the `$image_meta` argument.
`2.9.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 353](../../wordpress/wp-admin/includes/image.php#L353-L364)

### `attachment_thumbnail_args`

*Filters the parameters for the attachment thumbnail creation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image_attachment` | `array` | An array of parameters to create the thumbnail.
`$metadata` | `array` | Current attachment metadata.
`$uploaded` | `array` | {<br>    Information about the newly-uploaded file.<br><br>    @type string $file  Filename of the newly-uploaded file.<br>    @type string $url   URL of the uploaded file.<br>    @type string $type  File type.<br>}

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 529](../../wordpress/wp-admin/includes/image.php#L529-L544)

### `fallback_intermediate_image_sizes`

*Filters the image sizes generated for non-image mime types.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$fallback_sizes` | `string[]` | An array of image size names.
`$metadata` | `array` | Current attachment metadata.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 562](../../wordpress/wp-admin/includes/image.php#L562-L570)

### `wp_generate_attachment_metadata`

*Filters the generated attachment meta data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$metadata` | `array` | An array of attachment meta data.
`$attachment_id` | `int` | Current attachment ID.
`'create'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.3.0` | The `$context` parameter was added.
`2.1.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 620](../../wordpress/wp-admin/includes/image.php#L620-L631)

### `wp_read_image_metadata_types`

*Filters the image types to check for exif data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(IMAGETYPE_JPEG, IMAGETYPE_TIFF_II, IMAGETYPE_TIFF_MM)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 783](../../wordpress/wp-admin/includes/image.php#L783-L790)

### `wp_read_image_metadata`

*Filters the array of meta data read from an image's exif data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta` | `array` | Image meta data.
`$file` | `string` | Path to image file.
`$image_type` | `int` | Type of image, one of the `IMAGETYPE_XXX` constants.
`$iptc` | `array` | IPTC data.
`$exif` | `array` | EXIF data.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | The `$exif` parameter was added.
`4.4.0` | The `$iptc` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 876](../../wordpress/wp-admin/includes/image.php#L876-L889)

### `file_is_displayable_image`

*Filters whether the current image is displayable in the browser.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `bool` | Whether the image can be displayed. Default true.
`$path` | `string` | Path to the image.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 926](../../wordpress/wp-admin/includes/image.php#L926-L934)

### `load_image_to_edit`

*Filters the current image being loaded for editing.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image` | `resource\|\GdImage` | Current image.
`$attachment_id` | `int` | Attachment ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 971](../../wordpress/wp-admin/includes/image.php#L971-L981)

### `load_image_to_edit_filesystempath`

*Filters the path to an attachment's file when editing the image.*

The filter is evaluated for all image sizes except 'full'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filepath` |  | 
`$attachment_id` | `int` | Attachment ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 1016](../../wordpress/wp-admin/includes/image.php#L1016-L1028)

### `load_image_to_edit_attachmenturl`

*Filters the path to an attachment's URL when editing the image.*

The filter is only evaluated if the file isn't stored locally and `allow_url_fopen` is enabled on the server.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_get_attachment_url($attachment_id)` |  | 
`$attachment_id` | `int` | Attachment ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 1032](../../wordpress/wp-admin/includes/image.php#L1032-L1044)

### `load_image_to_edit_path`

*Filters the returned path or URL of the current image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filepath` | `string\|false` | File path or URL to current image, or false.
`$attachment_id` | `int` | Attachment ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/includes/image.php](../../wordpress/wp-admin/includes/image.php), [line 1047](../../wordpress/wp-admin/includes/image.php#L1047-L1057)

### `replace_editor`

*This filter is documented in wp-admin/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 309](../../wordpress/wp-admin/includes/class-wp-screen.php#L309-L310)

### `contextual_help_list`

*Filters the legacy contextual help list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(self::$_old_compat_help, $this)` |  | 
`'3.3.0'` |  | 
`'get_current_screen()->add_help_tab(), get_current_screen()->remove_help_tab()'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 789](../../wordpress/wp-admin/includes/class-wp-screen.php#L789-L804)

### `contextual_help`

*Filters the legacy contextual help text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($old_help, $this->id, $this)` |  | 
`'3.3.0'` |  | 
`'get_current_screen()->add_help_tab(), get_current_screen()->remove_help_tab()'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 808](../../wordpress/wp-admin/includes/class-wp-screen.php#L808-L824)

### `default_contextual_help`

*Filters the default legacy contextual help text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('')` |  | 
`'3.3.0'` |  | 
`'get_current_screen()->add_help_tab(), get_current_screen()->remove_help_tab()'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 829](../../wordpress/wp-admin/includes/class-wp-screen.php#L829-L843)

### `screen_layout_columns`

*Filters the array of screen layout columns.*

This hook provides back-compat for plugins using the back-compat
Filters instead of add_screen_option().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$this->id` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 928](../../wordpress/wp-admin/includes/class-wp-screen.php#L928-L940)

### `screen_settings`

*Filters the screen settings text displayed in the Screen Options tab.*

This filter is currently only used on the Widgets screen to enable
accessibility mode.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->_screen_settings` |  | 
`$this` | `\WP_Screen` | WP_Screen object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1008](../../wordpress/wp-admin/includes/class-wp-screen.php#L1008-L1019)

### `screen_options_show_screen`

*Filters whether to show the Screen Options tab.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$show_screen` | `bool` | Whether to show Screen Options tab.<br>Default true.
`$this` | `\WP_Screen` | Current WP_Screen instance.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1025](../../wordpress/wp-admin/includes/class-wp-screen.php#L1025-L1034)

### `screen_options_show_submit`

*Filters whether to show the Screen Options submit button.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1083](../../wordpress/wp-admin/includes/class-wp-screen.php#L1083-L1092)

### `comments_per_page`

*This filter is documented in wp-admin/includes/class-wp-comments-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$per_page` |  | 
`$comment_status` |  | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1255](../../wordpress/wp-admin/includes/class-wp-screen.php#L1255-L1256)

### `edit_categories_per_page`

*This filter is documented in wp-admin/includes/class-wp-terms-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$per_page` |  | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1258](../../wordpress/wp-admin/includes/class-wp-screen.php#L1258-L1259)

### `{$option}`

*This filter is documented in wp-admin/includes/class-wp-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$per_page` |  | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1261](../../wordpress/wp-admin/includes/class-wp-screen.php#L1261-L1262)

### `edit_posts_per_page`

*This filter is documented in wp-admin/includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$per_page` |  | 
`$this->post_type` |  | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1267](../../wordpress/wp-admin/includes/class-wp-screen.php#L1267-L1268)

### `view_mode_post_types`

*Filters the post types that have different view mode options.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$view_mode_post_types` | `string[]` | Array of post types that can change view modes.<br>Default post types with show_ui on.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/includes/class-wp-screen.php](../../wordpress/wp-admin/includes/class-wp-screen.php), [line 1307](../../wordpress/wp-admin/includes/class-wp-screen.php#L1307-L1315)

### `plugin_auto_update_debug_string`

*Filters the text string of the auto-updates setting for each plugin in the Site Health debug data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$auto_updates_string` | `string` | The string output for the auto-updates column.
`$plugin_path` | `string` | The path to the plugin file.
`$plugin` | `array` | An array of plugin data.
`$enabled` | `bool` | Whether auto-updates are enabled for this item.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-debug-data.php](../../wordpress/wp-admin/includes/class-wp-debug-data.php), [line 1000](../../wordpress/wp-admin/includes/class-wp-debug-data.php#L1000-L1010)

### `theme_auto_update_debug_string`

*This filter is documented in wp-admin/includes/class-wp-debug-data.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$auto_updates_string` |  | 
`$active_theme` |  | 
`$enabled` |  | 

Source: [wordpress/wp-admin/includes/class-wp-debug-data.php](../../wordpress/wp-admin/includes/class-wp-debug-data.php), [line 1142](../../wordpress/wp-admin/includes/class-wp-debug-data.php#L1142-L1143)

### `theme_auto_update_debug_string`

*This filter is documented in wp-admin/includes/class-wp-debug-data.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$auto_updates_string` |  | 
`$parent_theme` |  | 
`$enabled` |  | 

Source: [wordpress/wp-admin/includes/class-wp-debug-data.php](../../wordpress/wp-admin/includes/class-wp-debug-data.php), [line 1228](../../wordpress/wp-admin/includes/class-wp-debug-data.php#L1228-L1229)

### `theme_auto_update_debug_string`

*Filters the text string of the auto-updates setting for each theme in the Site Health debug data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$auto_updates_string` | `string` | The string output for the auto-updates column.
`$theme` | `\WP_Theme` | An object of theme data.
`$enabled` | `bool` | Whether auto-updates are enabled for this item.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/includes/class-wp-debug-data.php](../../wordpress/wp-admin/includes/class-wp-debug-data.php), [line 1316](../../wordpress/wp-admin/includes/class-wp-debug-data.php#L1316-L1325)

### `debug_information`

*Add or modify the debug information.*

Plugin or themes may wish to introduce their own debug information without creating additional admin pages
they can utilize this filter to introduce their own sections or add more data to existing sections.

Array keys for sections added by core are all prefixed with `wp-`, plugins and themes should use their own slug as
a prefix, both for consistency as well as avoiding key collisions. Note that the array keys are used as labels
for the copied data.

All strings are expected to be plain text except $description that can contain inline HTML tags (see below).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$info` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-admin/includes/class-wp-debug-data.php](../../wordpress/wp-admin/includes/class-wp-debug-data.php), [line 1354](../../wordpress/wp-admin/includes/class-wp-debug-data.php#L1354-L1396)

### `get_editable_authors`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$authors` |  | 

Source: [wordpress/wp-admin/includes/deprecated.php](../../wordpress/wp-admin/includes/deprecated.php), [line 270](../../wordpress/wp-admin/includes/deprecated.php#L270-L270)

### `get_others_drafts`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$other_unpubs` |  | 

Source: [wordpress/wp-admin/includes/deprecated.php](../../wordpress/wp-admin/includes/deprecated.php), [line 710](../../wordpress/wp-admin/includes/deprecated.php#L710-L710)

### `wp_create_thumbnail`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`image_resize($file, $max_side, $max_side)` |  | 

Source: [wordpress/wp-admin/includes/deprecated.php](../../wordpress/wp-admin/includes/deprecated.php), [line 1132](../../wordpress/wp-admin/includes/deprecated.php#L1132-L1132)

### `image_size_names_choose`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('thumbnail' => __('Thumbnail'), 'medium' => __('Medium'), 'large' => __('Large'), 'full' => __('Full Size'))` |  | 

Source: [wordpress/wp-admin/includes/class-custom-background.php](../../wordpress/wp-admin/includes/class-custom-background.php), [line 593](../../wordpress/wp-admin/includes/class-custom-background.php#L593-L602)

### `parent_file`

*Filters the parent file of an admin menu sub-menu item.*

Allows plugins to move sub-menu items around.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parent_file` | `string` | The parent file.

Source: [wordpress/wp-admin/menu-header.php](../../wordpress/wp-admin/menu-header.php), [line 29](../../wordpress/wp-admin/menu-header.php#L29-L38)

### `submenu_file`

*Filters the file of an admin menu sub-menu item.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$submenu_file` | `string` | The submenu file.
`$parent_file` | `string` | The submenu item's parent file.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-admin/menu-header.php](../../wordpress/wp-admin/menu-header.php), [line 40](../../wordpress/wp-admin/menu-header.php#L40-L48)

### `allow_dev_auto_core_updates`

*This filter is documented in wp-admin/includes/class-core-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$upgrade_dev` |  | 

Source: [wordpress/wp-admin/update-core.php](../../wordpress/wp-admin/update-core.php), [line 353](../../wordpress/wp-admin/update-core.php#L353-L354)

### `allow_minor_auto_core_updates`

*This filter is documented in wp-admin/includes/class-core-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$upgrade_minor` |  | 

Source: [wordpress/wp-admin/update-core.php](../../wordpress/wp-admin/update-core.php), [line 355](../../wordpress/wp-admin/update-core.php#L355-L356)

### `allow_major_auto_core_updates`

*This filter is documented in wp-admin/includes/class-core-upgrader.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$upgrade_major` |  | 

Source: [wordpress/wp-admin/update-core.php](../../wordpress/wp-admin/update-core.php), [line 357](../../wordpress/wp-admin/update-core.php#L357-L358)

### `edit_comment_misc_actions`

*Filters miscellaneous actions for the edit comment form sidebar.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$comment` | `\WP_Comment` | Current comment object.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-admin/edit-form-comment.php](../../wordpress/wp-admin/edit-form-comment.php), [line 188](../../wordpress/wp-admin/edit-form-comment.php#L188-L196)

### `all_plugins`

*This filter is documented in wp-admin/includes/class-wp-plugins-list-table.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_plugins()` |  | 

Source: [wordpress/wp-admin/plugins.php](../../wordpress/wp-admin/plugins.php), [line 506](../../wordpress/wp-admin/plugins.php#L506-L507)

### `handle_bulk_actions-{$screen}`

*This action is documented in wp-admin/edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sendback` |  | 
`$action` |  | 
`$plugins` |  | 

Source: [wordpress/wp-admin/plugins.php](../../wordpress/wp-admin/plugins.php), [line 524](../../wordpress/wp-admin/plugins.php#L524-L525)

### `delete_site_email_content`

*Filters the text for the email sent to the site admin when a request to delete a site in a Multisite network is submitted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | The email text.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/ms-delete-site.php](../../wordpress/wp-admin/ms-delete-site.php), [line 74](../../wordpress/wp-admin/ms-delete-site.php#L74-L81)

### `redirect_user_admin_request`

*Filters whether to redirect the request to the User Admin in Multisite.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_user_admin_request` | `bool` | Whether the request should be redirected.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/user/admin.php](../../wordpress/wp-admin/user/admin.php), [line 21](../../wordpress/wp-admin/user/admin.php#L21-L28)

### `handle_bulk_actions-{$screen}`

*This action is documented in wp-admin/edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` |  | 
`$wp_list_table->current_action()` |  | 
`$tags` |  | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 206](../../wordpress/wp-admin/edit-tags.php#L206-L207)

### `redirect_term_location`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` |  | 
`$tax` |  | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 228](../../wordpress/wp-admin/edit-tags.php#L228-L228)

### `taxonomy_parent_dropdown_args`

*Filters the taxonomy parent drop-down on the Edit Term page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$dropdown_args` | `array` | {<br>    An array of taxonomy parent drop-down arguments.<br><br>    @type int\|bool $hide_empty       Whether to hide terms not attached to any posts. Default 0\|false.<br>    @type bool     $hide_if_empty    Whether to hide the drop-down if no terms exist. Default false.<br>    @type string   $taxonomy         The taxonomy slug.<br>    @type string   $name             Value of the name attribute to use for the drop-down select element.<br>                                     Default 'parent'.<br>    @type string   $orderby          The field to order by. Default 'name'.<br>    @type bool     $hierarchical     Whether the taxonomy is hierarchical. Default true.<br>    @type string   $show_option_none Label to display if there are no terms. Default 'None'.<br>}
`$taxonomy` | `string` | The taxonomy slug.
`'new'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.2.0` | Added `$context` parameter.
`3.7.0` | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 470](../../wordpress/wp-admin/edit-tags.php#L470-L491)

### `the_category`

*This filter is documented in wp-includes/category-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_cat_name(get_option('default_category'))` |  | 
`''` |  | 
`''` |  | 

Source: [wordpress/wp-admin/edit-tags.php](../../wordpress/wp-admin/edit-tags.php), [line 604](../../wordpress/wp-admin/edit-tags.php#L604-L605)

### `async_upload_{$type}`

*Filters the returned ID of an uploaded attachment.*

The dynamic portion of the hook name, `$type`, refers to the attachment type,
such as 'image', 'audio', 'video', 'file', etc.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | Uploaded attachment ID.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-admin/async-upload.php](../../wordpress/wp-admin/async-upload.php), [line 119](../../wordpress/wp-admin/async-upload.php#L119-L129)

### `enable_post_by_email_configuration`

*This filter is documented in wp-admin/options.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/options-writing.php](../../wordpress/wp-admin/options-writing.php), [line 28](../../wordpress/wp-admin/options-writing.php#L28-L29)

### `enable_update_services_configuration`

*This filter is documented in wp-admin/options-writing.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/options-writing.php](../../wordpress/wp-admin/options-writing.php), [line 39](../../wordpress/wp-admin/options-writing.php#L39-L40)

### `enable_post_by_email_configuration`

*This filter is documented in wp-admin/options.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/options-writing.php](../../wordpress/wp-admin/options-writing.php), [line 137](../../wordpress/wp-admin/options-writing.php#L137-L138)

### `enable_update_services_configuration`

*Filters whether to enable the Update Services section in the Writing settings screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/options-writing.php](../../wordpress/wp-admin/options-writing.php), [line 192](../../wordpress/wp-admin/options-writing.php#L192-L199)

### `users_have_additional_content`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$userids` |  | 

Source: [wordpress/wp-admin/users.php](../../wordpress/wp-admin/users.php), [line 297](../../wordpress/wp-admin/users.php#L297-L297)

### `handle_bulk_actions-{$screen}`

*This action is documented in wp-admin/edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sendback` |  | 
`$wp_list_table->current_action()` |  | 
`$userids` |  | 

Source: [wordpress/wp-admin/users.php](../../wordpress/wp-admin/users.php), [line 508](../../wordpress/wp-admin/users.php#L508-L509)

### `thread_comments_depth_max`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`10` |  | 

Source: [wordpress/wp-admin/options-discussion.php](../../wordpress/wp-admin/options-discussion.php), [line 106](../../wordpress/wp-admin/options-discussion.php#L106-L106)

### `avatar_defaults`

*Filters the default avatars.*

Avatars are stored in key/value pairs, where the key is option value,
and the name is the displayed avatar name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$avatar_defaults` | `string[]` | Associative array of default avatars.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/options-discussion.php](../../wordpress/wp-admin/options-discussion.php), [line 283](../../wordpress/wp-admin/options-discussion.php#L283-L293)

### `default_avatar_select`

*Filters the HTML output of the default avatar list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$avatar_list` | `string` | HTML markup of the avatar list.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-admin/options-discussion.php](../../wordpress/wp-admin/options-discussion.php), [line 310](../../wordpress/wp-admin/options-discussion.php#L310-L317)

### `handle_bulk_actions-{$screen}`

*This action is documented in wp-admin/edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` |  | 
`$doaction` |  | 
`$post_ids` |  | 

Source: [wordpress/wp-admin/upload.php](../../wordpress/wp-admin/upload.php), [line 203](../../wordpress/wp-admin/upload.php#L203-L204)

### `install_themes_tabs`

*Filters the tabs shown on the Add Themes screen.*

This filter is for backward compatibility only, for the suppression of the upload tab.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('upload' => __('Upload Theme'))` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-admin/theme-install.php](../../wordpress/wp-admin/theme-install.php), [line 143](../../wordpress/wp-admin/theme-install.php#L143-L152)

### `comment_edit_redirect`

*Filters the URI the user is redirected to after editing a comment in the admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` | `string` | The URI the user will be redirected to.
`$comment_id` | `int` | The ID of the comment being edited.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-admin/comment.php](../../wordpress/wp-admin/comment.php), [line 353](../../wordpress/wp-admin/comment.php#L353-L361)

### `invited_user_email`

*Filters the contents of the email sent when an existing user is invited to join the site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_user_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The email address of the invited user.<br>    @type string $subject The subject of the email.<br>    @type string $message The content of the email.<br>    @type string $headers Headers.<br>}
`$user_id` | `int` | The invited user's ID.
`$role` | `array` | Array containing role information for the invited user.
`$newuser_key` | `string` | The key of the invitation.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 141](../../wordpress/wp-admin/user-new.php#L141-L159)

### `pre_user_login`

*This filter is documented in wp-includes/user.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`sanitize_user(wp_unslash($_REQUEST['user_login']), true)` |  | 

Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 209](../../wordpress/wp-admin/user-new.php#L209-L210)

### `autocomplete_users_for_site_admins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-admin/user-new.php](../../wordpress/wp-admin/user-new.php), [line 309](../../wordpress/wp-admin/user-new.php#L309-L309)

### `option_page_capability_{$option_page}`

*Filters the capability required when using the Settings API.*

By default, the options groups for all registered settings require the manage_options capability.
This filter is required to change the capability required for a certain options page.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$capability` | `string` | The capability used for the page, which is manage_options by default.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-admin/options.php](../../wordpress/wp-admin/options.php), [line 34](../../wordpress/wp-admin/options.php#L34-L44)

### `enable_post_by_email_configuration`

*Filters whether the post-by-email functionality is enabled.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-admin/options.php](../../wordpress/wp-admin/options.php), [line 190](../../wordpress/wp-admin/options.php#L190-L197)

### `whitelist_options`

*Filters the allowed options list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($allowed_options)` |  | 
`'5.5.0'` |  | 
`'allowed_options'` |  | 
`__('Please consider writing more inclusive code.')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-admin/options.php](../../wordpress/wp-admin/options.php), [line 202](../../wordpress/wp-admin/options.php#L202-L216)

### `allowed_options`

*Filters the allowed options list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_options` | `array` | The allowed options list.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-admin/options.php](../../wordpress/wp-admin/options.php), [line 218](../../wordpress/wp-admin/options.php#L218-L225)

### `editable_slug`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag->slug` |  | 
`$tag` |  | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 153](../../wordpress/wp-admin/edit-tag-form.php#L153-L153)

### `taxonomy_parent_dropdown_args`

*This filter is documented in wp-admin/edit-tags.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$dropdown_args` |  | 
`$taxonomy` |  | 
`'edit'` |  | 

Source: [wordpress/wp-admin/edit-tag-form.php](../../wordpress/wp-admin/edit-tag-form.php), [line 176](../../wordpress/wp-admin/edit-tag-form.php#L176-L177)

### `handle_bulk_actions-{$screen}`

*Fires when a custom bulk action should be handled.*

The redirect link should be modified with success or failure feedback
from the action to be used to display feedback to the user.

The dynamic portion of the hook name, `$screen`, refers to the current screen ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sendback` | `string` | The redirect URL.
`$doaction` | `string` | The action being taken.
`$post_ids` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-admin/edit.php](../../wordpress/wp-admin/edit.php), [line 195](../../wordpress/wp-admin/edit.php#L195-L210)

### `bulk_post_updated_messages`

*Filters the bulk action updated messages.*

By default, custom post types use the messages for the 'post' post type.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$bulk_messages` | `array[]` | Arrays of messages, each keyed by the corresponding post type. Messages are<br>keyed with 'updated', 'locked', 'deleted', 'trashed', and 'untrashed'.
`$bulk_counts` | `int[]` | Array of item counts for each message, used to build internationalized strings.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-admin/edit.php](../../wordpress/wp-admin/edit.php), [line 380](../../wordpress/wp-admin/edit.php#L380-L391)

### `tables_to_repair`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-admin/maint/repair.php](../../wordpress/wp-admin/maint/repair.php), [line 92](../../wordpress/wp-admin/maint/repair.php#L92-L92)

### `do_mu_upgrade`

*Filters whether to attempt to perform the multisite DB upgrade routine.*

In single site, the user would be redirected to wp-admin/upgrade.php.
In multisite, the DB upgrade routine is automatically fired, but only
when this filter returns true.

If the network is 50 sites or less, it will run every time. Otherwise,
it will throttle itself to reduce load.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 59](../../wordpress/wp-admin/admin.php#L59-L73)

### `force_filtered_html_on_import`

*Whether to filter imported data through kses on import.*

Multisite uses this hook to filter all data through kses by default,
as a super administrator may be assisting an untrusted user.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-admin/admin.php](../../wordpress/wp-admin/admin.php), [line 339](../../wordpress/wp-admin/admin.php#L339-L349)

### `block_editor_preload_paths`

*Preload common data by specifying an array of REST API paths that will be preloaded.*

Filters the array of paths that will be preloaded.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$preload_paths` | `string[]` | Array of paths to preload.
`$post` | `\WP_Post` | Post being edited.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 60](../../wordpress/wp-admin/edit-form-blocks.php#L60-L70)

### `allowed_block_types`

*Filters the allowed block types for the editor, defaulting to true (all
block types supported).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post` | `\WP_Post` | The post resource data.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 152](../../wordpress/wp-admin/edit-form-blocks.php#L152-L162)

### `default_page_template_title`

*This filter is documented in wp-admin/includes/meta-boxes.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Default template')` |  | 
`'rest-api'` |  | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 173](../../wordpress/wp-admin/edit-form-blocks.php#L173-L174)

### `image_size_names_choose`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('thumbnail' => __('Thumbnail'), 'medium' => __('Medium'), 'large' => __('Large'), 'full' => __('Full Size'))` |  | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 234](../../wordpress/wp-admin/edit-form-blocks.php#L234-L243)

### `show_post_locked_dialog`

*This filter is documented in wp-admin/includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post` |  | 
`$user_id` |  | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 267](../../wordpress/wp-admin/edit-form-blocks.php#L267-L268)

### `write_your_story`

*Filters the body placeholder text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Start writing or type / to choose a block')` |  | 
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 298](../../wordpress/wp-admin/edit-form-blocks.php#L298-L306)

### `enter_title_here`

*This filter is documented in wp-admin/edit-form-advanced.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Add title')` |  | 
`$post` |  | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 316](../../wordpress/wp-admin/edit-form-blocks.php#L316-L317)

### `block_editor_settings`

*Filters the settings to pass to the block editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$editor_settings` | `array` | Default editor settings.
`$post` | `\WP_Post` | Post being edited.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 421](../../wordpress/wp-admin/edit-form-blocks.php#L421-L429)

### `block_editor_no_javascript_message`

*Filters the message displayed in the block editor interface when JavaScript is
not enabled in the browser.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message` | `string` | The message being displayed.
`$post` | `\WP_Post` | The post being edited.

**Changelog**

Version | Description
------- | -----------
`5.0.3` | 

Source: [wordpress/wp-admin/edit-form-blocks.php](../../wordpress/wp-admin/edit-form-blocks.php), [line 472](../../wordpress/wp-admin/edit-form-blocks.php#L472-L481)

### `enable_edit_any_user_configuration`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 95](../../wordpress/wp-admin/user-edit.php#L95-L95)

### `user_{$name}_label`

*Filters a user contactmethod label.*

The dynamic portion of the filter hook, `$name`, refers to
each of the keys in the contactmethods array.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$desc` | `string` | The translatable label for the contactmethod.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 551](../../wordpress/wp-admin/user-edit.php#L551-L561)

### `user_profile_picture_description`

*Filters the user profile picture description displayed under the Gravatar.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$description` | `string` | The description that will be printed.
`$profileuser` | `\WP_User` | The current WP_User object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Added the `$profileuser` parameter.
`4.4.0` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 597](../../wordpress/wp-admin/user-edit.php#L597-L606)

### `show_password_fields`

*Filters the display of the password fields.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$profileuser` | `\WP_User` | User object for the current user to edit.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Now evaluated only in user-edit.php.
`2.8.0` | Added the `$profileuser` parameter.
`1.5.1` | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 613](../../wordpress/wp-admin/user-edit.php#L613-L623)

### `additional_capabilities_display`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$profileuser` |  | 

Source: [wordpress/wp-admin/user-edit.php](../../wordpress/wp-admin/user-edit.php), [line 839](../../wordpress/wp-admin/user-edit.php#L839-L839)

### `wp_signup_location`

*This filter is documented in wp-login.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`network_site_url('wp-signup.php')` |  | 

Source: [wordpress/wp-admin/my-sites.php](../../wordpress/wp-admin/my-sites.php), [line 70](../../wordpress/wp-admin/my-sites.php#L70-L71)

### `myblogs_options`

*Enable the Global Settings section on the My Sites screen.*

By default, the Global Settings section is hidden. Passing a non-empty
string to this filter will enable the section, and allow new settings
to be added, either globally or for specific sites.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`'global'` |  | 

Source: [wordpress/wp-admin/my-sites.php](../../wordpress/wp-admin/my-sites.php), [line 97](../../wordpress/wp-admin/my-sites.php#L97-L109)

### `myblogs_blog_actions`

*Filters the row links displayed for each site on the My Sites screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions` | `string` | The HTML site link markup.
`$user_blog` | `object` | An object containing the site data.

Source: [wordpress/wp-admin/my-sites.php](../../wordpress/wp-admin/my-sites.php), [line 130](../../wordpress/wp-admin/my-sites.php#L130-L138)

### `myblogs_options`

*This filter is documented in wp-admin/my-sites.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$user_blog` |  | 

Source: [wordpress/wp-admin/my-sites.php](../../wordpress/wp-admin/my-sites.php), [line 142](../../wordpress/wp-admin/my-sites.php#L142-L143)

### `handle_bulk_actions-{$screen}`

*This action is documented in wp-admin/edit.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_to` |  | 
`$doaction` |  | 
`$bulklinks` |  | 

Source: [wordpress/wp-admin/link-manager.php](../../wordpress/wp-admin/link-manager.php), [line 37](../../wordpress/wp-admin/link-manager.php#L37-L38)

### `date_i18n`

*Filters the date formatted based on the locale.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$date` | `string` | Formatted date string.
`$format` | `string` | Format to display the date.
`$timestamp` | `int` | A sum of Unix timestamp and timezone offset in seconds.<br>Might be without offset if input omitted timestamp but requested GMT.
`$gmt` | `bool` | Whether to use GMT timezone. Only applies if timestamp was not provided.<br>Default false.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 194](../../wordpress/wp-includes/functions.php#L194-L206)

### `wp_date`

*Filters the date formatted based on the locale.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$date` | `string` | Formatted date string.
`$format` | `string` | Format to display the date.
`$timestamp` | `int` | Unix timestamp.
`$timezone` | `\DateTimeZone` | Timezone.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 292](../../wordpress/wp-includes/functions.php#L292-L302)

### `number_format_i18n`

*Filters the number formatted based on the locale.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$formatted` | `string` | Converted number in string format.
`$number` | `float` | The number to convert based on locale.
`$decimals` | `int` | Precision of the number of decimal places.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `$number` and `$decimals` parameters were added.
`2.8.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 417](../../wordpress/wp-includes/functions.php#L417-L427)

### `enclosure_links`

*Filters the list of enclosure links before querying the database.*

Allows for the addition and/or removal of potential enclosures to save
to postmeta before checking the database for existing enclosures.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_links` | `string[]` | An array of enclosure links.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 888](../../wordpress/wp-includes/functions.php#L888-L899)

### `removable_query_args`

*Filters the list of query variable names to remove.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$removable_query_args` | `string[]` | An array of query variable names to remove from a URL.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 1215](../../wordpress/wp-includes/functions.php#L1215-L1222)

### `status_header`

*Filters an HTTP status header.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$status_header` | `string` | HTTP status header.
`$code` | `int` | HTTP status code.
`$description` | `string` | Description for the status code.
`$protocol` | `string` | Server protocol.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 1416](../../wordpress/wp-includes/functions.php#L1416-L1426)

### `nocache_headers`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$headers` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 1465](../../wordpress/wp-includes/functions.php#L1465-L1465)

### `robots_txt`

*Filters the robots.txt output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The robots.txt output.
`$public` | `bool` | Whether the site is considered "public".

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 1664](../../wordpress/wp-includes/functions.php#L1664-L1672)

### `upload_dir`

*Filters the uploads directory data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cache[$key]` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 2301](../../wordpress/wp-includes/functions.php#L2301-L2317)

### `pre_wp_unique_filename_file_list`

*Filters the file list used for calculating a unique filename for a newly added file.*

Returning an array from the filter will effectively short-circuit retrieval
from the filesystem and return the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$dir` | `string` | The directory for the new file.
`$filename` | `string` | The proposed filename for the new file.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 2547](../../wordpress/wp-includes/functions.php#L2547-L2560)

### `wp_unique_filename`

*Filters the result when generating a unique file name.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filename` | `string` | Unique file name.
`$ext` | `string` | File extension, eg. ".png".
`$dir` | `string` | Directory path.
`$unique_filename_callback` | `callable\|null` | Callback function that generates the unique file name.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 2591](../../wordpress/wp-includes/functions.php#L2591-L2601)

### `wp_upload_bits`

*Filters whether to treat the upload bits as an error.*

Returning a non-array from the filter will effectively short-circuit preparing the upload bits
and return that value instead. An error message should be returned as a string.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('name' => $name, 'bits' => $bits, 'time' => $time)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 2688](../../wordpress/wp-includes/functions.php#L2688-L2705)

### `wp_handle_upload`

*This filter is documented in wp-admin/includes/file.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('file' => $new_file, 'url' => $url, 'type' => $wp_filetype['type'], 'error' => false)` |  | 
`'sideload'` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 2755](../../wordpress/wp-includes/functions.php#L2755-L2765)

### `getimagesize_mimes_to_exts`

*Filters the list mapping image mime types to their respective extensions.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('image/jpeg' => 'jpg', 'image/png' => 'png', 'image/gif' => 'gif', 'image/bmp' => 'bmp', 'image/tiff' => 'tif')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 2868](../../wordpress/wp-includes/functions.php#L2868-L2884)

### `wp_check_filetype_and_ext`

*Filters the "real" file type of the given file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`compact('ext', 'type', 'proper_filename')` |  | 
`$file` | `string` | Full path to the file.
`$filename` | `string` | The name of the file (may differ from $file due to<br>$file being in a tmp directory).
`$mimes` | `string[]` | Array of mime types keyed by their file extension regex.
`$real_mime` | `string\|false` | The actual mime type or false if the type cannot be determined.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The $real_mime parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3012](../../wordpress/wp-includes/functions.php#L3012-L3031)

### `mime_types`

*Filters the list of mime types and file extensions.*

This filter should be used to add, not remove, mime types. To remove
mime types, use the %1$s filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(
    // Image formats.
    'jpg|jpeg|jpe' => 'image/jpeg',
    'gif' => 'image/gif',
    'png' => 'image/png',
    'bmp' => 'image/bmp',
    'tiff|tif' => 'image/tiff',
    'ico' => 'image/x-icon',
    'heic' => 'image/heic',
    // Video formats.
    'asf|asx' => 'video/x-ms-asf',
    'wmv' => 'video/x-ms-wmv',
    'wmx' => 'video/x-ms-wmx',
    'wm' => 'video/x-ms-wm',
    'avi' => 'video/avi',
    'divx' => 'video/divx',
    'flv' => 'video/x-flv',
    'mov|qt' => 'video/quicktime',
    'mpeg|mpg|mpe' => 'video/mpeg',
    'mp4|m4v' => 'video/mp4',
    'ogv' => 'video/ogg',
    'webm' => 'video/webm',
    'mkv' => 'video/x-matroska',
    '3gp|3gpp' => 'video/3gpp',
    // Can also be audio.
    '3g2|3gp2' => 'video/3gpp2',
    // Can also be audio.
    // Text formats.
    'txt|asc|c|cc|h|srt' => 'text/plain',
    'csv' => 'text/csv',
    'tsv' => 'text/tab-separated-values',
    'ics' => 'text/calendar',
    'rtx' => 'text/richtext',
    'css' => 'text/css',
    'htm|html' => 'text/html',
    'vtt' => 'text/vtt',
    'dfxp' => 'application/ttaf+xml',
    // Audio formats.
    'mp3|m4a|m4b' => 'audio/mpeg',
    'aac' => 'audio/aac',
    'ra|ram' => 'audio/x-realaudio',
    'wav' => 'audio/wav',
    'ogg|oga' => 'audio/ogg',
    'flac' => 'audio/flac',
    'mid|midi' => 'audio/midi',
    'wma' => 'audio/x-ms-wma',
    'wax' => 'audio/x-ms-wax',
    'mka' => 'audio/x-matroska',
    // Misc application formats.
    'rtf' => 'application/rtf',
    'js' => 'application/javascript',
    'pdf' => 'application/pdf',
    'swf' => 'application/x-shockwave-flash',
    'class' => 'application/java',
    'tar' => 'application/x-tar',
    'zip' => 'application/zip',
    'gz|gzip' => 'application/x-gzip',
    'rar' => 'application/rar',
    '7z' => 'application/x-7z-compressed',
    'exe' => 'application/x-msdownload',
    'psd' => 'application/octet-stream',
    'xcf' => 'application/octet-stream',
    // MS Office formats.
    'doc' => 'application/msword',
    'pot|pps|ppt' => 'application/vnd.ms-powerpoint',
    'wri' => 'application/vnd.ms-write',
    'xla|xls|xlt|xlw' => 'application/vnd.ms-excel',
    'mdb' => 'application/vnd.ms-access',
    'mpp' => 'application/vnd.ms-project',
    'docx' => 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
    'docm' => 'application/vnd.ms-word.document.macroEnabled.12',
    'dotx' => 'application/vnd.openxmlformats-officedocument.wordprocessingml.template',
    'dotm' => 'application/vnd.ms-word.template.macroEnabled.12',
    'xlsx' => 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
    'xlsm' => 'application/vnd.ms-excel.sheet.macroEnabled.12',
    'xlsb' => 'application/vnd.ms-excel.sheet.binary.macroEnabled.12',
    'xltx' => 'application/vnd.openxmlformats-officedocument.spreadsheetml.template',
    'xltm' => 'application/vnd.ms-excel.template.macroEnabled.12',
    'xlam' => 'application/vnd.ms-excel.addin.macroEnabled.12',
    'pptx' => 'application/vnd.openxmlformats-officedocument.presentationml.presentation',
    'pptm' => 'application/vnd.ms-powerpoint.presentation.macroEnabled.12',
    'ppsx' => 'application/vnd.openxmlformats-officedocument.presentationml.slideshow',
    'ppsm' => 'application/vnd.ms-powerpoint.slideshow.macroEnabled.12',
    'potx' => 'application/vnd.openxmlformats-officedocument.presentationml.template',
    'potm' => 'application/vnd.ms-powerpoint.template.macroEnabled.12',
    'ppam' => 'application/vnd.ms-powerpoint.addin.macroEnabled.12',
    'sldx' => 'application/vnd.openxmlformats-officedocument.presentationml.slide',
    'sldm' => 'application/vnd.ms-powerpoint.slide.macroEnabled.12',
    'onetoc|onetoc2|onetmp|onepkg' => 'application/onenote',
    'oxps' => 'application/oxps',
    'xps' => 'application/vnd.ms-xpsdocument',
    // OpenOffice formats.
    'odt' => 'application/vnd.oasis.opendocument.text',
    'odp' => 'application/vnd.oasis.opendocument.presentation',
    'ods' => 'application/vnd.oasis.opendocument.spreadsheet',
    'odg' => 'application/vnd.oasis.opendocument.graphics',
    'odc' => 'application/vnd.oasis.opendocument.chart',
    'odb' => 'application/vnd.oasis.opendocument.database',
    'odf' => 'application/vnd.oasis.opendocument.formula',
    // WordPerfect formats.
    'wp|wpd' => 'application/wordperfect',
    // iWork formats.
    'key' => 'application/vnd.apple.keynote',
    'numbers' => 'application/vnd.apple.numbers',
    'pages' => 'application/vnd.apple.pages',
)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3078](../../wordpress/wp-includes/functions.php#L3078-L3195)

### `ext2type`

*Filters file type based on the extension name.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('image' => array('jpg', 'jpeg', 'jpe', 'gif', 'png', 'bmp', 'tif', 'tiff', 'ico', 'heic'), 'audio' => array('aac', 'ac3', 'aif', 'aiff', 'flac', 'm3a', 'm4a', 'm4b', 'mka', 'mp1', 'mp2', 'mp3', 'ogg', 'oga', 'ram', 'wav', 'wma'), 'video' => array('3g2', '3gp', '3gpp', 'asf', 'avi', 'divx', 'dv', 'flv', 'm4v', 'mkv', 'mov', 'mp4', 'mpeg', 'mpg', 'mpv', 'ogm', 'ogv', 'qt', 'rm', 'vob', 'wmv'), 'document' => array('doc', 'docx', 'docm', 'dotm', 'odt', 'pages', 'pdf', 'xps', 'oxps', 'rtf', 'wp', 'wpd', 'psd', 'xcf'), 'spreadsheet' => array('numbers', 'ods', 'xls', 'xlsx', 'xlsm', 'xlsb'), 'interactive' => array('swf', 'key', 'ppt', 'pptx', 'pptm', 'pps', 'ppsx', 'ppsm', 'sldx', 'sldm', 'odp'), 'text' => array('asc', 'csv', 'tsv', 'txt'), 'archive' => array('bz2', 'cab', 'dmg', 'gz', 'rar', 'sea', 'sit', 'sqx', 'tar', 'tgz', 'zip', '7z'), 'code' => array('css', 'htm', 'html', 'php', 'js'))` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3207](../../wordpress/wp-includes/functions.php#L3207-L3229)

### `upload_mimes`

*Filters list of allowed mime types and file extensions.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$t` | `array` | Mime types keyed by the file extension regex corresponding to those types.
`$user` | `int\|\WP_User\|null` | User ID, User object or null if not provided (indicates current user).

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3253](../../wordpress/wp-includes/functions.php#L3253-L3261)

### `wp_die_ajax_handler`

*Filters the callback for killing WordPress execution for Ajax requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'_ajax_wp_die_handler'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3362](../../wordpress/wp-includes/functions.php#L3362-L3369)

### `wp_die_json_handler`

*Filters the callback for killing WordPress execution for JSON requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'_json_wp_die_handler'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3371](../../wordpress/wp-includes/functions.php#L3371-L3378)

### `wp_die_jsonp_handler`

*Filters the callback for killing WordPress execution for JSONP requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'_jsonp_wp_die_handler'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3380](../../wordpress/wp-includes/functions.php#L3380-L3387)

### `wp_die_xmlrpc_handler`

*Filters the callback for killing WordPress execution for XML-RPC requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'_xmlrpc_wp_die_handler'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3389](../../wordpress/wp-includes/functions.php#L3389-L3396)

### `wp_die_xml_handler`

*Filters the callback for killing WordPress execution for XML requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'_xml_wp_die_handler'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3402](../../wordpress/wp-includes/functions.php#L3402-L3409)

### `wp_die_handler`

*Filters the callback for killing WordPress execution for all non-Ajax, non-JSON, non-XML requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'_default_wp_die_handler'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 3411](../../wordpress/wp-includes/functions.php#L3411-L3418)

### `smilies`

*Filters all the smilies.*

This filter must be added before `smilies_init` is run, as
it is normally only run once to setup the smilies regex.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wpsmiliestrans` | `string[]` | List of the smilies' hexadecimal representations, keyed by their smily code.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 4386](../../wordpress/wp-includes/functions.php#L4386-L4396)

### `load_default_widgets`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 4720](../../wordpress/wp-includes/functions.php#L4720-L4720)

### `deprecated_function_trigger_error`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 4850](../../wordpress/wp-includes/functions.php#L4850-L4850)

### `deprecated_constructor_trigger_error`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 4942](../../wordpress/wp-includes/functions.php#L4942-L4942)

### `deprecated_file_trigger_error`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5038](../../wordpress/wp-includes/functions.php#L5038-L5038)

### `deprecated_argument_trigger_error`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5134](../../wordpress/wp-includes/functions.php#L5134-L5134)

### `deprecated_hook_trigger_error`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5224](../../wordpress/wp-includes/functions.php#L5224-L5224)

### `doing_it_wrong_trigger_error`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$function` |  | 
`$message` |  | 
`$version` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5292](../../wordpress/wp-includes/functions.php#L5292-L5292)

### `iis7_supports_permalinks`

*Filters whether IIS 7+ supports pretty permalinks.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$supports_permalinks` | `bool` | Whether IIS7 supports permalinks. Default false.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5413](../../wordpress/wp-includes/functions.php#L5413-L5420)

### `get_main_network_id`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$main_network_id` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5689](../../wordpress/wp-includes/functions.php#L5689-L5689)

### `global_terms_enabled`

*Filters whether global terms are enabled.*

Returning a non-null value from the filter will effectively short-circuit the function
and return the value of the 'global_terms_enabled' site option instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 5707](../../wordpress/wp-includes/functions.php#L5707-L5717)

### `extra_{$context}_headers`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6136](../../wordpress/wp-includes/functions.php#L6136-L6136)

### `kses_allowed_protocols`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$protocols` |  | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6398](../../wordpress/wp-includes/functions.php#L6398-L6398)

### `wp_checkdate`

*Filters whether the given date is valid for the Gregorian calendar.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`checkdate($month, $day, $year)` |  | 
`$source_date` | `string` | Date to check.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6545](../../wordpress/wp-includes/functions.php#L6545-L6553)

### `wp_auth_check_load`

*Filters whether to load the authentication check.*

Returning a falsey value from the filter will effectively short-circuit
loading the authentication check.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$show` | `bool` | Whether to load the authentication check.
`$screen` | `\WP_Screen` | The current screen object.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6580](../../wordpress/wp-includes/functions.php#L6580-L6591)

### `wp_auth_check_same_domain`

*Filters whether the authentication check originated at the same domain.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$same_domain` | `bool` | Whether the authentication check originated at the same domain.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6610](../../wordpress/wp-includes/functions.php#L6610-L6617)

### `wp_delete_file`

*Filters the path of the file to delete.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` | `string` | Path to the file to delete.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6806](../../wordpress/wp-includes/functions.php#L6806-L6813)

### `admin_memory_limit`

*Filters the maximum memory limit available for administration screens.*

This only applies to administrators, who may require more memory for tasks
like updates. Memory limits when processing images (uploaded or edited by
users of any role) are handled separately.

The `WP_MAX_MEMORY_LIMIT` constant specifically defines the maximum memory
limit available when in the administration back end. The default is 256M
(256 megabytes of memory) or the original `memory_limit` php.ini value if
this is higher.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filtered_limit` | `int\|string` | The maximum WordPress memory limit. Accepts an integer<br>(bytes), or a shorthand string notation, such as '256M'.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | The default now takes the original `memory_limit` into account.
`3.0.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6940](../../wordpress/wp-includes/functions.php#L6940-L6958)

### `image_memory_limit`

*Filters the memory limit allocated for image manipulation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filtered_limit` | `int\|string` | Maximum memory limit to allocate for images.<br>Default `WP_MAX_MEMORY_LIMIT` or the original<br>php.ini `memory_limit`, whichever is higher.<br>Accepts an integer (bytes), or a shorthand string<br>notation, such as '256M'.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | The default now takes the original `memory_limit` into account.
`3.5.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6962](../../wordpress/wp-includes/functions.php#L6962-L6974)

### `{$context}_memory_limit`

*Filters the memory limit allocated for arbitrary contexts.*

The dynamic portion of the hook name, `$context`, refers to an arbitrary
context passed on calling the function. This allows for plugins to define
their own contexts for raising the memory limit.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filtered_limit` | `int\|string` | Maximum memory limit to allocate for images.<br>Default '256M' or the original php.ini `memory_limit`,<br>whichever is higher. Accepts an integer (bytes), or a<br>shorthand string notation, such as '256M'.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 6978](../../wordpress/wp-includes/functions.php#L6978-L6992)

### `send_site_admin_email_change_email`

*Filters whether to send the site admin email change notification email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$send` | `bool` | Whether to send the email notification.
`$old_email` | `string` | The old site admin email address.
`$new_email` | `string` | The new site admin email address.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7119](../../wordpress/wp-includes/functions.php#L7119-L7128)

### `site_admin_email_change_email`

*Filters the contents of the email notification sent when the site admin email address is changed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_change_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The intended recipient.<br>    @type string $subject The subject of the email.<br>    @type string $message The content of the email.<br>        The following strings have a special meaning and will get replaced dynamically:<br>        - ###OLD_EMAIL### The old site admin email address.<br>        - ###NEW_EMAIL### The new site admin email address.<br>        - ###SITENAME###  The name of the site.<br>        - ###SITEURL###   The URL to the site.<br>    @type string $headers Headers.<br>}
`$old_email` | `string` | The old site admin email address.
`$new_email` | `string` | The new site admin email address.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7160](../../wordpress/wp-includes/functions.php#L7160-L7181)

### `wp_privacy_anonymize_data`

*Filters the anonymous data for each type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$anonymous` | `string` | Anonymized data.
`$type` | `string` | Type of the data.
`$data` | `string` | Original data.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7306](../../wordpress/wp-includes/functions.php#L7306-L7315)

### `wp_privacy_exports_dir`

*Filters the directory used to store personal data export files.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$exports_dir` | `string` | Exports directory.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Exports now use relative paths, so changes to the directory
via this filter should be reflected on the server.
`4.9.6` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7331](../../wordpress/wp-includes/functions.php#L7331-L7340)

### `wp_privacy_exports_url`

*Filters the URL of the directory used to store personal data export files.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$exports_url` | `string` | Exports directory URL.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Exports now use relative paths, so changes to the directory URL
via this filter should be reflected on the server.
`4.9.6` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7356](../../wordpress/wp-includes/functions.php#L7356-L7365)

### `wp_privacy_export_expiration`

*Filters the lifetime, in seconds, of a personal data export file.*

By default, the lifetime is 3 days. Once the file reaches that age, it will automatically
be deleted by a cron job.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`3 * DAY_IN_SECONDS` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7403](../../wordpress/wp-includes/functions.php#L7403-L7413)

### `wp_update_php_url`

*Filters the URL to learn more about updating the PHP version the site is running on.*

Providing an empty string is not allowed and will result in the default URL being used. Furthermore
the page the URL links to should preferably be localized in the site language.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_url` | `string` | URL to learn more about updating PHP.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7444](../../wordpress/wp-includes/functions.php#L7444-L7454)

### `wp_direct_php_update_url`

*Filters the URL for directly updating the PHP version the site is running on from the host.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$direct_update_url` | `string` | URL for directly updating PHP.

**Changelog**

Version | Description
------- | -----------
`5.1.1` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7544](../../wordpress/wp-includes/functions.php#L7544-L7551)

### `wp_update_https_url`

*Filters the URL to learn more about updating the HTTPS version the site is running on.*

Providing an empty string is not allowed and will result in the default URL being used. Furthermore
the page the URL links to should preferably be localized in the site language.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_url` | `string` | URL to learn more about updating HTTPS.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7603](../../wordpress/wp-includes/functions.php#L7603-L7613)

### `wp_direct_update_https_url`

*Filters the URL for directly updating the PHP version the site is running on from the host.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$direct_update_url` | `string` | URL for directly updating PHP.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7656](../../wordpress/wp-includes/functions.php#L7656-L7663)

### `pre_recurse_dirsize`

*Filters the amount of storage space used by one directory and all its children, in megabytes.*

Return the actual used space to short-circuit the recursive PHP file size calculation
and use something else, like a CDN API or native operating system tools for better performance.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$directory` |  | 
`$exclude` |  | 
`$max_execution_time` |  | 
`$directory_cache` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/functions.php](../../wordpress/wp-includes/functions.php), [line 7753](../../wordpress/wp-includes/functions.php#L7753-L7763)

### `widget_archives_dropdown_args`

*This filter is documented in wp-includes/widgets/class-wp-widget-archives.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('type' => 'monthly', 'format' => 'option', 'show_post_count' => $show_post_count)` |  | 

Source: [wordpress/wp-includes/blocks/archives.php](../../wordpress/wp-includes/blocks/archives.php), [line 29](../../wordpress/wp-includes/blocks/archives.php#L29-L37)

### `widget_archives_args`

*This filter is documented in wp-includes/widgets/class-wp-widget-archives.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('type' => 'monthly', 'show_post_count' => $show_post_count)` |  | 

Source: [wordpress/wp-includes/blocks/archives.php](../../wordpress/wp-includes/blocks/archives.php), [line 76](../../wordpress/wp-includes/blocks/archives.php#L76-L83)

### `widget_comments_args`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('number' => $attributes['commentsToShow'], 'status' => 'approve', 'post_status' => 'publish')` |  | 

Source: [wordpress/wp-includes/blocks/latest-comments.php](../../wordpress/wp-includes/blocks/latest-comments.php), [line 46](../../wordpress/wp-includes/blocks/latest-comments.php#L46-L53)

### `pre_do_shortcode_tag`

*Filters whether to call a shortcode callback.*

Returning a non-false value from filter will short-circuit the
shortcode generation process, returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$tag` | `string` | Shortcode name.
`$attr` | `array\|string` | Shortcode attributes array or empty string.
`$m` | `array` | Regular expression match array.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/shortcodes.php](../../wordpress/wp-includes/shortcodes.php), [line 323](../../wordpress/wp-includes/shortcodes.php#L323-L336)

### `do_shortcode_tag`

*Filters the output created by a shortcode callback.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | Shortcode output.
`$tag` | `string` | Shortcode name.
`$attr` | `array\|string` | Shortcode attributes array or empty string.
`$m` | `array` | Regular expression match array.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/shortcodes.php](../../wordpress/wp-includes/shortcodes.php), [line 345](../../wordpress/wp-includes/shortcodes.php#L345-L355)

### `shortcode_atts_{$shortcode}`

*Filters shortcode attributes.*

If the third parameter of the shortcode_atts() function is present then this filter is available.
The third parameter, $shortcode, is the name of the shortcode.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$out` | `array` | The output array of shortcode attributes.
`$pairs` | `array` | The supported attributes and their defaults.
`$atts` | `array` | The user defined shortcode attributes.
`$shortcode` | `string` | The shortcode name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added the `$shortcode` parameter.
`3.6.0` | 

Source: [wordpress/wp-includes/shortcodes.php](../../wordpress/wp-includes/shortcodes.php), [line 583](../../wordpress/wp-includes/shortcodes.php#L583-L597)

### `strip_shortcodes_tagnames`

*Filters the list of shortcode tags to remove from the content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags_to_remove` | `array` | Array of shortcode tags to remove.
`$content` | `string` | Content shortcodes are being removed from.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/shortcodes.php](../../wordpress/wp-includes/shortcodes.php), [line 629](../../wordpress/wp-includes/shortcodes.php#L629-L637)

### `customize_sanitize_{$this->id}`

*Filters a Customize setting value in un-slashed form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the setting.
`$this` | `\WP_Customize_Setting` | WP_Customize_Setting instance.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 567](../../wordpress/wp-includes/class-wp-customize-setting.php#L567-L575)

### `customize_validate_{$this->id}`

*Validates a Customize setting value.*

Plugins should amend the `$validity` object via its `WP_Error::add()` method.

The dynamic portion of the hook name, `$this->ID`, refers to the setting ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$validity` | `\WP_Error` | Filtered from `true` to `WP_Error` when invalid.
`$value` | `mixed` | Value of the setting.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 598](../../wordpress/wp-includes/class-wp-customize-setting.php#L598-L611)

### `customize_value_{$id_base}`

*Filters a Customize setting value not handled as a theme_mod or option.*

The dynamic portion of the hook name, `$id_base`, refers to
the base slug of the setting name, initialized from `$this->id_data['base']`.

For settings handled as theme_mods or options, see those corresponding
functions for available hooks.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Added the `$this` setting instance as the second parameter.
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 752](../../wordpress/wp-includes/class-wp-customize-setting.php#L752-L767)

### `customize_sanitize_js_{$this->id}`

*Filters a Customize setting value for use in JavaScript.*

The dynamic portion of the hook name, `$this->id`, refers to the setting ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->value()` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-setting.php](../../wordpress/wp-includes/class-wp-customize-setting.php), [line 791](../../wordpress/wp-includes/class-wp-customize-setting.php#L791-L801)

### `block_type_metadata`

*Filters the metadata provided for registering a block type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$metadata` | `array` | Metadata for registering a block type.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/blocks.php](../../wordpress/wp-includes/blocks.php), [line 209](../../wordpress/wp-includes/blocks.php#L209-L216)

### `block_type_metadata_settings`

*Filters the settings determined from the block type metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array_merge($settings, $args)` |  | 
`$metadata` | `array` | Metadata provided for registering a block type.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/blocks.php](../../wordpress/wp-includes/blocks.php), [line 310](../../wordpress/wp-includes/blocks.php#L310-L325)

### `excerpt_allowed_blocks`

*Filters the list of blocks that can contribute to the excerpt.*

If a dynamic block is added to this list, it must not generate another
excerpt, as this will cause an infinite loop to occur.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_blocks` | `array` | The list of allowed blocks.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/blocks.php](../../wordpress/wp-includes/blocks.php), [line 663](../../wordpress/wp-includes/blocks.php#L663-L673)

### `pre_render_block`

*Allows render_block() to be short-circuited, by returning a non-null value.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$parsed_block` | `array` | The block being rendered.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/blocks.php](../../wordpress/wp-includes/blocks.php), [line 741](../../wordpress/wp-includes/blocks.php#L741-L749)

### `render_block_data`

*Filters the block being rendered in render_block(), before it's processed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_block` | `array` | The block being rendered.
`$source_block` | `array` | An un-modified copy of $parsed_block, as it appeared in the source content.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/blocks.php](../../wordpress/wp-includes/blocks.php), [line 756](../../wordpress/wp-includes/blocks.php#L756-L764)

### `render_block_context`

*Filters the default context provided to a rendered block.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$context` | `array` | Default context.
`$parsed_block` | `array` | Block being rendered, filtered by `render_block_data`.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/blocks.php](../../wordpress/wp-includes/blocks.php), [line 787](../../wordpress/wp-includes/blocks.php#L787-L795)

### `block_parser_class`

*Filter to allow plugins to replace the server-side block parser*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'WP_Block_Parser'` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/blocks.php](../../wordpress/wp-includes/blocks.php), [line 811](../../wordpress/wp-includes/blocks.php#L811-L818)

### `register_sidebar_defaults`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$defaults` |  | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 286](../../wordpress/wp-includes/widgets.php#L286-L286)

### `dynamic_sidebar_has_widgets`

*This filter is documented in wp-includes/widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$index` |  | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 701](../../wordpress/wp-includes/widgets.php#L701-L702)

### `dynamic_sidebar_params`

*Filters the parameters passed to a widget's display callback.*

Note: The filter is evaluated on both the front end and back end,
including for the Inactive Widgets sidebar on the Widgets screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$params` | `array` | {<br>    @type array $args  {<br>        An array of widget display arguments.<br><br>        @type string $name          Name of the sidebar the widget is assigned to.<br>        @type string $id            ID of the sidebar the widget is assigned to.<br>        @type string $description   The sidebar description.<br>        @type string $class         CSS class applied to the sidebar container.<br>        @type string $before_widget HTML markup to prepend to each widget in the sidebar.<br>        @type string $after_widget  HTML markup to append to each widget in the sidebar.<br>        @type string $before_title  HTML markup to prepend to the widget title when displayed.<br>        @type string $after_title   HTML markup to append to the widget title when displayed.<br>        @type string $widget_id     ID of the widget.<br>        @type string $widget_name   Name of the widget.<br>    }<br>    @type array $widget_args {<br>        An array of multi-widget arguments.<br><br>        @type int $number Number increment used for multiples of the same widget.<br>    }<br>}

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 759](../../wordpress/wp-includes/widgets.php#L759-L791)

### `dynamic_sidebar_has_widgets`

*Filters whether a sidebar has widgets.*

Note: The filter is also evaluated for empty sidebars, and on both the front end
and back end, including the Inactive Widgets sidebar on the Widgets screen.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$did_one` | `bool` | Whether at least one widget was rendered in the sidebar.<br>Default false.
`$index` | `int\|string` | Index, name, or ID of the dynamic sidebar.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 846](../../wordpress/wp-includes/widgets.php#L846-L858)

### `is_active_sidebar`

*Filters whether a dynamic sidebar is considered "active".*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_active_sidebar` | `bool` | Whether or not the sidebar should be considered "active".<br>In other words, whether the sidebar contains any widgets.
`$index` | `int\|string` | Index, name, or ID of the dynamic sidebar.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 966](../../wordpress/wp-includes/widgets.php#L966-L975)

### `sidebars_widgets`

*Filters the list of sidebars and their widgets.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sidebars_widgets` | `array` | An associative array of sidebars and their widgets.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 1020](../../wordpress/wp-includes/widgets.php#L1020-L1027)

### `widget_display_callback`

*This filter is documented in wp-includes/class-wp-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance` |  | 
`$widget_obj` |  | 
`$args` |  | 

Source: [wordpress/wp-includes/widgets.php](../../wordpress/wp-includes/widgets.php), [line 1197](../../wordpress/wp-includes/widgets.php#L1197-L1198)

### `get_comment_author`

*Filters the returned comment author name.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$author` | `string` | The comment author's username.
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` and `$comment` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 38](../../wordpress/wp-includes/comment-template.php#L38-L48)

### `comment_author`

*Filters the comment author's name for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$author` | `string` | The comment author's username.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` parameter was added.
`1.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 64](../../wordpress/wp-includes/comment-template.php#L64-L73)

### `get_comment_author_email`

*Filters the comment author's returned email address.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_author_email` |  | 
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` and `$comment` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 89](../../wordpress/wp-includes/comment-template.php#L89-L99)

### `author_email`

*Filters the comment author's email for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$author_email` | `string` | The comment author's email address.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` parameter was added.
`1.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 121](../../wordpress/wp-includes/comment-template.php#L121-L130)

### `comment_email`

*Filters the comment author's email for display.*

Care should be taken to protect the email address and assure that email
harvesters do not capture your commenter's email address.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_author_email` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment` parameter was added.
`1.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 181](../../wordpress/wp-includes/comment-template.php#L181-L193)

### `get_comment_author_link`

*Filters the comment author's link for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `string` | The HTML-formatted comment author link.<br>Empty for an invalid URL.
`$author` | `string` | The comment author's username.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$author` and `$comment_ID` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 230](../../wordpress/wp-includes/comment-template.php#L230-L241)

### `get_comment_author_IP`

*Filters the comment author's returned IP address.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_author_IP` |  | 
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` and `$comment` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 270](../../wordpress/wp-includes/comment-template.php#L270-L280)

### `get_comment_author_url`

*Filters the comment author's URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The comment author's URL.
`$id` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` and `$comment` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 317](../../wordpress/wp-includes/comment-template.php#L317-L327)

### `comment_url`

*Filters the comment author's URL for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$author_url` | `string` | The comment author's URL.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` parameter was added.
`1.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 343](../../wordpress/wp-includes/comment-template.php#L343-L352)

### `get_comment_author_url_link`

*Filters the comment author's returned URL link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `string` | The HTML-formatted comment author URL link.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 390](../../wordpress/wp-includes/comment-template.php#L390-L397)

### `comment_class`

*Filters the returned CSS classes for the current comment.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classes` | `string[]` | An array of comment classes.
`$class` | `string[]` | An array of additional classes added to the list.
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment object.
`$post_id` | `int\|\WP_Post` | The post ID or WP_Post object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 527](../../wordpress/wp-includes/comment-template.php#L527-L538)

### `get_comment_date`

*Filters the returned comment date.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$date` | `string\|int` | Formatted date string or Unix timestamp.
`$format` | `string` | PHP date format.
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 559](../../wordpress/wp-includes/comment-template.php#L559-L568)

### `comment_excerpt_length`

*Filters the maximum number of words used in the comment excerpt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_excerpt_length` | `int` | The amount of words you want to display in the comment excerpt.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 609](../../wordpress/wp-includes/comment-template.php#L609-L616)

### `get_comment_excerpt`

*Filters the retrieved comment excerpt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$excerpt` | `string` | The comment excerpt text.
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` and `$comment` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 620](../../wordpress/wp-includes/comment-template.php#L620-L630)

### `comment_excerpt`

*Filters the comment excerpt for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_excerpt` | `string` | The comment excerpt text.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` parameter was added.
`1.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 646](../../wordpress/wp-includes/comment-template.php#L646-L655)

### `get_comment_ID`

*Filters the returned comment ID.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` parameter was added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 668](../../wordpress/wp-includes/comment-template.php#L668-L677)

### `get_comment_link`

*Filters the returned single comment permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The comment permalink with '#comment-$id' appended.
`$comment` | `\WP_Comment` | The current comment object.
`$args` | `array` | An array of arguments to override the defaults.
`$cpage` | `int` | The calculated 'cpage' value.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added the `$cpage` parameter.
`2.8.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 788](../../wordpress/wp-includes/comment-template.php#L788-L801)

### `get_comments_link`

*Filters the returned post comments permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comments_link` | `string` | Post comments permalink with '#comments' appended.
`$post_id` | `int\|\WP_Post` | Post ID or WP_Post object.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 816](../../wordpress/wp-includes/comment-template.php#L816-L824)

### `get_comments_number`

*Filters the returned comment count for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$count` | `string\|int` | A string representing the number of comments a post has, otherwise 0.
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 864](../../wordpress/wp-includes/comment-template.php#L864-L872)

### `comments_number`

*Filters the comments count for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | A translatable string formatted based on whether the count<br>is equal to 0, 1, or 1+.
`$number` | `int` | The number of post comments.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 940](../../wordpress/wp-includes/comment-template.php#L940-L951)

### `get_comment_text`

*Filters the text of a comment.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_content` | `string` | Text of the comment.
`$comment` | `\WP_Comment` | The comment object.
`$args` | `array` | An array of arguments.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 987](../../wordpress/wp-includes/comment-template.php#L987-L998)

### `comment_text`

*Filters the text of a comment to be displayed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_text` | `string` | Text of the current comment.
`$comment` | `\WP_Comment\|null` | The comment object. Null if not found.
`$args` | `array` | An array of arguments.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1017](../../wordpress/wp-includes/comment-template.php#L1017-L1028)

### `get_comment_time`

*Filters the returned comment time.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$date` | `string\|int` | The comment time, formatted as a date string or Unix timestamp.
`$format` | `string` | PHP date format.
`$gmt` | `bool` | Whether the GMT date is in use.
`$translate` | `bool` | Whether the time is translated.
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1051](../../wordpress/wp-includes/comment-template.php#L1051-L1062)

### `get_comment_type`

*Filters the returned comment type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_type` |  | 
`$comment->comment_ID` |  | 
`$comment` | `\WP_Comment` | The comment object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$comment_ID` and `$comment` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1093](../../wordpress/wp-includes/comment-template.php#L1093-L1103)

### `trackback_url`

*Filters the returned trackback URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tb_url` | `string` | The trackback URL.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1156](../../wordpress/wp-includes/comment-template.php#L1156-L1163)

### `comments_open`

*Filters whether the current post is open for comments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$open` | `bool` | Whether the current post is open for comments.
`$post_id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1246](../../wordpress/wp-includes/comment-template.php#L1246-L1254)

### `pings_open`

*Filters whether the current post is open for pings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$open` | `bool` | Whether the current post is open for pings.
`$post_id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1276](../../wordpress/wp-includes/comment-template.php#L1276-L1284)

### `comments_template_top_level_query_args`

*Filters the arguments used in the top level comments query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$top_level_args` | `array` | {<br>    The top level query arguments for the comments template.<br><br>    @type bool         $count   Whether to return a comment count.<br>    @type string\|array $orderby The field(s) to order by.<br>    @type int          $post_id The post ID.<br>    @type string\|array $status  The comment status to limit results by.<br>}

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1437](../../wordpress/wp-includes/comment-template.php#L1437-L1453)

### `comments_template_query_args`

*Filters the arguments used to query comments in comments_template().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_args` | `array` | {<br>    Array of WP_Comment_Query arguments.<br><br>    @type string\|array $orderby                   Field(s) to order by.<br>    @type string       $order                     Order of results. Accepts 'ASC' or 'DESC'.<br>    @type string       $status                    Comment status.<br>    @type array        $include_unapproved        Array of IDs or email addresses whose unapproved comments<br>                                                  will be included in results.<br>    @type int          $post_id                   ID of the post.<br>    @type bool         $no_found_rows             Whether to refrain from querying for found rows.<br>    @type bool         $update_comment_meta_cache Whether to prime cache for comment meta.<br>    @type bool\|string  $hierarchical              Whether to query for comments hierarchically.<br>    @type int          $offset                    Comment offset.<br>    @type int          $number                    Number of comments to fetch.<br>}

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1461](../../wordpress/wp-includes/comment-template.php#L1461-L1484)

### `comments_array`

*Filters the comments array.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comments_flat` |  | 
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1510](../../wordpress/wp-includes/comment-template.php#L1510-L1518)

### `comments_template`

*Filters the path to the theme template file used for the comments template.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$theme_template` | `string` | The path to the theme template file.

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1544](../../wordpress/wp-includes/comment-template.php#L1544-L1551)

### `respond_link`

*Filters the respond link when a post has no comments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$respond_link` | `string` | The default response link.
`$post_id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1612](../../wordpress/wp-includes/comment-template.php#L1612-L1620)

### `comments_popup_link_attributes`

*Filters the comments link attributes for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attributes` | `string` | The comments link attributes. Default empty.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1631](../../wordpress/wp-includes/comment-template.php#L1631-L1638)

### `comment_reply_link_args`

*Filters the comment reply link arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Comment reply link arguments. See get_comment_reply_link()<br>for more information on accepted arguments.
`$comment` | `\WP_Comment` | The object of the comment being replied to.
`$post` | `\WP_Post` | The WP_Post object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1709](../../wordpress/wp-includes/comment-template.php#L1709-L1719)

### `comment_reply_link`

*Filters the comment reply link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args['before'] . $link . $args['after']` |  | 
`$args` | `array` | An array of arguments overriding the defaults.
`$comment` | `\WP_Comment` | The object of the comment being replied.
`$post` | `\WP_Post` | The WP_Post object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1762](../../wordpress/wp-includes/comment-template.php#L1762-L1772)

### `post_comments_link`

*Filters the formatted post comments link HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$formatted_link` |  | 
`$post` | `int\|\WP_Post` | The post ID or WP_Post object.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1855](../../wordpress/wp-includes/comment-template.php#L1855-L1863)

### `cancel_comment_reply_link`

*Filters the cancel comment reply link HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$formatted_link` | `string` | The HTML-formatted cancel comment reply link.
`$link` | `string` | Cancel comment reply link URL.
`$text` | `string` | Cancel comment reply link text.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1900](../../wordpress/wp-includes/comment-template.php#L1900-L1909)

### `comment_id_fields`

*Filters the returned comment ID fields.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `string` | The HTML-formatted hidden ID field comment elements.
`$post_id` | `int` | The post ID.
`$reply_to_id` | `int` | The ID of the comment being replied to.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 1941](../../wordpress/wp-includes/comment-template.php#L1941-L1950)

### `wp_list_comments_args`

*Filters the arguments used in retrieving the comment list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_args` | `array` | An array of arguments for displaying comments.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2091](../../wordpress/wp-includes/comment-template.php#L2091-L2100)

### `comment_form_default_fields`

*Filters the default comment form fields.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$fields` | `string[]` | Array of the default comment fields.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2420](../../wordpress/wp-includes/comment-template.php#L2420-L2427)

### `the_permalink`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_permalink($post_id)` |  | 
`$post_id` |  | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2445](../../wordpress/wp-includes/comment-template.php#L2445-L2445)

### `the_permalink`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_permalink($post_id)` |  | 
`$post_id` |  | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2458](../../wordpress/wp-includes/comment-template.php#L2458-L2458)

### `comment_form_defaults`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$defaults` |  | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2500](../../wordpress/wp-includes/comment-template.php#L2500-L2500)

### `comment_form_logged_in`

*Filters the 'logged in' message for the comment form for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args['logged_in_as']` |  | 
`$commenter` | `array` | An array containing the comment author's<br>username, email, and URL.
`$user_identity` | `string` | If the commenter is a registered user,<br>the display name, blank otherwise.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2564](../../wordpress/wp-includes/comment-template.php#L2564-L2575)

### `comment_form_fields`

*Filters the comment form fields, including the textarea.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_fields` | `array` | The comment fields.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2598](../../wordpress/wp-includes/comment-template.php#L2598-L2605)

### `comment_form_field_comment`

*Filters the content of the comment textarea field for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$field` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2618](../../wordpress/wp-includes/comment-template.php#L2618-L2625)

### `comment_form_field_{$name}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$field` |  | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2650](../../wordpress/wp-includes/comment-template.php#L2650-L2650)

### `comment_form_submit_button`

*Filters the submit button for the comment form to display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$submit_button` | `string` | HTML markup for the submit button.
`$args` | `array` | Arguments passed to comment_form().

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2671](../../wordpress/wp-includes/comment-template.php#L2671-L2679)

### `comment_form_submit_field`

*Filters the submit field for the comment form to display.*

The submit field includes the submit button, hidden fields for the
comment form, and any wrapper markup.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$submit_field` | `string` | HTML markup for the submit field.
`$args` | `array` | Arguments passed to comment_form().

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/comment-template.php](../../wordpress/wp-includes/comment-template.php), [line 2687](../../wordpress/wp-includes/comment-template.php#L2687-L2698)

### `_wp_post_revision_fields`

*Filters the list of fields saved in post revisions.*

Included by default: 'post_title', 'post_content' and 'post_excerpt'.

Disallowed fields: 'ID', 'post_name', 'post_parent', 'post_date',
'post_date_gmt', 'post_status', 'post_type', 'comment_count',
and 'post_author'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$fields` | `array` | List of fields to revision. Contains 'post_title',<br>'post_content', and 'post_excerpt' by default.
`$post` | `array` | A post array being processed for insertion as a post revision.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | The `$post` parameter was added.
`2.6.0` | 

Source: [wordpress/wp-includes/revision.php](../../wordpress/wp-includes/revision.php), [line 38](../../wordpress/wp-includes/revision.php#L38-L54)

### `wp_save_post_revision_check_for_changes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$last_revision` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/revision.php](../../wordpress/wp-includes/revision.php), [line 159](../../wordpress/wp-includes/revision.php#L159-L159)

### `wp_save_post_revision_post_has_changed`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_has_changed` |  | 
`$last_revision` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/revision.php](../../wordpress/wp-includes/revision.php), [line 181](../../wordpress/wp-includes/revision.php#L181-L181)

### `wp_revisions_to_keep`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$num` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/revision.php](../../wordpress/wp-includes/revision.php), [line 567](../../wordpress/wp-includes/revision.php#L567-L567)

### `post_format_rewrite_base`

*Filters the post formats rewrite base.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'type'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 35](../../wordpress/wp-includes/taxonomy.php#L35-L42)

### `taxonomy_labels_{$taxonomy}`

*Filters the labels of a specific taxonomy.*

The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$labels` | `object` | Object with labels for the taxonomy as member variables.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 625](../../wordpress/wp-includes/taxonomy.php#L625-L636)

### `get_term`

*Filters a taxonomy term object.*

The %1$s hook is also available for targeting a specific
taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_term` | `\WP_Term` | Term object.
`$taxonomy` | `string` | The taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | `$_term` is now a `WP_Term` object.
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 893](../../wordpress/wp-includes/taxonomy.php#L893-L905)

### `get_{$taxonomy}`

*Filters a taxonomy term object.*

The dynamic portion of the filter name, `$taxonomy`, refers
to the slug of the term's taxonomy.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_term` | `\WP_Term` | Term object.
`$taxonomy` | `string` | The taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | `$_term` is now a `WP_Term` object.
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 907](../../wordpress/wp-includes/taxonomy.php#L907-L919)

### `get_terms`

*Filters the found terms.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$terms` | `array` | Array of found terms.
`$term_query->query_vars['taxonomy']` |  | 
`$term_query->query_vars` |  | 
`$term_query` | `\WP_Term_Query` | The WP_Term_Query object.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Added the `$term_query` parameter.
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1248](../../wordpress/wp-includes/taxonomy.php#L1248-L1259)

### `edit_term_{$field}`

*Filters a term field to edit before it is sanitized.*

The dynamic portion of the filter name, `$field`, refers to the term field.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the term field.
`$term_id` | `int` | Term ID.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1610](../../wordpress/wp-includes/taxonomy.php#L1610-L1621)

### `edit_{$taxonomy}_{$field}`

*Filters the taxonomy field to edit before it is sanitized.*

The dynamic portions of the filter name, `$taxonomy` and `$field`, refer
to the taxonomy slug and taxonomy field, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the taxonomy field to edit.
`$term_id` | `int` | Term ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1623](../../wordpress/wp-includes/taxonomy.php#L1623-L1634)

### `pre_term_{$field}`

*Filters a term field value before it is sanitized.*

The dynamic portion of the filter name, `$field`, refers to the term field.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the term field.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1643](../../wordpress/wp-includes/taxonomy.php#L1643-L1653)

### `pre_{$taxonomy}_{$field}`

*Filters a taxonomy field before it is sanitized.*

The dynamic portions of the filter name, `$taxonomy` and `$field`, refer
to the taxonomy slug and field name, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the taxonomy field.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1655](../../wordpress/wp-includes/taxonomy.php#L1655-L1665)

### `pre_category_nicename`

*Filters the category nicename before it is sanitized.*

Use the %1$s hook instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `string` | The category nicename.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1669](../../wordpress/wp-includes/taxonomy.php#L1669-L1678)

### `term_{$field}_rss`

*Filters the term field for use in RSS.*

The dynamic portion of the filter name, `$field`, refers to the term field.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the term field.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1682](../../wordpress/wp-includes/taxonomy.php#L1682-L1692)

### `{$taxonomy}_{$field}_rss`

*Filters the taxonomy field for use in RSS.*

The dynamic portions of the hook name, `$taxonomy`, and `$field`, refer
to the taxonomy slug and field name, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the taxonomy field.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1694](../../wordpress/wp-includes/taxonomy.php#L1694-L1704)

### `term_{$field}`

*Filters the term field sanitized for display.*

The dynamic portion of the filter name, `$field`, refers to the term field name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the term field.
`$term_id` | `int` | Term ID.
`$taxonomy` | `string` | Taxonomy slug.
`$context` | `string` | Context to retrieve the term field value.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1708](../../wordpress/wp-includes/taxonomy.php#L1708-L1720)

### `{$taxonomy}_{$field}`

*Filters the taxonomy field sanitized for display.*

The dynamic portions of the filter name, `$taxonomy`, and `$field`, refer
to the taxonomy slug and taxonomy field, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the taxonomy field.
`$term_id` | `int` | Term ID.
`$context` | `string` | Context to retrieve the taxonomy field value.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 1722](../../wordpress/wp-includes/taxonomy.php#L1722-L1734)

### `wp_get_object_terms_args`

*Filters arguments for retrieving object terms.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | An array of arguments for retrieving terms for the given object(s).<br>See {@see \wp_get_object_terms()} for details.
`$object_ids` | `int[]` | Array of object IDs.
`$taxonomies` | `string[]` | Array of taxonomy names to retrieve terms from.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2098](../../wordpress/wp-includes/taxonomy.php#L2098-L2108)

### `get_object_terms`

*Filters the terms for a given object or objects.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$terms` | `\WP_Term[]` | Array of terms for the given object or objects.
`$object_ids` | `int[]` | Array of object IDs for which terms were retrieved.
`$taxonomies` | `string[]` | Array of taxonomy names from which terms were retrieved.
`$args` | `array` | Array of arguments for retrieving terms for the given<br>object(s). See wp_get_object_terms() for details.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2145](../../wordpress/wp-includes/taxonomy.php#L2145-L2156)

### `wp_get_object_terms`

*Filters the terms for a given object or objects.*

The `$taxonomies` parameter passed to this filter is formatted as a SQL fragment. The
%1$s filter is recommended as an alternative.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$terms` | `\WP_Term[]` | Array of terms for the given object or objects.
`$object_ids` | `string` | Comma separated list of object IDs for which terms were retrieved.
`$taxonomies` | `string` | SQL fragment of taxonomy names from which terms were retrieved.
`$args` | `array` | Array of arguments for retrieving terms for the given<br>object(s). See wp_get_object_terms() for details.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2161](../../wordpress/wp-includes/taxonomy.php#L2161-L2175)

### `pre_insert_term`

*Filters a term before it is sanitized and inserted into the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term` | `string\|\WP_Error` | The term name to add, or a WP_Error object if there's an error.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2232](../../wordpress/wp-includes/taxonomy.php#L2232-L2240)

### `wp_insert_term_data`

*Filters term data before it is inserted into the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | Term data to be inserted.
`$taxonomy` | `string` | Taxonomy slug.
`$args` | `array` | Arguments passed to wp_insert_term().

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2373](../../wordpress/wp-includes/taxonomy.php#L2373-L2382)

### `wp_insert_term_duplicate_term_check`

*Filters the duplicate term check that takes place during term creation.*

Term parent+taxonomy+slug combinations are meant to be unique, and wp_insert_term()
performs a last-minute confirmation of this uniqueness before allowing a new term
to be created. Plugins with different uniqueness requirements may use this filter
to bypass or modify the duplicate-term check.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$duplicate_term` | `object` | Duplicate term row from terms table, if found.
`$term` | `string` | Term being inserted.
`$taxonomy` | `string` | Taxonomy name.
`$args` | `array` | Term arguments passed to the function.
`$tt_id` | `int` | term_taxonomy_id for the newly created term.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2425](../../wordpress/wp-includes/taxonomy.php#L2425-L2441)

### `term_id_filter`

*Filters the term ID after a new term is created.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` | `int` | Term ID.
`$tt_id` | `int` | Term taxonomy ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2484](../../wordpress/wp-includes/taxonomy.php#L2484-L2492)

### `wp_unique_term_slug_is_bad_slug`

*Filters whether the proposed unique term slug is bad.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$needs_suffix` | `bool` | Whether the slug needs to be made unique with a suffix.
`$slug` | `string` | The slug.
`$term` | `object` | Term object.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2903](../../wordpress/wp-includes/taxonomy.php#L2903-L2912)

### `wp_unique_term_slug`

*Filters the unique term slug.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$slug` | `string` | Unique term slug.
`$term` | `object` | Term object.
`$original_slug` | `string` | Slug originally passed to the function for testing.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 2934](../../wordpress/wp-includes/taxonomy.php#L2934-L2943)

### `wp_update_term_parent`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args['parent']` |  | 
`$term_id` |  | 
`$taxonomy` |  | 
`$parsed_args` |  | 
`$args` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3082](../../wordpress/wp-includes/taxonomy.php#L3082-L3082)

### `wp_update_term_data`

*Filters term data before it is updated in the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | Term data to be updated.
`$term_id` | `int` | Term ID.
`$taxonomy` | `string` | Taxonomy slug.
`$args` | `array` | Arguments passed to wp_update_term().

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3117](../../wordpress/wp-includes/taxonomy.php#L3117-L3127)

### `term_id_filter`

*This filter is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_id` |  | 
`$tt_id` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3196](../../wordpress/wp-includes/taxonomy.php#L3196-L3197)

### `update_post_term_count_statuses`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_statuses` |  | 
`$taxonomy` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 3911](../../wordpress/wp-includes/taxonomy.php#L3911-L3911)

### `pre_term_link`

*Filters the permalink structure for a terms before token replacement occurs.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$termlink` | `string` | The permalink structure for the term's taxonomy.
`$term` | `\WP_Term` | The term object.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 4406](../../wordpress/wp-includes/taxonomy.php#L4406-L4414)

### `tag_link`

*Filters the tag link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$termlink` | `string` | Tag link URL.
`$term->term_id` |  | 

**Changelog**

Version | Description
------- | -----------
`5.4.1` | Restored (un-deprecated).
`2.5.0` | Deprecated in favor of {@see 'term_link'} filter.
`2.3.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 4448](../../wordpress/wp-includes/taxonomy.php#L4448-L4458)

### `category_link`

*Filters the category link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$termlink` | `string` | Category link URL.
`$term->term_id` |  | 

**Changelog**

Version | Description
------- | -----------
`5.4.1` | Restored (un-deprecated).
`2.5.0` | Deprecated in favor of {@see 'term_link'} filter.
`1.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 4461](../../wordpress/wp-includes/taxonomy.php#L4461-L4471)

### `term_link`

*Filters the term link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$termlink` | `string` | Term link URL.
`$term` | `\WP_Term` | Term object.
`$taxonomy` | `string` | Taxonomy slug.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 4474](../../wordpress/wp-includes/taxonomy.php#L4474-L4483)

### `get_ancestors`

*This filter is documented in wp-includes/taxonomy.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ancestors` |  | 
`$object_id` |  | 
`$object_type` |  | 
`$resource_type` |  | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 4712](../../wordpress/wp-includes/taxonomy.php#L4712-L4713)

### `get_ancestors`

*Filters a given object's ancestors.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ancestors` | `int[]` | An array of IDs of object ancestors.
`$object_id` | `int` | Object ID.
`$object_type` | `string` | Type of object.
`$resource_type` | `string` | Type of resource $object_type is.

**Changelog**

Version | Description
------- | -----------
`4.1.1` | Introduced the `$resource_type` parameter.
`3.1.0` | 

Source: [wordpress/wp-includes/taxonomy.php](../../wordpress/wp-includes/taxonomy.php), [line 4734](../../wordpress/wp-includes/taxonomy.php#L4734-L4745)

### `get_categories_taxonomy`

*Filters the taxonomy used to retrieve terms when calling get_categories().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args['taxonomy']` |  | 
`$args` | `array` | An array of arguments. See get_terms().

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/category.php](../../wordpress/wp-includes/category.php), [line 30](../../wordpress/wp-includes/category.php#L30-L38)

### `get_tags`

*Filters the array of term objects returned for the 'post_tag' taxonomy.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags` | `\WP_Term[]\|int\|\WP_Error` | Array of 'post_tag' term objects, a count thereof,<br>or WP_Error if any of the taxonomies do not exist.
`$args` | `array` | An array of arguments. @see get_terms()

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/category.php](../../wordpress/wp-includes/category.php), [line 302](../../wordpress/wp-includes/category.php#L302-L311)

### `comments_pre_query`

*Filters the comments data before the query takes place.*

Return a non-null value to bypass WordPress' default comment queries.

The expected return type from this filter depends on the value passed
in the request query vars:
- When `$this->query_vars['count']` is set, the filter should return
  the comment count as an integer.
- When `'ids' === $this->query_vars['fields']`, the filter should return
  an array of comment IDs.
- Otherwise the filter should return an array of WP_Comment objects.

Note that if the filter returns an array of comment data, it will be assigned
to the `comments` property of the current WP_Comment_Query instance.

Filtering functions that require pagination information are encouraged to set
the `found_comments` and `max_num_pages` properties of the WP_Comment_Query object,
passed to the filter by reference. If WP_Comment_Query does not perform a database
query, it will not have enough information to generate these values itself.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($comment_data, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The returned array of comment data is assigned to the `comments` property
of the current WP_Comment_Query instance.
`5.3.0` | 

Source: [wordpress/wp-includes/class-wp-comment-query.php](../../wordpress/wp-includes/class-wp-comment-query.php), [line 385](../../wordpress/wp-includes/class-wp-comment-query.php#L385-L415)

### `the_comments`

*Filters the comment query results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($_comments, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-comment-query.php](../../wordpress/wp-includes/class-wp-comment-query.php), [line 491](../../wordpress/wp-includes/class-wp-comment-query.php#L491-L499)

### `comments_clauses`

*Filters the comment query clauses.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(compact($pieces), &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-comment-query.php](../../wordpress/wp-includes/class-wp-comment-query.php), [line 901](../../wordpress/wp-includes/class-wp-comment-query.php#L901-L909)

### `found_comments_query`

*Filters the query used to retrieve found comment count.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'SELECT FOUND_ROWS()'` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-comment-query.php](../../wordpress/wp-includes/class-wp-comment-query.php), [line 965](../../wordpress/wp-includes/class-wp-comment-query.php#L965-L973)

### `get_bloginfo_rss`

*Filters the bloginfo for use in RSS feeds.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`convert_chars($info)` |  | 
`$show` | `string` | The type of blog information to retrieve.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 29](../../wordpress/wp-includes/feed.php#L29-L40)

### `bloginfo_rss`

*Filters the bloginfo for display in RSS feeds.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_bloginfo_rss($show)` |  | 
`$show` | `string` | The type of blog information to retrieve.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 57](../../wordpress/wp-includes/feed.php#L57-L67)

### `default_feed`

*Filters the default feed type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'rss2'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 81](../../wordpress/wp-includes/feed.php#L81-L89)

### `get_wp_title_rss`

*Filters the blog title for use as the feed title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_get_document_title()` |  | 
`$deprecated` | `string` | Unused.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$sep` parameter was deprecated and renamed to `$deprecated`.
`2.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 109](../../wordpress/wp-includes/feed.php#L109-L118)

### `wp_title_rss`

*Filters the blog title for display of the feed title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_wp_title_rss()` |  | 
`$deprecated` | `string` | Unused.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$sep` parameter was deprecated and renamed to `$deprecated`.
`2.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 135](../../wordpress/wp-includes/feed.php#L135-L146)

### `the_title_rss`

*Filters the post title for use in a feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | The current post title.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 159](../../wordpress/wp-includes/feed.php#L159-L166)

### `the_content`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_content()` |  | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 193](../../wordpress/wp-includes/feed.php#L193-L194)

### `the_content_feed`

*Filters the post content for use in feeds.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | The current post content.
`$feed_type` | `string` | Type of feed. Possible values include 'rss2', 'atom'.<br>Default 'rss2'.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 197](../../wordpress/wp-includes/feed.php#L197-L206)

### `the_excerpt_rss`

*Filters the post excerpt for a feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The current post excerpt.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 227](../../wordpress/wp-includes/feed.php#L227-L234)

### `the_permalink_rss`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_permalink()` |  | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 250](../../wordpress/wp-includes/feed.php#L250-L250)

### `comments_link_feed`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_comments_link()` |  | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 267](../../wordpress/wp-includes/feed.php#L267-L267)

### `comment_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_comment_link($comment)` |  | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 317](../../wordpress/wp-includes/feed.php#L317-L317)

### `comment_author_rss`

*Filters the current comment author for use in a feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_comment_author()` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 328](../../wordpress/wp-includes/feed.php#L328-L337)

### `comment_text_rss`

*Filters the current comment content for use in a feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_text` | `string` | The content of the current comment.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 356](../../wordpress/wp-includes/feed.php#L356-L363)

### `the_category_rss`

*Filters all of the post categories for display in a feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_list` | `string` | All of the RSS post categories.
`$type` | `string` | Type of feed. Possible values include 'rss2', 'atom'.<br>Default 'rss2'.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 417](../../wordpress/wp-includes/feed.php#L417-L426)

### `rss_enclosure`

*Filters the RSS enclosure HTML link tag for the current post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'<enclosure url="' . esc_url(trim($enclosure[0])) . '" length="' . absint(trim($enclosure[1])) . '" type="' . esc_attr($type) . '" />' . "\n"` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 487](../../wordpress/wp-includes/feed.php#L487-L494)

### `atom_enclosure`

*Filters the atom enclosure HTML link tag for the current post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html_link_tag` | `string` | The HTML link tag with a URI and other attributes.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 552](../../wordpress/wp-includes/feed.php#L552-L559)

### `self_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_self_link()` |  | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 683](../../wordpress/wp-includes/feed.php#L683-L683)

### `get_feed_build_date`

*Filters the date the last post or comment in the query was modified.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$max_modified_time` | `string\|false` | Date the last post or comment was modified in the query, in UTC.<br>False on failure.
`$format` | `string` | The date format requested in get_feed_build_date().

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 732](../../wordpress/wp-includes/feed.php#L732-L741)

### `feed_content_type`

*Filters the content type for a specific feed type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content_type` | `string` | Content type indicating the type of data that a feed contains.
`$type` | `string` | Type of feed. Possible values include 'rss', rss2', 'atom', and 'rdf'.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 766](../../wordpress/wp-includes/feed.php#L766-L774)

### `wp_feed_cache_transient_lifetime`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`12 * HOUR_IN_SECONDS` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/feed.php](../../wordpress/wp-includes/feed.php), [line 817](../../wordpress/wp-includes/feed.php#L817-L817)

### `list_cats`

*This filter is documented in wp-includes/category-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`esc_attr($category->name)` |  | 
`$category` |  | 

Source: [wordpress/wp-includes/class-walker-category.php](../../wordpress/wp-includes/class-walker-category.php), [line 99](../../wordpress/wp-includes/class-walker-category.php#L99-L100)

### `category_description`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$category->description` |  | 
`$category` |  | 

Source: [wordpress/wp-includes/class-walker-category.php](../../wordpress/wp-includes/class-walker-category.php), [line 119](../../wordpress/wp-includes/class-walker-category.php#L119-L119)

### `category_list_link_attributes`

*Filters the HTML attributes applied to a category list item's anchor element.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$atts` | `array` | {<br>    The HTML attributes applied to the list item's `<a>` element, empty strings are ignored.<br><br>    @type string $href  The href attribute.<br>    @type string $title The title attribute.<br>}
`$category` | `\WP_Term` | Term data object.
`$depth` | `int` | Depth of category, used for padding.
`$args` | `array` | An array of arguments.
`$id` | `int` | ID of the current category.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-walker-category.php](../../wordpress/wp-includes/class-walker-category.php), [line 122](../../wordpress/wp-includes/class-walker-category.php#L122-L138)

### `category_css_class`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$css_classes` |  | 
`$category` |  | 
`$depth` |  | 
`$args` |  | 

Source: [wordpress/wp-includes/class-walker-category.php](../../wordpress/wp-includes/class-walker-category.php), [line 235](../../wordpress/wp-includes/class-walker-category.php#L235-L235)

### `date_query_valid_columns`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$valid_columns` |  | 

Source: [wordpress/wp-includes/class-wp-date-query.php](../../wordpress/wp-includes/class-wp-date-query.php), [line 503](../../wordpress/wp-includes/class-wp-date-query.php#L503-L503)

### `get_date_sql`

*Filters the date query WHERE clause.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$where` | `string` | WHERE clause of the date query.
`$this` | `\WP_Date_Query` | The WP_Date_Query instance.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/class-wp-date-query.php](../../wordpress/wp-includes/class-wp-date-query.php), [line 552](../../wordpress/wp-includes/class-wp-date-query.php#L552-L560)

### `core_version_check_locale`

*Filters the locale requested for WordPress core translations.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_locale()` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/update.php](../../wordpress/wp-includes/update.php), [line 63](../../wordpress/wp-includes/update.php#L63-L70)

### `core_version_check_query_args`

*Filters the query arguments sent as part of the core version check.*

WARNING: Changing this data may result in your site not receiving security updates.
Please exercise extreme caution.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query` | `array` | {<br>    Version check query arguments.<br><br>    @type string $version            WordPress version number.<br>    @type string $php                PHP version number.<br>    @type string $locale             The locale to retrieve updates for.<br>    @type string $mysql              MySQL version number.<br>    @type string $local_package      The value of the $wp_local_package global, when set.<br>    @type int    $blogs              Number of sites on this WordPress installation.<br>    @type int    $users              Number of users on this WordPress installation.<br>    @type int    $multisite_enabled  Whether this WordPress installation uses Multisite.<br>    @type int    $initial_db_version Database version of WordPress at time of installation.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/update.php](../../wordpress/wp-includes/update.php), [line 107](../../wordpress/wp-includes/update.php#L107-L129)

### `plugins_update_check_locales`

*Filters the locales requested for plugin translations.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$locales` | `array` | Plugin locales. Default is all available locales of the site.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | The default value of the `$locales` parameter changed to include all locales.
`3.7.0` | 

Source: [wordpress/wp-includes/update.php](../../wordpress/wp-includes/update.php), [line 360](../../wordpress/wp-includes/update.php#L360-L368)

### `themes_update_check_locales`

*Filters the locales requested for theme translations.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$locales` | `array` | Theme locales. Default is all available locales of the site.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | The default value of the `$locales` parameter changed to include all locales.
`3.7.0` | 

Source: [wordpress/wp-includes/update.php](../../wordpress/wp-includes/update.php), [line 565](../../wordpress/wp-includes/update.php#L565-L573)

### `wp_get_update_data`

*Filters the returned array of update data for plugins, themes, and WordPress core.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$update_data` | `array` | {<br>    Fetched update data.<br><br>    @type array   $counts       An array of counts for available plugin, theme, and WordPress updates.<br>    @type string  $update_title Titles of available updates.<br>}
`$titles` | `array` | An array of update counts and UI strings for available updates.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/update.php](../../wordpress/wp-includes/update.php), [line 763](../../wordpress/wp-includes/update.php#L763-L776)

### `enable_maintenance_mode`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$upgrading` |  | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 329](../../wordpress/wp-includes/load.php#L329-L329)

### `enable_wp_debug_mode_checks`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 442](../../wordpress/wp-includes/load.php#L442-L442)

### `is_protected_endpoint`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 973](../../wordpress/wp-includes/load.php#L973-L973)

### `wp_protected_ajax_actions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$actions_to_protect` |  | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1012](../../wordpress/wp-includes/load.php#L1012-L1012)

### `wp_doing_ajax`

*Filters whether the current request is a WordPress Ajax request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`defined('DOING_AJAX') && DOING_AJAX` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1467](../../wordpress/wp-includes/load.php#L1467-L1474)

### `wp_using_themes`

*Filters whether the current request should use themes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`defined('WP_USE_THEMES') && WP_USE_THEMES` |  | 

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1485](../../wordpress/wp-includes/load.php#L1485-L1492)

### `wp_doing_cron`

*Filters whether the current request is a WordPress cron request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`defined('DOING_CRON') && DOING_CRON` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1503](../../wordpress/wp-includes/load.php#L1503-L1510)

### `file_mod_allowed`

*Filters whether file modifications are allowed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`!defined('DISALLOW_FILE_MODS') || !DISALLOW_FILE_MODS` |  | 
`$context` | `string` | The usage context.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1549](../../wordpress/wp-includes/load.php#L1549-L1557)

### `rest_jsonp_enabled`

*This filter is documented in wp-includes/rest-api/class-wp-rest-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1651](../../wordpress/wp-includes/load.php#L1651-L1652)

### `wp_is_site_protected_by_basic_auth`

*Filters whether a site is protected by HTTP Basic Auth.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_protected` | `bool` | Whether the site is protected by Basic Auth.
`$context` | `string` | The context to check for protection. One of 'login', 'admin', or 'front'.

**Changelog**

Version | Description
------- | -----------
`5.6.1` | 

Source: [wordpress/wp-includes/load.php](../../wordpress/wp-includes/load.php), [line 1742](../../wordpress/wp-includes/load.php#L1742-L1750)

### `recovery_mode_cookie_length`

*Filters the length of time a Recovery Mode cookie is valid for.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`WEEK_IN_SECONDS` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode-cookie-service.php](../../wordpress/wp-includes/class-wp-recovery-mode-cookie-service.php), [line 38](../../wordpress/wp-includes/class-wp-recovery-mode-cookie-service.php#L38-L45)

### `recovery_mode_cookie_length`

*This filter is documented in wp-includes/class-wp-recovery-mode-cookie-service.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`WEEK_IN_SECONDS` |  | 

Source: [wordpress/wp-includes/class-wp-recovery-mode-cookie-service.php](../../wordpress/wp-includes/class-wp-recovery-mode-cookie-service.php), [line 97](../../wordpress/wp-includes/class-wp-recovery-mode-cookie-service.php#L97-L98)

### `wp_editor_settings`

*Filters the wp_editor() settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$settings` | `array` | Array of editor arguments.
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'. Accepts 'classic-block'<br>when called from block editor's Classic block.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 71](../../wordpress/wp-includes/class-wp-editor.php#L71-L82)

### `the_editor`

*Filters the HTML markup output that displays the editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'<div id="wp-' . $editor_id_attr . '-editor-container" class="wp-editor-container">' . $quicktags_toolbar . '<textarea' . $editor_class . $height . $tabindex . $autocomplete . ' cols="40" name="' . esc_attr($set['textarea_name']) . '" ' . 'id="' . $editor_id_attr . '">%s</textarea></div>'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 255](../../wordpress/wp-includes/class-wp-editor.php#L255-L268)

### `the_editor_content`

*Filters the default editor content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | Default editor content.
`$default_editor` | `string` | The default editor for the current user.<br>Either 'html' or 'tinymce'.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 275](../../wordpress/wp-includes/class-wp-editor.php#L275-L284)

### `htmledit_pre`

*This filter is documented in wp-includes/deprecated.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($content)` |  | 
`'4.3.0'` |  | 
`'format_for_editor'` |  | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 293](../../wordpress/wp-includes/class-wp-editor.php#L293-L294)

### `richedit_pre`

*This filter is documented in wp-includes/deprecated.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($content)` |  | 
`'4.3.0'` |  | 
`'format_for_editor'` |  | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 296](../../wordpress/wp-includes/class-wp-editor.php#L296-L297)

### `quicktags_settings`

*Filters the Quicktags settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$qtInit` | `array` | Quicktags settings.
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 348](../../wordpress/wp-includes/class-wp-editor.php#L348-L356)

### `teeny_mce_plugins`

*Filters the list of teenyMCE plugins.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('colorpicker', 'lists', 'fullscreen', 'image', 'wordpress', 'wpeditimage', 'wplink')` |  | 
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 372](../../wordpress/wp-includes/class-wp-editor.php#L372-L393)

### `mce_external_plugins`

*Filters the list of TinyMCE external plugins.*

The filter takes an associative array of external plugins for
TinyMCE in the form 'plugin_name' => 'url'.

The url should be absolute, and should include the js filename
to be loaded. For example:
'myplugin' => 'http://mysite.com/wp-content/plugins/myfolder/mce_plugin.js'.

If the external plugin adds a button, it should be added with
one of the 'mce_buttons' filters.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'. Accepts 'classic-block'<br>when called from block editor's Classic block.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | The `$editor_id` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 396](../../wordpress/wp-includes/class-wp-editor.php#L396-L416)

### `tiny_mce_plugins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$plugins` |  | 
`$editor_id` |  | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 456](../../wordpress/wp-includes/class-wp-editor.php#L456-L456)

### `mce_external_languages`

*Filters the translations loaded for external TinyMCE 3.x plugins.*

The filter takes an associative array ('plugin_name' => 'path')
where 'path' is the include path to the file.

The language file should follow the same format as wp_mce_translation(),
and should define a variable ($strings) that holds all translated strings.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | The `$editor_id` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 467](../../wordpress/wp-includes/class-wp-editor.php#L467-L482)

### `disable_captions`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 555](../../wordpress/wp-includes/class-wp-editor.php#L555-L556)

### `mce_css`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mce_css` |  | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 589](../../wordpress/wp-includes/class-wp-editor.php#L589-L589)

### `teeny_mce_buttons`

*Filters the list of teenyMCE buttons (Text tab).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mce_buttons` | `array` | An array of teenyMCE buttons.
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 618](../../wordpress/wp-includes/class-wp-editor.php#L618-L627)

### `mce_buttons`

*Filters the first-row list of TinyMCE buttons (Visual tab).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mce_buttons` | `array` | First-row list of buttons.
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'. Accepts 'classic-block'<br>when called from block editor's Classic block.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 659](../../wordpress/wp-includes/class-wp-editor.php#L659-L669)

### `mce_buttons_2`

*Filters the second-row list of TinyMCE buttons (Visual tab).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mce_buttons_2` | `array` | Second-row list of buttons.
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'. Accepts 'classic-block'<br>when called from block editor's Classic block.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 688](../../wordpress/wp-includes/class-wp-editor.php#L688-L698)

### `mce_buttons_3`

*Filters the third-row list of TinyMCE buttons (Visual tab).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'. Accepts 'classic-block'<br>when called from block editor's Classic block.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 700](../../wordpress/wp-includes/class-wp-editor.php#L700-L710)

### `mce_buttons_4`

*Filters the fourth-row list of TinyMCE buttons (Visual tab).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'. Accepts 'classic-block'<br>when called from block editor's Classic block.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 712](../../wordpress/wp-includes/class-wp-editor.php#L712-L722)

### `teeny_mce_before_init`

*Filters the teenyMCE config before init.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mceInit` | `array` | An array with teenyMCE config.
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 784](../../wordpress/wp-includes/class-wp-editor.php#L784-L793)

### `tiny_mce_before_init`

*Filters the TinyMCE config before init.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mceInit` | `array` | An array with TinyMCE config.
`$editor_id` | `string` | Unique editor identifier, e.g. 'content'. Accepts 'classic-block'<br>when called from block editor's Classic block.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | The `$editor_id` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 796](../../wordpress/wp-includes/class-wp-editor.php#L796-L806)

### `wp_mce_translation`

*Filters translated strings prepared for TinyMCE.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mce_translation` | `array` | Key/value pairs of strings.
`$mce_locale` | `string` | Locale.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 1469](../../wordpress/wp-includes/class-wp-editor.php#L1469-L1477)

### `wp_link_query_args`

*Filters the link query arguments.*

Allows modification of the link query arguments before querying.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query` | `array` | An array of WP_Query arguments.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 1754](../../wordpress/wp-includes/class-wp-editor.php#L1754-L1765)

### `wp_link_query`

*Filters the link query results.*

Allows modification of the returned link query results.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$results` | `array` | {<br>    An array of associative arrays of query results.<br><br>    @type array ...$0 {<br>        @type int    $ID        Post ID.<br>        @type string $title     The trimmed, escaped post title.<br>        @type string $permalink Post permalink.<br>        @type string $info      A 'Y/m/d'-formatted date for 'post' post type,<br>                                the 'singular_name' post type label otherwise.<br>    }<br>}
`$query` | `array` | An array of WP_Query arguments.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/class-wp-editor.php](../../wordpress/wp-includes/class-wp-editor.php), [line 1788](../../wordpress/wp-includes/class-wp-editor.php#L1788-L1810)

### `script_loader_src`

*Filters the script loader source.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$src` | `string` | Script loader source path.
`$handle` | `string` | Script handle.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/class.wp-scripts.php](../../wordpress/wp-includes/class.wp-scripts.php), [line 320](../../wordpress/wp-includes/class.wp-scripts.php#L320-L328)

### `script_loader_src`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$src` |  | 
`$handle` |  | 

Source: [wordpress/wp-includes/class.wp-scripts.php](../../wordpress/wp-includes/class.wp-scripts.php), [line 381](../../wordpress/wp-includes/class.wp-scripts.php#L381-L381)

### `script_loader_tag`

*Filters the HTML script tag of an enqueued script.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag` | `string` | The `<script>` tag for the enqueued script.
`$handle` | `string` | The script's registered handle.
`$src` | `string` | The script's source URL.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/class.wp-scripts.php](../../wordpress/wp-includes/class.wp-scripts.php), [line 391](../../wordpress/wp-includes/class.wp-scripts.php#L391-L400)

### `print_scripts_array`

*Filters the list of script dependencies left to print.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->to_do` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/class.wp-scripts.php](../../wordpress/wp-includes/class.wp-scripts.php), [line 638](../../wordpress/wp-includes/class.wp-scripts.php#L638-L645)

### `session_token_manager`

*Filters the class name for the session token manager.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'WP_User_Meta_Session_Tokens'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-session-tokens.php](../../wordpress/wp-includes/class-wp-session-tokens.php), [line 49](../../wordpress/wp-includes/class-wp-session-tokens.php#L49-L57)

### `attach_session_information`

*Filters the information attached to the newly created session.*

Can be used to attach further information to a session.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$this->user_id` |  | 

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-session-tokens.php](../../wordpress/wp-includes/class-wp-session-tokens.php), [line 123](../../wordpress/wp-includes/class-wp-session-tokens.php#L123-L133)

### `session_token_manager`

*This filter is documented in wp-includes/class-wp-session-tokens.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'WP_User_Meta_Session_Tokens'` |  | 

Source: [wordpress/wp-includes/class-wp-session-tokens.php](../../wordpress/wp-includes/class-wp-session-tokens.php), [line 225](../../wordpress/wp-includes/class-wp-session-tokens.php#L225-L226)

### `run_wptexturize`

*Filters whether to skip running wptexturize().*

Returning false from the filter will effectively short-circuit wptexturize()
and return the original text passed to the function instead.

The filter runs only once, the first time wptexturize() is called.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$run_texturize` | `bool` | Whether to short-circuit wptexturize().

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 64](../../wordpress/wp-includes/formatting.php#L64-L78)

### `no_texturize_tags`

*Filters the list of HTML elements not to texturize.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_no_texturize_tags` | `string[]` | An array of HTML element names.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 211](../../wordpress/wp-includes/formatting.php#L211-L218)

### `no_texturize_shortcodes`

*Filters the list of shortcodes not to texturize.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_no_texturize_shortcodes` | `string[]` | An array of shortcode names.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 219](../../wordpress/wp-includes/formatting.php#L219-L226)

### `sanitize_file_name_chars`

*Filters the list of characters to remove from a filename.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$special_chars` | `string[]` | Array of characters to remove.
`$filename_raw` | `string` | The original filename to be sanitized.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2010](../../wordpress/wp-includes/formatting.php#L2010-L2018)

### `sanitize_file_name`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filename` |  | 
`$filename_raw` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2038](../../wordpress/wp-includes/formatting.php#L2038-L2039)

### `sanitize_file_name`

*Filters a sanitized filename string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filename` | `string` | Sanitized filename.
`$filename_raw` | `string` | The filename prior to sanitization.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2071](../../wordpress/wp-includes/formatting.php#L2071-L2079)

### `sanitize_user`

*Filters a sanitized username string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$username` | `string` | Sanitized username.
`$raw_username` | `string` | The username prior to sanitization.
`$strict` | `bool` | Whether to limit the sanitization to specific characters.

**Changelog**

Version | Description
------- | -----------
`2.0.1` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2115](../../wordpress/wp-includes/formatting.php#L2115-L2124)

### `sanitize_key`

*Filters a sanitized key string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$key` | `string` | Sanitized key.
`$raw_key` | `string` | The key prior to sanitization.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2143](../../wordpress/wp-includes/formatting.php#L2143-L2151)

### `sanitize_title`

*Filters a sanitized title string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | Sanitized title.
`$raw_title` | `string` | The title prior to sanitization.
`$context` | `string` | The context for which the title is being sanitized.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2179](../../wordpress/wp-includes/formatting.php#L2179-L2188)

### `sanitize_html_class`

*Filters a sanitized HTML class string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sanitized` | `string` | The sanitized HTML class.
`$class` | `string` | HTML class before sanitization.
`$fallback` | `string` | The fallback string.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2357](../../wordpress/wp-includes/formatting.php#L2357-L2366)

### `format_to_edit`

*Filters the text to be formatted for editing.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | The text, prior to formatting for editing.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2639](../../wordpress/wp-includes/formatting.php#L2639-L2646)

### `make_clickable_rel`

*Filters the rel value that is added to URL matches converted to links.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rel` | `string` | The rel value.
`$url` | `string` | The matched URL being converted to a link tag.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2862](../../wordpress/wp-includes/formatting.php#L2862-L2870)

### `make_clickable_rel`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rel` |  | 
`$dest` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 2910](../../wordpress/wp-includes/formatting.php#L2910-L2911)

### `wp_targeted_link_rel`

*Filters the rel values that are added to links with `target` attribute.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'noopener'` |  | 
`$link_html` | `string` | The matched content of the link tag including all HTML attributes.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3218](../../wordpress/wp-includes/formatting.php#L3218-L3226)

### `smilies_src`

*Filters the Smiley image URL before it's used in the image element.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`includes_url("images/smilies/{$img}")` |  | 
`$img` | `string` | Filename for the smiley image.
`site_url()` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3328](../../wordpress/wp-includes/formatting.php#L3328-L3337)

### `is_email`

*Filters whether an email address is valid.*

This filter is evaluated under several different contexts, such as 'email_too_short',
'email_no_at', 'local_invalid_chars', 'domain_period_sequence', 'domain_period_limits',
'domain_no_periods', 'sub_hyphen_limits', 'sub_invalid_chars', or no specific context.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` | `string` | The email address being checked.
`'email_too_short'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3412](../../wordpress/wp-includes/formatting.php#L3412-L3425)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` |  | 
`'email_no_at'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3430](../../wordpress/wp-includes/formatting.php#L3430-L3431)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` |  | 
`'local_invalid_chars'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3440](../../wordpress/wp-includes/formatting.php#L3440-L3441)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` |  | 
`'domain_period_sequence'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3447](../../wordpress/wp-includes/formatting.php#L3447-L3448)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` |  | 
`'domain_period_limits'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3453](../../wordpress/wp-includes/formatting.php#L3453-L3454)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` |  | 
`'domain_no_periods'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3462](../../wordpress/wp-includes/formatting.php#L3462-L3463)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` |  | 
`'sub_hyphen_limits'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3470](../../wordpress/wp-includes/formatting.php#L3470-L3471)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$email` |  | 
`'sub_invalid_chars'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3476](../../wordpress/wp-includes/formatting.php#L3476-L3477)

### `is_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email` |  | 
`$email` |  | 
`null` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3482](../../wordpress/wp-includes/formatting.php#L3482-L3483)

### `sanitize_email`

*Filters a sanitized email address.*

This filter is evaluated under several contexts, including 'email_too_short',
'email_no_at', 'local_invalid_chars', 'domain_period_sequence', 'domain_period_limits',
'domain_no_periods', 'domain_no_valid_subs', or no context.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$email` | `string` | The email address, as provided to sanitize_email().
`'email_too_short'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3622](../../wordpress/wp-includes/formatting.php#L3622-L3635)

### `sanitize_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$email` |  | 
`'email_no_at'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3640](../../wordpress/wp-includes/formatting.php#L3640-L3641)

### `sanitize_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$email` |  | 
`'local_invalid_chars'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3651](../../wordpress/wp-includes/formatting.php#L3651-L3652)

### `sanitize_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$email` |  | 
`'domain_period_sequence'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3659](../../wordpress/wp-includes/formatting.php#L3659-L3660)

### `sanitize_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$email` |  | 
`'domain_period_limits'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3666](../../wordpress/wp-includes/formatting.php#L3666-L3667)

### `sanitize_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$email` |  | 
`'domain_no_periods'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3675](../../wordpress/wp-includes/formatting.php#L3675-L3676)

### `sanitize_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$email` |  | 
`'domain_no_valid_subs'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3698](../../wordpress/wp-includes/formatting.php#L3698-L3699)

### `sanitize_email`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sanitized_email` |  | 
`$email` |  | 
`null` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3709](../../wordpress/wp-includes/formatting.php#L3709-L3710)

### `human_time_diff`

*Filters the human readable difference between two timestamps.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$since` | `string` | The difference in human readable text.
`$diff` | `int` | The difference in seconds.
`$from` | `int` | Unix timestamp from which the difference begins.
`$to` | `int` | Unix timestamp to end the time difference.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3784](../../wordpress/wp-includes/formatting.php#L3784-L3794)

### `the_content`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$text` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3822](../../wordpress/wp-includes/formatting.php#L3822-L3823)

### `excerpt_length`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$excerpt_length` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3836](../../wordpress/wp-includes/formatting.php#L3836-L3836)

### `excerpt_more`

*Filters the string in the "more" link displayed after a trimmed excerpt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`' ' . '[&hellip;]'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3838](../../wordpress/wp-includes/formatting.php#L3838-L3845)

### `wp_trim_excerpt`

*Filters the trimmed excerpt string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$text` | `string` | The trimmed text.
`$raw_excerpt` | `string` | The text prior to trimming.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3849](../../wordpress/wp-includes/formatting.php#L3849-L3857)

### `wp_trim_words`

*Filters the text content after words have been trimmed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$text` | `string` | The trimmed text.
`$num_words` | `int` | The number of words to trim the text to. Default 55.
`$more` | `string` | An optional string to append to the end of the trimmed text, e.g. &hellip;.
`$original_text` | `string` | The text before it was trimmed.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3906](../../wordpress/wp-includes/formatting.php#L3906-L3916)

### `pre_ent2ncr`

*Filters text before named entities are converted into numbered entities.*

A non-null string must be returned for the filter to be evaluated.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$text` | `string` | The text prior to entity conversion.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 3929](../../wordpress/wp-includes/formatting.php#L3929-L3939)

### `format_for_editor`

*Filters the text after it is formatted for the editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$text` | `string` | The formatted text.
`$default_editor` | `string` | The default editor for the current user.<br>It is usually either 'html' or 'tinymce'.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4229](../../wordpress/wp-includes/formatting.php#L4229-L4238)

### `clean_url`

*Filters a string cleaned and escaped for output as a URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$good_protocol_url` | `string` | The cleaned URL to be returned.
`$original_url` | `string` | The URL prior to cleaning.
`$_context` | `string` | If 'display', replace ampersands and single quotes only.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4394](../../wordpress/wp-includes/formatting.php#L4394-L4403)

### `js_escape`

*Filters a string cleaned and escaped for output in JavaScript.*

Text passed to esc_js() is stripped of invalid or special characters,
and properly slashed for output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$safe_text` | `string` | The text after it has been escaped.
`$text` | `string` | The text prior to being escaped.

**Changelog**

Version | Description
------- | -----------
`2.0.6` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4456](../../wordpress/wp-includes/formatting.php#L4456-L4467)

### `esc_html`

*Filters a string cleaned and escaped for output in HTML.*

Text passed to esc_html() is stripped of invalid or special characters
before output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$safe_text` | `string` | The text after it has been escaped.
`$text` | `string` | The text prior to being escaped.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4481](../../wordpress/wp-includes/formatting.php#L4481-L4492)

### `attribute_escape`

*Filters a string cleaned and escaped for output in an HTML attribute.*

Text passed to esc_attr() is stripped of invalid or special characters
before output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$safe_text` | `string` | The text after it has been escaped.
`$text` | `string` | The text prior to being escaped.

**Changelog**

Version | Description
------- | -----------
`2.0.6` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4506](../../wordpress/wp-includes/formatting.php#L4506-L4517)

### `esc_textarea`

*Filters a string cleaned and escaped for output in a textarea element.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$safe_text` | `string` | The text after it has been escaped.
`$text` | `string` | The text prior to being escaped.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4530](../../wordpress/wp-includes/formatting.php#L4530-L4538)

### `esc_xml`

*Filters a string cleaned and escaped for output in XML.*

Text passed to esc_xml() is stripped of invalid or special characters
before output. HTML named character references are converted to their
equivalent code points.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$safe_text` | `string` | The text after it has been escaped.
`$text` | `string` | The text prior to being escaped.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4583](../../wordpress/wp-includes/formatting.php#L4583-L4595)

### `tag_escape`

*Filters a string cleaned and escaped for output as an HTML tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$safe_tag` | `string` | The tag name after it has been escaped.
`$tag_name` | `string` | The text before it was escaped.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4608](../../wordpress/wp-includes/formatting.php#L4608-L4616)

### `sanitize_option_{$option}`

*Filters an option value following sanitization.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `string` | The sanitized option value.
`$option` | `string` | The option name.
`$original_value` | `string` | The original value passed to the function.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | Added the `$original_value` parameter.
`2.3.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4897](../../wordpress/wp-includes/formatting.php#L4897-L4907)

### `wp_parse_str`

*Filters the array of variables derived from a parsed string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$array` | `array` | The array populated with variables.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 4949](../../wordpress/wp-includes/formatting.php#L4949-L4956)

### `wp_sprintf`

*Filters a fragment from the pattern passed to wp_sprintf().*

If the fragment is unchanged, then sprintf() will be run on the fragment.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$fragment` | `string` | A fragment from the pattern.
`$arg` | `string` | The argument.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5064](../../wordpress/wp-includes/formatting.php#L5064-L5074)

### `wp_sprintf_l`

*Filters the translated delimiters used by wp_sprintf_l().*

Placeholders (%%s) are included to assist translators and then
removed before the array of strings reaches the filter.

Please note: Ampersands and entities should be avoided here.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(
    /* translators: Used to join items in a list with more than 2 items. */
    'between' => sprintf(__('%1$s, %2$s'), '', ''),
    /* translators: Used to join last two items in a list with more than 2 times. */
    'between_last_two' => sprintf(__('%1$s, and %2$s'), '', ''),
    /* translators: Used to join items in a list with only 2 items. */
    'between_only_two' => sprintf(__('%1$s and %2$s'), '', ''),
)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5114](../../wordpress/wp-includes/formatting.php#L5114-L5135)

### `sanitize_text_field`

*Filters a sanitized text field string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filtered` | `string` | The sanitized string.
`$str` | `string` | The string prior to being sanitized.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5335](../../wordpress/wp-includes/formatting.php#L5335-L5343)

### `sanitize_textarea_field`

*Filters a sanitized textarea field string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filtered` | `string` | The sanitized string.
`$str` | `string` | The string prior to being sanitized.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5363](../../wordpress/wp-includes/formatting.php#L5363-L5371)

### `sanitize_mime_type`

*Filters a mime type following sanitization.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sani_mime_type` | `string` | The sanitized mime type.
`$mime_type` | `string` | The mime type prior to sanitization.

**Changelog**

Version | Description
------- | -----------
`3.1.3` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5475](../../wordpress/wp-includes/formatting.php#L5475-L5483)

### `sanitize_trackback_urls`

*Filters a list of trackback URLs following sanitization.*

The string returned here consists of a space or carriage return-delimited list
of trackback URLs.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$urls_to_ping` | `string` | Sanitized space or carriage return separated URLs.
`$to_ping` | `string` | Space or carriage return separated URLs before sanitization.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5503](../../wordpress/wp-includes/formatting.php#L5503-L5514)

### `wp_spaces_regexp`

*Filters the regexp for common whitespace characters.*

This string is substituted for the \s sequence as needed in regular
expressions. For websites not written in English, different characters
may represent whitespace. For websites not encoded in UTF-8, the 0xC2 0xA0
sequence may not be in use.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'[\\r\\n\\t ]|\\xC2\\xA0|&nbsp;'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5591](../../wordpress/wp-includes/formatting.php#L5591-L5603)

### `emoji_url`

*Filters the URL where emoji png images are hosted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'https://s.w.org/images/core/emoji/13.0.1/72x72/'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5668](../../wordpress/wp-includes/formatting.php#L5668-L5675)

### `emoji_ext`

*Filters the extension of the emoji png files.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'.png'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5677](../../wordpress/wp-includes/formatting.php#L5677-L5684)

### `emoji_svg_url`

*Filters the URL where emoji SVG images are hosted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'https://s.w.org/images/core/emoji/13.0.1/svg/'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5686](../../wordpress/wp-includes/formatting.php#L5686-L5693)

### `emoji_svg_ext`

*Filters the extension of the emoji SVG files.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'.svg'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5695](../../wordpress/wp-includes/formatting.php#L5695-L5702)

### `script_loader_src`

*This filter is documented in wp-includes/class.wp-scripts.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`includes_url("js/wp-emoji.js?{$version}")` |  | 
`'wpemoji'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5710](../../wordpress/wp-includes/formatting.php#L5710-L5711)

### `script_loader_src`

*This filter is documented in wp-includes/class.wp-scripts.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`includes_url("js/twemoji.js?{$version}")` |  | 
`'twemoji'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5712](../../wordpress/wp-includes/formatting.php#L5712-L5713)

### `script_loader_src`

*This filter is documented in wp-includes/class.wp-scripts.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`includes_url("js/wp-emoji-release.min.js?{$version}")` |  | 
`'concatemoji'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5724](../../wordpress/wp-includes/formatting.php#L5724-L5725)

### `emoji_url`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'https://s.w.org/images/core/emoji/13.0.1/72x72/'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5807](../../wordpress/wp-includes/formatting.php#L5807-L5808)

### `emoji_ext`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'.png'` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5810](../../wordpress/wp-includes/formatting.php#L5810-L5811)

### `wp_mail_content_type`

*This filter is documented in wp-includes/pluggable.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content_type` |  | 

Source: [wordpress/wp-includes/formatting.php](../../wordpress/wp-includes/formatting.php), [line 5922](../../wordpress/wp-includes/formatting.php#L5922-L5923)

### `oembed_default_width`

*Filters the maxwidth oEmbed parameter.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`600` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-oembed-controller.php](../../wordpress/wp-includes/class-wp-oembed-controller.php), [line 25](../../wordpress/wp-includes/class-wp-oembed-controller.php#L25-L32)

### `oembed_request_post_id`

*Filters the determined post ID.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` | `int` | The post ID.
`$request['url']` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-oembed-controller.php](../../wordpress/wp-includes/class-wp-oembed-controller.php), [line 121](../../wordpress/wp-includes/class-wp-oembed-controller.php#L121-L129)

### `oembed_result`

*This filter is documented in wp-includes/class-wp-oembed.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`_wp_oembed_get_object()->data2html((object) $data, $url)` |  | 
`$url` |  | 
`$args` |  | 

Source: [wordpress/wp-includes/class-wp-oembed-controller.php](../../wordpress/wp-includes/class-wp-oembed-controller.php), [line 222](../../wordpress/wp-includes/class-wp-oembed-controller.php#L222-L223)

### `rest_oembed_ttl`

*Filters the oEmbed TTL value (time to live).*

Similar to the %1$s filter, but for the REST API
oEmbed proxy endpoint.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`DAY_IN_SECONDS` |  | 
`$url` | `string` | The attempted embed URL.
`$args` | `array` | An array of embed request arguments.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/class-wp-oembed-controller.php](../../wordpress/wp-includes/class-wp-oembed-controller.php), [line 225](../../wordpress/wp-includes/class-wp-oembed-controller.php#L225-L237)

### `can_add_user_to_blog`

*Filters whether a user should be added to a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$user_id` | `int` | User ID.
`$role` | `string` | User role.
`$blog_id` | `int` | Site ID.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 177](../../wordpress/wp-includes/ms-functions.php#L177-L188)

### `is_email_address_unsafe`

*Filters whether an email address is unsafe.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_email_address_unsafe` | `bool` | Whether the email address is "unsafe". Default false.
`$user_email` | `string` | User email address.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 432](../../wordpress/wp-includes/ms-functions.php#L432-L440)

### `illegal_user_logins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 500](../../wordpress/wp-includes/ms-functions.php#L500-L500)

### `wpmu_validate_user_signup`

*Filters the validated user registration details.*

This does not allow you to override the username or email of the user during
registration. The values are solely used for validation and error handling.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `array` | {<br>    The array of user name, email, and the error messages.<br><br>    @type string   $user_name     Sanitized and unique username.<br>    @type string   $orig_username Original username.<br>    @type string   $user_email    User email address.<br>    @type WP_Error $errors        WP_Error object containing any errors found.<br>}

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 576](../../wordpress/wp-includes/ms-functions.php#L576-L593)

### `minimum_site_name_length`

*Filters the minimum site name length required when validating a site signup.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`4` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 664](../../wordpress/wp-includes/ms-functions.php#L664-L671)

### `newblogname`

*Filters the new site name during registration.*

The name is the site's subdomain or the site's subdirectory
path depending on the network settings.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$blogname` | `string` | Site name.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 688](../../wordpress/wp-includes/ms-functions.php#L688-L698)

### `wpmu_validate_blog_signup`

*Filters site details and error messages following registration.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `array` | {<br>    Array of domain, path, blog name, blog title, user and error messages.<br><br>    @type string         $domain     Domain for the site.<br>    @type string         $path       Path for the site. Used in subdirectory installations.<br>    @type string         $blogname   The unique site name (slug).<br>    @type string         $blog_title Blog title.<br>    @type string\|WP_User $user       By default, an empty string. A user object if provided.<br>    @type WP_Error       $errors     WP_Error containing any errors found.<br>}

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 752](../../wordpress/wp-includes/ms-functions.php#L752-L768)

### `signup_site_meta`

*Filters the metadata for a site signup.*

The metadata will be serialized prior to storing it in the database.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta` | `array` | Signup meta data. Default empty array.
`$domain` | `string` | The requested domain.
`$path` | `string` | The requested path.
`$title` | `string` | The requested site title.
`$user` | `string` | The user's requested login name.
`$user_email` | `string` | The user's email address.
`$key` | `string` | The user's activation key.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 790](../../wordpress/wp-includes/ms-functions.php#L790-L805)

### `signup_user_meta`

*Filters the metadata for a user signup.*

The metadata will be serialized prior to storing it in the database.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta` | `array` | Signup meta data. Default empty array.
`$user` | `string` | The user's requested login name.
`$user_email` | `string` | The user's email address.
`$key` | `string` | The user's activation key.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 859](../../wordpress/wp-includes/ms-functions.php#L859-L871)

### `wpmu_signup_blog_notification`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$domain` |  | 
`$path` |  | 
`$title` |  | 
`$user_login` |  | 
`$user_email` |  | 
`$key` |  | 
`$meta` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 939](../../wordpress/wp-includes/ms-functions.php#L939-L939)

### `wpmu_signup_blog_notification_email`

*Filters the message content of the new blog notification email.*

Content should be formatted for transmission via wp_mail().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`/* translators: New site notification email. 1: Activation URL, 2: New site URL. */
__("To activate your blog, please click the following link:\n\n%1\$s\n\nAfter you activate, you will receive *another email* with your login.\n\nAfter you activate, you can visit your site here:\n\n%2\$s")` |  | 
`$domain` | `string` | Site domain.
`$path` | `string` | Site path.
`$title` | `string` | Site title.
`$user_login` | `string` | User login name.
`$user_email` | `string` | User email address.
`$key` | `string` | Activation key created in wpmu_signup_blog().
`$meta` | `array` | Signup meta data. By default, contains the requested privacy setting and lang_id.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 965](../../wordpress/wp-includes/ms-functions.php#L965-L992)

### `wpmu_signup_blog_notification_subject`

*Filters the subject of the new blog notification email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`/* translators: New site notification email subject. 1: Network title, 2: New site URL. */
_x('[%1$s] Activate %2$s', 'New site notification email subject')` |  | 
`$domain` | `string` | Site domain.
`$path` | `string` | Site path.
`$title` | `string` | Site title.
`$user_login` | `string` | User login name.
`$user_email` | `string` | User email address.
`$key` | `string` | Activation key created in wpmu_signup_blog().
`$meta` | `array` | Signup meta data. By default, contains the requested privacy setting and lang_id.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 999](../../wordpress/wp-includes/ms-functions.php#L999-L1024)

### `wpmu_signup_user_notification`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_login` |  | 
`$user_email` |  | 
`$key` |  | 
`$meta` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1071](../../wordpress/wp-includes/ms-functions.php#L1071-L1071)

### `wpmu_signup_user_notification_email`

*Filters the content of the notification email for new user sign-up.*

Content should be formatted for transmission via wp_mail().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`/* translators: New user notification email. %s: Activation URL. */
__("To activate your user, please click the following link:\n\n%s\n\nAfter you activate, you will receive *another email* with your login.")` |  | 
`$user_login` | `string` | User login name.
`$user_email` | `string` | User email address.
`$key` | `string` | Activation key created in wpmu_signup_user().
`$meta` | `array` | Signup meta data. Default empty array.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1088](../../wordpress/wp-includes/ms-functions.php#L1088-L1109)

### `wpmu_signup_user_notification_subject`

*Filters the subject of the notification email of new user signup.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`/* translators: New user notification email subject. 1: Network title, 2: New user login. */
_x('[%1$s] Activate %2$s', 'New user notification email subject')` |  | 
`$user_login` | `string` | User login name.
`$user_email` | `string` | User email address.
`$key` | `string` | Activation key created in wpmu_signup_user().
`$meta` | `array` | Signup meta data. Default empty array.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1114](../../wordpress/wp-includes/ms-functions.php#L1114-L1133)

### `newblog_notify_siteadmin`

*Filters the message body of the new site activation email sent
to the network administrator.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$msg` | `string` | Email body.
`$blog_id` | `int` | The new site's ID.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | The `$blog_id` parameter was added.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1458](../../wordpress/wp-includes/ms-functions.php#L1458-L1468)

### `newuser_notify_siteadmin`

*Filters the message body of the new user activation email sent
to the network administrator.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$msg` | `string` | Email body.
`$user` | `\WP_User` | WP_User instance of the new user.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1515](../../wordpress/wp-includes/ms-functions.php#L1515-L1524)

### `domain_exists`

*Filters whether a site name is taken.*

The name is the site's subdomain or the site's subdirectory
path depending on the network settings.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `int\|null` | The site ID if the site name exists, null otherwise.
`$domain` | `string` | Domain to be checked.
`$path` | `string` | Path to be checked.
`$network_id` | `int` | Network ID. Relevant only on multi-network installations.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1561](../../wordpress/wp-includes/ms-functions.php#L1561-L1574)

### `wpmu_welcome_notification`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$blog_id` |  | 
`$user_id` |  | 
`$password` |  | 
`$title` |  | 
`$meta` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1610](../../wordpress/wp-includes/ms-functions.php#L1610-L1610)

### `update_welcome_email`

*Filters the content of the welcome email sent to the site administrator after site activation.*

Content should be formatted for transmission via wp_mail().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$welcome_email` | `string` | Message body of the email.
`$blog_id` | `int` | Site ID.
`$user_id` | `int` | User ID of the site administrator.
`$password` | `string` | User password, or "N/A" if the user account is not new.
`$title` | `string` | Site title.
`$meta` | `array` | Signup meta data. By default, contains the requested privacy setting and lang_id.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1647](../../wordpress/wp-includes/ms-functions.php#L1647-L1661)

### `update_welcome_subject`

*Filters the subject of the welcome email sent to the site administrator after site activation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`sprintf($subject, $current_network->site_name, wp_unslash($title))` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1680](../../wordpress/wp-includes/ms-functions.php#L1680-L1687)

### `send_new_site_email`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$site` |  | 
`$user` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1731](../../wordpress/wp-includes/ms-functions.php#L1731-L1731)

### `new_site_email`

*Filters the content of the email sent to the Multisite network administrator when a new site is created.*

Content should be formatted for transmission via wp_mail().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_site_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The email address of the recipient.<br>    @type string $subject The subject of the email.<br>    @type string $message The content of the email.<br>    @type string $headers Headers.<br>}
`$site` | `\WP_Site` | Site object of the new site.
`$user` | `\WP_User` | User object of the administrator of the new site.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1778](../../wordpress/wp-includes/ms-functions.php#L1778-L1796)

### `wpmu_welcome_user_notification`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` |  | 
`$password` |  | 
`$meta` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1841](../../wordpress/wp-includes/ms-functions.php#L1841-L1841)

### `update_welcome_user_email`

*Filters the content of the welcome email after user activation.*

Content should be formatted for transmission via wp_mail().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$welcome_email` | `string` | The message body of the account activation success email.
`$user_id` | `int` | User ID.
`$password` | `string` | User password.
`$meta` | `array` | Signup meta data. Default empty array.

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1851](../../wordpress/wp-includes/ms-functions.php#L1851-L1863)

### `update_welcome_user_subject`

*Filters the subject of the welcome email after user activation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`sprintf($subject, $current_network->site_name, $user->user_login)` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 1886](../../wordpress/wp-includes/ms-functions.php#L1886-L1893)

### `blog_redirect_404`

*Filters the redirect URL for 404s on the main site.*

The filter is only evaluated if the NOBLOGREDIRECT constant is defined.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`NOBLOGREDIRECT` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2226](../../wordpress/wp-includes/ms-functions.php#L2226-L2235)

### `enable_live_network_counts`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_small_network` |  | 
`'sites'` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2542](../../wordpress/wp-includes/ms-functions.php#L2542-L2542)

### `enable_live_network_counts`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_small_network` |  | 
`'users'` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2564](../../wordpress/wp-includes/ms-functions.php#L2564-L2564)

### `pre_get_space_used`

*Filters the amount of storage space used by the current site, in megabytes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2624](../../wordpress/wp-includes/ms-functions.php#L2624-L2631)

### `get_space_allowed`

*Filters the upload quota for the current site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$space_allowed` | `int` | Upload quota in megabytes for the current blog.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2659](../../wordpress/wp-includes/ms-functions.php#L2659-L2666)

### `wp_is_large_network`

*Filters whether the network is considered large.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$count > 10000` |  | 
`'users'` |  | 
`$count` | `int` | The count of items for the component.
`$network_id` | `int` | The ID of the network being checked.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | The `$network_id` parameter has been added.
`3.3.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2747](../../wordpress/wp-includes/ms-functions.php#L2747-L2758)

### `wp_is_large_network`

*This filter is documented in wp-includes/ms-functions.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$count > 10000` |  | 
`'sites'` |  | 
`$count` |  | 
`$network_id` |  | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2763](../../wordpress/wp-includes/ms-functions.php#L2763-L2764)

### `subdirectory_reserved_names`

*Filters reserved site names on a sub-directory Multisite installation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$names` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 'wp-admin', 'wp-content', 'wp-includes', 'wp-json', and 'embed' were added
to the reserved names list.
`3.0.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2788](../../wordpress/wp-includes/ms-functions.php#L2788-L2797)

### `new_network_admin_email_content`

*Filters the text of the email sent when a change of network admin email address is attempted.*

The following strings have a special meaning and will get replaced dynamically:
###USERNAME###  The current user's username.
###ADMIN_URL### The link to click on to confirm the email change.
###EMAIL###     The proposed new network admin email address.
###SITENAME###  The name of the network.
###SITEURL###   The URL to the network.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_text` | `string` | Text in the email.
`$new_admin_email` | `array` | {<br>    Data relating to the new network admin email address.<br><br>    @type string $hash     The secure hash used in the confirmation link URL.<br>    @type string $newemail The proposed new network admin email address.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2844](../../wordpress/wp-includes/ms-functions.php#L2844-L2864)

### `send_network_admin_email_change_email`

*Filters whether to send the network admin email change notification email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$send` | `bool` | Whether to send the email notification.
`$old_email` | `string` | The old network admin email address.
`$new_email` | `string` | The new network admin email address.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2906](../../wordpress/wp-includes/ms-functions.php#L2906-L2916)

### `network_admin_email_change_email`

*Filters the contents of the email notification sent when the network admin email address is changed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_change_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The intended recipient.<br>    @type string $subject The subject of the email.<br>    @type string $message The content of the email.<br>        The following strings have a special meaning and will get replaced dynamically:<br>        - ###OLD_EMAIL### The old network admin email address.<br>        - ###NEW_EMAIL### The new network admin email address.<br>        - ###SITENAME###  The name of the network.<br>        - ###SITEURL###   The URL to the site.<br>    @type string $headers Headers.<br>}
`$old_email` | `string` | The old network admin email address.
`$new_email` | `string` | The new network admin email address.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/ms-functions.php](../../wordpress/wp-includes/ms-functions.php), [line 2947](../../wordpress/wp-includes/ms-functions.php#L2947-L2969)

### `customize_nav_menu_available_items`

*Filters the available menu items.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$items` | `array` | The array of menu items.
`$type` | `string` | The object type.
`$object` | `string` | The object name.
`$page` | `int` | The current page number.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/class-wp-customize-nav-menus.php](../../wordpress/wp-includes/class-wp-customize-nav-menus.php), [line 290](../../wordpress/wp-includes/class-wp-customize-nav-menus.php#L290-L300)

### `customize_nav_menu_searched_items`

*Filters the available menu items during a search request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$items` | `array` | The array of menu items.
`$args` | `array` | Includes 'pagenum' and 's' (search) arguments.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/class-wp-customize-nav-menus.php](../../wordpress/wp-includes/class-wp-customize-nav-menus.php), [line 465](../../wordpress/wp-includes/class-wp-customize-nav-menus.php#L465-L473)

### `customize_nav_menu_available_item_types`

*Filters the available menu item types.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$item_types` | `array` | Navigation menu item types.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Each array item now includes a `$type_label` in addition to `$title`, `$type`, and `$object`.
`4.3.0` | 

Source: [wordpress/wp-includes/class-wp-customize-nav-menus.php](../../wordpress/wp-includes/class-wp-customize-nav-menus.php), [line 916](../../wordpress/wp-includes/class-wp-customize-nav-menus.php#L916-L924)

### `do_parse_request`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$this` |  | 
`$extra_query_vars` |  | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 145](../../wordpress/wp-includes/class-wp.php#L145-L145)

### `query_vars`

*Filters the query variables allowed before processing.*

Allows (publicly allowed) query vars to be added, removed, or changed prior
to executing the query. Needed to allow custom rewrite rules using your own arguments
to work, or any other custom query variables you want to be publicly available.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->public_query_vars` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 277](../../wordpress/wp-includes/class-wp.php#L277-L288)

### `request`

*Filters the array of parsed query variables.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->query_vars` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 372](../../wordpress/wp-includes/class-wp.php#L372-L379)

### `wp_headers`

*Filters the HTTP headers before they're sent to the browser.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$headers` | `string[]` | Associative array of headers to be sent.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 487](../../wordpress/wp-includes/class-wp.php#L487-L495)

### `query_string`

*Filters the query string before parsing.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this->query_string)` |  | 
`'2.1.0'` |  | 
`'query_vars, request'` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 551](../../wordpress/wp-includes/class-wp.php#L551-L564)

### `pre_handle_404`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$wp_query` |  | 

Source: [wordpress/wp-includes/class-wp.php](../../wordpress/wp-includes/class-wp.php), [line 663](../../wordpress/wp-includes/class-wp.php#L663-L663)

### `list_cats`

*This filter is documented in wp-includes/category-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$category->name` |  | 
`$category` |  | 

Source: [wordpress/wp-includes/class-walker-category-dropdown.php](../../wordpress/wp-includes/class-walker-category-dropdown.php), [line 60](../../wordpress/wp-includes/class-walker-category-dropdown.php#L60-L61)

### `sites_pre_query`

*Filters the site data before the get_sites query takes place.*

Return a non-null value to bypass WordPress' default site queries.

The expected return type from this filter depends on the value passed
in the request query vars:
- When `$this->query_vars['count']` is set, the filter should return
  the site count as an integer.
- When `'ids' === $this->query_vars['fields']`, the filter should return
  an array of site IDs.
- Otherwise the filter should return an array of WP_Site objects.

Note that if the filter returns an array of site data, it will be assigned
to the `sites` property of the current WP_Site_Query instance.

Filtering functions that require pagination information are encouraged to set
the `found_sites` and `max_num_pages` properties of the WP_Site_Query object,
passed to the filter by reference. If WP_Site_Query does not perform a database
query, it will not have enough information to generate these values itself.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($site_data, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The returned array of site data is assigned to the `sites` property
of the current WP_Site_Query instance.
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-site-query.php](../../wordpress/wp-includes/class-wp-site-query.php), [line 293](../../wordpress/wp-includes/class-wp-site-query.php#L293-L323)

### `the_sites`

*Filters the site query results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($_sites, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-site-query.php](../../wordpress/wp-includes/class-wp-site-query.php), [line 393](../../wordpress/wp-includes/class-wp-site-query.php#L393-L401)

### `site_search_columns`

*Filters the columns to search in a WP_Site_Query search.*

The default columns include 'domain' and 'path.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$search_columns` | `string[]` | Array of column names to be searched.
`$this->query_vars['search']` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-site-query.php](../../wordpress/wp-includes/class-wp-site-query.php), [line 594](../../wordpress/wp-includes/class-wp-site-query.php#L594-L605)

### `sites_clauses`

*Filters the site query clauses.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(compact($pieces), &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-site-query.php](../../wordpress/wp-includes/class-wp-site-query.php), [line 634](../../wordpress/wp-includes/class-wp-site-query.php#L634-L642)

### `found_sites_query`

*Filters the query used to retrieve found site count.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'SELECT FOUND_ROWS()'` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-site-query.php](../../wordpress/wp-includes/class-wp-site-query.php), [line 697](../../wordpress/wp-includes/class-wp-site-query.php#L697-L705)

### `customize_panel_active`

*Filters response of WP_Customize_Panel::active().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$active` | `bool` | Whether the Customizer panel is active.
`$panel` | `\WP_Customize_Panel` | WP_Customize_Panel instance.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/class-wp-customize-panel.php](../../wordpress/wp-includes/class-wp-customize-panel.php), [line 186](../../wordpress/wp-includes/class-wp-customize-panel.php#L186-L194)

### `wp_kses_allowed_html`

*Filters the HTML that is allowed for a given context.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$context` | `array[]\|string` | Context to judge allowed tags by.
`'explicit'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 850](../../wordpress/wp-includes/kses.php#L850-L858)

### `wp_kses_allowed_html`

*This filter is documented in wp-includes/kses.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowedposttags` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 863](../../wordpress/wp-includes/kses.php#L863-L864)

### `wp_kses_allowed_html`

*This filter is documented in wp-includes/kses.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 880](../../wordpress/wp-includes/kses.php#L880-L881)

### `wp_kses_allowed_html`

*This filter is documented in wp-includes/kses.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 890](../../wordpress/wp-includes/kses.php#L890-L891)

### `wp_kses_allowed_html`

*This filter is documented in wp-includes/kses.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 894](../../wordpress/wp-includes/kses.php#L894-L895)

### `wp_kses_allowed_html`

*This filter is documented in wp-includes/kses.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowedentitynames` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 898](../../wordpress/wp-includes/kses.php#L898-L899)

### `wp_kses_allowed_html`

*This filter is documented in wp-includes/kses.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowedtags` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 903](../../wordpress/wp-includes/kses.php#L903-L904)

### `pre_kses`

*Filters content to be run through KSES.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$string` | `string` | Content to filter through KSES.
`$allowed_html` | `array[]\|string` | An array of allowed HTML elements and attributes,<br>or a context name such as 'post'. See wp_kses_allowed_html()<br>for the list of accepted context names.
`$allowed_protocols` | `string[]` | Array of allowed URL protocols.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 924](../../wordpress/wp-includes/kses.php#L924-L935)

### `wp_kses_uri_attributes`

*Filters the list of attributes that are required to contain a URL.*

Use this filter to add any `data-` attributes that are required to be
validated as a URL.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$uri_attributes` | `string[]` | HTML attribute names whose value contains a URL.

**Changelog**

Version | Description
------- | -----------
`5.0.1` | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 1011](../../wordpress/wp-includes/kses.php#L1011-L1021)

### `safe_style_css`

*Filters list of allowed CSS attributes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('background', 'background-color', 'background-image', 'background-position', 'background-size', 'background-attachment', 'background-blend-mode', 'border', 'border-radius', 'border-width', 'border-color', 'border-style', 'border-right', 'border-right-color', 'border-right-style', 'border-right-width', 'border-bottom', 'border-bottom-color', 'border-bottom-style', 'border-bottom-width', 'border-left', 'border-left-color', 'border-left-style', 'border-left-width', 'border-top', 'border-top-color', 'border-top-style', 'border-top-width', 'border-spacing', 'border-collapse', 'caption-side', 'columns', 'column-count', 'column-fill', 'column-gap', 'column-rule', 'column-span', 'column-width', 'color', 'font', 'font-family', 'font-size', 'font-style', 'font-variant', 'font-weight', 'letter-spacing', 'line-height', 'text-align', 'text-decoration', 'text-indent', 'text-transform', 'height', 'min-height', 'max-height', 'width', 'min-width', 'max-width', 'margin', 'margin-right', 'margin-bottom', 'margin-left', 'margin-top', 'padding', 'padding-right', 'padding-bottom', 'padding-left', 'padding-top', 'flex', 'flex-basis', 'flex-direction', 'flex-flow', 'flex-grow', 'flex-shrink', 'grid-template-columns', 'grid-auto-columns', 'grid-column-start', 'grid-column-end', 'grid-column-gap', 'grid-template-rows', 'grid-auto-rows', 'grid-row-start', 'grid-row-end', 'grid-row-gap', 'grid-gap', 'justify-content', 'justify-items', 'justify-self', 'align-content', 'align-items', 'align-self', 'clear', 'cursor', 'direction', 'float', 'list-style-type', 'overflow', 'vertical-align')` |  | 

**Changelog**

Version | Description
------- | -----------
`5.3.1` | Added support for gradient backgrounds.
`5.3.0` | Added support for `grid`, `flex` and `column` layout properties.
Extend `background-*` support of individual properties.
`5.2.0` | Added support for `background-position` and `grid-template-columns`.
`5.1.0` | Added support for `text-transform`.
`5.0.0` | Added support for `background-image`.
`4.6.0` | Added support for `list-style-type`.
`4.4.0` | Added support for `min-height`, `max-height`, `min-width`, and `max-width`.
`2.8.1` | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 2162](../../wordpress/wp-includes/kses.php#L2162-L2290)

### `safecss_filter_attr_allow_css`

*Filters the check for unsafe CSS in `safecss_filter_attr`.*

Enables developers to determine whether a section of CSS should be allowed or discarded.
By default, the value will be false if the part contains \ ( & } = or comments.
Return true to allow the CSS part to be included in the output.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allow_css` | `bool` | Whether the CSS in the test string is considered safe.
`$css_test_string` | `string` | The CSS string to test.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/kses.php](../../wordpress/wp-includes/kses.php), [line 2385](../../wordpress/wp-includes/kses.php#L2385-L2397)

### `get_attached_file`

*Filters the attached file based on the given ID.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` | `string\|false` | The file path to where the attached file should be, false otherwise.
`$attachment_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 513](../../wordpress/wp-includes/post.php#L513-L521)

### `update_attached_file`

*Filters the path to the attached file to update.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` | `string` | Path to the attached file to update.
`$attachment_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 541](../../wordpress/wp-includes/post.php#L541-L549)

### `_wp_relative_upload_path`

*Filters the relative path to an uploaded file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_path` | `string` | Relative path to the file.
`$path` | `string` | Full path to the file.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 579](../../wordpress/wp-includes/post.php#L579-L587)

### `get_post_status`

*Filters the post status.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_status` | `string` | The post status.
`$post` | `\WP_Post` | The post object.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | The attachment post type is now passed through this filter.
`4.4.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 943](../../wordpress/wp-includes/post.php#L943-L952)

### `post_type_labels_{$post_type}`

*Filters the labels of a specific post type.*

The dynamic portion of the hook name, `$post_type`, refers to
the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$labels` | `object` | Object with labels for the post type as member variables.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 1769](../../wordpress/wp-includes/post.php#L1769-L1781)

### `is_sticky`

*Filters whether a post is sticky.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_sticky` | `bool` | Whether a post is sticky.
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2402](../../wordpress/wp-includes/post.php#L2402-L2410)

### `edit_{$field}`

*Filters the value of a specific post field to edit.*

The dynamic portion of the hook name, `$field`, refers to the post
field name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the post field.
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2504](../../wordpress/wp-includes/post.php#L2504-L2515)

### `{$field_no_prefix}_edit_pre`

*Filters the value of a specific post field to edit.*

The dynamic portion of the hook name, `$field_no_prefix`, refers to
the post field name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the post field.
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2517](../../wordpress/wp-includes/post.php#L2517-L2528)

### `edit_post_{$field}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$post_id` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2530](../../wordpress/wp-includes/post.php#L2530-L2530)

### `pre_{$field}`

*Filters the value of a specific post field before saving.*

The dynamic portion of the hook name, `$field`, refers to the post
field name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the post field.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2545](../../wordpress/wp-includes/post.php#L2545-L2555)

### `{$field_no_prefix}_save_pre`

*Filters the value of a specific field before saving.*

The dynamic portion of the hook name, `$field_no_prefix`, refers
to the post field name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the post field.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2557](../../wordpress/wp-includes/post.php#L2557-L2567)

### `pre_post_{$field}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2569](../../wordpress/wp-includes/post.php#L2569-L2569)

### `{$field}_pre`

*Filters the value of a specific post field before saving.*

The dynamic portion of the hook name, `$field`, refers to the post
field name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the post field.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2571](../../wordpress/wp-includes/post.php#L2571-L2581)

### `{$field}`

*Filters the value of a specific post field for display.*

The dynamic portion of the hook name, `$field`, refers to the post
field name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the prefixed post field.
`$post_id` | `int` | Post ID.
`$context` | `string` | Context for how to sanitize the field.<br>Accepts 'raw', 'edit', 'db', 'display',<br>'attribute', or 'js'. Default 'display'.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2588](../../wordpress/wp-includes/post.php#L2588-L2602)

### `post_{$field}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$post_id` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2604](../../wordpress/wp-includes/post.php#L2604-L2604)

### `wp_count_posts`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$counts` |  | 
`$type` |  | 
`$perm` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2759](../../wordpress/wp-includes/post.php#L2759-L2760)

### `wp_count_posts`

*Modify returned post counts by status for the current post type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$counts` | `object` | An object containing the current post_type's post<br>counts by status.
`$type` | `string` | Post type.
`$perm` | `string` | The permission to determine if the posts are 'readable'<br>by the current user.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2787](../../wordpress/wp-includes/post.php#L2787-L2798)

### `wp_count_attachments`

*Modify returned attachment counts by mime type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`(object) $counts` |  | 
`$mime_type` | `string\|string[]` | Array or comma-separated list of MIME patterns.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2829](../../wordpress/wp-includes/post.php#L2829-L2838)

### `post_mime_types`

*Filters the default list of post mime types.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_mime_types` | `array` | Default list of post mime types.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 2935](../../wordpress/wp-includes/post.php#L2935-L2942)

### `pre_delete_post`

*Filters whether a post deletion should take place.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post` | `\WP_Post` | Post object.
`$force_delete` | `bool` | Whether to bypass the Trash.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3100](../../wordpress/wp-includes/post.php#L3100-L3109)

### `pre_trash_post`

*Filters whether a post trashing should take place.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3280](../../wordpress/wp-includes/post.php#L3280-L3288)

### `pre_untrash_post`

*Filters whether a post untrashing should take place.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post` | `\WP_Post` | Post object.
`$previous_status` | `string` | The status of the post at the point where it was trashed.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The `$previous_status` parameter was added.
`4.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3356](../../wordpress/wp-includes/post.php#L3356-L3366)

### `wp_untrash_post_status`

*Filters the status that a post gets assigned when it is restored from the trash (untrashed).*

By default posts that are restored will be assigned a status of 'draft'. Return the value of `$previous_status`
in order to assign the status that the post had before it was trashed. The `wp_untrash_post_set_previous_status()`
function is available for this.

Prior to WordPress 5.6.0, restored posts were always assigned their original status.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_status` | `string` | The new status of the post being restored.
`$post_id` | `int` | The ID of the post being restored.
`$previous_status` | `string` | The status of the post at the point where it was trashed.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3384](../../wordpress/wp-includes/post.php#L3384-L3399)

### `wp_insert_post_empty_content`

*Filters whether the post should be considered "empty".*

The post is considered "empty" if both:
1. The post type supports the title, editor, and excerpt fields
2. The title, editor, and excerpt fields are all empty

Returning a truthy value from the filter will effectively short-circuit
the new post being inserted and return 0. If $wp_error is true, a WP_Error
will be returned instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$maybe_empty` | `bool` | Whether the post should be considered "empty".
`$postarr` | `array` | Array of post data.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 3831](../../wordpress/wp-includes/post.php#L3831-L3847)

### `wp_insert_post_parent`

*Filters the post parent -- used to check for and prevent hierarchy loops.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_parent` | `int` | Post parent ID.
`$post_ID` | `int` | Post ID.
`$new_postarr` | `array` | Array of parsed post data.
`$postarr` | `array` | Array of sanitized, but otherwise unmodified post data.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4002](../../wordpress/wp-includes/post.php#L4002-L4012)

### `add_trashed_suffix_to_trashed_posts`

*Filters whether or not to add a `__trashed` suffix to trashed posts that match the name of the updated post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post_name` | `string` | The name of the post being updated.
`$post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4029](../../wordpress/wp-includes/post.php#L4029-L4038)

### `wp_insert_attachment_data`

*Filters attachment post data before it is updated in or added to the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | An array of slashed, sanitized, and processed attachment post data.
`$postarr` | `array` | An array of slashed and sanitized attachment post data, but not processed.
`$unsanitized_postarr` | `array` | An array of slashed yet *unsanitized* and unprocessed attachment post data<br>as originally passed to wp_insert_post().

**Changelog**

Version | Description
------- | -----------
`5.4.1` | `$unsanitized_postarr` argument added.
`3.9.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4071](../../wordpress/wp-includes/post.php#L4071-L4082)

### `wp_insert_post_data`

*Filters slashed post data just before it is inserted into the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | An array of slashed, sanitized, and processed post data.
`$postarr` | `array` | An array of sanitized (and slashed) but otherwise unmodified post data.
`$unsanitized_postarr` | `array` | An array of slashed yet *unsanitized* and unprocessed post data as<br>originally passed to wp_insert_post().

**Changelog**

Version | Description
------- | -----------
`5.4.1` | `$unsanitized_postarr` argument added.
`2.7.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4084](../../wordpress/wp-includes/post.php#L4084-L4095)

### `pre_wp_unique_post_slug`

*Filters the post slug before it is generated to be unique.*

Returning a non-null value will short-circuit the
unique slug generation, returning the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$slug` | `string` | The desired slug (post_name).
`$post_ID` | `int` | Post ID.
`$post_status` | `string` | The post status.
`$post_type` | `string` | Post type.
`$post_parent` | `int` | Post parent ID.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4659](../../wordpress/wp-includes/post.php#L4659-L4674)

### `wp_unique_post_slug_is_bad_attachment_slug`

*Filters whether the post slug would make a bad attachment slug.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$slug` | `string` | The post slug.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4693](../../wordpress/wp-includes/post.php#L4693-L4701)

### `wp_unique_post_slug_is_bad_hierarchical_slug`

*Filters whether the post slug would make a bad hierarchical post slug.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$slug` | `string` | The post slug.
`$post_type` | `string` | Post type.
`$post_parent` | `int` | Post parent ID.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4727](../../wordpress/wp-includes/post.php#L4727-L4737)

### `wp_unique_post_slug_is_bad_flat_slug`

*Filters whether the post slug would be bad as a flat slug.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$slug` | `string` | The post slug.
`$post_type` | `string` | Post type.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4784](../../wordpress/wp-includes/post.php#L4784-L4793)

### `wp_unique_post_slug`

*Filters the unique post slug.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$slug` | `string` | The post slug.
`$post_ID` | `int` | Post ID.
`$post_status` | `string` | The post status.
`$post_type` | `string` | Post type.
`$post_parent` | `int` | Post parent ID
`$original_slug` | `string` | The original post slug.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4810](../../wordpress/wp-includes/post.php#L4810-L4822)

### `default_category_post_types`

*Filters post types (in addition to 'post') that require a default category.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 4955](../../wordpress/wp-includes/post.php#L4955-L4962)

### `add_ping`

*Filters the new ping URL to add for the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new` | `string` | New ping URL to add.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5118](../../wordpress/wp-includes/post.php#L5118-L5125)

### `get_enclosed`

*Filters the list of enclosures already enclosed for the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pung` | `string[]` | Array of enclosures for the given post.
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5157](../../wordpress/wp-includes/post.php#L5157-L5165)

### `get_pung`

*Filters the list of already-pinged URLs for the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pung` | `string[]` | Array of URLs already pinged for the given post.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5188](../../wordpress/wp-includes/post.php#L5188-L5195)

### `get_to_ping`

*Filters the list of URLs yet to ping for the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$to_ping` | `string[]` | List of URLs yet to ping.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5217](../../wordpress/wp-includes/post.php#L5217-L5224)

### `get_page_uri`

*Filters the URI for a page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$uri` | `string` | Page URI.
`$page` | `\WP_Post` | Page object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5573](../../wordpress/wp-includes/post.php#L5573-L5581)

### `get_pages`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pages` |  | 
`$parsed_args` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5688](../../wordpress/wp-includes/post.php#L5688-L5689)

### `get_pages`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$parsed_args` |  | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5848](../../wordpress/wp-includes/post.php#L5848-L5849)

### `get_pages`

*Filters the retrieved list of pages.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pages` | `\WP_Post[]` | Array of page objects.
`$parsed_args` | `array` | Array of get_pages() arguments.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 5893](../../wordpress/wp-includes/post.php#L5893-L5901)

### `pre_delete_attachment`

*Filters whether an attachment deletion should take place.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post` | `\WP_Post` | Post object.
`$force_delete` | `bool` | Whether to bypass the Trash.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6020](../../wordpress/wp-includes/post.php#L6020-L6029)

### `wp_get_attachment_metadata`

*Filters the attachment meta data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | Array of meta data for the given attachment.
`$attachment_id` | `int` | Attachment post ID.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6224](../../wordpress/wp-includes/post.php#L6224-L6232)

### `wp_update_attachment_metadata`

*Filters the updated attachment meta data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | Array of updated attachment meta data.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6253](../../wordpress/wp-includes/post.php#L6253-L6261)

### `wp_get_attachment_url`

*Filters the attachment URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | URL for the given attachment.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6328](../../wordpress/wp-includes/post.php#L6328-L6336)

### `wp_get_attachment_caption`

*Filters the attachment caption.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$caption` | `string` | Caption for the given attachment.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6367](../../wordpress/wp-includes/post.php#L6367-L6375)

### `wp_get_attachment_thumb_file`

*Filters the attachment thumbnail file path.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$thumbfile` | `string` | File path to the attachment thumbnail.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6404](../../wordpress/wp-includes/post.php#L6404-L6412)

### `wp_get_attachment_thumb_url`

*Filters the attachment thumbnail URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | URL for the attachment thumbnail.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6451](../../wordpress/wp-includes/post.php#L6451-L6459)

### `icon_dir`

*Filters the icon directory path.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`ABSPATH . WPINC . '/images/media'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6575](../../wordpress/wp-includes/post.php#L6575-L6582)

### `icon_dir_uri`

*Filters the icon directory URI.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`includes_url('images/media')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6584](../../wordpress/wp-includes/post.php#L6584-L6591)

### `icon_dirs`

*Filters the array of icon directory URIs.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($icon_dir => $icon_dir_uri)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6593](../../wordpress/wp-includes/post.php#L6593-L6600)

### `wp_mime_type_icon`

*Filters the mime type icon.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$icon` | `string` | Path to the mime type icon.
`$mime` | `string` | Mime type.
`$post_id` | `int` | Attachment ID. Will equal 0 if the function passed<br>the mime type.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6659](../../wordpress/wp-includes/post.php#L6659-L6669)

### `pub_priv_sql_capability`

*Filters the capability to read private posts for a custom post type
when generating SQL for getting posts by author.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('')` |  | 
`'3.2.0'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6812](../../wordpress/wp-includes/post.php#L6812-L6821)

### `get_lastpostdate`

*Filters the most recent time that a post on the site was published.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$lastpostdate` | `string\|false` | The most recent time that a post was published,<br>in 'Y-m-d H:i:s' format. False on failure.
`$timezone` | `string` | Location to use for getting the post published date.<br>See get_lastpostdate() for accepted `$timezone` values.
`$post_type` | `string` | The post type to check.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$post_type` parameter.
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6884](../../wordpress/wp-includes/post.php#L6884-L6896)

### `pre_get_lastpostmodified`

*Pre-filter the return value of get_lastpostmodified() before the query is run.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$timezone` | `string` | Location to use for getting the post modified date.<br>See get_lastpostdate() for accepted `$timezone` values.
`$post_type` | `string` | The post type to check.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6916](../../wordpress/wp-includes/post.php#L6916-L6928)

### `get_lastpostmodified`

*Filters the most recent time that a post on the site was modified.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$lastpostmodified` | `string\|false` | The most recent time that a post was modified,<br>in 'Y-m-d H:i:s' format. False on failure.
`$timezone` | `string` | Location to use for getting the post modified date.<br>See get_lastpostdate() for accepted `$timezone` values.
`$post_type` | `string` | The post type to check.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$post_type` parameter.
`2.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 6941](../../wordpress/wp-includes/post.php#L6941-L6953)

### `wp_get_original_image_path`

*Filters the path to the original image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$original_image` | `string` | Path to original image file.
`$attachment_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 7677](../../wordpress/wp-includes/post.php#L7677-L7685)

### `wp_get_original_image_url`

*Filters the URL to the original attachment image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$original_image_url` | `string` | URL to original image.
`$attachment_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/post.php](../../wordpress/wp-includes/post.php), [line 7719](../../wordpress/wp-includes/post.php#L7719-L7727)

### `get_terms_defaults`

*Filters the terms query default arguments.*

Use %1$s to filter the passed arguments.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->query_var_defaults` |  | 
`$taxonomies` | `string[]` | An array of taxonomy names.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 243](../../wordpress/wp-includes/class-wp-term-query.php#L243-L253)

### `get_terms_args`

*Filters the terms query arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | An array of get_terms() arguments.
`$taxonomies` | `string[]` | An array of taxonomy names.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 393](../../wordpress/wp-includes/class-wp-term-query.php#L393-L401)

### `list_terms_exclusions`

*Filters the terms to exclude from the terms query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$exclusions` | `string` | `NOT IN` clause of the terms query.
`$args` | `array` | An array of terms query arguments.
`$taxonomies` | `string[]` | An array of taxonomy names.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 507](../../wordpress/wp-includes/class-wp-term-query.php#L507-L516)

### `get_terms_fields`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$selects` |  | 
`$args` |  | 
`$taxonomies` |  | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 680](../../wordpress/wp-includes/class-wp-term-query.php#L680-L680)

### `terms_clauses`

*Filters the terms query SQL clauses.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`compact('fields', 'join', 'where', 'distinct', 'orderby', 'order', 'limits')` |  | 
`$taxonomies` | `string[]` | An array of taxonomy names.
`$args` | `array` | An array of term query arguments.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 690](../../wordpress/wp-includes/class-wp-term-query.php#L690-L699)

### `terms_pre_query`

*Filters the terms array before the query takes place.*

Return a non-null value to bypass WordPress' default term queries.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this->terms, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 722](../../wordpress/wp-includes/class-wp-term-query.php#L722-L733)

### `get_terms_orderby`

*Filters the ORDERBY clause of the terms query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$orderby` | `string` | `ORDERBY` clause of the terms query.
`$this->query_vars` |  | 
`$this->query_vars['taxonomy']` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-term-query.php](../../wordpress/wp-includes/class-wp-term-query.php), [line 924](../../wordpress/wp-includes/class-wp-term-query.php#L924-L933)

### `wp_rest_search_handlers`

*Filters the search handlers to use in the REST search controller.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$search_handlers` | `array` | List of search handlers to use in the controller. Each search<br>handler instance must extend the `WP_REST_Search_Handler` class.<br>Default is only a handler for posts.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 282](../../wordpress/wp-includes/rest-api.php#L282-L291)

### `rest_url_prefix`

*Filters the REST URL prefix.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp-json'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 368](../../wordpress/wp-includes/rest-api.php#L368-L375)

### `rest_url`

*Filters the REST URL.*

Use this filter to adjust the url returned by the get_rest_url() function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | REST URL.
`$path` | `string` | REST route.
`$blog_id` | `int\|null` | Blog ID.
`$scheme` | `string` | Sanitization scheme.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 437](../../wordpress/wp-includes/rest-api.php#L437-L449)

### `wp_rest_server_class`

*Filters the REST Server Class.*

This filter allows you to adjust the server class used by the REST API, using a
different class to handle requests.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'WP_REST_Server'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 498](../../wordpress/wp-includes/rest-api.php#L498-L508)

### `rest_avatar_sizes`

*Filters the REST avatar sizes.*

Use this filter to adjust the array of sizes returned by the
`rest_get_avatar_sizes` function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(24, 48, 96)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 1175](../../wordpress/wp-includes/rest-api.php#L1175-L1186)

### `rest_route_for_post`

*Filters the REST API route for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$route` | `string` | The route path.
`$post` | `\WP_Post` | The post object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 3037](../../wordpress/wp-includes/rest-api.php#L3037-L3045)

### `rest_route_for_term`

*Filters the REST API route for a term.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$route` | `string` | The route path.
`$term` | `\WP_Term` | The term object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 3082](../../wordpress/wp-includes/rest-api.php#L3082-L3090)

### `rest_queried_resource_route`

*Filters the REST route for the currently queried object.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$route` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api.php](../../wordpress/wp-includes/rest-api.php), [line 3111](../../wordpress/wp-includes/rest-api.php#L3111-L3118)

### `wp_http_cookie_value`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->value` |  | 
`$this->name` |  | 

Source: [wordpress/wp-includes/class-wp-http-cookie.php](../../wordpress/wp-includes/class-wp-http-cookie.php), [line 227](../../wordpress/wp-includes/class-wp-http-cookie.php#L227-L227)

### `post_rewrite_rules`

*Filters rewrite rules used for "post" archives.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_rewrite` | `string[]` | Array of rewrite rules for posts, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1303](../../wordpress/wp-includes/class-wp-rewrite.php#L1303-L1310)

### `date_rewrite_rules`

*Filters rewrite rules used for date archives.*

Likely date archives would include /yyyy/, /yyyy/mm/, and /yyyy/mm/dd/.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$date_rewrite` | `string[]` | Array of rewrite rules for date archives, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1315](../../wordpress/wp-includes/class-wp-rewrite.php#L1315-L1324)

### `root_rewrite_rules`

*Filters rewrite rules used for root-level archives.*

Likely root-level archives would include pagination rules for the homepage
as well as site-wide post feeds (e.g. /feed/, and /feed/atom/).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$root_rewrite` | `string[]` | Array of root-level rewrite rules, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1329](../../wordpress/wp-includes/class-wp-rewrite.php#L1329-L1339)

### `comments_rewrite_rules`

*Filters rewrite rules used for comment feed archives.*

Likely comments feed archives include /comments/feed/, and /comments/feed/atom/.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comments_rewrite` | `string[]` | Array of rewrite rules for the site-wide comments feeds, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1344](../../wordpress/wp-includes/class-wp-rewrite.php#L1344-L1353)

### `search_rewrite_rules`

*Filters rewrite rules used for search archives.*

Likely search-related archives include /search/search+query/ as well as
pagination and feed paths for a search.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$search_rewrite` | `string[]` | Array of rewrite rules for search queries, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1359](../../wordpress/wp-includes/class-wp-rewrite.php#L1359-L1369)

### `author_rewrite_rules`

*Filters rewrite rules used for author archives.*

Likely author archives would include /author/author-name/, as well as
pagination and feed paths for author archives.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$author_rewrite` | `string[]` | Array of rewrite rules for author archives, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1374](../../wordpress/wp-includes/class-wp-rewrite.php#L1374-L1384)

### `page_rewrite_rules`

*Filters rewrite rules used for "page" post type archives.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$page_rewrite` | `string[]` | Array of rewrite rules for the "page" post type, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1389](../../wordpress/wp-includes/class-wp-rewrite.php#L1389-L1396)

### `{$permastructname}_rewrite_rules`

*Filters rewrite rules used for individual permastructs.*

The dynamic portion of the hook name, `$permastructname`, refers
to the name of the registered permastruct, e.g. 'post_tag' (tags),
'category' (categories), etc.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rules` | `string[]` | Array of rewrite rules generated for the current permastruct, keyed by their regex pattern.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1410](../../wordpress/wp-includes/class-wp-rewrite.php#L1410-L1421)

### `tag_rewrite_rules`

*Filters rewrite rules used specifically for Tags.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($rules)` |  | 
`'3.1.0'` |  | 
`'post_tag_rewrite_rules'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1425](../../wordpress/wp-includes/class-wp-rewrite.php#L1425-L1433)

### `rewrite_rules_array`

*Filters the full set of generated rewrite rules.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->rules` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1455](../../wordpress/wp-includes/class-wp-rewrite.php#L1455-L1462)

### `mod_rewrite_rules`

*Filters the list of rewrite rules formatted for output to an .htaccess file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rules` | `string` | mod_rewrite Rewrite rules formatted for .htaccess.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1566](../../wordpress/wp-includes/class-wp-rewrite.php#L1566-L1573)

### `rewrite_rules`

*Filters the list of rewrite rules formatted for output to an .htaccess file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($rules)` |  | 
`'1.5.0'` |  | 
`'mod_rewrite_rules'` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1575](../../wordpress/wp-includes/class-wp-rewrite.php#L1575-L1583)

### `iis7_url_rewrite_rules`

*Filters the list of rewrite rules formatted for output to a web.config.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rules` | `string` | Rewrite rules formatted for IIS web.config.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1628](../../wordpress/wp-includes/class-wp-rewrite.php#L1628-L1635)

### `flush_rewrite_rules_hard`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/class-wp-rewrite.php](../../wordpress/wp-includes/class-wp-rewrite.php), [line 1865](../../wordpress/wp-includes/class-wp-rewrite.php#L1865-L1865)

### `pre_http_send_through_proxy`

*Filters whether to preempt sending the request through the proxy.*

Returning false will bypass the proxy; returning true will send
the request through the proxy. Returning null bypasses the filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$uri` | `string` | URL of the request.
`$check` | `array` | Associative array result of parsing the request URL with `parse_url()`.
`$home` | `array` | Associative array result of parsing the site URL with `parse_url()`.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-http-proxy.php](../../wordpress/wp-includes/class-wp-http-proxy.php), [line 176](../../wordpress/wp-includes/class-wp-http-proxy.php#L176-L189)

### `wp_signup_location`

*This filter is documented in wp-login.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`network_site_url('wp-signup.php')` |  | 

Source: [wordpress/wp-includes/canonical.php](../../wordpress/wp-includes/canonical.php), [line 533](../../wordpress/wp-includes/canonical.php#L533-L534)

### `redirect_canonical`

*Filters the canonical redirect URL.*

Returning false to this filter will cancel the redirect.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_url` | `string` | The redirect URL.
`$requested_url` | `string` | The requested URL.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/canonical.php](../../wordpress/wp-includes/canonical.php), [line 779](../../wordpress/wp-includes/canonical.php#L779-L789)

### `do_redirect_guess_404_permalink`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/canonical.php](../../wordpress/wp-includes/canonical.php), [line 894](../../wordpress/wp-includes/canonical.php#L894-L894)

### `pre_redirect_guess_404_permalink`

*Short-circuits the redirect URL guessing for 404 requests.*

Returning a non-null value from the filter will effectively short-circuit
the URL guessing, returning the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/canonical.php](../../wordpress/wp-includes/canonical.php), [line 898](../../wordpress/wp-includes/canonical.php#L898-L909)

### `strict_redirect_guess_404_permalink`

*Filters whether to perform a strict guess for a 404 redirect.*

Returning a truthy value from the filter will redirect only exact post_name matches.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/canonical.php](../../wordpress/wp-includes/canonical.php), [line 915](../../wordpress/wp-includes/canonical.php#L915-L924)

### `protected_title_format`

*Filters the text prepended to the post title for protected posts.*

The filter is only applied on the front end.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepend` | `string` | Text displayed before the post title.<br>Default 'Protected: %s'.
`$post` | `\WP_Post` | Current post object.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 129](../../wordpress/wp-includes/post-template.php#L129-L140)

### `private_title_format`

*Filters the text prepended to the post title of private posts.*

The filter is only applied on the front end.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepend` | `string` | Text displayed before the post title.<br>Default 'Private: %s'.
`$post` | `\WP_Post` | Current post object.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 147](../../wordpress/wp-includes/post-template.php#L147-L158)

### `the_title`

*Filters the post title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | The post title.
`$id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 163](../../wordpress/wp-includes/post-template.php#L163-L171)

### `the_guid`

*Filters the escaped Global Unique Identifier (guid) of the post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$guid` | `string` | Escaped Global Unique Identifier (guid) of the post.
`$id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 193](../../wordpress/wp-includes/post-template.php#L193-L203)

### `get_the_guid`

*Filters the Global Unique Identifier (guid) of the post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$guid` | `string` | Global Unique Identifier (guid) of the post.
`$id` | `int` | The post ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 224](../../wordpress/wp-includes/post-template.php#L224-L232)

### `the_content`

*Filters the post content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | Content of the current post.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 246](../../wordpress/wp-includes/post-template.php#L246-L253)

### `the_content_more_link`

*Filters the Read More link text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`' <a href="' . get_permalink($_post) . "#more-{$_post->ID}\" class=\"more-link\">{$more_link_text}</a>"` |  | 
`$more_link_text` | `string` | Read More text.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 361](../../wordpress/wp-includes/post-template.php#L361-L369)

### `the_excerpt`

*Filters the displayed post excerpt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_excerpt()` |  | 

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 385](../../wordpress/wp-includes/post-template.php#L385-L394)

### `get_the_excerpt`

*Filters the retrieved post excerpt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_excerpt` |  | 
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Introduced the `$post` parameter.
`1.2.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 420](../../wordpress/wp-includes/post-template.php#L420-L429)

### `post_class`

*Filters the list of CSS class names for the current post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classes` | `string[]` | An array of post class names.
`$class` | `string[]` | An array of additional class names added to the post.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 572](../../wordpress/wp-includes/post-template.php#L572-L581)

### `body_class`

*Filters the list of CSS body class names for the current post or page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classes` | `string[]` | An array of body class names.
`$class` | `string[]` | An array of additional class names added to the body.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 828](../../wordpress/wp-includes/post-template.php#L828-L836)

### `post_password_required`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 853](../../wordpress/wp-includes/post-template.php#L853-L854)

### `post_password_required`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 858](../../wordpress/wp-includes/post-template.php#L858-L859)

### `post_password_required`

*Filters whether a post requires the user to supply a password.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$required` | `bool` | Whether the user needs to supply a password. True if password has not been<br>provided or is incorrect, false if password has been supplied or is not required.
`$post` | `\WP_Post` | Post data.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 872](../../wordpress/wp-includes/post-template.php#L872-L881)

### `wp_link_pages_args`

*Filters the arguments used in retrieving page links for paginated posts.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_args` | `array` | An array of page link arguments. See wp_link_pages()<br>for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 944](../../wordpress/wp-includes/post-template.php#L944-L952)

### `wp_link_pages_link`

*Filters the HTML output of individual page number links.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The page number HTML output.
`$i` | `int` | Page number for paginated posts' page links.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 965](../../wordpress/wp-includes/post-template.php#L965-L973)

### `wp_link_pages_link`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$prev` |  | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 986](../../wordpress/wp-includes/post-template.php#L986-L987)

### `wp_link_pages_link`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$next` |  | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 996](../../wordpress/wp-includes/post-template.php#L996-L997)

### `wp_link_pages`

*Filters the HTML output of page links for paginated posts.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | HTML output of paginated posts' page links.
`$args` | `array` | An array of arguments. See wp_link_pages()<br>for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1003](../../wordpress/wp-includes/post-template.php#L1003-L1012)

### `the_meta_key`

*Filters the HTML output of the li element in the post custom fields list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | The HTML output for the li element.
`$key` | `string` | Meta key.
`$value` | `string` | Meta value.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1113](../../wordpress/wp-includes/post-template.php#L1113-L1122)

### `wp_dropdown_pages`

*Filters the HTML output of a list of pages as a drop down.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | HTML output for drop down list of pages.
`$parsed_args` | `array` | The parsed arguments array. See wp_dropdown_pages()<br>for information on accepted arguments.
`$pages` | `\WP_Post[]` | Array of the page objects.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | `$parsed_args` and `$pages` added as arguments.
`2.1.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1206](../../wordpress/wp-includes/post-template.php#L1206-L1217)

### `wp_list_pages_excludes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$exclude_array` |  | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1306](../../wordpress/wp-includes/post-template.php#L1306-L1306)

### `wp_list_pages`

*Filters the HTML output of the pages to list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | HTML output of the pages list.
`$parsed_args` | `array` | An array of page-listing arguments. See wp_list_pages()<br>for information on accepted arguments.
`$pages` | `\WP_Post[]` | Array of the page objects.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | `$pages` added as arguments.
`1.5.1` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1334](../../wordpress/wp-includes/post-template.php#L1334-L1347)

### `wp_page_menu_args`

*Filters the arguments used to generate a page-based menu.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | An array of page menu arguments. See wp_page_menu()<br>for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1417](../../wordpress/wp-includes/post-template.php#L1417-L1427)

### `wp_page_menu`

*Filters the HTML output of a page-based menu.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu` | `string` | The HTML output.
`$args` | `array` | An array of arguments. See wp_page_menu()<br>for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1491](../../wordpress/wp-includes/post-template.php#L1491-L1502)

### `wp_get_attachment_link`

*Filters a retrieved attachment page link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`"<a href='" . esc_url($url) . "'>{$link_text}</a>"` |  | 
`$id` | `int` | Post ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$permalink` | `bool` | Whether to add permalink to image. Default false.
`$icon` | `bool` | Whether to include an icon.
`$text` | `string\|false` | If string, will be link text.
`$attr` | `array\|string` | Array or string of attributes.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | Added the $attr parameter.
`2.7.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1642](../../wordpress/wp-includes/post-template.php#L1642-L1657)

### `prepend_attachment`

*Filters the attachment markup to be prepended to the post content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$p` | `string` | The attachment HTML output.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1695](../../wordpress/wp-includes/post-template.php#L1695-L1704)

### `the_password_form`

*Filters the HTML output for the protected post password form.*

If modifying the password field, please note that the core database schema
limits the password field to 20 characters regardless of the value of the
size attribute in the form input.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The password form HTML output.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1729](../../wordpress/wp-includes/post-template.php#L1729-L1740)

### `wp_post_revision_title_expanded`

*Filters the formatted author and date for a revision.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$revision_date_author` | `string` | The formatted string.
`$revision` | `\WP_Post` | The revision object.
`$link` | `bool` | Whether to link to the revisions page, as passed into<br>wp_post_revision_title_expanded().

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/post-template.php](../../wordpress/wp-includes/post-template.php), [line 1905](../../wordpress/wp-includes/post-template.php#L1905-L1915)

### `customize_loaded_components`

*Filters the core Customizer components to load.*

This allows Core components to be excluded from being instantiated by
filtering them out of the array. Note that this filter generally runs
during the %1$s action, so it cannot be added
in a theme.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->components` |  | 
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 336](../../wordpress/wp-includes/class-wp-customize-manager.php#L336-L351)

### `customize_changeset_branching`

*Filters whether or not changeset branching is allowed.*

By default in core, when changeset branching is not allowed, changesets will operate
linearly in that only one saved changeset will exist at a time (with a 'draft' or
'future' status). This makes the Customizer operate in a way that is similar to going to
"edit" to one existing post: all users will be making changes to the same post, and autosave
revisions will be made for that post.

By contrast, when changeset branching is allowed, then the model is like users going
to "add new" for a page and each user makes changes independently of each other since
they are all operating on their own separate pages, each getting their own separate
initial auto-drafts and then once initially saved, autosave revisions on top of that
user's specific post.

Since linear changesets are deemed to be more suitable for the majority of WordPress users,
they are the default. For WordPress sites that have heavy site management in the Customizer
by multiple users then branching changesets should be enabled by means of this filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->branching` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 774](../../wordpress/wp-includes/class-wp-customize-manager.php#L774-L799)

### `customize_validate_{$setting->id}`

*This filter is documented in wp-includes/class-wp-customize-setting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`new WP_Error()` |  | 
`$unsanitized_value` |  | 
`$setting` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 2360](../../wordpress/wp-includes/class-wp-customize-manager.php#L2360-L2361)

### `customize_save_response`

*Filters response data for a successful customize_save Ajax request.*

This filter does not apply if there was a nonce or authentication failure.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | Additional information passed back to the 'saved'<br>event on `wp.customize`.
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 2586](../../wordpress/wp-includes/class-wp-customize-manager.php#L2586-L2597)

### `customize_changeset_save_data`

*Filters the settings' data that will be persisted into the changeset.*

Plugins may amend additional data (such as additional meta for settings) into the changeset with this filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | Updated changeset data, mapping setting IDs to arrays containing a $value item and optionally other metadata.
`$filter_context` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 2870](../../wordpress/wp-includes/class-wp-customize-manager.php#L2870-L2890)

### `pre_trash_post`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3073](../../wordpress/wp-includes/class-wp-customize-manager.php#L3073-L3074)

### `customize_dynamic_setting_args`

*This filter is documented in wp-includes/class-wp-customize-manager.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 
`$id` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3758](../../wordpress/wp-includes/class-wp-customize-manager.php#L3758-L3759)

### `customize_dynamic_setting_class`

*This filter is documented in wp-includes/class-wp-customize-manager.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$class` |  | 
`$id` |  | 
`$args` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3761](../../wordpress/wp-includes/class-wp-customize-manager.php#L3761-L3762)

### `customize_dynamic_setting_args`

*Filters a dynamic setting's constructor args.*

For a dynamic setting to be registered, this filter must be employed
to override the default false value with an array of args to pass to
the WP_Customize_Setting constructor.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$setting_args` | `false\|array` | The arguments to the WP_Customize_Setting constructor.
`$setting_id` | `string` | ID for dynamic setting, usually coming from `$_POST['customized']`.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3796](../../wordpress/wp-includes/class-wp-customize-manager.php#L3796-L3808)

### `customize_dynamic_setting_class`

*Allow non-statically created settings to be constructed with custom WP_Customize_Setting subclass.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$setting_class` | `string` | WP_Customize_Setting or a subclass.
`$setting_id` | `string` | ID for dynamic setting, usually coming from `$_POST['customized']`.
`$setting_args` | `array` | WP_Customize_Setting or a subclass.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 3813](../../wordpress/wp-includes/class-wp-customize-manager.php#L3813-L3822)

### `customize_allowed_urls`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_urls` |  | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 4624](../../wordpress/wp-includes/class-wp-customize-manager.php#L4624-L4624)

### `customize_refresh_nonces`

*Filters nonces for Customizer.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nonces` | `string[]` | Array of refreshed nonces for save and<br>preview actions.
`$this` | `\WP_Customize_Manager` | WP_Customize_Manager instance.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 4750](../../wordpress/wp-includes/class-wp-customize-manager.php#L4750-L4759)

### `customize_previewable_devices`

*Filters the available devices to allow previewing in the Customizer.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$devices` | `array` | List of devices with labels and default setting.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 5000](../../wordpress/wp-includes/class-wp-customize-manager.php#L5000-L5009)

### `customize_load_themes`

*Filters the theme data loaded in the customizer.*

This allows theme data to be loading from an external source,
or modification of data loaded from `wp_prepare_themes_for_js()`
or WordPress.org via `themes_api()`.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$themes` | `array` | Nested array of theme data.
`$args` | `array` | List of arguments, such as page, search term, and tags to query for.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/class-wp-customize-manager.php](../../wordpress/wp-includes/class-wp-customize-manager.php), [line 5911](../../wordpress/wp-includes/class-wp-customize-manager.php#L5911-L5928)

### `rss_update_period`

*This filter is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'hourly'` |  | 

Source: [wordpress/wp-includes/feed-rdf.php](../../wordpress/wp-includes/feed-rdf.php), [line 39](../../wordpress/wp-includes/feed-rdf.php#L39-L40)

### `rss_update_frequency`

*This filter is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'1'` |  | 

Source: [wordpress/wp-includes/feed-rdf.php](../../wordpress/wp-includes/feed-rdf.php), [line 45](../../wordpress/wp-includes/feed-rdf.php#L45-L46)

### `url_to_postid`

*Filters the URL to derive the post ID from.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The URL to derive the post ID from.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/rewrite.php](../../wordpress/wp-includes/rewrite.php), [line 491](../../wordpress/wp-includes/rewrite.php#L491-L498)

### `pre_option_{$option}`

*Filters the value of an existing option before it is retrieved.*

The dynamic portion of the hook name, `$option`, refers to the option name.

Returning a truthy value from the filter will effectively short-circuit retrieval
and return the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$option` | `string` | Option name.
`$default` | `mixed` | The fallback value to return if the option does not exist.<br>Default false.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `$default` parameter was added.
`4.4.0` | The `$option` parameter was added.
`1.5.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 62](../../wordpress/wp-includes/option.php#L62-L82)

### `default_option_{$option}`

*Filters the default value for an option.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` | `mixed` | The default value to return if the option does not exist<br>in the database.
`$option` | `string` | Option name.
`$passed_default` | `bool` | Was `get_option()` passed a default value?

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$passed_default` parameter was added to distinguish between a `false` value and the default parameter value.
`4.4.0` | The `$option` parameter was added.
`3.4.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 100](../../wordpress/wp-includes/option.php#L100-L114)

### `default_option_{$option}`

*This filter is documented in wp-includes/option.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` |  | 
`$option` |  | 
`$passed_default` |  | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 139](../../wordpress/wp-includes/option.php#L139-L140)

### `default_option_{$option}`

*This filter is documented in wp-includes/option.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` |  | 
`$option` |  | 
`$passed_default` |  | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 152](../../wordpress/wp-includes/option.php#L152-L153)

### `option_{$option}`

*Filters the value of an existing option.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`maybe_unserialize($value)` |  | 
`$option` | `string` | Option name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$option` parameter was added.
`3.0.0` | 
`1.5.0` | As 'option_' . $setting

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 166](../../wordpress/wp-includes/option.php#L166-L179)

### `pre_cache_alloptions`

*Filters all options before caching them.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$alloptions` | `array` | Array with all options.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 250](../../wordpress/wp-includes/option.php#L250-L257)

### `alloptions`

*Filters all options after retrieving them.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$alloptions` | `array` | Array with all options.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 263](../../wordpress/wp-includes/option.php#L263-L270)

### `pre_update_option_{$option}`

*Filters a specific option before its value is (maybe) serialized and updated.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | The new, unserialized option value.
`$old_value` | `mixed` | The old option value.
`$option` | `string` | Option name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$option` parameter was added.
`2.6.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 372](../../wordpress/wp-includes/option.php#L372-L384)

### `pre_update_option`

*Filters an option before its value is (maybe) serialized and updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | The new, unserialized option value.
`$option` | `string` | Name of the option.
`$old_value` | `mixed` | The old option value.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 386](../../wordpress/wp-includes/option.php#L386-L395)

### `default_option_{$option}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$option` |  | 
`false` |  | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 411](../../wordpress/wp-includes/option.php#L411-L411)

### `default_option_{$option}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$option` |  | 
`false` |  | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 564](../../wordpress/wp-includes/option.php#L564-L564)

### `pre_transient_{$transient}`

*Filters the value of an existing transient before it is retrieved.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

Returning a truthy value from the filter will effectively short-circuit retrieval
and return the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added
`2.8.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 769](../../wordpress/wp-includes/option.php#L769-L785)

### `transient_{$transient}`

*Filters an existing transient's value.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of transient.
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added
`2.8.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 814](../../wordpress/wp-includes/option.php#L814-L825)

### `pre_set_transient_{$transient}`

*Filters a specific transient before its value is set.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | New value of transient.
`$expiration` | `int` | Time until expiration in seconds.
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added.
`4.2.0` | The `$expiration` parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 847](../../wordpress/wp-includes/option.php#L847-L860)

### `expiration_of_transient_{$transient}`

*Filters the expiration for a transient before its value is set.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$expiration` | `int` | Time until expiration in seconds. Use 0 for no expiration.
`$value` | `mixed` | New value of transient.
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 862](../../wordpress/wp-includes/option.php#L862-L873)

### `pre_site_option_{$option}`

*Filters the value of an existing network option before it is retrieved.*

The dynamic portion of the hook name, `$option`, refers to the option name.

Returning a truthy value from the filter will effectively short-circuit retrieval
and return the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$option` | `string` | Option name.
`$network_id` | `int` | ID of the network.
`$default` | `mixed` | The fallback value to return if the option does not exist.<br>Default false.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `$default` parameter was added.
`4.7.0` | The `$network_id` parameter was added.
`4.4.0` | The `$option` parameter was added.
`3.0.0` | 
`2.9.0` | As 'pre_site_option_' . $key

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1326](../../wordpress/wp-includes/option.php#L1326-L1349)

### `default_site_option_{$option}`

*Filters a specific default network option.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` | `mixed` | The value to return if the site option does not exist<br>in the database.
`$option` | `string` | Option name.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`4.4.0` | The `$option` parameter was added.
`3.4.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1361](../../wordpress/wp-includes/option.php#L1361-L1375)

### `default_site_option_{$option}`

*This filter is documented in wp-includes/option.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` |  | 
`$option` |  | 
`$network_id` |  | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1379](../../wordpress/wp-includes/option.php#L1379-L1380)

### `default_site_option_{$option}`

*This filter is documented in wp-includes/option.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` |  | 
`$option` |  | 
`$network_id` |  | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1402](../../wordpress/wp-includes/option.php#L1402-L1403)

### `site_option_{$option}`

*Filters the value of an existing network option.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of network option.
`$option` | `string` | Option name.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`4.4.0` | The `$option` parameter was added.
`3.0.0` | 
`2.9.0` | As 'site_option_' . $key

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1413](../../wordpress/wp-includes/option.php#L1413-L1427)

### `pre_add_site_option_{$option}`

*Filters the value of a specific network option before it is added.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of network option.
`$option` | `string` | Option name.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`4.4.0` | The `$option` parameter was added.
`3.0.0` | 
`2.9.0` | As 'pre_add_site_option_' . $key

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1462](../../wordpress/wp-includes/option.php#L1462-L1476)

### `pre_update_site_option_{$option}`

*Filters a specific network option before its value is updated.*

The dynamic portion of the hook name, `$option`, refers to the option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | New value of the network option.
`$old_value` | `mixed` | Old value of the network option.
`$option` | `string` | Option name.
`$network_id` | `int` | ID of the network.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | The `$network_id` parameter was added.
`4.4.0` | The `$option` parameter was added.
`3.0.0` | 
`2.9.0` | As 'pre_update_site_option_' . $key

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1682](../../wordpress/wp-includes/option.php#L1682-L1697)

### `pre_site_transient_{$transient}`

*Filters the value of an existing site transient before it is retrieved.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

Returning a truthy value from the filter will effectively short-circuit retrieval
and return the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added.
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1845](../../wordpress/wp-includes/option.php#L1845-L1861)

### `site_transient_{$transient}`

*Filters the value of an existing site transient.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of site transient.
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added.
`2.9.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1888](../../wordpress/wp-includes/option.php#L1888-L1899)

### `pre_set_site_transient_{$transient}`

*Filters the value of a specific site transient before it is set.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | New value of site transient.
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The `$transient` parameter was added.
`3.0.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1920](../../wordpress/wp-includes/option.php#L1920-L1931)

### `expiration_of_site_transient_{$transient}`

*Filters the expiration for a site transient before its value is set.*

The dynamic portion of the hook name, `$transient`, refers to the transient name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$expiration` | `int` | Time until expiration in seconds. Use 0 for no expiration.
`$value` | `mixed` | New value of site transient.
`$transient` | `string` | Transient name.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 1935](../../wordpress/wp-includes/option.php#L1935-L1946)

### `register_setting_args`

*Filters the registration arguments when registering a setting.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of setting registration arguments.
`$defaults` | `array` | Array of default arguments.
`$option_group` | `string` | Setting group.
`$option_name` | `string` | Setting name.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/option.php](../../wordpress/wp-includes/option.php), [line 2243](../../wordpress/wp-includes/option.php#L2243-L2253)

### `{$tag}`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 

Source: [wordpress/wp-includes/plugin.php](../../wordpress/wp-includes/plugin.php), [line 640](../../wordpress/wp-includes/plugin.php#L640-L640)

### `get_the_categories`

*Filters the array of categories to return for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$categories` | `\WP_Term[]` | An array of categories to return for the post.
`$post_id` | `int\|false` | ID of the post.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added `$post_id` parameter.
`3.1.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 89](../../wordpress/wp-includes/category-template.php#L89-L98)

### `the_category`

*This filter is documented in wp-includes/category-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$separator` |  | 
`$parents` |  | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 144](../../wordpress/wp-includes/category-template.php#L144-L145)

### `the_category_list`

*Filters the categories before building the category list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_category($post_id)` |  | 
`$post_id` | `int\|bool` | ID of the post we're retrieving categories for.<br>When `false`, we assume the current post in the loop.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 148](../../wordpress/wp-includes/category-template.php#L148-L157)

### `the_category`

*This filter is documented in wp-includes/category-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Uncategorized')` |  | 
`$separator` |  | 
`$parents` |  | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 160](../../wordpress/wp-includes/category-template.php#L160-L161)

### `the_category`

*Filters the category or list of categories.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$thelist` | `string` | List of categories for the current post.
`$separator` | `string` | Separator used between the categories.
`$parents` | `string` | How to display the category parents. Accepts 'multiple',<br>'single', or empty.

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 219](../../wordpress/wp-includes/category-template.php#L219-L229)

### `list_cats`

*Filters a taxonomy drop-down display element.*

A variety of taxonomy drop-down display elements can be modified
just prior to display via this filter. Filterable arguments include
'show_option_none', 'show_option_all', and various forms of the
term name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_args['show_option_none']` |  | 
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`1.2.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 412](../../wordpress/wp-includes/category-template.php#L412-L427)

### `list_cats`

*This filter is documented in wp-includes/category-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_args['show_option_all']` |  | 
`null` |  | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 435](../../wordpress/wp-includes/category-template.php#L435-L436)

### `list_cats`

*This filter is documented in wp-includes/category-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_args['show_option_none']` |  | 
`null` |  | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 443](../../wordpress/wp-includes/category-template.php#L443-L444)

### `wp_dropdown_cats`

*Filters the taxonomy drop-down output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | HTML output.
`$parsed_args` | `array` | Arguments used to build the drop-down.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 461](../../wordpress/wp-includes/category-template.php#L461-L469)

### `wp_list_categories`

*Filters the HTML output of a taxonomy list.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | HTML output.
`$args` | `array` | An array of taxonomy-listing arguments. See wp_list_categories()<br>for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 659](../../wordpress/wp-includes/category-template.php#L659-L668)

### `wp_tag_cloud`

*Filters the tag cloud output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `string\|string[]` | Tag cloud as a string or an array, depending on 'format' argument.
`$args` | `array` | An array of tag cloud arguments. See wp_tag_cloud()<br>for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 756](../../wordpress/wp-includes/category-template.php#L756-L765)

### `tag_cloud_sort`

*Filters how the items in a tag cloud are sorted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags` | `\WP_Term[]` | Ordered array of terms.
`$args` | `array` | An array of tag cloud arguments.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 879](../../wordpress/wp-includes/category-template.php#L879-L887)

### `wp_generate_tag_cloud_data`

*Filters the data used to generate the tag cloud.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tags_data` | `array[]` | An array of term data arrays for terms used to generate the tag cloud.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 979](../../wordpress/wp-includes/category-template.php#L979-L986)

### `wp_generate_tag_cloud`

*Filters the generated output of a tag cloud.*

The filter is only evaluated if a true value is passed
to the $filter argument in wp_generate_tag_cloud().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `string[]\|string` | String containing the generated HTML tag cloud output<br>or an array of tag links if the 'format' argument<br>equals 'array'.
`$tags` | `\WP_Term[]` | An array of terms used in the tag cloud.
`$args` | `array` | An array of wp_generate_tag_cloud() arguments.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 1025](../../wordpress/wp-includes/category-template.php#L1025-L1041)

### `get_the_tags`

*Filters the array of tags for the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$terms` | `\WP_Term[]\|false\|\WP_Error` | Array of WP_Term objects on success, false if there are no terms<br>or the post does not exist, WP_Error on failure.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 1166](../../wordpress/wp-includes/category-template.php#L1166-L1176)

### `the_tags`

*Filters the tags list for a given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag_list` | `string` | List of tags.
`$before` | `string` | String to use before the tags.
`$sep` | `string` | String to use between the tags.
`$after` | `string` | String to use after the tags.
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 1194](../../wordpress/wp-includes/category-template.php#L1194-L1205)

### `get_the_terms`

*Filters the list of terms attached to the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$terms` | `\WP_Term[]\|\WP_Error` | Array of attached terms, or WP_Error on failure.
`$post->ID` |  | 
`$taxonomy` | `string` | Name of the taxonomy.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 1289](../../wordpress/wp-includes/category-template.php#L1289-L1298)

### `term_links-{$taxonomy}`

*Filters the term links for a given taxonomy.*

The dynamic portion of the filter name, `$taxonomy`, refers
to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$links` | `string[]` | An array of term links.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 1343](../../wordpress/wp-includes/category-template.php#L1343-L1353)

### `the_terms`

*Filters the list of terms to display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term_list` | `string` | List of terms to display.
`$taxonomy` | `string` | The taxonomy name.
`$before` | `string` | String to use before the terms.
`$sep` | `string` | String to use between the terms.
`$after` | `string` | String to use after the terms.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/category-template.php](../../wordpress/wp-includes/category-template.php), [line 1442](../../wordpress/wp-includes/category-template.php#L1442-L1453)

### `process_text_diff_html`

*Contextually filters a diffed line.*

Filters TextDiff processing of diffed line. By default, diffs are processed with
htmlspecialchars. Use this filter to remove or change the processing. Passes a context
indicating if the line is added, deleted or unchanged.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$processed_line` | `string` | The processed diffed line.
`$line` | `string` | The unprocessed diffed line.
`'added'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/class-wp-text-diff-renderer-table.php](../../wordpress/wp-includes/class-wp-text-diff-renderer-table.php), [line 162](../../wordpress/wp-includes/class-wp-text-diff-renderer-table.php#L162-L175)

### `process_text_diff_html`

*This filter is documented in wp-includes/wp-diff.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$processed_line` |  | 
`$line` |  | 
`'deleted'` |  | 

Source: [wordpress/wp-includes/class-wp-text-diff-renderer-table.php](../../wordpress/wp-includes/class-wp-text-diff-renderer-table.php), [line 200](../../wordpress/wp-includes/class-wp-text-diff-renderer-table.php#L200-L201)

### `process_text_diff_html`

*This filter is documented in wp-includes/wp-diff.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$processed_line` |  | 
`$line` |  | 
`'unchanged'` |  | 

Source: [wordpress/wp-includes/class-wp-text-diff-renderer-table.php](../../wordpress/wp-includes/class-wp-text-diff-renderer-table.php), [line 225](../../wordpress/wp-includes/class-wp-text-diff-renderer-table.php#L225-L226)

### `has_post_thumbnail`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$has_thumbnail` |  | 
`$post` |  | 
`$thumbnail_id` |  | 

Source: [wordpress/wp-includes/post-thumbnail-template.php](../../wordpress/wp-includes/post-thumbnail-template.php), [line 38](../../wordpress/wp-includes/post-thumbnail-template.php#L38-L38)

### `post_thumbnail_size`

*Filters the post thumbnail size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$post_id` parameter.
`2.9.0` | 

Source: [wordpress/wp-includes/post-thumbnail-template.php](../../wordpress/wp-includes/post-thumbnail-template.php), [line 147](../../wordpress/wp-includes/post-thumbnail-template.php#L147-L157)

### `post_thumbnail_html`

*Filters the post thumbnail HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | The post thumbnail HTML.
`$post->ID` |  | 
`$post_thumbnail_id` | `int` | The post thumbnail ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$attr` | `string` | Query string of attributes.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/post-thumbnail-template.php](../../wordpress/wp-includes/post-thumbnail-template.php), [line 197](../../wordpress/wp-includes/post-thumbnail-template.php#L197-L209)

### `the_post_thumbnail_caption`

*Filters the displayed post thumbnail caption.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_post_thumbnail_caption($post)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/post-thumbnail-template.php](../../wordpress/wp-includes/post-thumbnail-template.php), [line 282](../../wordpress/wp-includes/post-thumbnail-template.php#L282-L289)

### `xmlrpc_methods`

*Filters the methods exposed by the XML-RPC server.*

This filter can be used to add new methods, and remove built-in methods.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->methods` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 157](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L157-L166)

### `pre_option_enable_xmlrpc`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 238](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L238-L238)

### `option_enable_xmlrpc`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 240](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L240-L240)

### `xmlrpc_enabled`

*Filters whether XML-RPC methods requiring authentication are enabled.*

Contrary to the way it's named, this filter does not control whether XML-RPC is *fully*
enabled, rather, it only controls whether XML-RPC methods requiring authentication - such
as for publishing purposes - are enabled.

Further, the filter does not control whether pingbacks or other custom endpoints that don't
require authentication are enabled. This behavior is expected, and due to how parity was matched
with the `enable_xmlrpc` UI option the filter replaced when it was introduced in 3.5.

To disable XML-RPC methods that require authentication, use:

    add_filter( 'xmlrpc_enabled', '__return_false' );

For more granular control over all XML-RPC methods and requests, see the %1$s
and %2$s hooks.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$enabled` | `bool` | Whether XML-RPC is enabled. Default true.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 243](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L243-L265)

### `xmlrpc_login_error`

*Filters the XML-RPC user login error message.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->error` |  | 
`$user` | `\WP_Error` | WP_Error object.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 284](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L284-L292)

### `xmlrpc_blog_options`

*Filters the XML-RPC blog options property.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->blog_options` |  | 

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 626](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L626-L633)

### `xmlrpc_prepare_taxonomy`

*Filters XML-RPC-prepared data for the given taxonomy.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_taxonomy` | `array` | An array of taxonomy data.
`$taxonomy` | `\WP_Taxonomy` | Taxonomy object.
`$fields` | `array` | The subset of taxonomy fields to return.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 779](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L779-L788)

### `xmlrpc_prepare_term`

*Filters XML-RPC-prepared data for the given term.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_term` | `array` | An array of term data.
`$term` | `array\|object` | Term object or array.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 815](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L815-L823)

### `xmlrpc_prepare_post`

*Filters XML-RPC-prepared date for the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_post` | `array` | An array of modified post data.
`$post` | `array` | An array of post data.
`$fields` | `array` | An array of post fields.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 941](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L941-L950)

### `xmlrpc_prepare_post_type`

*Filters XML-RPC-prepared date for the given post type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_post_type` | `array` | An array of post type data.
`$post_type` | `\WP_Post_Type` | Post type object.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Converted the `$post_type` parameter to accept a WP_Post_Type object.
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 994](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L994-L1003)

### `xmlrpc_prepare_media_item`

*Filters XML-RPC-prepared data for the given media item.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_media_item` | `array` | An array of media item data.
`$media_item` | `\WP_Post` | Media item object.
`$thumbnail_size` | `string` | Image size.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1033](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1033-L1042)

### `xmlrpc_prepare_page`

*Filters XML-RPC-prepared data for the given page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_page` | `array` | An array of page data.
`$page` | `\WP_Post` | Page object.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1114](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1114-L1122)

### `xmlrpc_prepare_comment`

*Filters XML-RPC-prepared data for the given comment.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_comment` | `array` | An array of prepared comment data.
`$comment` | `\WP_Comment` | Comment object.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1161](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1161-L1169)

### `xmlrpc_prepare_user`

*Filters XML-RPC-prepared data for the given user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_user` | `array` | An array of user data.
`$user` | `\WP_User` | User object.
`$fields` | `array` | An array of user fields.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1207](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1207-L1216)

### `xmlrpc_wp_insert_post_data`

*Filters post data array to be inserted via XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_data` | `array` | Parsed array of post data.
`$content_struct` | `array` | Post data array.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1630](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1630-L1638)

### `xmlrpc_default_post_fields`

*Filters the list of post query fields used by the given XML-RPC method.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('post', 'terms', 'custom_fields')` |  | 
`'wp.getPost'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1859](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1859-L1867)

### `xmlrpc_default_post_fields`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('post', 'terms', 'custom_fields')` |  | 
`'wp.getPosts'` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 1927](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L1927-L1928)

### `xmlrpc_default_taxonomy_fields`

*Filters the taxonomy query fields used by the given XML-RPC method.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('labels', 'cap', 'object_type')` |  | 
`'wp.getTaxonomy'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2490](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2490-L2498)

### `xmlrpc_default_taxonomy_fields`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('labels', 'cap', 'object_type')` |  | 
`'wp.getTaxonomies'` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2555](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2555-L2556)

### `xmlrpc_default_user_fields`

*Filters the default user query fields used by the given XML-RPC method.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('all')` |  | 
`'wp.getUser'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2634](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2634-L2642)

### `xmlrpc_default_user_fields`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('all')` |  | 
`'wp.getUsers'` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2704](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2704-L2705)

### `xmlrpc_default_user_fields`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('all')` |  | 
`'wp.getProfile'` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 2784](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L2784-L2785)

### `xmlrpc_allow_anonymous_comments`

*Filters whether to allow anonymous comments over XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3841](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3841-L3849)

### `allow_empty_comment`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$comment` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 3940](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L3940-L3941)

### `xmlrpc_default_posttype_fields`

*Filters the default query fields used by the given XML-RPC method.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('labels', 'cap', 'taxonomies')` |  | 
`'wp.getPostType'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4486](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4486-L4494)

### `xmlrpc_default_posttype_fields`

*This action is documented in wp-includes/class-wp-xmlrpc-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('labels', 'cap', 'taxonomies')` |  | 
`'wp.getPostTypes'` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4550](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4550-L4551)

### `xmlrpc_default_revision_fields`

*Filters the default revision query fields used by the given XML-RPC method.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('post_date', 'post_date_gmt')` |  | 
`'wp.getRevisions'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 4613](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L4613-L4621)

### `pre_upload_error`

*Filters whether to preempt the XML-RPC media upload.*

Passing a truthy value will effectively short-circuit the media upload,
returning that value as a 500 error instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6356](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6356-L6366)

### `xmlrpc_text_filters`

*Filters the MoveableType text filters list for XML-RPC.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6666](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6666-L6673)

### `pingback_ping_source_uri`

*Filters the pingback source URI.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pagelinkedfrom` | `string` | URI of the page linked from.
`$pagelinkedto` | `string` | URI of the page linked to.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6797](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6797-L6805)

### `http_headers_useragent`

*This filter is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'WordPress/' . get_bloginfo('version') . '; ' . get_bloginfo('url')` |  | 
`$pagelinkedfrom` |  | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6883](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6883-L6884)

### `pre_remote_source`

*Filters the pingback remote source.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$remote_source` | `string` | Response source for the page linked from.
`$pagelinkedto` | `string` | URL of the page linked to.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 6905](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L6905-L6913)

### `xmlrpc_pingback_error`

*Filters the XML-RPC pingback error return.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`new IXR_Error($code, $message)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.1` | 

Source: [wordpress/wp-includes/class-wp-xmlrpc-server.php](../../wordpress/wp-includes/class-wp-xmlrpc-server.php), [line 7071](../../wordpress/wp-includes/class-wp-xmlrpc-server.php#L7071-L7078)

### `stylesheet`

*Filters the name of current stylesheet.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_option('stylesheet')` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 174](../../wordpress/wp-includes/theme.php#L174-L181)

### `stylesheet_directory`

*Filters the stylesheet directory path for current theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet_dir` | `string` | Absolute path to the current theme.
`$stylesheet` | `string` | Directory name of the current theme.
`$theme_root` | `string` | Absolute path to themes directory.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 196](../../wordpress/wp-includes/theme.php#L196-L205)

### `stylesheet_directory_uri`

*Filters the stylesheet directory URI.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet_dir_uri` | `string` | Stylesheet directory URI.
`$stylesheet` | `string` | Name of the activated theme's directory.
`$theme_root_uri` | `string` | Themes root URI.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 220](../../wordpress/wp-includes/theme.php#L220-L229)

### `stylesheet_uri`

*Filters the URI of the current theme stylesheet.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet_uri` | `string` | Stylesheet URI for the current theme/child theme.
`$stylesheet_dir_uri` | `string` | Stylesheet directory URI for the current theme/child theme.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 245](../../wordpress/wp-includes/theme.php#L245-L253)

### `locale_stylesheet_uri`

*Filters the localized stylesheet URI.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet_uri` | `string` | Localized stylesheet URI.
`$stylesheet_dir_uri` | `string` | Stylesheet directory URI.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 289](../../wordpress/wp-includes/theme.php#L289-L297)

### `template`

*Filters the name of the current theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_option('template')` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 308](../../wordpress/wp-includes/theme.php#L308-L315)

### `template_directory`

*Filters the current theme directory path.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$template_dir` | `string` | The path of the current theme directory.
`$template` | `string` | Directory name of the current theme.
`$theme_root` | `string` | Absolute path to the themes directory.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 330](../../wordpress/wp-includes/theme.php#L330-L339)

### `template_directory_uri`

*Filters the current theme directory URI.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$template_dir_uri` | `string` | The URI of the current theme directory.
`$template` | `string` | Directory name of the current theme.
`$theme_root_uri` | `string` | The themes root URI.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 354](../../wordpress/wp-includes/theme.php#L354-L363)

### `wp_cache_themes_persistently`

*Filters whether to get the cache of the registered theme directories.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`'search_theme_directories'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 467](../../wordpress/wp-includes/theme.php#L467-L475)

### `theme_root`

*Filters the absolute path to the themes directory.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$theme_root` | `string` | Absolute path to themes directory.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 602](../../wordpress/wp-includes/theme.php#L602-L609)

### `theme_root_uri`

*Filters the URI for themes directory.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$theme_root_uri` | `string` | The URI for themes directory.
`get_option('siteurl')` |  | 
`$stylesheet_or_template` | `string` | The stylesheet or template name of the theme.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 653](../../wordpress/wp-includes/theme.php#L653-L662)

### `validate_current_theme`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 856](../../wordpress/wp-includes/theme.php#L856-L856)

### `theme_mod_{$name}`

*Filters the theme modification, or 'theme_mod', value.*

The dynamic portion of the hook name, `$name`, refers to the key name
of the modification array. For example, 'header_textcolor', 'header_image',
and so on depending on the theme options.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mods[$name]` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1010](../../wordpress/wp-includes/theme.php#L1010-L1021)

### `theme_mod_{$name}`

*This filter is documented in wp-includes/theme.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` |  | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1033](../../wordpress/wp-includes/theme.php#L1033-L1034)

### `pre_set_theme_mod_{$name}`

*Filters the theme modification, or 'theme_mod', value on save.*

The dynamic portion of the hook name, `$name`, refers to the key name
of the modification array. For example, 'header_textcolor', 'header_image',
and so on depending on the theme options.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `string` | The new value of the theme modification.
`$old_value` | `string` | The current value of the theme modification.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1051](../../wordpress/wp-includes/theme.php#L1051-L1063)

### `get_header_image_tag`

*Filters the markup of header images.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | The HTML image tag markup being filtered.
`$header` | `object` | The custom header object returned by 'get_custom_header()'.
`$attr` | `array` | Array of the attributes for the image tag.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1241](../../wordpress/wp-includes/theme.php#L1241-L1250)

### `get_header_video_url`

*Filters the header video URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | Header video URL, if available.

**Changelog**

Version | Description
------- | -----------
`4.7.3` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1540](../../wordpress/wp-includes/theme.php#L1540-L1547)

### `header_video_settings`

*Filters header video settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$settings` | `array` | An array of header video settings.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1603](../../wordpress/wp-includes/theme.php#L1603-L1610)

### `is_header_video_active`

*Filters whether the custom header video is eligible to show on the current page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$show_video` | `bool` | Whether the custom header video should be shown. Returns the value<br>of the theme setting for the `custom-header`'s `video-active-callback`.<br>If no callback is set, the default value is that of `is_front_page()`.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1648](../../wordpress/wp-includes/theme.php#L1648-L1657)

### `wp_get_custom_css`

*Filters the Custom CSS Output into the <head>.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$css` | `string` | CSS pulled in from the Custom CSS CPT.
`$stylesheet` | `string` | The theme stylesheet name.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1910](../../wordpress/wp-includes/theme.php#L1910-L1918)

### `update_custom_css_data`

*Filters the `css` (`post_content`) and `preprocessed` (`post_content_filtered`) args for a `custom_css` post being updated.*

This filter can be used by plugin that offer CSS pre-processors, to store the original
pre-processed CSS in `post_content_filtered` and then store processed CSS in `post_content`.
When used in this way, the `post_content_filtered` should be supplied as the setting value
instead of `post_content` via a the `customize_value_custom_css` filter, for example:

<code>
add_filter( 'customize_value_custom_css', function( $value, $setting ) {
    $post = wp_get_custom_css_post( $setting->stylesheet );
    if ( $post && ! empty( $post->post_content_filtered ) ) {
        $css = $post->post_content_filtered;
    }
    return $css;
}, 10, 2 );
</code>

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | {<br>    Custom CSS data.<br><br>    @type string $css          CSS stored in `post_content`.<br>    @type string $preprocessed Pre-processed CSS stored in `post_content_filtered`. Normally empty string.<br>}
`array_merge($args, compact('css'))` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 1953](../../wordpress/wp-includes/theme.php#L1953-L1986)

### `editor_stylesheets`

*Filters the array of URLs of stylesheets applied to the editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheets` | `string[]` | Array of URLs of stylesheets to be applied to the editor.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 2127](../../wordpress/wp-includes/theme.php#L2127-L2134)

### `get_theme_starter_content`

*Filters the expanded array of starter content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `array` | Array of starter content.
`$config` | `array` | Array of theme-specific starter content configuration.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 2443](../../wordpress/wp-includes/theme.php#L2443-L2451)

### `current_theme_supports-{$feature}`

*Filters whether the current theme supports a specific feature.*

The dynamic portion of the hook name, `$feature`, refers to the specific
theme feature. See add_theme_support() for the list of possible values.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$args` | `array` | Array of arguments for the feature.
`$_wp_theme_features[$feature]` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/theme.php](../../wordpress/wp-includes/theme.php), [line 3016](../../wordpress/wp-includes/theme.php#L3016-L3028)

### `wp_feed_cache_transient_lifetime`

*Filters the transient lifetime of the feed cache.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$lifetime` | `int` | Cache duration in seconds. Default is 43200 seconds (12 hours).
`$filename` | `string` | Unique identifier for the cache object.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-feed-cache-transient.php](../../wordpress/wp-includes/class-wp-feed-cache-transient.php), [line 58](../../wordpress/wp-includes/class-wp-feed-cache-transient.php#L58-L66)

### `wp_cache_themes_persistently`

*This action is documented in wp-includes/theme.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`'WP_Theme'` |  | 

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 194](../../wordpress/wp-includes/class-wp-theme.php#L194-L195)

### `theme_templates`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_templates` |  | 
`$this` |  | 
`$post` |  | 
`$post_type` |  | 

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 1265](../../wordpress/wp-includes/class-wp-theme.php#L1265-L1265)

### `theme_{$post_type}_templates`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_templates` |  | 
`$this` |  | 
`$post` |  | 
`$post_type` |  | 

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 1281](../../wordpress/wp-includes/class-wp-theme.php#L1281-L1281)

### `theme_scandir_exclusions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('CVS', 'node_modules', 'vendor', 'bower_components')` |  | 

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 1327](../../wordpress/wp-includes/class-wp-theme.php#L1327-L1327)

### `network_allowed_themes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::get_allowed_on_network()` |  | 
`$blog_id` |  | 

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 1457](../../wordpress/wp-includes/class-wp-theme.php#L1457-L1457)

### `allowed_themes`

*Filters the array of themes allowed on the network.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_themes` | `string[]` | An array of theme stylesheet names.

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 1474](../../wordpress/wp-includes/class-wp-theme.php#L1474-L1481)

### `site_allowed_themes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_themes[$blog_id]` |  | 
`$blog_id` |  | 

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 1510](../../wordpress/wp-includes/class-wp-theme.php#L1510-L1510)

### `site_allowed_themes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_themes[$blog_id]` |  | 
`$blog_id` |  | 

Source: [wordpress/wp-includes/class-wp-theme.php](../../wordpress/wp-includes/class-wp-theme.php), [line 1561](../../wordpress/wp-includes/class-wp-theme.php#L1561-L1561)

### `incompatible_sql_modes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->incompatible_modes` |  | 

Source: [wordpress/wp-includes/wp-db.php](../../wordpress/wp-includes/wp-db.php), [line 864](../../wordpress/wp-includes/wp-db.php#L864-L864)

### `query`

*Filters the database query.*

Some queries are made before the plugins have been loaded,
and thus cannot be filtered with this method.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query` | `string` | Database query.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/wp-db.php](../../wordpress/wp-includes/wp-db.php), [line 1906](../../wordpress/wp-includes/wp-db.php#L1906-L1916)

### `log_query_custom_data`

*Filters the custom data to log alongside a query.*

Caution should be used when modifying any of this data, it is recommended that any additional
information you need to store about a query be added as a new associative array element.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_data` | `array` | Custom query data.
`$query` | `string` | The query's SQL.
`$query_time` | `float` | Total time spent on the query, in seconds.
`$query_callstack` | `string` | Comma-separated list of the calling functions.
`$query_start` | `float` | Unix timestamp of the time at the start of the query.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/wp-db.php](../../wordpress/wp-includes/wp-db.php), [line 2085](../../wordpress/wp-includes/wp-db.php#L2085-L2099)

### `pre_get_table_charset`

*Filters the table charset value before the DB is checked.*

Passing a non-null value to the filter will effectively short-circuit
checking the DB for the charset, returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$table` | `string` | The name of the table being checked.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/wp-db.php](../../wordpress/wp-includes/wp-db.php), [line 2749](../../wordpress/wp-includes/wp-db.php#L2749-L2760)

### `pre_get_col_charset`

*Filters the column charset value before the DB is checked.*

Passing a non-null value to the filter will short-circuit
checking the DB for the charset, returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$table` | `string` | The name of the table being checked.
`$column` | `string` | The name of the column being checked.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/wp-db.php](../../wordpress/wp-includes/wp-db.php), [line 2853](../../wordpress/wp-includes/wp-db.php#L2853-L2865)

### `secure_signon_cookie`

*Filters whether to use a secure sign-on cookie.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$secure_cookie` | `bool` | Whether to use a secure sign-on cookie.
`$credentials` | `array` | {<br>    Array of entered sign-on data.<br><br>    @type string $user_login    Username.<br>    @type string $user_password Password entered.<br>    @type bool   $remember      Whether to 'remember' the user. Increases the time<br>                                that the cookie will be kept. Default false.<br>}

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 73](../../wordpress/wp-includes/user.php#L73-L88)

### `wp_authenticate_user`

*Filters whether the given user can be authenticated with the provided $password.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` | `\WP_User\|\WP_Error` | WP_User or WP_Error object if a previous<br>callback failed authentication.
`$password` | `string` | Password to check against the user.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 156](../../wordpress/wp-includes/user.php#L156-L165)

### `wp_authenticate_user`

*This filter is documented in wp-includes/user.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user` |  | 
`$password` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 235](../../wordpress/wp-includes/user.php#L235-L236)

### `application_password_is_api_request`

*Filters whether this is an API request that Application Passwords can be used on.*

By default, Application Passwords is available for the REST API and XML-RPC.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_api_request` | `bool` | If this is an acceptable API request.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 323](../../wordpress/wp-includes/user.php#L323-L332)

### `check_is_user_spammed`

*Filters whether the user has been marked as a spammer.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`is_user_spammy($user)` |  | 
`$user` | `\WP_User` | User to check against.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 491](../../wordpress/wp-includes/user.php#L491-L499)

### `get_usernumposts`

*Filters the number of posts a user has written.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$count` | `int` | The user's post count.
`$userid` | `int` | User ID.
`$post_type` | `string\|array` | Single post type or array of post types to count the number of posts for.
`$public_only` | `bool` | Whether to limit counted posts to public posts.

**Changelog**

Version | Description
------- | -----------
`4.3.1` | Added `$public_only` argument.
`4.1.0` | Added `$post_type` argument.
`2.7.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 557](../../wordpress/wp-includes/user.php#L557-L569)

### `get_user_option_{$option}`

*Filters a specific user option value.*

The dynamic portion of the hook name, `$option`, refers to the user option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `mixed` | Value for the user's option.
`$option` | `string` | Name of the option being retrieved.
`$user` | `\WP_User` | WP_User object of the user whose option is being retrieved.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 672](../../wordpress/wp-includes/user.php#L672-L683)

### `pre_get_blogs_of_user`

*Filters the list of a user's sites before it is populated.*

Returning a non-null value from the filter will effectively short circuit
get_blogs_of_user(), returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$user_id` | `int` | User ID.
`$all` | `bool` | Whether the returned array should contain all sites, including<br>those marked 'deleted', 'archived', or 'spam'. Default false.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 788](../../wordpress/wp-includes/user.php#L788-L801)

### `get_blogs_of_user`

*Filters the list of sites a user belongs to.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sites` | `object[]` | An array of site objects belonging to the user.
`$user_id` | `int` | User ID.
`$all` | `bool` | Whether the returned sites array should contain all sites, including<br>those marked 'deleted', 'archived', or 'spam'. Default false.

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 883](../../wordpress/wp-includes/user.php#L883-L893)

### `pre_count_users`

*Filters the user count before queries are run.*

Return a non-null value to cause count_users() to return early.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$strategy` | `string` | Optional. The computational strategy to use when counting the users.<br>Accepts either 'time' or 'memory'. Default 'time'.
`$site_id` | `int\|null` | Optional. The site ID to count users for. Defaults to the current site.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1078](../../wordpress/wp-includes/user.php#L1078-L1090)

### `wp_dropdown_users_args`

*Filters the query arguments for the list of users in the dropdown.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_args` | `array` | The query arguments for get_users().
`$parsed_args` | `array` | The arguments passed to wp_dropdown_users() combined with the defaults.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1340](../../wordpress/wp-includes/user.php#L1340-L1348)

### `wp_dropdown_users`

*Filters the wp_dropdown_users() HTML output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | HTML output generated by wp_dropdown_users().

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1407](../../wordpress/wp-includes/user.php#L1407-L1414)

### `edit_{$field}`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$user_id` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1457](../../wordpress/wp-includes/user.php#L1457-L1458)

### `edit_user_{$field}`

*Filters a user field value in the 'edit' context.*

The dynamic portion of the hook name, `$field`, refers to the prefixed user
field being filtered, such as 'user_login', 'user_email', 'first_name', etc.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the prefixed user field.
`$user_id` | `int` | User ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1461](../../wordpress/wp-includes/user.php#L1461-L1472)

### `pre_{$field}`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1482](../../wordpress/wp-includes/user.php#L1482-L1483)

### `pre_user_{$field}`

*Filters the value of a user field in the 'db' context.*

The dynamic portion of the hook name, `$field`, refers to the prefixed user
field being filtered, such as 'user_login', 'user_email', 'first_name', etc.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | Value of the prefixed user field.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1486](../../wordpress/wp-includes/user.php#L1486-L1496)

### `{$field}`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$user_id` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1502](../../wordpress/wp-includes/user.php#L1502-L1503)

### `user_{$field}`

*Filters the value of a user field in a standard context.*

The dynamic portion of the hook name, `$field`, refers to the prefixed user
field being filtered, such as 'user_login', 'user_email', 'first_name', etc.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | The user object value to sanitize.
`$user_id` | `int` | User ID.
`$context` | `string` | The context to filter within.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1506](../../wordpress/wp-includes/user.php#L1506-L1518)

### `username_exists`

*Filters whether the given username exists.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int\|false` | The user ID associated with the username,<br>or false if the username does not exist.
`$username` | `string` | The username to check for existence.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1610](../../wordpress/wp-includes/user.php#L1610-L1619)

### `email_exists`

*Filters whether the given email exists.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_id` | `int\|false` | The user ID associated with the email,<br>or false if the email does not exist.
`$email` | `string` | The email to check for existence.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1642](../../wordpress/wp-includes/user.php#L1642-L1651)

### `validate_username`

*Filters whether the provided username is valid.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$valid` | `bool` | Whether given username is valid.
`$username` | `string` | Username to check.

**Changelog**

Version | Description
------- | -----------
`2.0.1` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1667](../../wordpress/wp-includes/user.php#L1667-L1675)

### `pre_user_login`

*Filters a username after it has been sanitized.*

This filter is called before the user is created or updated.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sanitized_user_login` | `string` | Username after it has been sanitized.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1770](../../wordpress/wp-includes/user.php#L1770-L1779)

### `illegal_user_logins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1802](../../wordpress/wp-includes/user.php#L1802-L1802)

### `pre_user_nicename`

*Filters a user's nicename before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_nicename` | `string` | The user's nicename.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1823](../../wordpress/wp-includes/user.php#L1823-L1830)

### `pre_user_email`

*Filters a user's email before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$raw_user_email` | `string` | The user's email.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1848](../../wordpress/wp-includes/user.php#L1848-L1855)

### `pre_user_url`

*Filters a user's URL before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$raw_user_url` | `string` | The user's URL.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1871](../../wordpress/wp-includes/user.php#L1871-L1878)

### `pre_user_nickname`

*Filters a user's nickname before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nickname` | `string` | The user's nickname.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1895](../../wordpress/wp-includes/user.php#L1895-L1902)

### `pre_user_first_name`

*Filters a user's first name before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$first_name` | `string` | The user's first name.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1906](../../wordpress/wp-includes/user.php#L1906-L1913)

### `pre_user_last_name`

*Filters a user's last name before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$last_name` | `string` | The user's last name.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1917](../../wordpress/wp-includes/user.php#L1917-L1924)

### `pre_user_display_name`

*Filters a user's display name before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$display_name` | `string` | The user's display name.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1943](../../wordpress/wp-includes/user.php#L1943-L1950)

### `pre_user_description`

*Filters a user's description before the user is created or updated.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$description` | `string` | The user's description.

**Changelog**

Version | Description
------- | -----------
`2.0.3` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1954](../../wordpress/wp-includes/user.php#L1954-L1961)

### `wp_pre_insert_user_data`

*Filters user data before the record is created or updated.*

It only includes data in the users table, not any user metadata.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | {<br>    Values and keys for the user.<br><br>    @type string $user_login      The user's login. Only included if $update == false<br>    @type string $user_pass       The user's password.<br>    @type string $user_email      The user's email.<br>    @type string $user_url        The user's url.<br>    @type string $user_nicename   The user's nice name. Defaults to a URL-safe version of user's login<br>    @type string $display_name    The user's display name.<br>    @type string $user_registered MySQL timestamp describing the moment when the user registered. Defaults to<br>                                  the current UTC timestamp.<br>}
`$update` | `bool` | Whether the user is being updated rather than created.
`$update ? (int) $ID : null` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 1989](../../wordpress/wp-includes/user.php#L1989-L2011)

### `insert_user_meta`

*Filters a user's meta values and keys immediately after the user is created or updated
and before any user meta is inserted or updated.*

Does not include contact methods. These are added using `wp_get_user_contact_methods( $user )`.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta` | `array` | {<br>    Default meta values and keys for the user.<br><br>    @type string   $nickname             The user's nickname. Default is the user's username.<br>    @type string   $first_name           The user's first name.<br>    @type string   $last_name            The user's last name.<br>    @type string   $description          The user's description.<br>    @type string   $rich_editing         Whether to enable the rich-editor for the user. Default 'true'.<br>    @type string   $syntax_highlighting  Whether to enable the rich code editor for the user. Default 'true'.<br>    @type string   $comment_shortcuts    Whether to enable keyboard shortcuts for the user. Default 'false'.<br>    @type string   $admin_color          The color scheme for a user's admin screen. Default 'fresh'.<br>    @type int\|bool $use_ssl              Whether to force SSL on the user's admin area. 0\|false if SSL<br>                                         is not forced.<br>    @type string   $show_admin_bar_front Whether to show the admin bar on the front end for the user.<br>                                         Default 'true'.<br>    @type string   $locale               User's locale. Default empty.<br>}
`$user` | `\WP_User` | User object.
`$update` | `bool` | Whether the user is being updated rather than created.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2030](../../wordpress/wp-includes/user.php#L2030-L2058)

### `send_password_change_email`

*Filters whether to send the password change email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$user` | `array` | The original user array.
`$userdata` | `array` | The updated user array.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2174](../../wordpress/wp-includes/user.php#L2174-L2185)

### `send_email_change_email`

*Filters whether to send the email change email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$user` | `array` | The original user array.
`$userdata` | `array` | The updated user array.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2189](../../wordpress/wp-includes/user.php#L2189-L2200)

### `password_change_email`

*Filters the contents of the email sent when the user's password is changed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pass_change_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The intended recipients. Add emails in a comma separated string.<br>    @type string $subject The subject of the email.<br>    @type string $message The content of the email.<br>        The following strings have a special meaning and will get replaced dynamically:<br>        - ###USERNAME###    The current user's username.<br>        - ###ADMIN_EMAIL### The admin email in case this was unexpected.<br>        - ###EMAIL###       The user's email address.<br>        - ###SITENAME###    The name of the site.<br>        - ###SITEURL###     The URL to the site.<br>    @type string $headers Headers. Add headers in a newline (\r\n) separated string.<br>}
`$user` | `array` | The original user array.
`$userdata` | `array` | The updated user array.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2243](../../wordpress/wp-includes/user.php#L2243-L2265)

### `email_change_email`

*Filters the contents of the email sent when the user's email is changed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_change_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The intended recipients.<br>    @type string $subject The subject of the email.<br>    @type string $message The content of the email.<br>        The following strings have a special meaning and will get replaced dynamically:<br>        - ###USERNAME###    The current user's username.<br>        - ###ADMIN_EMAIL### The admin email in case this was unexpected.<br>        - ###NEW_EMAIL###   The new email address.<br>        - ###EMAIL###       The old email address.<br>        - ###SITENAME###    The name of the site.<br>        - ###SITEURL###     The URL to the site.<br>    @type string $headers Headers.<br>}
`$user` | `array` | The original user array.
`$userdata` | `array` | The updated user array.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2301](../../wordpress/wp-includes/user.php#L2301-L2324)

### `auth_cookie_expiration`

*This filter is documented in wp-includes/pluggable.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`2 * DAY_IN_SECONDS` |  | 
`$ID` |  | 
`false` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2350](../../wordpress/wp-includes/user.php#L2350-L2351)

### `user_contactmethods`

*Filters the user contact methods.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$methods` | `string[]` | Array of contact method labels keyed by contact method.
`$user` | `\WP_User` | WP_User object.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2426](../../wordpress/wp-includes/user.php#L2426-L2434)

### `password_hint`

*Filters the text describing the site's password complexity policy.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$hint` | `string` | The password hint text.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2462](../../wordpress/wp-includes/user.php#L2462-L2469)

### `allow_password_reset`

*Filters whether to allow a password to be reset.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allow` | `bool` | Whether to allow the password to be reset. Default true.
`$user->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2515](../../wordpress/wp-includes/user.php#L2515-L2523)

### `password_reset_expiration`

*Filters the expiration time of password reset keys.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`DAY_IN_SECONDS` |  | 

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2607](../../wordpress/wp-includes/user.php#L2607-L2614)

### `password_reset_key_expired`

*Filters the return value of check_password_reset_key() when an
old-style key is used.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `\WP_Error` | A WP_Error object denoting an expired key.<br>Return a WP_User object to validate the key.
`$user_id` | `int` | The matched user ID.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | Previously key hashes were stored without an expiration time.
`3.7.0` | Previously plain-text keys were stored in the database.

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2641](../../wordpress/wp-includes/user.php#L2641-L2652)

### `lostpassword_user_data`

*Filters the user data during a password reset request.*

Allows, for example, custom validation using data other than username or email address.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_data` | `\WP_User\|false` | WP_User object if found, false if the user does not exist.
`$errors` | `\WP_Error` | A WP_Error object containing any errors generated<br>by using invalid credentials.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2691](../../wordpress/wp-includes/user.php#L2691-L2702)

### `lostpassword_errors`

*Filters the errors encountered on a password reset request.*

The filtered WP_Error object may, for example, contain errors for an invalid
username or email address. A WP_Error object should always be returned,
but may or may not contain errors.

If any errors are present in $errors, this will abort the password reset request.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | A WP_Error object containing any errors generated<br>by using invalid credentials.
`$user_data` | `\WP_User\|false` | WP_User object if found, false if the user does not exist.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2717](../../wordpress/wp-includes/user.php#L2717-L2732)

### `retrieve_password_title`

*Filters the subject of the password reset email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | Email subject.
`$user_login` | `string` | The username for the user.
`$user_data` | `\WP_User` | WP_User object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added the `$user_login` and `$user_data` parameters.
`2.8.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2790](../../wordpress/wp-includes/user.php#L2790-L2800)

### `retrieve_password_message`

*Filters the message body of the password reset mail.*

If the filtered message is empty, the password reset email will not be sent.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message` | `string` | Email message.
`$key` | `string` | The activation key.
`$user_login` | `string` | The username for the user.
`$user_data` | `\WP_User` | WP_User object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | Added `$user_login` and `$user_data` parameters.
`2.8.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2802](../../wordpress/wp-includes/user.php#L2802-L2815)

### `user_registration_email`

*Filters the email address of a user being registered.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$user_email` | `string` | The email address of the new user.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2882](../../wordpress/wp-includes/user.php#L2882-L2889)

### `illegal_user_logins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2902](../../wordpress/wp-includes/user.php#L2902-L2902)

### `registration_errors`

*Filters the errors encountered when a new user is being registered.*

The filtered WP_Error object may, for example, contain errors for an invalid
or existing username or email address. A WP_Error object should always be returned,
but may or may not contain errors.

If any errors are present in $errors, this will abort the user's registration.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | A WP_Error object containing any errors encountered<br>during registration.
`$sanitized_user_login` | `string` | User's username after it has been sanitized.
`$user_email` | `string` | User's email.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 2931](../../wordpress/wp-includes/user.php#L2931-L2947)

### `determine_current_user`

*Filters the current user.*

The default filters use this to determine the current user from the
request's cookies, if available.

Returning a value of false will effectively short-circuit setting
the current user.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3148](../../wordpress/wp-includes/user.php#L3148-L3161)

### `new_user_email_content`

*Filters the text of the email sent when a change of user email address is attempted.*

The following strings have a special meaning and will get replaced dynamically:
- ###USERNAME###  The current user's username.
- ###ADMIN_URL### The link to click on to confirm the email change.
- ###EMAIL###     The new email.
- ###SITENAME###  The name of the site.
- ###SITEURL###   The URL to the site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_text` | `string` | Text in the email.
`$new_user_email` | `array` | {<br>    Data relating to the new user email address.<br><br>    @type string $hash     The secure hash used in the confirmation link URL.<br>    @type string $newemail The proposed new email address.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.0` | This filter is no longer Multisite specific.

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3246](../../wordpress/wp-includes/user.php#L3246-L3267)

### `wp_privacy_additional_user_profile_data`

*Filter to extend the user's profile data for the privacy exporter.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$user` | `\WP_User` | The user whose data is being exported.
`$reserved_names` | `string[]` | An array of reserved names. Any item in `$additional_user_data`<br>that uses one of these for its `name` will not be included in the export.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3409](../../wordpress/wp-includes/user.php#L3409-L3424)

### `user_request_confirmed_email_to`

*Filters the recipient of the data request confirmation notification.*

In a Multisite environment, this will default to the email address of the
network admin because, by default, single site admins do not have the
capabilities required to process requests. Some networks may wish to
delegate those capabilities to a single-site admin, or a dedicated person
responsible for managing privacy requests.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_site_option('admin_email')` |  | 
`$request` | `\WP_User_Request` | The request that is initiating the notification.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3591](../../wordpress/wp-includes/user.php#L3591-L3605)

### `user_confirmed_action_email_content`

*Filters the body of the user request confirmation email.*

The email is sent to an administrator when an user request is confirmed.
The following strings have a special meaning and will get replaced dynamically:

###SITENAME###    The name of the site.
###USER_EMAIL###  The user email for the request.
###DESCRIPTION### Description of the action being performed so the user knows what the email is for.
###MANAGE_URL###  The URL to manage requests.
###SITEURL###     The URL to the site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_text` | `string` | Text in the email.
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request     User request object.<br>    @type string          $user_email  The email address confirming a request<br>    @type string          $description Description of the action being performed so the user knows what the email is for.<br>    @type string          $manage_url  The link to click manage privacy requests of this type.<br>    @type string          $sitename    The site name sending the mail.<br>    @type string          $siteurl     The site URL sending the mail.<br>    @type string          $admin_email The administrator email receiving the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3635](../../wordpress/wp-includes/user.php#L3635-L3662)

### `user_request_confirmed_email_subject`

*Filters the subject of the user request confirmation email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$subject` | `string` | The email subject.
`$email_data['sitename']` |  | 
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request     User request object.<br>    @type string          $user_email  The email address confirming a request<br>    @type string          $description Description of the action being performed so the user knows what the email is for.<br>    @type string          $manage_url  The link to click manage privacy requests of this type.<br>    @type string          $sitename    The site name sending the mail.<br>    @type string          $siteurl     The site URL sending the mail.<br>    @type string          $admin_email The administrator email receiving the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.8` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3677](../../wordpress/wp-includes/user.php#L3677-L3696)

### `user_request_confirmed_email_headers`

*Filters the headers of the user request confirmation email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$headers` | `string\|array` | The email headers.
`$subject` | `string` | The email subject.
`$content` | `string` | The email content.
`$request_id` | `int` | The request ID.
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request     User request object.<br>    @type string          $user_email  The email address confirming a request<br>    @type string          $description Description of the action being performed so the user knows what the email is for.<br>    @type string          $manage_url  The link to click manage privacy requests of this type.<br>    @type string          $sitename    The site name sending the mail.<br>    @type string          $siteurl     The site URL sending the mail.<br>    @type string          $admin_email The administrator email receiving the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3700](../../wordpress/wp-includes/user.php#L3700-L3721)

### `user_erasure_fulfillment_email_to`

*Filters the recipient of the data erasure fulfillment notification.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$request->email` |  | 
`$request` | `\WP_User_Request` | The request that is initiating the notification.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3761](../../wordpress/wp-includes/user.php#L3761-L3769)

### `user_erasure_complete_email_subject`

*Filters the subject of the email sent when an erasure request is completed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$subject` | `string` | The email subject.
`$email_data['sitename']` |  | 
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request            User request object.<br>    @type string          $message_recipient  The address that the email will be sent to. Defaults<br>                                              to the value of `$request->email`, but can be changed<br>                                              by the `user_erasure_fulfillment_email_to` filter.<br>    @type string          $privacy_policy_url Privacy policy URL.<br>    @type string          $sitename           The site name sending the mail.<br>    @type string          $siteurl            The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.8` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3785](../../wordpress/wp-includes/user.php#L3785-L3804)

### `user_confirmed_action_email_content`

*Filters the body of the data erasure fulfillment notification.*

The email is sent to a user when a their data erasure request is fulfilled
by an administrator.

The following strings have a special meaning and will get replaced dynamically:

###SITENAME###           The name of the site.
###PRIVACY_POLICY_URL### Privacy policy page URL.
###SITEURL###            The URL to the site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_text` | `string` | Text in the email.
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request            User request object.<br>    @type string          $message_recipient  The address that the email will be sent to. Defaults<br>                                              to the value of `$request->email`, but can be changed<br>                                              by the `user_erasure_fulfillment_email_to` filter.<br>    @type string          $privacy_policy_url Privacy policy URL.<br>    @type string          $sitename           The site name sending the mail.<br>    @type string          $siteurl            The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3836](../../wordpress/wp-includes/user.php#L3836-L3863)

### `user_erasure_complete_email_headers`

*Filters the headers of the data erasure fulfillment notification.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$headers` | `string\|array` | The email headers.
`$subject` | `string` | The email subject.
`$content` | `string` | The email content.
`$request_id` | `int` | The request ID.
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request            User request object.<br>    @type string          $message_recipient  The address that the email will be sent to. Defaults<br>                                              to the value of `$request->email`, but can be changed<br>                                              by the `user_erasure_fulfillment_email_to` filter.<br>    @type string          $privacy_policy_url Privacy policy URL.<br>    @type string          $sitename           The site name sending the mail.<br>    @type string          $siteurl            The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3871](../../wordpress/wp-includes/user.php#L3871-L3892)

### `user_request_action_confirmed_message`

*Filters the message displayed to a user when they confirm a data request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message` | `string` | The message to the user.
`$request_id` | `int` | The ID of the request being confirmed.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 3930](../../wordpress/wp-includes/user.php#L3930-L3938)

### `user_request_action_description`

*Filters the user action description.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$description` | `string` | The default description.
`$action_name` | `string` | The name of the request.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 4036](../../wordpress/wp-includes/user.php#L4036-L4044)

### `user_request_action_email_content`

*Filters the text of the email sent when an account action is attempted.*

The following strings have a special meaning and will get replaced dynamically:

###DESCRIPTION### Description of the action being performed so the user knows what the email is for.
###CONFIRM_URL### The link to click on to confirm the account action.
###SITENAME###    The name of the site.
###SITEURL###     The URL to the site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email_text` | `string` | Text in the email.
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request     User request object.<br>    @type string          $email       The email address this is being sent to.<br>    @type string          $description Description of the action being performed so the user knows what the email is for.<br>    @type string          $confirm_url The link to click on to confirm the account action.<br>    @type string          $sitename    The site name sending the mail.<br>    @type string          $siteurl     The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 4109](../../wordpress/wp-includes/user.php#L4109-L4133)

### `user_request_action_email_subject`

*Filters the subject of the email sent when an account action is attempted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$subject` | `string` | The email subject.
`$email_data['sitename']` |  | 
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request     User request object.<br>    @type string          $email       The email address this is being sent to.<br>    @type string          $description Description of the action being performed so the user knows what the email is for.<br>    @type string          $confirm_url The link to click on to confirm the account action.<br>    @type string          $sitename    The site name sending the mail.<br>    @type string          $siteurl     The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 4144](../../wordpress/wp-includes/user.php#L4144-L4162)

### `user_request_action_email_headers`

*Filters the headers of the email sent when an account action is attempted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$headers` | `string\|array` | The email headers.
`$subject` | `string` | The email subject.
`$content` | `string` | The email content.
`$request_id` | `int` | The request ID.
`$email_data` | `array` | {<br>    Data relating to the account action email.<br><br>    @type WP_User_Request $request     User request object.<br>    @type string          $email       The email address this is being sent to.<br>    @type string          $description Description of the action being performed so the user knows what the email is for.<br>    @type string          $confirm_url The link to click on to confirm the account action.<br>    @type string          $sitename    The site name sending the mail.<br>    @type string          $siteurl     The site URL sending the mail.<br>}

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 4166](../../wordpress/wp-includes/user.php#L4166-L4186)

### `user_request_key_expiration`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`DAY_IN_SECONDS` |  | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 4273](../../wordpress/wp-includes/user.php#L4273-L4273)

### `wp_is_application_passwords_available`

*Filters whether Application Passwords is available.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$available` | `bool` | True if available, false otherwise.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 4319](../../wordpress/wp-includes/user.php#L4319-L4326)

### `wp_is_application_passwords_available_for_user`

*Filters whether Application Passwords is available for a specific user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$user` | `\WP_User` | The user to check.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/user.php](../../wordpress/wp-includes/user.php), [line 4353](../../wordpress/wp-includes/user.php#L4353-L4361)

### `http_origin`

*Change the origin of an HTTP request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$origin` | `string` | The original origin for the request.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/http.php](../../wordpress/wp-includes/http.php), [line 397](../../wordpress/wp-includes/http.php#L397-L404)

### `allowed_http_origins`

*Change the origin types allowed for HTTP requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed_origins` | `string[]` | {<br>    Array of default allowed HTTP origins.<br><br>    @type string $0 Non-secure URL for admin origin.<br>    @type string $1 Secure URL for admin origin.<br>    @type string $2 Non-secure URL for home origin.<br>    @type string $3 Secure URL for home origin.<br>}

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/http.php](../../wordpress/wp-includes/http.php), [line 428](../../wordpress/wp-includes/http.php#L428-L442)

### `allowed_http_origin`

*Change the allowed HTTP origin result.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$origin` | `string` | Origin URL if allowed, empty string if not.
`$origin_arg` | `string` | Original origin string passed into is_allowed_http_origin function.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/http.php](../../wordpress/wp-includes/http.php), [line 464](../../wordpress/wp-includes/http.php#L464-L472)

### `http_request_host_is_external`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$host` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/http.php](../../wordpress/wp-includes/http.php), [line 572](../../wordpress/wp-includes/http.php#L572-L572)

### `add_{$meta_type}_metadata`

*Short-circuits adding metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$meta_value` | `mixed` | Metadata value. Must be serializable if non-scalar.
`$unique` | `bool` | Whether the specified meta key should be unique for the object.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 56](../../wordpress/wp-includes/meta.php#L56-L71)

### `update_{$meta_type}_metadata`

*Short-circuits updating metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$meta_value` | `mixed` | Metadata value. Must be serializable if non-scalar.
`$prev_value` | `mixed` | Optional. Previous value to check before updating.<br>If specified, only update existing metadata entries with<br>this value. Otherwise, update all entries.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 188](../../wordpress/wp-includes/meta.php#L188-L205)

### `delete_{$meta_type}_metadata`

*Short-circuits deleting metadata of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$meta_value` | `mixed` | Metadata value. Must be serializable if non-scalar.
`$delete_all` | `bool` | Whether to delete the matching metadata entries<br>for all objects, ignoring the specified $object_id.<br>Default false.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 359](../../wordpress/wp-includes/meta.php#L359-L376)

### `get_{$meta_type}_metadata`

*Short-circuits the return value of a meta field.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

Possible filter names include:

 - `get_post_metadata`
 - `get_comment_metadata`
 - `get_term_metadata`
 - `get_user_metadata`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$single` | `bool` | Whether to return only the first value of the specified `$meta_key`.
`$meta_type` | `string` | Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',<br>or any other object type with an associated meta table.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$meta_type` parameter.
`3.1.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 539](../../wordpress/wp-includes/meta.php#L539-L564)

### `default_{$meta_type}_metadata`

*Filters the default metadata value for a specified meta key and object.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

Possible filter names include:

 - `default_post_metadata`
 - `default_comment_metadata`
 - `default_term_metadata`
 - `default_user_metadata`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `mixed` | The value to return, either a single metadata value or an array<br>of values depending on the value of `$single`.
`$object_id` | `int` | ID of the object metadata is for.
`$meta_key` | `string` | Metadata key.
`$single` | `bool` | Whether to return only the first value of the specified `$meta_key`.
`$meta_type` | `string` | Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',<br>or any other object type with an associated meta table.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 622](../../wordpress/wp-includes/meta.php#L622-L645)

### `get_{$meta_type}_metadata`

*This filter is documented in wp-includes/meta.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$object_id` |  | 
`$meta_key` |  | 
`true` |  | 
`$meta_type` |  | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 675](../../wordpress/wp-includes/meta.php#L675-L676)

### `get_{$meta_type}_metadata_by_mid`

*Short-circuits the return value when fetching a meta field by meta ID.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$meta_id` | `int` | Meta ID.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 735](../../wordpress/wp-includes/meta.php#L735-L747)

### `update_{$meta_type}_metadata_by_mid`

*Short-circuits updating metadata of a specific type by meta ID.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$meta_id` | `int` | Meta ID.
`$meta_value` | `mixed` | Meta value. Must be serializable if non-scalar.
`$meta_key` | `string\|false` | Meta key, if provided.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 802](../../wordpress/wp-includes/meta.php#L802-L816)

### `delete_{$meta_type}_metadata_by_mid`

*Short-circuits deleting metadata of a specific type by meta ID.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$meta_id` | `int` | Meta ID.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 918](../../wordpress/wp-includes/meta.php#L918-L930)

### `update_{$meta_type}_metadata_cache`

*Short-circuits updating the metadata cache of a specific type.*

The dynamic portion of the hook, `$meta_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).
Returning a non-null value will effectively short-circuit the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$object_ids` | `int[]` | Array of object IDs to update the meta cache for.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 1023](../../wordpress/wp-includes/meta.php#L1023-L1035)

### `is_protected_meta`

*Filters whether a meta key is considered protected.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$protected` | `bool` | Whether the key is considered protected.
`$meta_key` | `string` | Metadata key.
`$meta_type` | `string` | Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',<br>or any other object type with an associated meta table.

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 1165](../../wordpress/wp-includes/meta.php#L1165-L1175)

### `sanitize_{$object_type}_meta_{$meta_key}_for_{$object_subtype}`

*Filters the sanitization of a specific meta key of a specific meta type and subtype.*

The dynamic portions of the hook name, `$object_type`, `$meta_key`,
and `$object_subtype`, refer to the metadata object type (comment, post, term, or user),
the meta key value, and the object subtype respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_value` | `mixed` | Metadata value to sanitize.
`$meta_key` | `string` | Metadata key.
`$object_type` | `string` | Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',<br>or any other object type with an associated meta table.
`$object_subtype` | `string` | Object subtype.

**Changelog**

Version | Description
------- | -----------
`4.9.8` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 1194](../../wordpress/wp-includes/meta.php#L1194-L1209)

### `sanitize_{$object_type}_meta_{$meta_key}`

*Filters the sanitization of a specific meta key of a specific meta type.*

The dynamic portions of the hook name, `$meta_type`, and `$meta_key`,
refer to the metadata object type (comment, post, term, or user) and the meta
key value, respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_value` | `mixed` | Metadata value to sanitize.
`$meta_key` | `string` | Metadata key.
`$object_type` | `string` | Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',<br>or any other object type with an associated meta table.

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 1212](../../wordpress/wp-includes/meta.php#L1212-L1226)

### `register_meta_args`

*Filters the registration arguments when registering meta.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of meta registration arguments.
`$defaults` | `array` | Array of default arguments.
`$object_type` | `string` | Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',<br>or any other object type with an associated meta table.
`$meta_key` | `string` | Meta key.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 1314](../../wordpress/wp-includes/meta.php#L1314-L1325)

### `get_object_subtype_{$object_type}`

*Filters the object subtype identifier for a non-standard object type.*

The dynamic portion of the hook, `$object_type`, refers to the meta object type
(post, comment, term, user, or any other type with an associated meta table).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$object_subtype` | `string` | Empty string to override.
`$object_id` | `int` | ID of the object to get the subtype for.

**Changelog**

Version | Description
------- | -----------
`4.9.8` | 

Source: [wordpress/wp-includes/meta.php](../../wordpress/wp-includes/meta.php), [line 1661](../../wordpress/wp-includes/meta.php#L1661-L1672)

### `wp_fatal_error_handler_enabled`

*Filters whether the fatal error handler is enabled.*

**Important:** This filter runs before it can be used by plugins. It cannot
be used by plugins, mu-plugins, or themes. To use this filter you must define
a `$wp_filter` global before WordPress loads, usually in `wp-config.php`.

Example:

    $GLOBALS['wp_filter'] = array(
        'wp_fatal_error_handler_enabled' => array(
            10 => array(
                array(
                    'accepted_args' => 0,
                    'function'      => function() {
                        return false;
                    },
                ),
            ),
        ),
    );

Alternatively you can use the `WP_DISABLE_FATAL_ERROR_HANDLER` constant.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$enabled` | `bool` | True if the fatal error handler is enabled, false otherwise.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/error-protection.php](../../wordpress/wp-includes/error-protection.php), [line 111](../../wordpress/wp-includes/error-protection.php#L111-L139)

### `http_request_timeout`

*Filters the timeout value for an HTTP request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`5` |  | 
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The `$url` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 152](../../wordpress/wp-includes/class-http.php#L152-L161)

### `http_request_redirection_count`

*Filters the number of redirects allowed during an HTTP request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`5` |  | 
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The `$url` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 162](../../wordpress/wp-includes/class-http.php#L162-L171)

### `http_request_version`

*Filters the version of the HTTP protocol used in a request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'1.0'` |  | 
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The `$url` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 172](../../wordpress/wp-includes/class-http.php#L172-L181)

### `http_headers_useragent`

*Filters the user agent value sent with an HTTP request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'WordPress/' . get_bloginfo('version') . '; ' . get_bloginfo('url')` |  | 
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The `$url` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 182](../../wordpress/wp-includes/class-http.php#L182-L191)

### `http_request_reject_unsafe_urls`

*Filters whether to pass URLs through wp_http_validate_url() in an HTTP request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The `$url` parameter was added.
`3.6.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 192](../../wordpress/wp-includes/class-http.php#L192-L201)

### `http_request_args`

*Filters the arguments used in an HTTP request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$parsed_args` | `array` | An array of HTTP request arguments.
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 224](../../wordpress/wp-includes/class-http.php#L224-L232)

### `pre_http_request`

*Filters the preemptive return value of an HTTP request.*

Returning a non-false value from the filter will short-circuit the HTTP request and return
early with that value. A filter should return one of:

 - An array containing 'headers', 'body', 'response', 'cookies', and 'filename' elements
 - A WP_Error instance
 - boolean false to avoid short-circuiting the response

Returning any other value may result in unexpected behaviour.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$parsed_args` | `array` | HTTP request arguments.
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 239](../../wordpress/wp-includes/class-http.php#L239-L257)

### `https_ssl_verify`

*Filters whether SSL should be verified for non-local requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$options['verify']` |  | 
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The `$url` parameter was added.
`2.8.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 367](../../wordpress/wp-includes/class-http.php#L367-L376)

### `http_response`

*Filters the HTTP API response immediately before the response is returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | HTTP response.
`$parsed_args` | `array` | HTTP request arguments.
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 437](../../wordpress/wp-includes/class-http.php#L437-L446)

### `http_api_transports`

*Filters which HTTP transports are available and in what order.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$transports` | `string[]` | Array of HTTP transports to check. Default array contains<br>'curl' and 'streams', in that order.
`$args` | `array` | HTTP request arguments.
`$url` | `string` | The URL to request.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 520](../../wordpress/wp-includes/class-http.php#L520-L530)

### `http_response`

*This filter is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` |  | 
`$args` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 589](../../wordpress/wp-includes/class-http.php#L589-L590)

### `block_local_requests`

*Filters whether to block local HTTP API requests.*

A local request is one to `localhost` or to the same host as the site itself.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-http.php](../../wordpress/wp-includes/class-http.php), [line 879](../../wordpress/wp-includes/class-http.php#L879-L888)

### `get_site`

*Fires after a site is retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_site` | `\WP_Site` | Site data.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 325](../../wordpress/wp-includes/ms-site.php#L325-L332)

### `wp_normalize_site_data`

*Filters passed site data in order to normalize it.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | Associative array of site data passed to the respective function.<br>See {@see \wp_insert_site()} for the possibly included data.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 490](../../wordpress/wp-includes/ms-site.php#L490-L498)

### `wp_initialize_site_args`

*Filters the arguments for initializing a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Arguments to modify the initialization behavior.
`$site` | `\WP_Site` | Site that is being initialized.
`$network` | `\WP_Network` | Network that the site belongs to.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 705](../../wordpress/wp-includes/ms-site.php#L705-L714)

### `wpmu_drop_tables`

*Filters the tables to drop when the site is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tables` | `string[]` | Array of names of the site tables to be dropped.
`$site->id` |  | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 844](../../wordpress/wp-includes/ms-site.php#L844-L852)

### `wpmu_delete_blog_upload_dir`

*Filters the upload base directory to delete when the site is deleted.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$uploads['basedir']` |  | 
`$site->id` |  | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 858](../../wordpress/wp-includes/ms-site.php#L858-L866)

### `pre_wp_is_site_initialized`

*Filters the check for whether a site is initialized before the database is accessed.*

Returning a non-null value will effectively short-circuit the function, returning
that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$site_id` | `int` | The site ID that is being checked.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/ms-site.php](../../wordpress/wp-includes/ms-site.php), [line 934](../../wordpress/wp-includes/ms-site.php#L934-L946)

### `blog_details`

*Filters a blog's details.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($details)` |  | 
`'4.7.0'` |  | 
`'site_details'` |  | 

Source: [wordpress/wp-includes/ms-blogs.php](../../wordpress/wp-includes/ms-blogs.php), [line 257](../../wordpress/wp-includes/ms-blogs.php#L257-L265)

### `blog_option_{$option}`

*Filters a blog option value.*

The dynamic portion of the hook name, `$option`, refers to the blog option name.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `string` | The option value.
`$id` | `int` | Blog ID.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/ms-blogs.php](../../wordpress/wp-includes/ms-blogs.php), [line 371](../../wordpress/wp-includes/ms-blogs.php#L371-L381)

### `wp_should_handle_php_error`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$error` |  | 

Source: [wordpress/wp-includes/class-wp-fatal-error-handler.php](../../wordpress/wp-includes/class-wp-fatal-error-handler.php), [line 121](../../wordpress/wp-includes/class-wp-fatal-error-handler.php#L121-L121)

### `wp_php_error_message`

*Filters the message that the default PHP error template displays.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message` | `string` | HTML error message to display.
`$error` | `array` | Error information retrieved from `error_get_last()`.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-fatal-error-handler.php](../../wordpress/wp-includes/class-wp-fatal-error-handler.php), [line 204](../../wordpress/wp-includes/class-wp-fatal-error-handler.php#L204-L212)

### `wp_php_error_args`

*Filters the arguments passed to {@see wp_die()} for the default PHP error template.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Associative array of arguments passed to `wp_die()`. By default these contain a<br>'response' key, and optionally 'link_url' and 'link_text' keys.
`$error` | `array` | Error information retrieved from `error_get_last()`.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-fatal-error-handler.php](../../wordpress/wp-includes/class-wp-fatal-error-handler.php), [line 214](../../wordpress/wp-includes/class-wp-fatal-error-handler.php#L214-L223)

### `the_title_rss`

*This filter is documented in wp-includes/feed.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 

Source: [wordpress/wp-includes/feed-atom-comments.php](../../wordpress/wp-includes/feed-atom-comments.php), [line 80](../../wordpress/wp-includes/feed-atom-comments.php#L80-L81)

### `block_default_classname`

*Filters the default block className for server rendered blocks.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classname` |  | 
`$block_name` | `string` | The block name.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/block-supports/generated-classname.php](../../wordpress/wp-includes/block-supports/generated-classname.php), [line 27](../../wordpress/wp-includes/block-supports/generated-classname.php#L27-L35)

### `embed_thumbnail_id`

*Filters the thumbnail image ID for use in the embed template.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$thumbnail_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/theme-compat/embed-content.php](../../wordpress/wp-includes/theme-compat/embed-content.php), [line 25](../../wordpress/wp-includes/theme-compat/embed-content.php#L25-L32)

### `embed_thumbnail_image_size`

*Filters the thumbnail image size for use in the embed template.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image_size` | `string` | Thumbnail image size.
`$thumbnail_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Added `$thumbnail_id` parameter.
`4.4.0` | 

Source: [wordpress/wp-includes/theme-compat/embed-content.php](../../wordpress/wp-includes/theme-compat/embed-content.php), [line 50](../../wordpress/wp-includes/theme-compat/embed-content.php#L50-L59)

### `embed_thumbnail_image_shape`

*Filters the thumbnail shape for use in the embed template.*

Rectangular images are shown above the title while square images
are shown next to the content.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$shape` | `string` | Thumbnail image shape. Either 'rectangular' or 'square'.
`$thumbnail_id` | `int` | Attachment ID.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Added `$thumbnail_id` parameter.
`4.4.0` | 

Source: [wordpress/wp-includes/theme-compat/embed-content.php](../../wordpress/wp-includes/theme-compat/embed-content.php), [line 63](../../wordpress/wp-includes/theme-compat/embed-content.php#L63-L75)

### `blog_details`

*This filter is documented in wp-includes/ms-blogs.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($details)` |  | 
`'4.7.0'` |  | 
`'site_details'` |  | 

Source: [wordpress/wp-includes/class-wp-site.php](../../wordpress/wp-includes/class-wp-site.php), [line 338](../../wordpress/wp-includes/class-wp-site.php#L338-L339)

### `site_details`

*Filters a site's extended properties.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$details` | `\stdClass` | The site details.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-site.php](../../wordpress/wp-includes/class-wp-site.php), [line 341](../../wordpress/wp-includes/class-wp-site.php#L341-L348)

### `graceful_fail`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message` |  | 

Source: [wordpress/wp-includes/ms-deprecated.php](../../wordpress/wp-includes/ms-deprecated.php), [line 91](../../wordpress/wp-includes/ms-deprecated.php#L91-L91)

### `graceful_fail_template`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'<!DOCTYPE html>
<html><head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>Error!</title>
<style type="text/css">
img {
	border: 0;
}
body {
line-height: 1.6em; font-family: Georgia, serif; width: 390px; margin: auto;
text-align: center;
}
.message {
	font-size: 22px;
	width: 350px;
	margin: auto;
}
</style>
</head>
<body>
<p class="message">%s</p>
</body>
</html>'` |  | 

Source: [wordpress/wp-includes/ms-deprecated.php](../../wordpress/wp-includes/ms-deprecated.php), [line 92](../../wordpress/wp-includes/ms-deprecated.php#L92-L115)

### `get_network`

*Fires after a network is retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_network` | `\WP_Network` | Network data.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/ms-network.php](../../wordpress/wp-includes/ms-network.php), [line 41](../../wordpress/wp-includes/ms-network.php#L41-L48)

### `auth_{$object_type}_meta_{$meta_key}_for_{$object_subtype}`

*Filters whether the user is allowed to edit a specific meta key of a specific object type and subtype.*

The dynamic portions of the hook name, `$object_type`, `$meta_key`,
and `$object_subtype`, refer to the metadata object type (comment, post, term or user),
the meta key value, and the object subtype respectively.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed` | `bool` | Whether the user can add the object meta. Default false.
`$meta_key` | `string` | The meta key.
`$object_id` | `int` | Object ID.
`$user_id` | `int` | User ID.
`$cap` | `string` | Capability name.
`$caps` | `string[]` | Array of the user's capabilities.

**Changelog**

Version | Description
------- | -----------
`4.9.8` | 

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 318](../../wordpress/wp-includes/capabilities.php#L318-L334)

### `auth_{$object_type}_meta_{$meta_key}`

*Filters whether the user is allowed to edit a specific meta key of a specific object type.*

Return true to have the mapped meta caps from `edit_{$object_type}` apply.

The dynamic portion of the hook name, `$object_type` refers to the object type being filtered.
The dynamic portion of the hook name, `$meta_key`, refers to the meta key passed to map_meta_cap().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allowed` | `bool` | Whether the user can add the object meta. Default false.
`$meta_key` | `string` | The meta key.
`$object_id` | `int` | Object ID.
`$user_id` | `int` | User ID.
`$cap` | `string` | Capability name.
`$caps` | `string[]` | Array of the user's capabilities.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 
`3.3.0` | As `auth_post_meta_{$meta_key}`.

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 337](../../wordpress/wp-includes/capabilities.php#L337-L355)

### `auth_{$object_type}_{$object_subtype}_meta_{$meta_key}`

*Filters whether the user is allowed to edit meta for specific object types/subtypes.*

Return true to have the mapped meta caps from `edit_{$object_type}` apply.

The dynamic portion of the hook name, `$object_type` refers to the object type being filtered.
The dynamic portion of the hook name, `$object_subtype` refers to the object subtype being filtered.
The dynamic portion of the hook name, `$meta_key`, refers to the meta key passed to map_meta_cap().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($allowed, $meta_key, $object_id, $user_id, $cap, $caps)` |  | 
`'4.9.8'` |  | 
`"auth_{$object_type}_meta_{$meta_key}_for_{$object_subtype}"` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Renamed from `auth_post_{$post_type}_meta_{$meta_key}` to
`auth_{$object_type}_{$object_subtype}_meta_{$meta_key}`.
`4.6.0` | As `auth_post_{$post_type}_meta_{$meta_key}`.

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 360](../../wordpress/wp-includes/capabilities.php#L360-L386)

### `map_meta_cap`

*Filters the primitive capabilities required of the given user to satisfy the
capability being checked.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$caps` | `string[]` | Primitive capabilities required of the user.
`$cap` | `string` | Capability being checked.
`$user_id` | `int` | The user ID.
`$args` | `array` | Adds context to the capability check, typically<br>starting with an object ID.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/capabilities.php](../../wordpress/wp-includes/capabilities.php), [line 646](../../wordpress/wp-includes/capabilities.php#L646-L658)

### `rss_update_period`

*This filter is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'hourly'` |  | 

Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 55](../../wordpress/wp-includes/feed-rss2-comments.php#L55-L56)

### `rss_update_frequency`

*This filter is documented in wp-includes/feed-rss2.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'1'` |  | 

Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 61](../../wordpress/wp-includes/feed-rss2-comments.php#L61-L62)

### `the_title_rss`

*This filter is documented in wp-includes/feed.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 

Source: [wordpress/wp-includes/feed-rss2-comments.php](../../wordpress/wp-includes/feed-rss2-comments.php), [line 83](../../wordpress/wp-includes/feed-rss2-comments.php#L83-L84)

### `the_permalink`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_permalink($post)` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 27](../../wordpress/wp-includes/link-template.php#L27-L27)

### `user_trailingslashit`

*Filters the trailing-slashed string, depending on whether the site is set to use trailing slashes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$string` | `string` | URL with or without a trailing slash.
`$type_of_url` | `string` | The type of URL being considered. Accepts 'single', 'single_trackback',<br>'single_feed', 'single_paged', 'commentpaged', 'paged', 'home', 'feed',<br>'category', 'page', 'year', 'month', 'day', 'post_type_archive'.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 55](../../wordpress/wp-includes/link-template.php#L55-L65)

### `pre_post_link`

*Filters the permalink structure for a post before token replacement occurs.*

Only applies to posts with post_type of 'post'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$permalink` | `string` | The site's permalink structure.
`$post` | `\WP_Post` | The post in question.
`$leavename` | `bool` | Whether to keep the post name.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 206](../../wordpress/wp-includes/link-template.php#L206-L217)

### `post_link_category`

*Filters the category that gets used in the %category% permalink token.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cats[0]` |  | 
`$cats` | `array` | Array of all categories (WP_Term objects) associated with the post.
`$post` | `\WP_Post` | The post in question.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 235](../../wordpress/wp-includes/link-template.php#L235-L244)

### `post_link`

*Filters the permalink for a post.*

Only applies to posts with post_type of 'post'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$permalink` | `string` | The post's permalink.
`$post` | `\WP_Post` | The post in question.
`$leavename` | `bool` | Whether to keep the post name.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 293](../../wordpress/wp-includes/link-template.php#L293-L304)

### `post_type_link`

*Filters the permalink for a post of a custom post type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_link` | `string` | The post's permalink.
`$post` | `\WP_Post` | The post in question.
`$leavename` | `bool` | Whether to keep the post name.
`$sample` | `bool` | Is it a sample permalink.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 360](../../wordpress/wp-includes/link-template.php#L360-L370)

### `page_link`

*Filters the permalink for a page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The page's permalink.
`$post->ID` |  | 
`$sample` | `bool` | Is it a sample permalink.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 395](../../wordpress/wp-includes/link-template.php#L395-L404)

### `_get_page_link`

*Filters the permalink for a non-page_on_front page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The page's permalink.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 443](../../wordpress/wp-includes/link-template.php#L443-L451)

### `attachment_link`

*Filters the permalink for an attachment.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The attachment's permalink.
`$post->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | Providing an empty string will now disable
the view attachment page link on the media modal.
`2.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 519](../../wordpress/wp-includes/link-template.php#L519-L529)

### `year_link`

*Filters the year archive permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$yearlink` | `string` | Permalink for the year archive.
`$year` | `int` | Year for the archive.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 555](../../wordpress/wp-includes/link-template.php#L555-L563)

### `month_link`

*Filters the month archive permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$monthlink` | `string` | Permalink for the month archive.
`$year` | `int` | Year for the archive.
`$month` | `int` | The month for the archive.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 594](../../wordpress/wp-includes/link-template.php#L594-L603)

### `day_link`

*Filters the day archive permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$daylink` | `string` | Permalink for the day archive.
`$year` | `int` | Year for the archive.
`$month` | `int` | Month for the archive.
`$day` | `int` | The day for the archive.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 640](../../wordpress/wp-includes/link-template.php#L640-L650)

### `the_feed_link`

*Filters the feed link anchor tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The complete anchor tag for a feed link.
`$feed` | `string` | The feed type. Possible values include 'rss2', 'atom',<br>or an empty string for the default feed type.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 665](../../wordpress/wp-includes/link-template.php#L665-L674)

### `feed_link`

*Filters the feed type permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The feed permalink.
`$feed` | `string` | The feed type. Possible values include 'rss2', 'atom',<br>or an empty string for the default feed type.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 718](../../wordpress/wp-includes/link-template.php#L718-L727)

### `post_comments_feed_link`

*Filters the post comments feed permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | Post comments feed permalink.

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 802](../../wordpress/wp-includes/link-template.php#L802-L809)

### `post_comments_feed_link_html`

*Filters the post comment feed link anchor tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The complete anchor tag for the comment feed link.
`$post_id` | `int` | Post ID.
`$feed` | `string` | The feed type. Possible values include 'rss2', 'atom',<br>or an empty string for the default feed type.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 833](../../wordpress/wp-includes/link-template.php#L833-L843)

### `author_feed_link`

*Filters the feed link for a given author.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The author feed link.
`$feed` | `string` | Feed type. Possible values include 'rss2', 'atom'.

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 880](../../wordpress/wp-includes/link-template.php#L880-L888)

### `category_feed_link`

*Filters the category feed link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The category feed link.
`$feed` | `string` | Feed type. Possible values include 'rss2', 'atom'.

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 960](../../wordpress/wp-includes/link-template.php#L960-L968)

### `tag_feed_link`

*Filters the post tag feed link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The tag feed link.
`$feed` | `string` | Feed type. Possible values include 'rss2', 'atom'.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 970](../../wordpress/wp-includes/link-template.php#L970-L978)

### `taxonomy_feed_link`

*Filters the feed link for a taxonomy other than 'category' or 'post_tag'.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The taxonomy feed link.
`$feed` | `string` | Feed type. Possible values include 'rss2', 'atom'.
`$taxonomy` | `string` | The taxonomy name.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 980](../../wordpress/wp-includes/link-template.php#L980-L989)

### `get_edit_tag_link`

*Filters the edit link for a tag (or term in another taxonomy).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_edit_term_link($tag_id, $taxonomy)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1019](../../wordpress/wp-includes/link-template.php#L1019-L1026)

### `edit_tag_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1050](../../wordpress/wp-includes/link-template.php#L1050-L1050)

### `get_edit_term_link`

*Filters the edit link for a term.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` | `string` | The edit link.
`$term_id` | `int` | Term ID.
`$taxonomy` | `string` | Taxonomy name.
`$object_type` | `string` | The object type (eg. the post type).

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1095](../../wordpress/wp-includes/link-template.php#L1095-L1105)

### `edit_term_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$term->term_id` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1148](../../wordpress/wp-includes/link-template.php#L1148-L1148)

### `search_link`

*Filters the search permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | Search permalink.
`$search` | `string` | The URL-encoded search term.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1187](../../wordpress/wp-includes/link-template.php#L1187-L1195)

### `search_feed_link`

*Filters the search feed link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | Search feed link.
`$feed` | `string` | Feed type. Possible values include 'rss2', 'atom'.
`'posts'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1227](../../wordpress/wp-includes/link-template.php#L1227-L1236)

### `search_feed_link`

*This filter is documented in wp-includes/link-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$feed` |  | 
`'comments'` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1268](../../wordpress/wp-includes/link-template.php#L1268-L1269)

### `post_type_archive_link`

*This filter is documented in wp-includes/link-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$post_type` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1301](../../wordpress/wp-includes/link-template.php#L1301-L1302)

### `post_type_archive_link`

*Filters the post type archive permalink.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The post type archive permalink.
`$post_type` | `string` | Post type name.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1321](../../wordpress/wp-includes/link-template.php#L1321-L1329)

### `post_type_archive_feed_link`

*Filters the post type archive feed link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The post type archive feed link.
`$feed` | `string` | Feed type. Possible values include 'rss2', 'atom'.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1365](../../wordpress/wp-includes/link-template.php#L1365-L1373)

### `preview_post_link`

*Filters the URL used for a post preview.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$preview_link` | `string` | URL used for the post preview.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | Added the `$post` parameter.
`2.0.5` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1406](../../wordpress/wp-includes/link-template.php#L1406-L1415)

### `get_edit_post_link`

*Filters the post edit link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The edit link.
`$post->ID` |  | 
`$context` | `string` | The link context. If set to 'display' then ampersands<br>are encoded.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1460](../../wordpress/wp-includes/link-template.php#L1460-L1470)

### `edit_post_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$post->ID` |  | 
`$text` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1511](../../wordpress/wp-includes/link-template.php#L1511-L1511)

### `get_delete_post_link`

*Filters the post delete link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_nonce_url($delete_link, "{$action}-post_{$post->ID}")` |  | 
`$post->ID` |  | 
`$force_delete` | `bool` | Whether to bypass the Trash and force deletion. Default false.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1549](../../wordpress/wp-includes/link-template.php#L1549-L1558)

### `get_edit_comment_link`

*Filters the comment edit link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` | `string` | The edit link.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1578](../../wordpress/wp-includes/link-template.php#L1578-L1585)

### `edit_comment_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$comment->comment_ID` |  | 
`$text` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1619](../../wordpress/wp-includes/link-template.php#L1619-L1619)

### `get_edit_bookmark_link`

*Filters the bookmark edit link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` | `string` | The edit link.
`$link->link_id` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1639](../../wordpress/wp-includes/link-template.php#L1639-L1647)

### `edit_bookmark_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 
`$bookmark->link_id` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1681](../../wordpress/wp-includes/link-template.php#L1681-L1681)

### `get_edit_user_link`

*Filters the user edit link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The edit link.
`$user->ID` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1713](../../wordpress/wp-includes/link-template.php#L1713-L1721)

### `get_{$adjacent}_post_excluded_terms`

*Filters the IDs of terms excluded from adjacent post queries.*

The dynamic portion of the hook name, `$adjacent`, refers to the type
of adjacency, 'next' or 'previous'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$excluded_terms` | `array\|string` | Array of excluded term IDs. Empty string if none were provided.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1808](../../wordpress/wp-includes/link-template.php#L1808-L1818)

### `get_{$adjacent}_post_join`

*Filters the JOIN clause in the SQL for an adjacent post query.*

The dynamic portion of the hook name, `$adjacent`, refers to the type
of adjacency, 'next' or 'previous'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$join` | `string` | The JOIN clause in the SQL.
`$in_same_term` | `bool` | Whether post should be in a same taxonomy term.
`$excluded_terms` | `array` | Array of excluded term IDs.
`$taxonomy` | `string` | Taxonomy. Used to identify the term used when `$in_same_term` is true.
`$post` | `\WP_Post` | WP_Post object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added the `$taxonomy` and `$post` parameters.
`2.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1879](../../wordpress/wp-includes/link-template.php#L1879-L1894)

### `get_{$adjacent}_post_where`

*Filters the WHERE clause in the SQL for an adjacent post query.*

The dynamic portion of the hook name, `$adjacent`, refers to the type
of adjacency, 'next' or 'previous'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wpdb->prepare("WHERE p.post_date {$op} %s AND p.post_type = %s {$where}", $current_post_date, $post->post_type)` |  | 
`$in_same_term` | `bool` | Whether post should be in a same taxonomy term.
`$excluded_terms` | `array` | Array of excluded term IDs.
`$taxonomy` | `string` | Taxonomy. Used to identify the term used when `$in_same_term` is true.
`$post` | `\WP_Post` | WP_Post object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | Added the `$taxonomy` and `$post` parameters.
`2.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1896](../../wordpress/wp-includes/link-template.php#L1896-L1911)

### `get_{$adjacent}_post_sort`

*Filters the ORDER BY clause in the SQL for an adjacent post query.*

The dynamic portion of the hook name, `$adjacent`, refers to the type
of adjacency, 'next' or 'previous'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`"ORDER BY p.post_date {$order} LIMIT 1"` |  | 
`$post` | `\WP_Post` | WP_Post object.
`$order` | `string` | Sort order. 'DESC' for previous post, 'ASC' for next.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$order` parameter.
`4.4.0` | Added the `$post` parameter.
`2.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 1913](../../wordpress/wp-includes/link-template.php#L1913-L1927)

### `{$adjacent}_post_rel_link`

*Filters the adjacent post relational link.*

The dynamic portion of the hook name, `$adjacent`, refers to the type
of adjacency, 'next' or 'previous'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The relational link.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2001](../../wordpress/wp-includes/link-template.php#L2001-L2011)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2242](../../wordpress/wp-includes/link-template.php#L2242-L2243)

### `{$adjacent}_post_link`

*Filters the adjacent post link.*

The dynamic portion of the hook name, `$adjacent`, refers to the type
of adjacency, 'next' or 'previous'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The adjacent post link.
`$format` | `string` | Link anchor format.
`$link` | `string` | Link permalink format.
`$post` | `\WP_Post` | The adjacent post.
`$adjacent` | `string` | Whether the post is previous or next.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | Added the `$adjacent` parameter.
`2.6.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2258](../../wordpress/wp-includes/link-template.php#L2258-L2273)

### `get_pagenum_link`

*Filters the page number link for the current request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `string` | The page number link.
`$pagenum` | `int` | The page number.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | Added the `$pagenum` argument.
`2.5.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2356](../../wordpress/wp-includes/link-template.php#L2356-L2365)

### `next_posts_link_attributes`

*Filters the anchor tag attributes for the next posts page link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2449](../../wordpress/wp-includes/link-template.php#L2449-L2456)

### `previous_posts_link_attributes`

*Filters the anchor tag attributes for the previous posts page link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2535](../../wordpress/wp-includes/link-template.php#L2535-L2542)

### `navigation_markup_template`

*Filters the navigation markup template.*

Note: The filtered template HTML must contain specifiers for the navigation
class (%%1$s), the screen-reader-text value (%%2$s), placement of the navigation
links (%%3$s), and ARIA label text if screen-reader-text does not fit that (%%4$s):

    <nav class="navigation %%1$s" role="navigation" aria-label="%%4$s">
        <h2 class="screen-reader-text">%%2$s</h2>
        <div class="nav-links">%%3$s</div>
    </nav>

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$template` | `string` | The default template.
`$class` | `string` | The class passed by the calling function.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2871](../../wordpress/wp-includes/link-template.php#L2871-L2889)

### `get_comments_pagenum_link`

*Filters the comments page number link for the current request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `string` | The comments page number link.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2930](../../wordpress/wp-includes/link-template.php#L2930-L2937)

### `next_comments_link_attributes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 2989](../../wordpress/wp-includes/link-template.php#L2989-L2989)

### `previous_comments_link_attributes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3036](../../wordpress/wp-includes/link-template.php#L3036-L3036)

### `home_url`

*Filters the home URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete home URL including scheme and path.
`$path` | `string` | Path relative to the home URL. Blank string if no path is specified.
`$orig_scheme` | `string\|null` | Scheme to give the home URL context. Accepts 'http', 'https',<br>'relative', 'rest', or null.
`$blog_id` | `int\|null` | Site ID, or null for the current site.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3287](../../wordpress/wp-includes/link-template.php#L3287-L3298)

### `site_url`

*Filters the site URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete site URL including scheme and path.
`$path` | `string` | Path relative to the site URL. Blank string if no path is specified.
`$scheme` | `string\|null` | Scheme to give the site URL context. Accepts 'http', 'https', 'login',<br>'login_post', 'admin', 'relative' or null.
`$blog_id` | `int\|null` | Site ID, or null for the current site.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3351](../../wordpress/wp-includes/link-template.php#L3351-L3362)

### `admin_url`

*Filters the admin area URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete admin area URL including scheme and path.
`$path` | `string` | Path relative to the admin area URL. Blank string if no path is specified.
`$blog_id` | `int\|null` | Site ID, or null for the current site.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3398](../../wordpress/wp-includes/link-template.php#L3398-L3407)

### `includes_url`

*Filters the URL to the includes directory.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL to the includes directory including scheme and path.
`$path` | `string` | Path relative to the URL to the wp-includes directory. Blank string<br>if no path is specified.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3427](../../wordpress/wp-includes/link-template.php#L3427-L3436)

### `content_url`

*Filters the URL to the content directory.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL to the content directory including scheme and path.
`$path` | `string` | Path relative to the URL to the content directory. Blank string<br>if no path is specified.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3454](../../wordpress/wp-includes/link-template.php#L3454-L3463)

### `plugins_url`

*Filters the URL to the plugins directory.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL to the plugins directory including scheme and path.
`$path` | `string` | Path relative to the URL to the plugins directory. Blank string<br>if no path is specified.
`$plugin` | `string` | The plugin file path to be relative to. Blank string if no plugin<br>is specified.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3505](../../wordpress/wp-includes/link-template.php#L3505-L3516)

### `network_site_url`

*Filters the network site URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete network site URL including scheme and path.
`$path` | `string` | Path relative to the network site URL. Blank string if<br>no path is specified.
`$scheme` | `string\|null` | Scheme to give the URL context. Accepts 'http', 'https',<br>'relative' or null.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3552](../../wordpress/wp-includes/link-template.php#L3552-L3563)

### `network_home_url`

*Filters the network home URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete network home URL including scheme and path.
`$path` | `string` | Path relative to the network home URL. Blank string<br>if no path is specified.
`$orig_scheme` | `string\|null` | Scheme to give the URL context. Accepts 'http', 'https',<br>'relative' or null.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3602](../../wordpress/wp-includes/link-template.php#L3602-L3613)

### `network_admin_url`

*Filters the network admin URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete network admin URL including scheme and path.
`$path` | `string` | Path relative to the network admin URL. Blank string if<br>no path is specified.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3637](../../wordpress/wp-includes/link-template.php#L3637-L3646)

### `user_admin_url`

*Filters the user admin URL for the current user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL including scheme and path.
`$path` | `string` | Path relative to the URL. Blank string if<br>no path is specified.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3666](../../wordpress/wp-includes/link-template.php#L3666-L3675)

### `self_admin_url`

*Filters the admin URL for the current site or network depending on context.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL including scheme and path.
`$path` | `string` | Path relative to the URL. Blank string if no path is specified.
`$scheme` | `string` | The scheme to use.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3697](../../wordpress/wp-includes/link-template.php#L3697-L3706)

### `set_url_scheme`

*Filters the resulting URL after setting the scheme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL including scheme and path.
`$scheme` | `string` | Scheme applied to the URL. One of 'http', 'https', or 'relative'.
`$orig_scheme` | `string\|null` | Scheme requested for the URL. One of 'http', 'https', 'login',<br>'login_post', 'admin', 'relative', 'rest', 'rpc', or null.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3745](../../wordpress/wp-includes/link-template.php#L3745-L3755)

### `user_dashboard_url`

*Filters the dashboard URL for a user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL including scheme and path.
`$user_id` | `int` | The user ID.
`$path` | `string` | Path relative to the URL. Blank string if no path is specified.
`$scheme` | `string` | Scheme to give the URL context. Accepts 'http', 'https', 'login',<br>'login_post', 'admin', 'relative' or null.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3798](../../wordpress/wp-includes/link-template.php#L3798-L3809)

### `edit_profile_url`

*Filters the URL for a user's profile editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The complete URL including scheme and path.
`$user_id` | `int` | The user ID.
`$scheme` | `string` | Scheme to give the URL context. Accepts 'http', 'https', 'login',<br>'login_post', 'admin', 'relative' or null.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3833](../../wordpress/wp-includes/link-template.php#L3833-L3843)

### `get_canonical_url`

*Filters the canonical URL for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$canonical_url` | `string` | The post's canonical URL.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3888](../../wordpress/wp-includes/link-template.php#L3888-L3896)

### `pre_get_shortlink`

*Filters whether to preempt generating a shortlink for the given post.*

Returning a truthy value from the filter will effectively short-circuit
the shortlink generation process, returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$id` | `int` | Post ID, or 0 for the current post.
`$context` | `string` | The context for the link. One of 'post' or 'query',
`$allow_slugs` | `bool` | Whether to allow post slugs in the shortlink.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3944](../../wordpress/wp-includes/link-template.php#L3944-L3957)

### `get_shortlink`

*Filters the shortlink for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$shortlink` | `string` | Shortlink URL.
`$id` | `int` | Post ID, or 0 for the current post.
`$context` | `string` | The context for the link. One of 'post' or 'query',
`$allow_slugs` | `bool` | Whether to allow post slugs in the shortlink. Not used by default.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 3987](../../wordpress/wp-includes/link-template.php#L3987-L3997)

### `the_shortlink`

*Filters the short link anchor tag for a post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | Shortlink anchor tag.
`$shortlink` | `string` | Shortlink URL.
`$text` | `string` | Shortlink's text.
`$title` | `string` | Shortlink's title attribute.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4068](../../wordpress/wp-includes/link-template.php#L4068-L4078)

### `get_avatar_comment_types`

*Filters the list of allowed comment types for retrieving avatars.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('comment')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4126](../../wordpress/wp-includes/link-template.php#L4126-L4133)

### `pre_get_avatar_data`

*Filters whether to retrieve the avatar URL early.*

Passing a non-null value in the 'url' member of the return array will
effectively short circuit get_avatar_data(), passing the value through
the %1$s filter and returning early.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Arguments passed to get_avatar_data(), after processing.
`$id_or_email` | `mixed` | The Gravatar to retrieve. Accepts a user ID, Gravatar MD5 hash,<br>user email, WP_User object, WP_Post object, or WP_Comment object.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4239](../../wordpress/wp-includes/link-template.php#L4239-L4252)

### `get_avatar_data`

*This filter is documented in wp-includes/link-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 
`$id_or_email` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4255](../../wordpress/wp-includes/link-template.php#L4255-L4256)

### `get_avatar_data`

*This filter is documented in wp-includes/link-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 
`$id_or_email` |  | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4287](../../wordpress/wp-includes/link-template.php#L4287-L4288)

### `get_avatar_url`

*Filters the avatar URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The URL of the avatar.
`$id_or_email` | `mixed` | The Gravatar to retrieve. Accepts a user ID, Gravatar MD5 hash,<br>user email, WP_User object, WP_Post object, or WP_Comment object.
`$args` | `array` | Arguments passed to get_avatar_data(), after processing.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4334](../../wordpress/wp-includes/link-template.php#L4334-L4344)

### `get_avatar_data`

*Filters the avatar data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Arguments passed to get_avatar_data(), after processing.
`$id_or_email` | `mixed` | The Gravatar to retrieve. Accepts a user ID, Gravatar MD5 hash,<br>user email, WP_User object, WP_Post object, or WP_Comment object.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4346](../../wordpress/wp-includes/link-template.php#L4346-L4355)

### `theme_file_uri`

*Filters the URL to a file in the theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The file URL.
`$file` | `string` | The requested file to search for.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4380](../../wordpress/wp-includes/link-template.php#L4380-L4388)

### `parent_theme_file_uri`

*Filters the URL to a file in the parent theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The file URL.
`$file` | `string` | The requested file to search for.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4408](../../wordpress/wp-includes/link-template.php#L4408-L4416)

### `theme_file_path`

*Filters the path to a file in the theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$path` | `string` | The file path.
`$file` | `string` | The requested file to search for.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4441](../../wordpress/wp-includes/link-template.php#L4441-L4449)

### `parent_theme_file_path`

*Filters the path to a file in the parent theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$path` | `string` | The file path.
`$file` | `string` | The requested file to search for.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4469](../../wordpress/wp-includes/link-template.php#L4469-L4477)

### `privacy_policy_url`

*Filters the URL of the privacy policy page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The URL to the privacy policy page. Empty string<br>if it doesn't exist.
`$policy_page_id` | `int` | The ID of privacy policy page.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4495](../../wordpress/wp-includes/link-template.php#L4495-L4504)

### `the_privacy_policy_link`

*Filters the privacy policy link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The privacy policy link. Empty string if it<br>doesn't exist.
`$privacy_policy_url` | `string` | The URL of the privacy policy. Empty string<br>if it doesn't exist.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/link-template.php](../../wordpress/wp-includes/link-template.php), [line 4543](../../wordpress/wp-includes/link-template.php#L4543-L4553)

### `site_url`

*This filter is documented in wp-includes/link-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_option('siteurl')` |  | 
`''` |  | 
`null` |  | 
`null` |  | 

Source: [wordpress/wp-includes/https-detection.php](../../wordpress/wp-includes/https-detection.php), [line 55](../../wordpress/wp-includes/https-detection.php#L55-L56)

### `pre_wp_update_https_detection_errors`

*Short-circuits the process of detecting errors related to HTTPS support.*

Returning a `WP_Error` from the filter will effectively short-circuit the default logic of trying a remote
request to the site over HTTPS, storing the errors array from the returned `WP_Error` instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/https-detection.php](../../wordpress/wp-includes/https-detection.php), [line 91](../../wordpress/wp-includes/https-detection.php#L91-L102)

### `ms_site_check`

*Filters checking the status of the current blog.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/ms-load.php](../../wordpress/wp-includes/ms-load.php), [line 76](../../wordpress/wp-includes/ms-load.php#L76-L83)

### `site_by_path_segments_count`

*Filters the number of path segments to consider when searching for a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$segments` | `int\|null` | The number of path segments to consider. WordPress by default looks at<br>one path segment following the network path. The function default of<br>null only makes sense when you know the requested path should match a site.
`$domain` | `string` | The requested domain.
`$path` | `string` | The requested path, in full.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/ms-load.php](../../wordpress/wp-includes/ms-load.php), [line 166](../../wordpress/wp-includes/ms-load.php#L166-L177)

### `pre_get_site_by_path`

*Determine a site by its domain and path.*

This allows one to short-circuit the default logic, perhaps by
replacing it with a routine that is more optimal for your setup.

Return null to avoid the short-circuit. Return false if no site
can be found at the requested domain and path. Otherwise, return
a site object.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$domain` | `string` | The requested domain.
`$path` | `string` | The requested path, in full.
`$segments` | `int\|null` | The suggested number of paths to consult.<br>Default null, meaning the entire path was to be consulted.
`$paths` | `string[]` | The paths to search for, based on $path and $segments.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/ms-load.php](../../wordpress/wp-includes/ms-load.php), [line 192](../../wordpress/wp-includes/ms-load.php#L192-L212)

### `get_meta_sql`

*Filters the meta query's generated SQL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($sql, $this->queries, $type, $primary_table, $primary_id_column, $context)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-wp-meta-query.php](../../wordpress/wp-includes/class-wp-meta-query.php), [line 345](../../wordpress/wp-includes/class-wp-meta-query.php#L345-L357)

### `meta_query_find_compatible_table_alias`

*Filters the table alias identified as compatible with the current clause.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$alias` | `string\|false` | Table alias, or false if none was found.
`$clause` | `array` | First-order query clause.
`$parent_query` | `array` | Parent of $clause.
`$this` | `\WP_Meta_Query` | WP_Meta_Query object.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/class-wp-meta-query.php](../../wordpress/wp-includes/class-wp-meta-query.php), [line 820](../../wordpress/wp-includes/class-wp-meta-query.php#L820-L830)

### `render_block`

*Filters the content of a single block.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$block_content` | `string` | The block content about to be appended.
`$this->parsed_block` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/class-wp-block.php](../../wordpress/wp-includes/class-wp-block.php), [line 236](../../wordpress/wp-includes/class-wp-block.php#L236-L244)

### `render_block_{$this->name}`

*Filters the content of a single block.*

The dynamic portion of the hook name, `$name`, refers to
the block name, e.g. "core/paragraph".

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$block_content` | `string` | The block content about to be appended.
`$this->parsed_block` |  | 

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/class-wp-block.php](../../wordpress/wp-includes/class-wp-block.php), [line 246](../../wordpress/wp-includes/class-wp-block.php#L246-L257)

### `use_google_chrome_frame`

*Filters whether Google Chrome Frame should be used, if available.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_admin` | `bool` | Whether to use the Google Chrome Frame. Default is the value of is_admin().

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-includes/vars.php](../../wordpress/wp-includes/vars.php), [line 73](../../wordpress/wp-includes/vars.php#L73-L80)

### `wp_is_mobile`

*Filters whether the request should be treated as coming from a mobile device or not.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_mobile` | `bool` | Whether the request is from a mobile device or not.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/vars.php](../../wordpress/wp-includes/vars.php), [line 161](../../wordpress/wp-includes/vars.php#L161-L168)

### `exit_on_http_head`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/template-loader.php](../../wordpress/wp-includes/template-loader.php), [line 26](../../wordpress/wp-includes/template-loader.php#L26-L26)

### `template_include`

*Filters the path of the current template before including it.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$template` | `string` | The path of the template to include.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/template-loader.php](../../wordpress/wp-includes/template-loader.php), [line 97](../../wordpress/wp-includes/template-loader.php#L97-L104)

### `embed_defaults`

*Filters the default array of embed dimensions.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`compact('width', 'height')` |  | 
`$url` | `string` | The URL that should be embedded.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 78](../../wordpress/wp-includes/embed.php#L78-L91)

### `load_default_embeds`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 201](../../wordpress/wp-includes/embed.php#L201-L201)

### `wp_audio_embed_handler`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp_embed_handler_audio'` |  | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 214](../../wordpress/wp-includes/embed.php#L214-L214)

### `wp_video_embed_handler`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'wp_embed_handler_video'` |  | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 223](../../wordpress/wp-includes/embed.php#L223-L223)

### `wp_embed_handler_youtube`

*Filters the YoutTube embed output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$embed` | `string` | YouTube embed output.
`$attr` | `array` | An array of embed attributes.
`$url` | `string` | The original URL that was matched by the regex.
`$rawattr` | `array` | The original unmodified attributes.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 246](../../wordpress/wp-includes/embed.php#L246-L258)

### `wp_embed_handler_audio`

*Filters the audio embed output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$audio` | `string` | Audio embed output.
`$attr` | `array` | An array of embed attributes.
`$url` | `string` | The original URL that was matched by the regex.
`$rawattr` | `array` | The original unmodified attributes.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 275](../../wordpress/wp-includes/embed.php#L275-L285)

### `wp_embed_handler_video`

*Filters the video embed output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$video` | `string` | Video embed output.
`$attr` | `array` | An array of embed attributes.
`$url` | `string` | The original URL that was matched by the regex.
`$rawattr` | `array` | The original unmodified attributes.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 307](../../wordpress/wp-includes/embed.php#L307-L317)

### `oembed_discovery_links`

*Filters the oEmbed discovery links HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | HTML of the discovery links.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 346](../../wordpress/wp-includes/embed.php#L346-L353)

### `post_embed_url`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$embed_url` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 395](../../wordpress/wp-includes/embed.php#L395-L395)

### `oembed_endpoint_url`

*Filters the oEmbed endpoint URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The URL to the oEmbed endpoint.
`$permalink` | `string` | The permalink used for the `url` query arg.
`$format` | `string` | The requested response format.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 422](../../wordpress/wp-includes/embed.php#L422-L431)

### `embed_html`

*Filters the embed HTML output for a given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The default iframe tag to display embedded content.
`$post` | `\WP_Post` | Current post object.
`$width` | `int` | Width of the response.
`$height` | `int` | Height of the response.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 493](../../wordpress/wp-includes/embed.php#L493-L503)

### `oembed_min_max_width`

*Filters the allowed minimum and maximum widths for the oEmbed response.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('min' => 200, 'max' => 600)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 528](../../wordpress/wp-includes/embed.php#L528-L546)

### `oembed_response_data`

*Filters the oEmbed response data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | The response data.
`$post` | `\WP_Post` | The post object.
`$width` | `int` | The requested width.
`$height` | `int` | The calculated height.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 568](../../wordpress/wp-includes/embed.php#L568-L578)

### `oembed_request_post_id`

*This filter is documented in wp-includes/class-wp-oembed-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 635](../../wordpress/wp-includes/embed.php#L635-L636)

### `oembed_iframe_title_attribute`

*Filters the title attribute of the given oEmbed HTML iframe.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | The title attribute.
`$result` | `string` | The oEmbed HTML result.
`$data` | `object` | A data object result from an oEmbed provider.
`$url` | `string` | The URL of the content to be embedded.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 840](../../wordpress/wp-includes/embed.php#L840-L850)

### `the_excerpt_embed`

*Filters the post excerpt for the embed template.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The current post excerpt.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 981](../../wordpress/wp-includes/embed.php#L981-L988)

### `embed_site_title_html`

*Filters the site title HTML in the embed footer.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$site_title` | `string` | The site title HTML.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/embed.php](../../wordpress/wp-includes/embed.php), [line 1217](../../wordpress/wp-includes/embed.php#L1217-L1224)

### `pre_schedule_event`

*Filter to preflight or hijack scheduling an event.*

Returning a non-null value will short-circuit adding the event to the
cron array, causing the function to return the filtered value instead.

Both single events and recurring events are passed through this filter;
single events have `$event->schedule` as false, whereas recurring events
have this set to a recurrence from wp_get_schedules(). Recurring
events also have the integer recurrence interval set as `$event->interval`.

For plugins replacing wp-cron, it is recommended you check for an
identical event within ten minutes and apply the %1$s
filter to check if another plugin has disallowed the event before scheduling.

Return true if the event was scheduled, false or a WP_Error if not.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$event` | `\stdClass` | {<br>    An object containing an event's data.<br><br>    @type string       $hook      Action hook to execute when the event is run.<br>    @type int          $timestamp Unix timestamp (UTC) for when to next run the event.<br>    @type string\|false $schedule  How often the event should subsequently recur.<br>    @type array        $args      Array containing each separate argument to pass to the hook's callback function.<br>    @type int          $interval  The interval time in seconds for the schedule. Only present for recurring events.<br>}
`$wp_error` | `bool` | Whether to return a WP_Error on failure.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | The `$wp_error` parameter was added, and a `WP_Error` object can now be returned.
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 59](../../wordpress/wp-includes/cron.php#L59-L91)

### `schedule_event`

*Modify an event before it is scheduled.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$event` | `\stdClass\|false` | {<br>    An object containing an event's data, or boolean false to prevent the event from being scheduled.<br><br>    @type string       $hook      Action hook to execute when the event is run.<br>    @type int          $timestamp Unix timestamp (UTC) for when to next run the event.<br>    @type string\|false $schedule  How often the event should subsequently recur.<br>    @type array        $args      Array containing each separate argument to pass to the hook's callback function.<br>    @type int          $interval  The interval time in seconds for the schedule. Only present for recurring events.<br>}

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 161](../../wordpress/wp-includes/cron.php#L161-L176)

### `pre_schedule_event`

*This filter is documented in wp-includes/cron.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$event` |  | 
`$wp_error` |  | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 269](../../wordpress/wp-includes/cron.php#L269-L270)

### `schedule_event`

*This filter is documented in wp-includes/cron.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$event` |  | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 287](../../wordpress/wp-includes/cron.php#L287-L288)

### `pre_reschedule_event`

*Filter to preflight or hijack rescheduling of events.*

Returning a non-null value will short-circuit the normal rescheduling
process, causing the function to return the filtered value instead.

For plugins replacing wp-cron, return true if the event was successfully
rescheduled, false if not.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$event` | `\stdClass` | {<br>    An object containing an event's data.<br><br>    @type string       $hook      Action hook to execute when the event is run.<br>    @type int          $timestamp Unix timestamp (UTC) for when to next run the event.<br>    @type string\|false $schedule  How often the event should subsequently recur.<br>    @type array        $args      Array containing each separate argument to pass to the hook's callback function.<br>    @type int          $interval  The interval time in seconds for the schedule. Only present for recurring events.<br>}
`$wp_error` | `bool` | Whether to return a WP_Error on failure.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | The `$wp_error` parameter was added, and a `WP_Error` object can now be returned.
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 377](../../wordpress/wp-includes/cron.php#L377-L401)

### `pre_unschedule_event`

*Filter to preflight or hijack unscheduling of events.*

Returning a non-null value will short-circuit the normal unscheduling
process, causing the function to return the filtered value instead.

For plugins replacing wp-cron, return true if the event was successfully
unscheduled, false if not.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$timestamp` | `int` | Timestamp for when to run the event.
`$hook` | `string` | Action hook, the execution of which will be unscheduled.
`$args` | `array` | Arguments to pass to the hook's callback function.
`$wp_error` | `bool` | Whether to return a WP_Error on failure.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | The `$wp_error` parameter was added, and a `WP_Error` object can now be returned.
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 474](../../wordpress/wp-includes/cron.php#L474-L492)

### `pre_clear_scheduled_hook`

*Filter to preflight or hijack clearing a scheduled hook.*

Returning a non-null value will short-circuit the normal unscheduling
process, causing the function to return the filtered value instead.

For plugins replacing wp-cron, return the number of events successfully
unscheduled (zero if no events were registered with the hook) or false
if unscheduling one or more events fails.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$hook` | `string` | Action hook, the execution of which will be unscheduled.
`$args` | `array` | Arguments to pass to the hook's callback function.
`$wp_error` | `bool` | Whether to return a WP_Error on failure.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | The `$wp_error` parameter was added, and a `WP_Error` object can now be returned.
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 554](../../wordpress/wp-includes/cron.php#L554-L572)

### `pre_unschedule_hook`

*Filter to preflight or hijack clearing all events attached to the hook.*

Returning a non-null value will short-circuit the normal unscheduling
process, causing the function to return the filtered value instead.

For plugins replacing wp-cron, return the number of events successfully
unscheduled (zero if no events were registered with the hook) or false
if unscheduling one or more events fails.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$hook` | `string` | Action hook, the execution of which will be unscheduled.
`$wp_error` | `bool` | Whether to return a WP_Error on failure.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | The `$wp_error` parameter was added, and a `WP_Error` object can now be returned.
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 644](../../wordpress/wp-includes/cron.php#L644-L661)

### `pre_get_scheduled_event`

*Filter to preflight or hijack retrieving a scheduled event.*

Returning a non-null value will short-circuit the normal process,
returning the filtered value instead.

Return false if the event does not exist, otherwise an event object
should be returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$hook` | `string` | Action hook of the event.
`$args` | `array` | Array containing each separate argument to pass to the hook's callback function.<br>Although not passed to a callback, these arguments are used to uniquely identify<br>the event.
`$timestamp` | `int\|null` | Unix timestamp (UTC) of the event. Null to retrieve next scheduled event.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 730](../../wordpress/wp-includes/cron.php#L730-L748)

### `cron_request`

*Filters the cron request arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('url' => add_query_arg('doing_wp_cron', $doing_wp_cron, site_url('wp-cron.php')), 'key' => $doing_wp_cron, 'args' => array(
    'timeout' => 0.01,
    'blocking' => false,
    /** This filter is documented in wp-includes/class-wp-http-streams.php */
    'sslverify' => apply_filters(false),
))` |  | 
`$doing_wp_cron` | `string` | The unix timestamp of the cron lock.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | The `$doing_wp_cron` parameter was added.
`3.5.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 888](../../wordpress/wp-includes/cron.php#L888-L922)

### `https_local_ssl_verify`

*This filter is documented in wp-includes/class-wp-http-streams.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 917](../../wordpress/wp-includes/cron.php#L917-L918)

### `cron_schedules`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 1064](../../wordpress/wp-includes/cron.php#L1064-L1064)

### `get_schedule`

*Filters the schedule for a hook.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$schedule` | `string\|false` | Schedule for the hook. False if not found.
`$hook` | `string` | Action hook to execute when cron is run.
`$args` | `array` | Arguments to pass to the hook's callback function.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 1088](../../wordpress/wp-includes/cron.php#L1088-L1097)

### `pre_get_ready_cron_jobs`

*Filter to preflight or hijack retrieving ready cron jobs.*

Returning an array will short-circuit the normal retrieval of ready
cron jobs, causing the function to return the filtered value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/cron.php](../../wordpress/wp-includes/cron.php), [line 1111](../../wordpress/wp-includes/cron.php#L1111-L1122)

### `embed_handler_html`

*Filters the returned embed HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `string\|false` | The HTML result of the shortcode, or false on failure.
`$url` | `string` | The embed URL.
`$attr` | `array` | An array of shortcode attributes.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-embed.php](../../wordpress/wp-includes/class-wp-embed.php), [line 157](../../wordpress/wp-includes/class-wp-embed.php#L157-L168)

### `oembed_ttl`

*Filters the oEmbed TTL value (time to live).*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`DAY_IN_SECONDS` |  | 
`$url` | `string` | The attempted embed URL.
`$attr` | `array` | An array of shortcode attributes.
`$post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-embed.php](../../wordpress/wp-includes/class-wp-embed.php), [line 235](../../wordpress/wp-includes/class-wp-embed.php#L235-L245)

### `embed_oembed_html`

*Filters the cached oEmbed HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cache` | `string\|false` | The cached HTML result, stored in post meta.
`$url` | `string` | The attempted embed URL.
`$attr` | `array` | An array of shortcode attributes.
`$post_ID` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-embed.php](../../wordpress/wp-includes/class-wp-embed.php), [line 275](../../wordpress/wp-includes/class-wp-embed.php#L275-L287)

### `embed_oembed_discover`

*Filters whether to inspect the given URL for discoverable link tags.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | The default value changed to true.
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-embed.php](../../wordpress/wp-includes/class-wp-embed.php), [line 291](../../wordpress/wp-includes/class-wp-embed.php#L291-L301)

### `embed_oembed_html`

*This filter is documented in wp-includes/class-wp-embed.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` |  | 
`$url` |  | 
`$attr` |  | 
`$post_ID` |  | 

Source: [wordpress/wp-includes/class-wp-embed.php](../../wordpress/wp-includes/class-wp-embed.php), [line 369](../../wordpress/wp-includes/class-wp-embed.php#L369-L370)

### `embed_cache_oembed_types`

*Filters the array of post types to cache oEmbed results for.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_types` | `string[]` | Array of post type names to cache oEmbed results for. Defaults to post types with `show_ui` set to true.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-embed.php](../../wordpress/wp-includes/class-wp-embed.php), [line 405](../../wordpress/wp-includes/class-wp-embed.php#L405-L412)

### `embed_maybe_make_link`

*Filters the returned, maybe-linked embed URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The linked or original URL.
`$url` | `string` | The original URL.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-embed.php](../../wordpress/wp-includes/class-wp-embed.php), [line 481](../../wordpress/wp-includes/class-wp-embed.php#L481-L489)

### `customize_section_active`

*Filters response of WP_Customize_Section::active().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$active` | `bool` | Whether the Customizer section is active.
`$section` | `\WP_Customize_Section` | WP_Customize_Section instance.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/class-wp-customize-section.php](../../wordpress/wp-includes/class-wp-customize-section.php), [line 202](../../wordpress/wp-includes/class-wp-customize-section.php#L202-L210)

### `get_bookmarks`

*Filters the returned list of bookmarks.*

The first time the hook is evaluated in this file, it returns the cached
bookmarks list. The second evaluation returns a cached bookmarks list if the
link category is passed but does not exist. The third evaluation returns
the full cached results.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$bookmarks` | `array` | List of the cached bookmarks.
`$parsed_args` | `array` | An array of bookmark query arguments.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/bookmark.php](../../wordpress/wp-includes/bookmark.php), [line 159](../../wordpress/wp-includes/bookmark.php#L159-L174)

### `get_bookmarks`

*This filter is documented in wp-includes/bookmark.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$parsed_args` |  | 

Source: [wordpress/wp-includes/bookmark.php](../../wordpress/wp-includes/bookmark.php), [line 227](../../wordpress/wp-includes/bookmark.php#L227-L228)

### `get_bookmarks`

*This filter is documented in wp-includes/bookmark.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$results` |  | 
`$parsed_args` |  | 

Source: [wordpress/wp-includes/bookmark.php](../../wordpress/wp-includes/bookmark.php), [line 320](../../wordpress/wp-includes/bookmark.php#L320-L321)

### `edit_{$field}`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$bookmark_id` |  | 

Source: [wordpress/wp-includes/bookmark.php](../../wordpress/wp-includes/bookmark.php), [line 426](../../wordpress/wp-includes/bookmark.php#L426-L427)

### `pre_{$field}`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 

Source: [wordpress/wp-includes/bookmark.php](../../wordpress/wp-includes/bookmark.php), [line 435](../../wordpress/wp-includes/bookmark.php#L435-L436)

### `{$field}`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$bookmark_id` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/bookmark.php](../../wordpress/wp-includes/bookmark.php), [line 438](../../wordpress/wp-includes/bookmark.php#L438-L439)

### `wp_sitemaps_enabled`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_enabled` |  | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps.php), [line 104](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps.php#L104-L104)

### `wp_sitemaps_post_types`

*Filters the list of post object sub types available within the sitemap.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_types` | `\WP_Post_Type[]` | Array of registered post type objects keyed by their name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php), [line 42](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php#L42-L49)

### `wp_sitemaps_posts_pre_url_list`

*Filters the posts URL list before it is generated.*

Passing a non-null value will effectively short-circuit the generation,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post_type` | `string` | Post type name.
`$page_num` | `int` | Page of results.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php), [line 69](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php#L69-L86)

### `wp_sitemaps_posts_show_on_front_entry`

*Filters the sitemap entry for the home page when the 'show_on_front' option equals 'posts'.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemap_entry` | `array` | Sitemap entry for the home page.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php), [line 109](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php#L109-L116)

### `wp_sitemaps_posts_entry`

*Filters the sitemap entry for an individual post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemap_entry` | `array` | Sitemap entry for the post.
`$post` | `\WP_Post` | Post object.
`$post_type` | `string` | Name of the post_type.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php), [line 125](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php#L125-L134)

### `wp_sitemaps_posts_pre_max_num_pages`

*Filters the max number of pages before it is generated.*

Passing a non-null value will short-circuit the generation,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$post_type` | `string` | Post type name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php), [line 154](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php#L154-L165)

### `wp_sitemaps_posts_query_args`

*Filters the query arguments for post type sitemap queries.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('orderby' => 'ID', 'order' => 'ASC', 'post_type' => $post_type, 'posts_per_page' => wp_sitemaps_get_max_urls($this->object_type), 'post_status' => array('publish'), 'no_found_rows' => true, 'update_post_term_cache' => false, 'update_post_meta_cache' => false)` |  | 
`$post_type` | `string` | Post type name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php), [line 190](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-posts.php#L190-L213)

### `wp_sitemaps_users_pre_url_list`

*Filters the users URL list before it is generated.*

Passing a non-null value will effectively short-circuit the generation,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$page_num` | `int` | Page of results.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php), [line 40](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php#L40-L55)

### `wp_sitemaps_users_entry`

*Filters the sitemap entry for an individual user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemap_entry` | `array` | Sitemap entry for the user.
`$user` | `\WP_User` | User object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php), [line 73](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php#L73-L81)

### `wp_sitemaps_users_pre_max_num_pages`

*Filters the max number of pages before it is generated.*

Passing a non-null value will effectively short-circuit the generation,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php), [line 101](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php#L101-L111)

### `wp_sitemaps_users_query_args`

*Filters the query arguments for authors with public posts.*

Allows modification of the authors query arguments before querying.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('has_published_posts' => array_keys($public_post_types), 'number' => wp_sitemaps_get_max_urls($this->object_type))` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php), [line 142](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-users.php#L142-L159)

### `wp_sitemaps_taxonomies`

*Filters the list of taxonomy object subtypes available within the sitemap.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$taxonomies` | `\WP_Taxonomy[]` | Array of registered taxonomy objects keyed by their name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php), [line 40](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php#L40-L47)

### `wp_sitemaps_taxonomies_pre_url_list`

*Filters the taxonomies URL list before it is generated.*

Passing a non-null value will effectively short-circuit the generation,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$taxonomy` | `string` | Taxonomy name.
`$page_num` | `int` | Page of results.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php), [line 67](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php#L67-L84)

### `wp_sitemaps_taxonomies_entry`

*Filters the sitemap entry for an individual term.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemap_entry` | `array` | Sitemap entry for the term.
`$term` | `\WP_Term` | Term object.
`$taxonomy` | `string` | Taxonomy name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php), [line 112](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php#L112-L121)

### `wp_sitemaps_taxonomies_pre_max_num_pages`

*Filters the max number of pages before it is generated.*

Passing a non-null value will short-circuit the generation,
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$taxonomy` | `string` | Taxonomy name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php), [line 142](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php#L142-L153)

### `wp_sitemaps_taxonomies_query_args`

*Filters the taxonomy terms query arguments.*

Allows modification of the taxonomy query arguments before querying.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('fields' => 'ids', 'taxonomy' => $taxonomy, 'orderby' => 'term_order', 'number' => wp_sitemaps_get_max_urls($this->object_type), 'hide_empty' => true, 'hierarchical' => false, 'update_term_meta_cache' => false)` |  | 
`$taxonomy` | `string` | Taxonomy name.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php), [line 173](../../wordpress/wp-includes/sitemaps/providers/class-wp-sitemaps-taxonomies.php#L173-L197)

### `wp_sitemaps_stylesheet_content`

*Filters the content of the sitemap stylesheet.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$xsl_content` | `string` | Full content for the XML stylesheet.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php), [line 143](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php#L143-L150)

### `wp_sitemaps_stylesheet_index_content`

*Filters the content of the sitemap index stylesheet.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$xsl_content` | `string` | Full content for the XML stylesheet.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php), [line 241](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php#L241-L248)

### `wp_sitemaps_stylesheet_css`

*Filters the CSS only for the sitemap stylesheet.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$css` | `string` | CSS to be applied to default XSL file.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php), [line 307](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-stylesheet.php#L307-L314)

### `wp_sitemaps_index_entry`

*Filters the sitemap entry for the sitemap index.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemap_entry` | `array` | Sitemap entry for the post.
`$this->object_type` |  | 
`$type['name']` |  | 
`$page` | `int` | Page number of results.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps-provider.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-provider.php), [line 114](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-provider.php#L114-L125)

### `wp_sitemaps_stylesheet_url`

*Filters the URL for the sitemap stylesheet.*

If a falsey value is returned, no stylesheet will be used and
the "raw" XML of the sitemap will be displayed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemap_url` | `string` | Full URL for the sitemaps XSL file.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps-renderer.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-renderer.php), [line 73](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-renderer.php#L73-L83)

### `wp_sitemaps_stylesheet_index_url`

*Filters the URL for the sitemap index stylesheet.*

If a falsey value is returned, no stylesheet will be used and
the "raw" XML of the sitemap index will be displayed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sitemap_url` | `string` | Full URL for the sitemaps index XSL file.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps-renderer.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-renderer.php), [line 104](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-renderer.php#L104-L114)

### `wp_sitemaps_add_provider`

*Filters the sitemap provider before it is added.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$provider` | `\WP_Sitemaps_Provider` | Instance of a WP_Sitemaps_Provider.
`$name` | `string` | Name of the sitemap provider.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps/class-wp-sitemaps-registry.php](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-registry.php), [line 41](../../wordpress/wp-includes/sitemaps/class-wp-sitemaps-registry.php#L41-L49)

### `wp_robots`

*Filters the directives to be included in the 'robots' meta tag.*

The meta tag will only be included as necessary.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/robots-template.php](../../wordpress/wp-includes/robots-template.php), [line 20](../../wordpress/wp-includes/robots-template.php#L20-L31)

### `wp_admin_bar_class`

*Filters the admin bar class to instantiate.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'WP_Admin_Bar'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/admin-bar.php](../../wordpress/wp-includes/admin-bar.php), [line 35](../../wordpress/wp-includes/admin-bar.php#L35-L42)

### `show_admin_bar`

*Filters whether to show the admin bar.*

Returning false to this hook is the recommended way to hide the admin bar.
The user's display preference is used for logged in users.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$show_admin_bar` | `bool` | Whether the admin bar should be shown. Default false.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/admin-bar.php](../../wordpress/wp-includes/admin-bar.php), [line 1222](../../wordpress/wp-includes/admin-bar.php#L1222-L1232)

### `customize_control_active`

*Filters response of WP_Customize_Control::active().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$active` | `bool` | Whether the Customizer control is active.
`$control` | `\WP_Customize_Control` | WP_Customize_Control instance.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-customize-control.php](../../wordpress/wp-includes/class-wp-customize-control.php), [line 261](../../wordpress/wp-includes/class-wp-customize-control.php#L261-L269)

### `wp_sitemaps_max_urls`

*Filters the maximum number of URLs displayed on a sitemap.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`2000` |  | 
`$object_type` | `string` | Object type for sitemap to be filtered (e.g. 'post', 'term', 'user').

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/sitemaps.php](../../wordpress/wp-includes/sitemaps.php), [line 80](../../wordpress/wp-includes/sitemaps.php#L80-L88)

### `page_css_class`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$css_class` |  | 
`$page` |  | 
`$depth` |  | 
`$args` |  | 
`$current_page` |  | 

Source: [wordpress/wp-includes/class-walker-page.php](../../wordpress/wp-includes/class-walker-page.php), [line 152](../../wordpress/wp-includes/class-walker-page.php#L152-L152)

### `page_menu_link_attributes`

*Filters the HTML attributes applied to a page menu item's anchor element.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$atts` | `array` | {<br>    The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.<br><br>    @type string $href         The href attribute.<br>    @type string $aria_current The aria-current attribute.<br>}
`$page` | `\WP_Post` | Page data object.
`$depth` | `int` | Depth of page, used for padding.
`$args` | `array` | An array of arguments.
`$current_page` | `int` | ID of the current page.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/class-walker-page.php](../../wordpress/wp-includes/class-walker-page.php), [line 167](../../wordpress/wp-includes/class-walker-page.php#L167-L183)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$page->post_title` |  | 
`$page->ID` |  | 

Source: [wordpress/wp-includes/class-walker-page.php](../../wordpress/wp-includes/class-walker-page.php), [line 198](../../wordpress/wp-includes/class-walker-page.php#L198-L199)

### `wp_nav_menu_args`

*Filters the arguments used to display a navigation menu.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of wp_nav_menu() arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu-template.php](../../wordpress/wp-includes/nav-menu-template.php), [line 88](../../wordpress/wp-includes/nav-menu-template.php#L88-L97)

### `pre_wp_nav_menu`

*Filters whether to short-circuit the wp_nav_menu() output.*

Returning a non-null value from the filter will short-circuit wp_nav_menu(),
echoing that value if $args->echo is true, returning that value otherwise.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$args` | `\stdClass` | An object containing wp_nav_menu() arguments.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/nav-menu-template.php](../../wordpress/wp-includes/nav-menu-template.php), [line 100](../../wordpress/wp-includes/nav-menu-template.php#L100-L113)

### `wp_nav_menu_container_allowedtags`

*Filters the list of HTML tags that are valid for use as menu containers.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('div', 'nav')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu-template.php](../../wordpress/wp-includes/nav-menu-template.php), [line 176](../../wordpress/wp-includes/nav-menu-template.php#L176-L184)

### `wp_nav_menu_objects`

*Filters the sorted list of menu item objects before generating the menu's HTML.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sorted_menu_items` | `array` | The menu items, sorted by each menu item's menu order.
`$args` | `\stdClass` | An object containing wp_nav_menu() arguments.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/nav-menu-template.php](../../wordpress/wp-includes/nav-menu-template.php), [line 218](../../wordpress/wp-includes/nav-menu-template.php#L218-L226)

### `wp_nav_menu_items`

*Filters the HTML list content for navigation menus.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$items` | `string` | The HTML list content for the menu items.
`$args` | `\stdClass` | An object containing wp_nav_menu() arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu-template.php](../../wordpress/wp-includes/nav-menu-template.php), [line 249](../../wordpress/wp-includes/nav-menu-template.php#L249-L259)

### `wp_nav_menu_{$menu->slug}_items`

*Filters the HTML list content for a specific navigation menu.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$items` | `string` | The HTML list content for the menu items.
`$args` | `\stdClass` | An object containing wp_nav_menu() arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu-template.php](../../wordpress/wp-includes/nav-menu-template.php), [line 260](../../wordpress/wp-includes/nav-menu-template.php#L260-L270)

### `wp_nav_menu`

*Filters the HTML content for navigation menus.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nav_menu` | `string` | The HTML content for the navigation menu.
`$args` | `\stdClass` | An object containing wp_nav_menu() arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu-template.php](../../wordpress/wp-includes/nav-menu-template.php), [line 284](../../wordpress/wp-includes/nav-menu-template.php#L284-L294)

### `recovery_mode_email_rate_limit`

*Filters the rate limit between sending new recovery mode email links.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`DAY_IN_SECONDS` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode.php](../../wordpress/wp-includes/class-wp-recovery-mode.php), [line 299](../../wordpress/wp-includes/class-wp-recovery-mode.php#L299-L306)

### `recovery_mode_email_link_ttl`

*Filters the amount of time the recovery mode email link is valid for.*

The ttl must be at least as long as the email rate limit.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$valid_for` | `int` | The number of seconds the link is valid for.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode.php](../../wordpress/wp-includes/class-wp-recovery-mode.php), [line 321](../../wordpress/wp-includes/class-wp-recovery-mode.php#L321-L330)

### `comment_text`

*This filter is documented in wp-includes/comment-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment` |  | 
`null` |  | 
`array()` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 47](../../wordpress/wp-includes/comment.php#L47-L48)

### `comment_max_links_url`

*Filters the number of links found in a comment.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$num_links` | `int` | The number of links found.
`$url` | `string` | Comment author's URL. Included in allowed links total.
`$comment` | `string` | Content of the comment.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Added the `$comment` parameter.
`3.0.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 55](../../wordpress/wp-includes/comment.php#L55-L65)

### `get_comment`

*Fires after a comment is retrieved.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_comment` | `\WP_Comment` | Comment data.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 212](../../wordpress/wp-includes/comment.php#L212-L219)

### `get_default_comment_status`

*Filters the default comment status for the given post type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$status` | `string` | Default status for the given post type,<br>either 'open' or 'closed'.
`$post_type` | `string` | Post type. Default is `post`.
`$comment_type` | `string` | Type of comment. Default is `comment`.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 299](../../wordpress/wp-includes/comment.php#L299-L309)

### `comment_cookie_lifetime`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`30000000` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 589](../../wordpress/wp-includes/comment.php#L589-L589)

### `pre_comment_author_name`

*Filters the comment author's name cookie before it is set.*

When this filter hook is evaluated in wp_filter_comment(),
the comment author's name string is passed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_COOKIE['comment_author_' . COOKIEHASH]` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 608](../../wordpress/wp-includes/comment.php#L608-L618)

### `pre_comment_author_email`

*Filters the comment author's email cookie before it is set.*

When this filter hook is evaluated in wp_filter_comment(),
the comment author's email string is passed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_COOKIE['comment_author_email_' . COOKIEHASH]` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 625](../../wordpress/wp-includes/comment.php#L625-L635)

### `pre_comment_author_url`

*Filters the comment author's URL cookie before it is set.*

When this filter hook is evaluated in wp_filter_comment(),
the comment author's URL string is passed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_COOKIE['comment_author_url_' . COOKIEHASH]` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 642](../../wordpress/wp-includes/comment.php#L642-L652)

### `duplicate_comment_id`

*Filters the ID, if any, of the duplicate comment found when creating a new comment.*

Return an empty value from this filter to allow what WP considers a duplicate comment.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$dupe_id` | `int` | ID of the comment identified as a duplicate.
`$commentdata` | `array` | Data for the comment being created.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 699](../../wordpress/wp-includes/comment.php#L699-L709)

### `comment_duplicate_message`

*Filters duplicate comment error message.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Duplicate comment detected; it looks as though you&#8217;ve already said that!')` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 721](../../wordpress/wp-includes/comment.php#L721-L728)

### `wp_is_comment_flood`

*Filters whether a comment is part of a comment flood.*

The default check is wp_check_comment_flood(). See check_comment_flood_db().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$commentdata['comment_author_IP']` |  | 
`$commentdata['comment_author_email']` |  | 
`$commentdata['comment_date_gmt']` |  | 
`$wp_error` | `bool` | Whether to return a WP_Error object instead of executing<br>wp_die() or die() if a comment flood is occurring.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$avoid_die` parameter was renamed to `$wp_error`.
`4.7.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 764](../../wordpress/wp-includes/comment.php#L764-L786)

### `comment_flood_message`

*This filter is documented in wp-includes/comment-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('You are posting comments too quickly. Slow down.')` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 789](../../wordpress/wp-includes/comment.php#L789-L790)

### `pre_comment_approved`

*Filters a comment's approval status before it is set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$approved` | `int\|string\|\WP_Error` | The approval status. Accepts 1, 0, 'spam', 'trash',<br>or WP_Error.
`$commentdata` | `array` | Comment data.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Returning a WP_Error value from the filter will short-circuit comment insertion
and allow skipping further processing.
`2.1.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 836](../../wordpress/wp-includes/comment.php#L836-L847)

### `comment_flood_filter`

*Filters the comment flood status.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$time_lastcomment` | `int` | Timestamp of when the last comment was posted.
`$time_newcomment` | `int` | Timestamp of when the new comment was posted.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 919](../../wordpress/wp-includes/comment.php#L919-L928)

### `comment_flood_message`

*Filters the comment flood error message.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('You are posting comments too quickly. Slow down.')` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 944](../../wordpress/wp-includes/comment.php#L944-L951)

### `get_page_of_comment_query_args`

*Filters the arguments used to query comments in get_page_of_comment().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment_args` | `array` | {<br>    Array of WP_Comment_Query arguments.<br><br>    @type string $type               Limit paginated comments to those matching a given type.<br>                                     Accepts 'comment', 'trackback', 'pingback', 'pings'<br>                                     (trackbacks and pingbacks), or 'all'. Default 'all'.<br>    @type int    $post_id            ID of the post.<br>    @type string $fields             Comment fields to return.<br>    @type bool   $count              Whether to return a comment count (true) or array<br>                                     of comment objects (false).<br>    @type string $status             Comment status.<br>    @type int    $parent             Parent ID of comment to retrieve children of.<br>    @type array  $date_query         Date query clauses to limit comments by. See WP_Date_Query.<br>    @type array  $include_unapproved Array of IDs or email addresses whose unapproved comments<br>                                     will be included in paginated comments.<br>}

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1157](../../wordpress/wp-includes/comment.php#L1157-L1181)

### `get_page_of_comment`

*Filters the calculated page on which a comment appears.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`(int) $page` |  | 
`$args` | `array` | {<br>    Arguments used to calculate pagination. These include arguments auto-detected by the function,<br>    based on query vars, system settings, etc. For pristine arguments passed to the function,<br>    see `$original_args`.<br><br>    @type string $type      Type of comments to count.<br>    @type int    $page      Calculated current page.<br>    @type int    $per_page  Calculated number of comments per page.<br>    @type int    $max_depth Maximum comment threading depth allowed.<br>}
`$original_args` | `array` | {<br>    Array of arguments passed to the function. Some or all of these may not be set.<br><br>    @type string $type      Type of comments to count.<br>    @type int    $page      Current comment page.<br>    @type int    $per_page  Number of comments per page.<br>    @type int    $max_depth Maximum comment threading depth allowed.<br>}
`$comment_ID` | `int` | ID of the comment.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | Introduced the `$comment_ID` parameter.
`4.4.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1196](../../wordpress/wp-includes/comment.php#L1196-L1223)

### `wp_get_comment_fields_max_lengths`

*Filters the lengths for the comment form fields.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$lengths` | `int[]` | Array of maximum lengths keyed by field name.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1271](../../wordpress/wp-includes/comment.php#L1271-L1278)

### `wp_count_comments`

*Filters the comments count for a given post or the whole site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$post_id` | `int` | The post ID. Can be 0 to represent the whole site.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1424](../../wordpress/wp-includes/comment.php#L1424-L1432)

### `wp_get_current_commenter`

*Filters the current commenter's name, email, and URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`compact('comment_author', 'comment_author_email', 'comment_author_url')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 1903](../../wordpress/wp-includes/comment.php#L1903-L1916)

### `pre_user_id`

*Filters the comment author's user ID before it is set.*

The first time this filter is evaluated, 'user_ID' is checked
(for back-compat), followed by the standard 'user_id' value.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['user_ID']` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2066](../../wordpress/wp-includes/comment.php#L2066-L2076)

### `pre_user_id`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['user_id']` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2078](../../wordpress/wp-includes/comment.php#L2078-L2079)

### `pre_comment_user_agent`

*Filters the comment author's browser user agent before it is set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`isset($commentdata['comment_agent']) ? $commentdata['comment_agent'] : ''` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2082](../../wordpress/wp-includes/comment.php#L2082-L2089)

### `pre_comment_author_name`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['comment_author']` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2090](../../wordpress/wp-includes/comment.php#L2090-L2091)

### `pre_comment_content`

*Filters the comment content before it is set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['comment_content']` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2092](../../wordpress/wp-includes/comment.php#L2092-L2099)

### `pre_comment_user_ip`

*Filters the comment author's IP address before it is set.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['comment_author_IP']` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2100](../../wordpress/wp-includes/comment.php#L2100-L2107)

### `pre_comment_author_url`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['comment_author_url']` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2108](../../wordpress/wp-includes/comment.php#L2108-L2109)

### `pre_comment_author_email`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata['comment_author_email']` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2110](../../wordpress/wp-includes/comment.php#L2110-L2111)

### `preprocess_comment`

*Filters a comment's data before it is sanitized and inserted into the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$commentdata` | `array` | Comment data.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | Comment data includes the `comment_agent` and `comment_author_IP` values.
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2201](../../wordpress/wp-includes/comment.php#L2201-L2209)

### `notify_moderator`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$maybe_notify` |  | 
`$comment_ID` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2300](../../wordpress/wp-includes/comment.php#L2300-L2301)

### `notify_post_author`

*Filters whether to send the post author new comment notification emails,
overriding the site setting.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$maybe_notify` | `bool` | Whether to notify the post author about the new comment.
`$comment_ID` | `int` | The ID of the comment for the notification.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2326](../../wordpress/wp-includes/comment.php#L2326-L2335)

### `comment_save_pre`

*Filters the comment content before it is updated in the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data['comment_content']` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2477](../../wordpress/wp-includes/comment.php#L2477-L2484)

### `wp_update_comment_data`

*Filters the comment data immediately before it is updated in the database.*

Note: data being passed to the filter is already unslashed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array\|\WP_Error` | The new, processed comment data, or WP_Error.
`$comment` | `array` | The old, unslashed comment data.
`$commentarr` | `array` | The new, raw comment data.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Returning a WP_Error value from the filter will short-circuit comment update
and allow skipping further processing.
`4.7.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2499](../../wordpress/wp-includes/comment.php#L2499-L2512)

### `pre_wp_update_comment_count_now`

*Filters a post's comment count before it is updated in the database.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$old` | `int` | The old comment count.
`$post_id` | `int` | Post ID.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2666](../../wordpress/wp-includes/comment.php#L2666-L2675)

### `the_content`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_content` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2907](../../wordpress/wp-includes/comment.php#L2907-L2908)

### `the_excerpt`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_excerpt` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2910](../../wordpress/wp-includes/comment.php#L2910-L2911)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_title` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 2917](../../wordpress/wp-includes/comment.php#L2917-L2918)

### `pingback_useragent`

*Filters the user agent sent when pinging-back a URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$client->useragent . ' -- WordPress/' . get_bloginfo('version')` |  | 
`$client->useragent` |  | 
`$pingback_server_url` | `string` | The server URL being linked to.
`$pagelinkedto` | `string` | URL of page linked to.
`$pagelinkedfrom` | `string` | URL of page linked from.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3047](../../wordpress/wp-includes/comment.php#L3047-L3059)

### `close_comments_for_post_types`

*Filters the list of post types to automatically close comments for.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('post')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3284](../../wordpress/wp-includes/comment.php#L3284-L3291)

### `close_comments_for_post_types`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('post')` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3335](../../wordpress/wp-includes/comment.php#L3335-L3336)

### `allow_empty_comment`

*Filters whether an empty comment should be allowed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$commentdata` | `array` | Array of comment data to be sent to wp_insert_comment().

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3544](../../wordpress/wp-includes/comment.php#L3544-L3552)

### `wp_anonymize_comment`

*Filters whether to anonymize the comment.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$comment` | `\WP_Comment` | WP_Comment object.
`$anonymized_comment` | `array` | Anonymized comment data.

**Changelog**

Version | Description
------- | -----------
`4.9.6` | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3754](../../wordpress/wp-includes/comment.php#L3754-L3764)

### `wp_update_comment_type_batch_size`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`100` |  | 

Source: [wordpress/wp-includes/comment.php](../../wordpress/wp-includes/comment.php), [line 3864](../../wordpress/wp-includes/comment.php#L3864-L3864)

### `wp_get_nav_menu_object`

*Filters the nav_menu term retrieved for wp_get_nav_menu_object().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_obj` | `\WP_Term\|false` | Term from nav_menu taxonomy, or false if nothing had been found.
`$menu` | `int\|string\|\WP_Term` | The menu ID, slug, name, or object passed to wp_get_nav_menu_object().

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 41](../../wordpress/wp-includes/nav-menu.php#L41-L49)

### `has_nav_menu`

*Filters whether a nav menu is assigned to the specified location.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$has_nav_menu` | `bool` | Whether there is a menu assigned to a location.
`$location` | `string` | Menu location.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 187](../../wordpress/wp-includes/nav-menu.php#L187-L195)

### `wp_get_nav_menu_name`

*Filters the navigation menu name being returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_name` | `string` | Menu name.
`$location` | `string` | Menu location identifier.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 219](../../wordpress/wp-includes/nav-menu.php#L219-L227)

### `wp_get_nav_menus`

*Filters the navigation menu objects being returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_terms($args)` |  | 
`$args` | `array` | An array of arguments used to retrieve menu objects.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 621](../../wordpress/wp-includes/nav-menu.php#L621-L631)

### `wp_get_nav_menu_items`

*Filters the navigation menu items being returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$items` | `array` | An array of menu item post objects.
`$menu` | `object` | The menu object.
`$args` | `array` | An array of arguments used to retrieve menu item objects.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 774](../../wordpress/wp-includes/nav-menu.php#L774-L783)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$original_object->post_title` |  | 
`$original_object->ID` |  | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 847](../../wordpress/wp-includes/nav-menu.php#L847-L848)

### `nav_menu_attr_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_item->post_excerpt` |  | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 919](../../wordpress/wp-includes/nav-menu.php#L919-L919)

### `nav_menu_description`

*Filters a navigation menu item's description.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_trim_words($menu_item->post_content, 200)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 922](../../wordpress/wp-includes/nav-menu.php#L922-L929)

### `nav_menu_attr_title`

*This filter is documented in wp-includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 953](../../wordpress/wp-includes/nav-menu.php#L953-L954)

### `nav_menu_description`

*This filter is documented in wp-includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 956](../../wordpress/wp-includes/nav-menu.php#L956-L957)

### `wp_setup_nav_menu_item`

*Filters a navigation menu item object.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_item` | `object` | The menu item object.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/nav-menu.php](../../wordpress/wp-includes/nav-menu.php), [line 983](../../wordpress/wp-includes/nav-menu.php#L983-L990)

### `image_size_names_choose`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('thumbnail' => __('Thumbnail'), 'medium' => __('Medium'), 'large' => __('Large'), 'full' => __('Full Size'))` |  | 

Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 850](../../wordpress/wp-includes/media-template.php#L850-L859)

### `image_size_names_choose`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('thumbnail' => __('Thumbnail'), 'medium' => __('Medium'), 'large' => __('Large'), 'full' => __('Full Size'))` |  | 

Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 930](../../wordpress/wp-includes/media-template.php#L930-L939)

### `disable_captions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 1019](../../wordpress/wp-includes/media-template.php#L1019-L1019)

### `disable_captions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 1082](../../wordpress/wp-includes/media-template.php#L1082-L1082)

### `image_size_names_choose`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('thumbnail' => __('Thumbnail'), 'medium' => __('Medium'), 'large' => __('Large'), 'full' => __('Full Size'))` |  | 

Source: [wordpress/wp-includes/media-template.php](../../wordpress/wp-includes/media-template.php), [line 1121](../../wordpress/wp-includes/media-template.php#L1121-L1130)

### `link_category`

*Filters the category name.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cat->name` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/bookmark-template.php](../../wordpress/wp-includes/bookmark-template.php), [line 270](../../wordpress/wp-includes/bookmark-template.php#L270-L277)

### `wp_list_bookmarks`

*Filters the bookmarks list before it is echoed or returned.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/bookmark-template.php](../../wordpress/wp-includes/bookmark-template.php), [line 311](../../wordpress/wp-includes/bookmark-template.php#L311-L318)

### `nav_menu_submenu_css_class`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classes` |  | 
`$args` |  | 
`$depth` |  | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 75](../../wordpress/wp-includes/class-walker-nav-menu.php#L75-L75)

### `nav_menu_item_args`

*Filters the arguments for a single nav menu item.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `\stdClass` | An object of wp_nav_menu() arguments.
`$item` | `\WP_Post` | Menu item data object.
`$depth` | `int` | Depth of menu item. Used for padding.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 131](../../wordpress/wp-includes/class-walker-nav-menu.php#L131-L140)

### `nav_menu_css_class`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array_filter($classes)` |  | 
`$item` |  | 
`$args` |  | 
`$depth` |  | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 153](../../wordpress/wp-includes/class-walker-nav-menu.php#L153-L153)

### `nav_menu_item_id`

*Filters the ID applied to a menu item's list item element.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'menu-item-' . $item->ID` |  | 
`$item` | `\WP_Post` | The current menu item.
`$args` | `\stdClass` | An object of wp_nav_menu() arguments.
`$depth` | `int` | Depth of menu item. Used for padding.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$depth` parameter was added.
`3.0.1` | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 156](../../wordpress/wp-includes/class-walker-nav-menu.php#L156-L167)

### `nav_menu_link_attributes`

*Filters the HTML attributes applied to a menu item's anchor element.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$atts` | `array` | {<br>    The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.<br><br>    @type string $title        Title attribute.<br>    @type string $target       Target attribute.<br>    @type string $rel          The rel attribute.<br>    @type string $href         The href attribute.<br>    @type string $aria_current The aria-current attribute.<br>}
`$item` | `\WP_Post` | The current menu item.
`$args` | `\stdClass` | An object of wp_nav_menu() arguments.
`$depth` | `int` | Depth of menu item. Used for padding.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | The `$depth` parameter was added.
`3.6.0` | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 183](../../wordpress/wp-includes/class-walker-nav-menu.php#L183-L202)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$item->title` |  | 
`$item->ID` |  | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 212](../../wordpress/wp-includes/class-walker-nav-menu.php#L212-L213)

### `nav_menu_item_title`

*Filters a menu item's title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | The menu item's title.
`$item` | `\WP_Post` | The current menu item.
`$args` | `\stdClass` | An object of wp_nav_menu() arguments.
`$depth` | `int` | Depth of menu item. Used for padding.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 215](../../wordpress/wp-includes/class-walker-nav-menu.php#L215-L225)

### `walker_nav_menu_start_el`

*Filters a menu item's starting output.*

The menu item's starting output only includes `$args->before`, the opening `<a>`,
the menu item's title, the closing `</a>`, and `$args->after`. Currently, there is
no filter for modifying the opening and closing `<li>` for a menu item.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$item_output` | `string` | The menu item's starting HTML output.
`$item` | `\WP_Post` | Menu item data object.
`$depth` | `int` | Depth of menu item. Used for padding.
`$args` | `\stdClass` | An object of wp_nav_menu() arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/class-walker-nav-menu.php](../../wordpress/wp-includes/class-walker-nav-menu.php), [line 233](../../wordpress/wp-includes/class-walker-nav-menu.php#L233-L247)

### `recovery_email_support_info`

*Filters the support message sent with the the fatal error protection email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`__('Please contact your host for assistance with investigating this issue further.')` |  | 

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode-email-service.php](../../wordpress/wp-includes/class-wp-recovery-mode-email-service.php), [line 133](../../wordpress/wp-includes/class-wp-recovery-mode-email-service.php#L133-L140)

### `recovery_email_debug_info`

*Filters the debug information included in the fatal error protection email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->get_debug($extension)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode-email-service.php](../../wordpress/wp-includes/class-wp-recovery-mode-email-service.php), [line 142](../../wordpress/wp-includes/class-wp-recovery-mode-email-service.php#L142-L149)

### `recovery_mode_email`

*Filters the contents of the Recovery Mode email.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$email` | `array` | {<br>    Used to build a call to wp_mail().<br><br>    @type string\|array $to          Array or comma-separated list of email addresses to send message.<br>    @type string       $subject     Email subject<br>    @type string       $message     Message contents<br>    @type string\|array $headers     Optional. Additional headers.<br>    @type string\|array $attachments Optional. Files to attach.<br>}
`$url` | `string` | URL to enter recovery mode.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The `$email` argument includes the `attachments` key.
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode-email-service.php](../../wordpress/wp-includes/class-wp-recovery-mode-email-service.php), [line 205](../../wordpress/wp-includes/class-wp-recovery-mode-email-service.php#L205-L222)

### `networks_pre_query`

*Filters the network data before the query takes place.*

Return a non-null value to bypass WordPress' default network queries.

The expected return type from this filter depends on the value passed
in the request query vars:
- When `$this->query_vars['count']` is set, the filter should return
  the network count as an integer.
- When `'ids' === $this->query_vars['fields']`, the filter should return
  an array of network IDs.
- Otherwise the filter should return an array of WP_Network objects.

Note that if the filter returns an array of network data, it will be assigned
to the `networks` property of the current WP_Network_Query instance.

Filtering functions that require pagination information are encouraged to set
the `found_networks` and `max_num_pages` properties of the WP_Network_Query object,
passed to the filter by reference. If WP_Network_Query does not perform a database
query, it will not have enough information to generate these values itself.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($network_data, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | The returned array of network data is assigned to the `networks` property
of the current WP_Network_Query instance.
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-network-query.php](../../wordpress/wp-includes/class-wp-network-query.php), [line 202](../../wordpress/wp-includes/class-wp-network-query.php#L202-L232)

### `the_networks`

*Filters the network query results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($_networks, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-network-query.php](../../wordpress/wp-includes/class-wp-network-query.php), [line 300](../../wordpress/wp-includes/class-wp-network-query.php#L300-L308)

### `networks_clauses`

*Filters the network query clauses.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(compact($pieces), &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-network-query.php](../../wordpress/wp-includes/class-wp-network-query.php), [line 443](../../wordpress/wp-includes/class-wp-network-query.php#L443-L451)

### `found_networks_query`

*Filters the query used to retrieve found network count.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'SELECT FOUND_ROWS()'` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-network-query.php](../../wordpress/wp-includes/class-wp-network-query.php), [line 506](../../wordpress/wp-includes/class-wp-network-query.php#L506-L514)

### `oembed_providers`

*Filters the list of sanctioned oEmbed providers.*

Since WordPress 4.4, oEmbed discovery is enabled for all users and allows embedding of sanitized
iframes. The providers in this list are sanctioned, meaning they are trusted and allowed to
embed any content, such as iframes, videos, JavaScript, and arbitrary HTML.

Supported providers:

|   Provider   |                     Flavor                |  Since  |
| ------------ | ----------------------------------------- | ------- |
| Dailymotion  | dailymotion.com                           | 2.9.0   |
| Flickr       | flickr.com                                | 2.9.0   |
| Scribd       | scribd.com                                | 2.9.0   |
| Vimeo        | vimeo.com                                 | 2.9.0   |
| WordPress.tv | wordpress.tv                              | 2.9.0   |
| YouTube      | youtube.com/watch                         | 2.9.0   |
| Crowdsignal  | polldaddy.com                             | 3.0.0   |
| SmugMug      | smugmug.com                               | 3.0.0   |
| YouTube      | youtu.be                                  | 3.0.0   |
| Twitter      | twitter.com                               | 3.4.0   |
| Slideshare   | slideshare.net                            | 3.5.0   |
| SoundCloud   | soundcloud.com                            | 3.5.0   |
| Dailymotion  | dai.ly                                    | 3.6.0   |
| Flickr       | flic.kr                                   | 3.6.0   |
| Spotify      | spotify.com                               | 3.6.0   |
| Imgur        | imgur.com                                 | 3.9.0   |
| Meetup.com   | meetup.com                                | 3.9.0   |
| Meetup.com   | meetu.ps                                  | 3.9.0   |
| Animoto      | animoto.com                               | 4.0.0   |
| Animoto      | video214.com                              | 4.0.0   |
| Issuu        | issuu.com                                 | 4.0.0   |
| Mixcloud     | mixcloud.com                              | 4.0.0   |
| Crowdsignal  | poll.fm                                   | 4.0.0   |
| TED          | ted.com                                   | 4.0.0   |
| YouTube      | youtube.com/playlist                      | 4.0.0   |
| Tumblr       | tumblr.com                                | 4.2.0   |
| Kickstarter  | kickstarter.com                           | 4.2.0   |
| Kickstarter  | kck.st                                    | 4.2.0   |
| Cloudup      | cloudup.com                               | 4.3.0   |
| ReverbNation | reverbnation.com                          | 4.4.0   |
| VideoPress   | videopress.com                            | 4.4.0   |
| Reddit       | reddit.com                                | 4.4.0   |
| Speaker Deck | speakerdeck.com                           | 4.4.0   |
| Twitter      | twitter.com/timelines                     | 4.5.0   |
| Twitter      | twitter.com/moments                       | 4.5.0   |
| Twitter      | twitter.com/user                          | 4.7.0   |
| Twitter      | twitter.com/likes                         | 4.7.0   |
| Twitter      | twitter.com/lists                         | 4.7.0   |
| Screencast   | screencast.com                            | 4.8.0   |
| Amazon       | amazon.com (com.mx, com.br, ca)           | 4.9.0   |
| Amazon       | amazon.de (fr, it, es, in, nl, ru, co.uk) | 4.9.0   |
| Amazon       | amazon.co.jp (com.au)                     | 4.9.0   |
| Amazon       | amazon.cn                                 | 4.9.0   |
| Amazon       | a.co                                      | 4.9.0   |
| Amazon       | amzn.to (eu, in, asia)                    | 4.9.0   |
| Amazon       | z.cn                                      | 4.9.0   |
| Someecards   | someecards.com                            | 4.9.0   |
| Someecards   | some.ly                                   | 4.9.0   |
| Crowdsignal  | survey.fm                                 | 5.1.0   |
| TikTok       | tiktok.com                                | 5.4.0   |

No longer supported providers:

|   Provider   |        Flavor        |   Since   |  Removed  |
| ------------ | -------------------- | --------- | --------- |
| Qik          | qik.com              | 2.9.0     | 3.9.0     |
| Viddler      | viddler.com          | 2.9.0     | 4.0.0     |
| Revision3    | revision3.com        | 2.9.0     | 4.2.0     |
| Blip         | blip.tv              | 2.9.0     | 4.4.0     |
| Rdio         | rdio.com             | 3.6.0     | 4.4.1     |
| Rdio         | rd.io                | 3.6.0     | 4.4.1     |
| Vine         | vine.co              | 4.1.0     | 4.9.0     |
| Photobucket  | photobucket.com      | 2.9.0     | 5.1.0     |
| Funny or Die | funnyordie.com       | 3.0.0     | 5.1.0     |
| CollegeHumor | collegehumor.com     | 4.0.0     | 5.3.1     |
| Hulu         | hulu.com             | 2.9.0     | 5.5.0     |
| Instagram    | instagram.com        | 3.5.0     | 5.5.2     |
| Instagram    | instagr.am           | 3.5.0     | 5.5.2     |
| Instagram TV | instagram.com        | 5.1.0     | 5.5.2     |
| Instagram TV | instagr.am           | 5.1.0     | 5.5.2     |
| Facebook     | facebook.com         | 4.7.0     | 5.5.2     |

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$providers` | `array[]` | An array of arrays containing data about popular oEmbed providers.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 121](../../wordpress/wp-includes/class-wp-oembed.php#L121-L210)

### `pre_oembed_result`

*Filters the oEmbed result before any HTTP requests are made.*

This allows one to short-circuit the default logic, perhaps by
replacing it with a routine that is more optimal for your setup.

Returning a non-null value from the filter will effectively short-circuit retrieval
and return the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$url` | `string` | The URL to the content that should be attempted to be embedded.
`$args` | `string\|array` | Optional. Additional arguments for retrieving embed HTML.<br>See wp_oembed_get() for accepted arguments. Default empty.

**Changelog**

Version | Description
------- | -----------
`4.5.3` | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 374](../../wordpress/wp-includes/class-wp-oembed.php#L374-L391)

### `oembed_result`

*Filters the HTML returned by the oEmbed provider.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->data2html($data, $url)` |  | 
`$url` | `string` | URL of the content to be embedded.
`$args` | `string\|array` | Optional. Additional arguments for retrieving embed HTML.<br>See wp_oembed_get() for accepted arguments. Default empty.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 403](../../wordpress/wp-includes/class-wp-oembed.php#L403-L413)

### `oembed_remote_get_args`

*Filters oEmbed remote get arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | oEmbed remote get arguments.
`$url` | `string` | URL to be inspected.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 430](../../wordpress/wp-includes/class-wp-oembed.php#L430-L440)

### `oembed_linktypes`

*Filters the link types that contain oEmbed provider URLs.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('application/json+oembed' => 'json', 'text/xml+oembed' => 'xml', 'application/xml+oembed' => 'xml')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 447](../../wordpress/wp-includes/class-wp-oembed.php#L447-L463)

### `oembed_fetch_url`

*Filters the oEmbed URL to be fetched.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$provider` | `string` | URL of the oEmbed provider.
`$url` | `string` | URL of the content to be embedded.
`$args` | `array` | Optional. Additional arguments for retrieving embed HTML.<br>See wp_oembed_get() for accepted arguments. Default empty.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `dnt` (Do Not Track) query parameter was added to all oEmbed provider URLs.
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 525](../../wordpress/wp-includes/class-wp-oembed.php#L525-L536)

### `oembed_remote_get_args`

*This filter is documented in wp-includes/class-wp-oembed.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`$provider_url_with_args` |  | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 560](../../wordpress/wp-includes/class-wp-oembed.php#L560-L561)

### `oembed_dataparse`

*Filters the returned oEmbed HTML.*

Use this filter to add support for custom data types, or to filter the result.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$return` | `string` | The returned oEmbed HTML.
`$data` | `object` | A data object result from an oEmbed provider.
`$url` | `string` | The URL of the content to be embedded.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/class-wp-oembed.php](../../wordpress/wp-includes/class-wp-oembed.php), [line 710](../../wordpress/wp-includes/class-wp-oembed.php#L710-L721)

### `wp_editor_set_quality`

*Filters the default image compression quality setting.*

Applies only during initial editor instantiation, or when set_quality() is run
manually without the `$quality` argument.

The WP_Image_Editor::set_quality() method has priority over the filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->default_quality` |  | 
`$this->mime_type` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-image-editor.php](../../wordpress/wp-includes/class-wp-image-editor.php), [line 228](../../wordpress/wp-includes/class-wp-image-editor.php#L228-L241)

### `jpeg_quality`

*Filters the JPEG compression quality for backward-compatibility.*

Applies only during initial editor instantiation, or when set_quality() is run
manually without the `$quality` argument.

The WP_Image_Editor::set_quality() method has priority over the filter.

The filter is evaluated under two contexts: 'image_resize', and 'edit_image',
(when a JPEG image is saved to file).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$quality` | `int` | Quality level between 0 (low) and 100 (high) of the JPEG.
`'image_resize'` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-image-editor.php](../../wordpress/wp-includes/class-wp-image-editor.php), [line 244](../../wordpress/wp-includes/class-wp-image-editor.php#L244-L260)

### `image_editor_default_mime_type`

*Filters default mime type prior to getting the file extension.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->default_mime_type` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/class-wp-image-editor.php](../../wordpress/wp-includes/class-wp-image-editor.php), [line 322](../../wordpress/wp-includes/class-wp-image-editor.php#L322-L331)

### `wp_image_maybe_exif_rotate`

*Filters the `$orientation` value to correct it before rotating or to prevemnt rotating the image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$orientation` | `int` | EXIF Orientation value as retrieved from the image file.
`$this->file` |  | 

**Changelog**

Version | Description
------- | -----------
`5.3.0` | 

Source: [wordpress/wp-includes/class-wp-image-editor.php](../../wordpress/wp-includes/class-wp-image-editor.php), [line 415](../../wordpress/wp-includes/class-wp-image-editor.php#L415-L423)

### `widget_display_callback`

*Filters the settings for a particular widget instance.*

Returning false will effectively short-circuit display of the widget.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance` | `array` | The current widget instance's settings.
`$this` |  | 
`$args` | `array` | An array of default widget arguments.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-widget.php](../../wordpress/wp-includes/class-wp-widget.php), [line 358](../../wordpress/wp-includes/class-wp-widget.php#L358-L369)

### `widget_update_callback`

*Filters a widget's settings before saving.*

Returning false will effectively short-circuit the widget's ability
to update settings.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance` | `array` | The current widget instance's settings.
`$new_instance` | `array` | Array of new widget settings.
`$old_instance` | `array` | Array of old widget settings.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-widget.php](../../wordpress/wp-includes/class-wp-widget.php), [line 449](../../wordpress/wp-includes/class-wp-widget.php#L449-L462)

### `widget_form_callback`

*Filters the widget instance's settings before displaying the control form.*

Returning false effectively short-circuits display of the control form.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance` | `array` | The current widget instance's settings.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-widget.php](../../wordpress/wp-includes/class-wp-widget.php), [line 505](../../wordpress/wp-includes/class-wp-widget.php#L505-L515)

### `wp_mail`

*Filters the wp_mail() arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`compact('to', 'subject', 'message', 'headers', 'attachments')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 174](../../wordpress/wp-includes/pluggable.php#L174-L189)

### `pre_wp_mail`

*Filters whether to preempt sending an email.*

Returning a non-null value will short-circuit %1$s, returning
that value instead. A boolean return value should be used to indicate whether
the email was successfully sent.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$atts` | `array` | {<br>    Array of the `wp_mail()` arguments.<br><br>    @type string\|string[] $to          Array or comma-separated list of email addresses to send message.<br>    @type string          $subject     Email subject.<br>    @type string          $message     Message contents.<br>    @type string\|string[] $headers     Additional headers.<br>    @type string\|string[] $attachments Paths to files to attach.<br>}

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 191](../../wordpress/wp-includes/pluggable.php#L191-L211)

### `wp_mail_from`

*Filters the email address to send from.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$from_email` | `string` | Email address to send from.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 378](../../wordpress/wp-includes/pluggable.php#L378-L385)

### `wp_mail_from_name`

*Filters the name to associate with the "from" email address.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$from_name` | `string` | Name associated with the "from" email address.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 387](../../wordpress/wp-includes/pluggable.php#L387-L394)

### `wp_mail_content_type`

*Filters the wp_mail() content type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content_type` | `string` | Default wp_mail() content type.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 462](../../wordpress/wp-includes/pluggable.php#L462-L469)

### `wp_mail_charset`

*Filters the default wp_mail() charset.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$charset` | `string` | Default email charset.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 483](../../wordpress/wp-includes/pluggable.php#L483-L490)

### `authenticate`

*Filters whether a set of user login credentials are valid.*

A WP_User object is returned if the credentials authenticate a user.
WP_Error or null otherwise.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$username` | `string` | Username or email address.
`$password` | `string` | User password

**Changelog**

Version | Description
------- | -----------
`4.5.0` | `$username` now accepts an email address.
`2.8.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 568](../../wordpress/wp-includes/pluggable.php#L568-L582)

### `auth_cookie`

*Filters the authentication cookie.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cookie` | `string` | Authentication cookie.
`$user_id` | `int` | User ID.
`$expiration` | `int` | The time the cookie expires as a UNIX timestamp.
`$scheme` | `string` | Cookie scheme used. Accepts 'auth', 'secure_auth', or 'logged_in'.
`$token` | `string` | User's session token used.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | The `$token` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 796](../../wordpress/wp-includes/pluggable.php#L796-L808)

### `auth_cookie_expiration`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`14 * DAY_IN_SECONDS` |  | 
`$user_id` |  | 
`$remember` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 889](../../wordpress/wp-includes/pluggable.php#L889-L889)

### `auth_cookie_expiration`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`2 * DAY_IN_SECONDS` |  | 
`$user_id` |  | 
`$remember` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 898](../../wordpress/wp-includes/pluggable.php#L898-L898)

### `secure_auth_cookie`

*Filters whether the auth cookie should only be sent over HTTPS.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$secure` | `bool` | Whether the cookie should only be sent over HTTPS.
`$user_id` | `int` | User ID.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 909](../../wordpress/wp-includes/pluggable.php#L909-L917)

### `secure_logged_in_cookie`

*Filters whether the logged in cookie should only be sent over HTTPS.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$secure_logged_in_cookie` | `bool` | Whether the logged in cookie should only be sent over HTTPS.
`$user_id` | `int` | User ID.
`$secure` | `bool` | Whether the auth cookie should only be sent over HTTPS.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 919](../../wordpress/wp-includes/pluggable.php#L919-L928)

### `send_auth_cookies`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 987](../../wordpress/wp-includes/pluggable.php#L987-L987)

### `send_auth_cookies`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1015](../../wordpress/wp-includes/pluggable.php#L1015-L1015)

### `secure_auth_redirect`

*Filters whether to use a secure authentication redirect.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$secure` | `bool` | Whether to use a secure authentication redirect. Default false.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1081](../../wordpress/wp-includes/pluggable.php#L1081-L1088)

### `auth_redirect_scheme`

*Filters the authentication redirect scheme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1101](../../wordpress/wp-includes/pluggable.php#L1101-L1108)

### `wp_redirect`

*Filters the redirect location.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$location` | `string` | The path or URL to redirect to.
`$status` | `int` | The HTTP response status code to use.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1282](../../wordpress/wp-includes/pluggable.php#L1282-L1290)

### `wp_redirect_status`

*Filters the redirect HTTP response status code to use.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$status` | `int` | The HTTP response status code to use.
`$location` | `string` | The path or URL to redirect to.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1292](../../wordpress/wp-includes/pluggable.php#L1292-L1300)

### `x_redirect_by`

*Filters the X-Redirect-By header.*

Allows applications to identify themselves when they're doing a redirect.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$x_redirect_by` | `string` | The application doing the redirect.
`$status` | `int` | Status code to use.
`$location` | `string` | The path to redirect to.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1316](../../wordpress/wp-includes/pluggable.php#L1316-L1327)

### `wp_safe_redirect_fallback`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`admin_url()` |  | 
`$status` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1435](../../wordpress/wp-includes/pluggable.php#L1435-L1435)

### `allowed_redirect_hosts`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($wpp['host'])` |  | 
`isset($lp['host']) ? $lp['host'] : ''` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1513](../../wordpress/wp-includes/pluggable.php#L1513-L1513)

### `comment_notification_recipients`

*Filters the list of email addresses to receive a comment notification.*

By default, only post authors are notified of comments. This filter allows
others to be added.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$emails` | `string[]` | An array of email addresses to receive a comment notification.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1552](../../wordpress/wp-includes/pluggable.php#L1552-L1563)

### `comment_notification_notify_author`

*Filters whether to notify comment authors of their comments on their own posts.*

By default, comment authors aren't notified of their comments on their own
posts. This filter allows you to override that.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`3.8.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1574](../../wordpress/wp-includes/pluggable.php#L1574-L1586)

### `comment_notification_text`

*Filters the comment notification email text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$notify_message` | `string` | The comment notification email text.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.2` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1711](../../wordpress/wp-includes/pluggable.php#L1711-L1719)

### `comment_notification_subject`

*Filters the comment notification email subject.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$subject` | `string` | The comment notification email subject.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.2` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1721](../../wordpress/wp-includes/pluggable.php#L1721-L1729)

### `comment_notification_headers`

*Filters the comment notification email headers.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message_headers` | `string` | Headers for the comment notification email.
`$comment->comment_ID` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.2` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1731](../../wordpress/wp-includes/pluggable.php#L1731-L1739)

### `notify_moderator`

*Filters whether to send the site moderator email notifications, overriding the site setting.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$maybe_notify` | `bool` | Whether to notify blog moderator.
`$comment_id` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1772](../../wordpress/wp-includes/pluggable.php#L1772-L1780)

### `comment_moderation_recipients`

*Filters the list of recipients for comment moderation emails.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$emails` | `string[]` | List of email addresses to notify for comment moderation.
`$comment_id` | `int` | Comment ID.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1884](../../wordpress/wp-includes/pluggable.php#L1884-L1892)

### `comment_moderation_text`

*Filters the comment moderation email text.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$notify_message` | `string` | Text of the comment moderation email.
`$comment_id` | `int` | Comment ID.

**Changelog**

Version | Description
------- | -----------
`1.5.2` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1894](../../wordpress/wp-includes/pluggable.php#L1894-L1902)

### `comment_moderation_subject`

*Filters the comment moderation email subject.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$subject` | `string` | Subject of the comment moderation email.
`$comment_id` | `int` | Comment ID.

**Changelog**

Version | Description
------- | -----------
`1.5.2` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1904](../../wordpress/wp-includes/pluggable.php#L1904-L1912)

### `comment_moderation_headers`

*Filters the comment moderation email headers.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message_headers` | `string` | Headers for the comment moderation email.
`$comment_id` | `int` | Comment ID.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1914](../../wordpress/wp-includes/pluggable.php#L1914-L1922)

### `wp_password_change_notification_email`

*Filters the contents of the password change notification email sent to the site admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_password_change_notification_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The intended recipient - site admin email address.<br>    @type string $subject The subject of the email.<br>    @type string $message The body of the email.<br>    @type string $headers The headers of the email.<br>}
`$user` | `\WP_User` | User object for user whose password was changed.
`$blogname` | `string` | The site title.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 1962](../../wordpress/wp-includes/pluggable.php#L1962-L1978)

### `wp_new_user_notification_email_admin`

*Filters the contents of the new user notification email sent to the site admin.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_new_user_notification_email_admin` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The intended recipient - site admin email address.<br>    @type string $subject The subject of the email.<br>    @type string $message The body of the email.<br>    @type string $headers The headers of the email.<br>}
`$user` | `\WP_User` | User object for new user.
`$blogname` | `string` | The site title.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2040](../../wordpress/wp-includes/pluggable.php#L2040-L2056)

### `wp_new_user_notification_email`

*Filters the contents of the new user notification email sent to the new user.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_new_user_notification_email` | `array` | {<br>    Used to build wp_mail().<br><br>    @type string $to      The intended recipient - New user email address.<br>    @type string $subject The subject of the email.<br>    @type string $message The body of the email.<br>    @type string $headers The headers of the email.<br>}
`$user` | `\WP_User` | User object for new user.
`$blogname` | `string` | The site title.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2097](../../wordpress/wp-includes/pluggable.php#L2097-L2113)

### `nonce_life`

*Filters the lifespan of nonces in seconds.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`DAY_IN_SECONDS` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2140](../../wordpress/wp-includes/pluggable.php#L2140-L2147)

### `nonce_user_logged_out`

*Filters whether the user who generated the nonce is logged out.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$uid` | `int` | ID of the nonce-owning user.
`$action` | `string` | The nonce action.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2172](../../wordpress/wp-includes/pluggable.php#L2172-L2180)

### `nonce_user_logged_out`

*This filter is documented in wp-includes/pluggable.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$uid` |  | 
`$action` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2234](../../wordpress/wp-includes/pluggable.php#L2234-L2235)

### `salt`

*Filters the WordPress salt.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cached_salts[$scheme]` |  | 
`$scheme` | `string` | Authentication scheme. Values include 'auth',<br>'secure_auth', 'logged_in', and 'nonce'.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2281](../../wordpress/wp-includes/pluggable.php#L2281-L2290)

### `salt`

*This filter is documented in wp-includes/pluggable.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cached_salts[$scheme]` |  | 
`$scheme` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2344](../../wordpress/wp-includes/pluggable.php#L2344-L2345)

### `check_password`

*Filters whether the plaintext password matches the encrypted password.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$check` | `bool` | Whether the passwords match.
`$password` | `string` | The plaintext password.
`$hash` | `string` | The hashed password.
`$user_id` | `string\|int` | User ID. Can be empty.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2428](../../wordpress/wp-includes/pluggable.php#L2428-L2438)

### `check_password`

*This filter is documented in wp-includes/pluggable.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$check` |  | 
`$password` |  | 
`$hash` |  | 
`$user_id` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2451](../../wordpress/wp-includes/pluggable.php#L2451-L2452)

### `random_password`

*Filters the randomly-generated password.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$password` | `string` | The generated password.
`$length` | `int` | The length of password to generate.
`$special_chars` | `bool` | Whether to include standard special characters.
`$extra_special_chars` | `bool` | Whether to include other special characters.

**Changelog**

Version | Description
------- | -----------
`5.3.0` | Added the `$length`, `$special_chars`, and `$extra_special_chars` parameters.
`3.0.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2486](../../wordpress/wp-includes/pluggable.php#L2486-L2497)

### `pre_get_avatar`

*Allows the HTML for a user's avatar to be returned early.*

Passing a non-null value will effectively short-circuit get_avatar(), passing
the value through the %1$s filter and returning early.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$id_or_email` | `mixed` | The avatar to retrieve. Accepts a user_id, Gravatar MD5 hash,<br>user email, WP_User object, WP_Post object, or WP_Comment object.
`$args` | `array` | Arguments passed to get_avatar_url(), after processing.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2694](../../wordpress/wp-includes/pluggable.php#L2694-L2707)

### `get_avatar`

*This filter is documented in wp-includes/pluggable.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$avatar` |  | 
`$id_or_email` |  | 
`$args['size']` |  | 
`$args['default']` |  | 
`$args['alt']` |  | 
`$args` |  | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2710](../../wordpress/wp-includes/pluggable.php#L2710-L2711)

### `get_avatar`

*Filters the HTML for a user's avatar.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$avatar` | `string` | HTML for the user's avatar.
`$id_or_email` | `mixed` | The avatar to retrieve. Accepts a user_id, Gravatar MD5 hash,<br>user email, WP_User object, WP_Post object, or WP_Comment object.
`$args['size']` |  | 
`$args['default']` |  | 
`$args['alt']` |  | 
`$args` | `array` | Arguments passed to get_avatar_data(), after processing.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | The `$args` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/pluggable.php](../../wordpress/wp-includes/pluggable.php), [line 2765](../../wordpress/wp-includes/pluggable.php#L2765-L2781)

### `wp_http_accept_encoding`

*Filters the allowed encoding types.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$type` | `string[]` | Array of what encoding types to accept and their priority values.
`$url` | `string` | URL of the HTTP request.
`$args` | `array` | HTTP request arguments.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/class-wp-http-encoding.php](../../wordpress/wp-includes/class-wp-http-encoding.php), [line 174](../../wordpress/wp-includes/class-wp-http-encoding.php#L174-L183)

### `pre_get_main_site_id`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/class-wp-network.php](../../wordpress/wp-includes/class-wp-network.php), [line 229](../../wordpress/wp-includes/class-wp-network.php#L229-L229)

### `network_by_path_segments_count`

*Filters the number of path segments to consider when searching for a site.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$segments` | `int\|null` | The number of path segments to consider. WordPress by default looks at<br>one path segment. The function default of null only makes sense when you<br>know the requested path should match a network.
`$domain` | `string` | The requested domain.
`$path` | `string` | The requested path, in full.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-network.php](../../wordpress/wp-includes/class-wp-network.php), [line 373](../../wordpress/wp-includes/class-wp-network.php#L373-L384)

### `pre_get_network_by_path`

*Determine a network by its domain and path.*

This allows one to short-circuit the default logic, perhaps by
replacing it with a routine that is more optimal for your setup.

Return null to avoid the short-circuit. Return false if no network
can be found at the requested domain and path. Otherwise, return
an object from wp_get_network().

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$domain` | `string` | The requested domain.
`$path` | `string` | The requested path, in full.
`$segments` | `int\|null` | The suggested number of paths to consult.<br>Default null, meaning the entire path was to be consulted.
`$paths` | `string[]` | Array of paths to search for, based on `$path` and `$segments`.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-network.php](../../wordpress/wp-includes/class-wp-network.php), [line 398](../../wordpress/wp-includes/class-wp-network.php#L398-L418)

### `old_slug_redirect_post_id`

*Filters the old slug redirect post ID.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$id` | `int` | The redirect post ID.

**Changelog**

Version | Description
------- | -----------
`4.9.3` | 

Source: [wordpress/wp-includes/query.php](../../wordpress/wp-includes/query.php), [line 1048](../../wordpress/wp-includes/query.php#L1048-L1055)

### `old_slug_redirect_url`

*Filters the old slug redirect URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The redirect URL.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/query.php](../../wordpress/wp-includes/query.php), [line 1069](../../wordpress/wp-includes/query.php#L1069-L1076)

### `https_local_ssl_verify`

*This filter is documented in wp-includes/class-wp-http-streams.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ssl_verify` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-wp-http-curl.php](../../wordpress/wp-includes/class-wp-http-curl.php), [line 115](../../wordpress/wp-includes/class-wp-http-curl.php#L115-L116)

### `https_ssl_verify`

*This filter is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ssl_verify` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-wp-http-curl.php](../../wordpress/wp-includes/class-wp-http-curl.php), [line 118](../../wordpress/wp-includes/class-wp-http-curl.php#L118-L119)

### `use_curl_transport`

*Filters whether cURL can be used as a transport for retrieving a URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$args` | `array` | An array of request arguments.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/class-wp-http-curl.php](../../wordpress/wp-includes/class-wp-http-curl.php), [line 398](../../wordpress/wp-includes/class-wp-http-curl.php#L398-L406)

### `wp_query_search_exclusion_prefix`

*Filters the prefix that indicates that a search term should be excluded from results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'-'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 1369](../../wordpress/wp-includes/class-wp-query.php#L1369-L1377)

### `wp_search_stopwords`

*Filters stopwords used when parsing search terms.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stopwords` | `string[]` | Array of stopwords.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 1485](../../wordpress/wp-includes/class-wp-query.php#L1485-L1492)

### `posts_search`

*Filters the search SQL that is used in the WHERE clause of WP_Query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($search, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2123](../../wordpress/wp-includes/class-wp-query.php#L2123-L2131)

### `posts_search_orderby`

*Filters the ORDER BY used when ordering search results.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$search_orderby` | `string` | The ORDER BY clause.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2378](../../wordpress/wp-includes/class-wp-query.php#L2378-L2386)

### `posts_where`

*Filters the WHERE clause of the query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($where, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2560](../../wordpress/wp-includes/class-wp-query.php#L2560-L2568)

### `posts_join`

*Filters the JOIN clause of the query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($join, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2570](../../wordpress/wp-includes/class-wp-query.php#L2570-L2578)

### `comment_feed_join`

*Filters the JOIN clause of the comments feed query before sending.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($cjoin, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2611](../../wordpress/wp-includes/class-wp-query.php#L2611-L2619)

### `comment_feed_where`

*Filters the WHERE clause of the comments feed query before sending.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($cwhere, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2621](../../wordpress/wp-includes/class-wp-query.php#L2621-L2629)

### `comment_feed_groupby`

*Filters the GROUP BY clause of the comments feed query before sending.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($cgroupby, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2631](../../wordpress/wp-includes/class-wp-query.php#L2631-L2639)

### `comment_feed_orderby`

*Filters the ORDER BY clause of the comments feed query before sending.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('comment_date_gmt DESC', &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2641](../../wordpress/wp-includes/class-wp-query.php#L2641-L2649)

### `comment_feed_limits`

*Filters the LIMIT clause of the comments feed query before sending.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('LIMIT ' . get_option('posts_per_rss'), &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2651](../../wordpress/wp-includes/class-wp-query.php#L2651-L2659)

### `posts_where_paged`

*Filters the WHERE clause of the query.*

Specifically for manipulating paging queries.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($where, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2694](../../wordpress/wp-includes/class-wp-query.php#L2694-L2704)

### `posts_groupby`

*Filters the GROUP BY clause of the query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($groupby, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2706](../../wordpress/wp-includes/class-wp-query.php#L2706-L2714)

### `posts_join_paged`

*Filters the JOIN clause of the query.*

Specifically for manipulating paging queries.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($join, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2716](../../wordpress/wp-includes/class-wp-query.php#L2716-L2726)

### `posts_orderby`

*Filters the ORDER BY clause of the query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($orderby, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.1` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2728](../../wordpress/wp-includes/class-wp-query.php#L2728-L2736)

### `posts_distinct`

*Filters the DISTINCT clause of the query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($distinct, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2738](../../wordpress/wp-includes/class-wp-query.php#L2738-L2746)

### `post_limits`

*Filters the LIMIT clause of the query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($limits, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2748](../../wordpress/wp-includes/class-wp-query.php#L2748-L2756)

### `posts_fields`

*Filters the SELECT clause of the query.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($fields, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2758](../../wordpress/wp-includes/class-wp-query.php#L2758-L2766)

### `posts_clauses`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(compact($pieces), &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2779](../../wordpress/wp-includes/class-wp-query.php#L2779-L2779)

### `posts_where_request`

*Filters the WHERE clause of the query.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($where, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2806](../../wordpress/wp-includes/class-wp-query.php#L2806-L2816)

### `posts_groupby_request`

*Filters the GROUP BY clause of the query.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($groupby, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2818](../../wordpress/wp-includes/class-wp-query.php#L2818-L2828)

### `posts_join_request`

*Filters the JOIN clause of the query.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($join, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2830](../../wordpress/wp-includes/class-wp-query.php#L2830-L2840)

### `posts_orderby_request`

*Filters the ORDER BY clause of the query.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($orderby, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2842](../../wordpress/wp-includes/class-wp-query.php#L2842-L2852)

### `posts_distinct_request`

*Filters the DISTINCT clause of the query.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($distinct, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2854](../../wordpress/wp-includes/class-wp-query.php#L2854-L2864)

### `posts_fields_request`

*Filters the SELECT clause of the query.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($fields, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2866](../../wordpress/wp-includes/class-wp-query.php#L2866-L2876)

### `post_limits_request`

*Filters the LIMIT clause of the query.*

For use by caching plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($limits, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2878](../../wordpress/wp-includes/class-wp-query.php#L2878-L2888)

### `posts_clauses_request`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(compact($pieces), &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2903](../../wordpress/wp-includes/class-wp-query.php#L2903-L2903)

### `posts_request`

*Filters the completed SQL query before sending.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this->request, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2930](../../wordpress/wp-includes/class-wp-query.php#L2930-L2938)

### `posts_pre_query`

*Filters the posts array before the query takes place.*

Return a non-null value to bypass WordPress' default post queries.

Filtering functions that require pagination information are encouraged to set
the `found_posts` and `max_num_pages` properties of the WP_Query object,
passed to the filter by reference. If WP_Query does not perform a database
query, it will not have enough information to generate these values itself.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(null, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2941](../../wordpress/wp-includes/class-wp-query.php#L2941-L2957)

### `split_the_query`

*Filters whether to split the query.*

Splitting the query will cause it to fetch just the IDs of the found posts
(and then individually fetch each post by ID), rather than fetching every
complete row at once. One massive result vs. many small results.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$split_the_query` | `bool` | Whether or not to split the query.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 2995](../../wordpress/wp-includes/class-wp-query.php#L2995-L3007)

### `posts_request_ids`

*Filters the Post IDs SQL request before sending.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->request` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3014](../../wordpress/wp-includes/class-wp-query.php#L3014-L3022)

### `posts_results`

*Filters the raw post results array, prior to status checks.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this->posts, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3046](../../wordpress/wp-includes/class-wp-query.php#L3046-L3054)

### `comment_feed_join`

*This filter is documented in wp-includes/query.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('', &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3058](../../wordpress/wp-includes/class-wp-query.php#L3058-L3059)

### `comment_feed_where`

*This filter is documented in wp-includes/query.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array("WHERE comment_post_ID = '{$this->posts[0]->ID}' AND comment_approved = '1'", &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3061](../../wordpress/wp-includes/class-wp-query.php#L3061-L3062)

### `comment_feed_groupby`

*This filter is documented in wp-includes/query.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('', &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3064](../../wordpress/wp-includes/class-wp-query.php#L3064-L3065)

### `comment_feed_orderby`

*This filter is documented in wp-includes/query.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('comment_date_gmt DESC', &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3068](../../wordpress/wp-includes/class-wp-query.php#L3068-L3069)

### `comment_feed_limits`

*This filter is documented in wp-includes/query.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('LIMIT ' . get_option('posts_per_rss'), &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3072](../../wordpress/wp-includes/class-wp-query.php#L3072-L3073)

### `the_preview`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this->posts[0], &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3137](../../wordpress/wp-includes/class-wp-query.php#L3137-L3137)

### `the_posts`

*Filters the array of retrieved posts after they've been fetched and
internally processed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this->posts, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3191](../../wordpress/wp-includes/class-wp-query.php#L3191-L3200)

### `found_posts_query`

*Filters the query to run for retrieving the found posts.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('SELECT FOUND_ROWS()', &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3250](../../wordpress/wp-includes/class-wp-query.php#L3250-L3258)

### `found_posts`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($this->found_posts, &$this)` |  | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 3281](../../wordpress/wp-includes/class-wp-query.php#L3281-L3281)

### `content_pagination`

*Filters the "pages" derived from splitting the post content.*

"Pages" are determined by splitting the post content based on the presence
of `<!-- nextpage -->` tags.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$pages` | `string[]` | Array of "pages" from the post content split by `<!-- nextpage -->` tags.
`$post` | `\WP_Post` | Current post object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-query.php](../../wordpress/wp-includes/class-wp-query.php), [line 4390](../../wordpress/wp-includes/class-wp-query.php#L4390-L4401)

### `locale`

*This filter is documented in wp-includes/l10n.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$locale` |  | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 34](../../wordpress/wp-includes/l10n.php#L34-L35)

### `locale`

*Filters the locale ID of the WordPress installation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$locale` | `string` | The locale ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 73](../../wordpress/wp-includes/l10n.php#L73-L80)

### `pre_determine_locale`

*Filters the locale for the current request prior to the default determination process.*

Using this filter allows to override the default logic, effectively short-circuiting the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 122](../../wordpress/wp-includes/l10n.php#L122-L131)

### `determine_locale`

*Filters the locale for the current request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$determined_locale` |  | 

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 151](../../wordpress/wp-includes/l10n.php#L151-L158)

### `gettext`

*Filters text with its translation.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$text` | `string` | Text to translate.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`2.0.11` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 180](../../wordpress/wp-includes/l10n.php#L180-L189)

### `gettext_{$domain}`

*Filters text with its translation for a domain.*

The dynamic portion of the hook, `$domain`, refers to the text domain.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$text` | `string` | Text to translate.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 191](../../wordpress/wp-includes/l10n.php#L191-L202)

### `gettext_with_context`

*Filters text with its translation based on context information.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$text` | `string` | Text to translate.
`$context` | `string` | Context information for the translators.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 247](../../wordpress/wp-includes/l10n.php#L247-L257)

### `gettext_with_context_{$domain}`

*Filters text with its translation based on context information for a domain.*

The dynamic portion of the hook, `$domain`, refers to the text domain.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$text` | `string` | Text to translate.
`$context` | `string` | Context information for the translators.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 259](../../wordpress/wp-includes/l10n.php#L259-L271)

### `ngettext`

*Filters the singular or plural form of a string.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$single` | `string` | The text to be used if the number is singular.
`$plural` | `string` | The text to be used if the number is plural.
`$number` | `string` | The number to compare against to use either the singular or plural form.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 470](../../wordpress/wp-includes/l10n.php#L470-L481)

### `ngettext_{$domain}`

*Filters the singular or plural form of a string for a domain.*

The dynamic portion of the hook, `$domain`, refers to the text domain.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$single` | `string` | The text to be used if the number is singular.
`$plural` | `string` | The text to be used if the number is plural.
`$number` | `string` | The number to compare against to use either the singular or plural form.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 483](../../wordpress/wp-includes/l10n.php#L483-L496)

### `ngettext_with_context`

*Filters the singular or plural form of a string with gettext context.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$single` | `string` | The text to be used if the number is singular.
`$plural` | `string` | The text to be used if the number is plural.
`$number` | `string` | The number to compare against to use either the singular or plural form.
`$context` | `string` | Context information for the translators.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 529](../../wordpress/wp-includes/l10n.php#L529-L541)

### `ngettext_with_context_{$domain}`

*Filters the singular or plural form of a string with gettext context for a domain.*

The dynamic portion of the hook, `$domain`, refers to the text domain.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translation` | `string` | Translated text.
`$single` | `string` | The text to be used if the number is singular.
`$plural` | `string` | The text to be used if the number is plural.
`$number` | `string` | The number to compare against to use either the singular or plural form.
`$context` | `string` | Context information for the translators.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 543](../../wordpress/wp-includes/l10n.php#L543-L557)

### `override_load_textdomain`

*Filters whether to override the .mo file loading.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.
`$mofile` | `string` | Path to the MO file.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 704](../../wordpress/wp-includes/l10n.php#L704-L713)

### `load_textdomain_mofile`

*Filters MO file path for loading translations for a specific text domain.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mofile` | `string` | Path to the MO file.
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 731](../../wordpress/wp-includes/l10n.php#L731-L739)

### `override_unload_textdomain`

*Filters whether to override the text domain unloading.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 777](../../wordpress/wp-includes/l10n.php#L777-L785)

### `plugin_locale`

*Filters a plugin's locale.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`determine_locale()` |  | 
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 870](../../wordpress/wp-includes/l10n.php#L870-L878)

### `plugin_locale`

*This filter is documented in wp-includes/l10n.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`determine_locale()` |  | 
`$domain` |  | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 911](../../wordpress/wp-includes/l10n.php#L911-L912)

### `theme_locale`

*Filters a theme's locale.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`determine_locale()` |  | 
`$domain` | `string` | Text domain. Unique identifier for retrieving translated strings.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 943](../../wordpress/wp-includes/l10n.php#L943-L951)

### `load_script_textdomain_relative_path`

*Filters the relative path of scripts used for finding translation files.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$relative` | `string\|false` | The relative path of the script. False if it could not be determined.
`$src` | `string` | The full source URL of the script.

**Changelog**

Version | Description
------- | -----------
`5.0.2` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 1085](../../wordpress/wp-includes/l10n.php#L1085-L1093)

### `pre_load_script_translations`

*Pre-filters script translations for the given file, script handle and text domain.*

Returning a non-null value allows to override the default logic, effectively short-circuiting the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$file` | `string\|false` | Path to the translation file to load. False if there isn't one.
`$handle` | `string` | Name of the script to register a translation domain to.
`$domain` | `string` | The text domain.

**Changelog**

Version | Description
------- | -----------
`5.0.2` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 1136](../../wordpress/wp-includes/l10n.php#L1136-L1148)

### `load_script_translation_file`

*Filters the file path for loading script translations for the given script handle and text domain.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$file` | `string\|false` | Path to the translation file to load. False if there isn't one.
`$handle` | `string` | Name of the script to register a translation domain to.
`$domain` | `string` | The text domain.

**Changelog**

Version | Description
------- | -----------
`5.0.2` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 1154](../../wordpress/wp-includes/l10n.php#L1154-L1163)

### `load_script_translations`

*Filters script translations for the given file, script handle and text domain.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$translations` | `string` | JSON-encoded translation data.
`$file` | `string` | Path to the translation file that was loaded.
`$handle` | `string` | Name of the script to register a translation domain to.
`$domain` | `string` | The text domain.

**Changelog**

Version | Description
------- | -----------
`5.0.2` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 1171](../../wordpress/wp-includes/l10n.php#L1171-L1181)

### `get_available_languages`

*Filters the list of available language codes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$languages` | `string[]` | An array of available language codes.
`$dir` | `string` | The directory where the language files were found.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/l10n.php](../../wordpress/wp-includes/l10n.php), [line 1385](../../wordpress/wp-includes/l10n.php#L1385-L1393)

### `{$type}_template_hierarchy`

*Filters the list of template filenames that are searched for when retrieving a template to use.*

The last element in the array should always be the fallback template for this query type.

Possible values for `$type` include: 'index', '404', 'archive', 'author', 'category', 'tag', 'taxonomy', 'date',
'embed', 'home', 'frontpage', 'privacypolicy', 'page', 'paged', 'search', 'single', 'singular', and 'attachment'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$templates` | `array` | A list of template candidates, in descending order of priority.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/template.php](../../wordpress/wp-includes/template.php), [line 30](../../wordpress/wp-includes/template.php#L30-L42)

### `{$type}_template`

*Filters the path of the queried template by type.*

The dynamic portion of the hook name, `$type`, refers to the filename -- minus the file
extension and any non-alphanumeric characters delimiting words -- of the file to load.
This hook also applies to various types of files loaded as part of the Template Hierarchy.

Possible values for `$type` include: 'index', '404', 'archive', 'author', 'category', 'tag', 'taxonomy', 'date',
'embed', 'home', 'frontpage', 'privacypolicy', 'page', 'paged', 'search', 'single', 'singular', and 'attachment'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$template` | `string` | Path to the template. See locate_template().
`$type` | `string` | Sanitized filename without extension.
`$templates` | `array` | A list of template candidates, in descending order of priority.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | The `$type` and `$templates` parameters were added.
`1.5.0` | 

Source: [wordpress/wp-includes/template.php](../../wordpress/wp-includes/template.php), [line 46](../../wordpress/wp-includes/template.php#L46-L63)

### `xmlrpc_element_limit`

*Filters the number of elements to parse in an XML-RPC response.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$element_limit` | `int` | Default elements limit.

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/IXR/class-IXR-message.php](../../wordpress/wp-includes/IXR/class-IXR-message.php), [line 79](../../wordpress/wp-includes/IXR/class-IXR-message.php#L79-L86)

### `xmlrpc_chunk_parsing_size`

*Filters the chunk size that can be used to parse an XML-RPC response message.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$chunk_size` | `int` | Chunk size to parse in bytes.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/IXR/class-IXR-message.php](../../wordpress/wp-includes/IXR/class-IXR-message.php), [line 103](../../wordpress/wp-includes/IXR/class-IXR-message.php#L103-L110)

### `style_loader_tag`

*Filters the HTML link tag of an enqueued style.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tag` |  | 
`$handle` | `string` | The style's registered handle.
`$href` | `string` | The stylesheet's source URL.
`$media` | `string` | The stylesheet's media attribute.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Introduced the `$media` parameter.
`4.3.0` | Introduced the `$href` parameter.
`2.6.0` | 

Source: [wordpress/wp-includes/class.wp-styles.php](../../wordpress/wp-includes/class.wp-styles.php), [line 239](../../wordpress/wp-includes/class.wp-styles.php#L239-L251)

### `style_loader_tag`

*This filter is documented in wp-includes/class.wp-styles.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rtl_tag` |  | 
`$handle` |  | 
`$rtl_href` |  | 
`$media` |  | 

Source: [wordpress/wp-includes/class.wp-styles.php](../../wordpress/wp-includes/class.wp-styles.php), [line 271](../../wordpress/wp-includes/class.wp-styles.php#L271-L272)

### `print_styles_array`

*Filters the array of enqueued styles before processing for output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->to_do` |  | 

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/class.wp-styles.php](../../wordpress/wp-includes/class.wp-styles.php), [line 373](../../wordpress/wp-includes/class.wp-styles.php#L373-L380)

### `style_loader_src`

*Filters an enqueued style's fully-qualified URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$src` | `string` | The source URL of the enqueued style.
`$handle` | `string` | The style's registered handle.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/class.wp-styles.php](../../wordpress/wp-includes/class.wp-styles.php), [line 404](../../wordpress/wp-includes/class.wp-styles.php#L404-L412)

### `editor_max_image_size`

*Filters the maximum image size dimensions for the editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($max_width, $max_height)` |  | 
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$context` | `string` | The context the image is being resized for.<br>Possible values are 'display' (like in a theme)<br>or 'edit' (like inserting into an editor).

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 116](../../wordpress/wp-includes/media.php#L116-L133)

### `image_downsize`

*Filters whether to preempt the output of image_downsize().*

Returning a truthy value from the filter will effectively short-circuit
down-sizing the image, returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$id` | `int` | Attachment ID for image.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 194](../../wordpress/wp-includes/media.php#L194-L207)

### `get_image_tag_class`

*Filters the value of the attachment's image tag class attribute.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$class` | `string` | CSS class name or space-separated list of classes.
`$id` | `int` | Attachment ID.
`$align` | `string` | Part of the class name for aligning the image.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 383](../../wordpress/wp-includes/media.php#L383-L394)

### `get_image_tag`

*Filters the HTML content for the image tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | HTML content for the image.
`$id` | `int` | Attachment ID.
`$alt` | `string` | Image description for the alt attribute.
`$title` | `string` | Image description for the title attribute.
`$align` | `string` | Part of the class name for aligning the image.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 398](../../wordpress/wp-includes/media.php#L398-L411)

### `wp_constrain_dimensions`

*Filters dimensions to constrain down-sampled images to.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($w, $h)` |  | 
`$current_width` | `int` | The current width of the image.
`$current_height` | `int` | The current height of the image.
`$max_width` | `int` | The maximum width permitted.
`$max_height` | `int` | The maximum height permitted.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 487](../../wordpress/wp-includes/media.php#L487-L503)

### `image_resize_dimensions`

*Filters whether to preempt calculating the image resize dimensions.*

Returning a non-null value from the filter will effectively short-circuit
image_resize_dimensions(), returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$orig_w` | `int` | Original width in pixels.
`$orig_h` | `int` | Original height in pixels.
`$dest_w` | `int` | New width in pixels.
`$dest_h` | `int` | New height in pixels.
`$crop` | `bool\|array` | Whether to crop image to specified width and height or resize.<br>An array can specify positioning of the crop area. Default false.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 540](../../wordpress/wp-includes/media.php#L540-L556)

### `wp_image_resize_identical_dimensions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$orig_w` |  | 
`$orig_h` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 648](../../wordpress/wp-includes/media.php#L648-L648)

### `image_get_intermediate_size`

*Filters the output of image_get_intermediate_size()*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` | `array` | Array of file relative path, width, and height on success. May also include<br>file absolute path and URL.
`$post_id` | `int` | The ID of the image attachment.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 836](../../wordpress/wp-includes/media.php#L836-L849)

### `intermediate_image_sizes`

*Filters the list of intermediate image sizes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_sizes` | `string[]` | An array of intermediate image size names. Defaults<br>are 'thumbnail', 'medium', 'medium_large', 'large'.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 867](../../wordpress/wp-includes/media.php#L867-L875)

### `icon_dir`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`ABSPATH . WPINC . '/images/media'` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 961](../../wordpress/wp-includes/media.php#L961-L962)

### `wp_get_attachment_image_src`

*Filters the attachment image source result.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image` | `array\|false` | {<br>    Array of image data, or boolean false if no image is available.<br><br>    @type string $0 Image source URL.<br>    @type int    $1 Image width in pixels.<br>    @type int    $2 Image height in pixels.<br>    @type bool   $3 Whether the image is a resized image.<br>}
`$attachment_id` | `int` | Image attachment ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$icon` | `bool` | Whether the image should be treated as an icon.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 973](../../wordpress/wp-includes/media.php#L973-L991)

### `wp_get_attachment_image_attributes`

*Filters the list of attachment image attributes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attr` | `string[]` | Array of attribute values for the image markup, keyed by attribute name.<br>See wp_get_attachment_image().
`$attachment` | `\WP_Post` | Image attachment post.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1079](../../wordpress/wp-includes/media.php#L1079-L1090)

### `wp_get_attachment_image`

*HTML img element representing an image attachment.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | HTML img element or empty string on failure.
`$attachment_id` | `int` | Image attachment ID.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$icon` | `bool` | Whether the image should be treated as an icon.
`$attr` | `string[]` | Array of attribute values for the image markup, keyed by attribute name.<br>See wp_get_attachment_image().

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1102](../../wordpress/wp-includes/media.php#L1102-L1115)

### `wp_calculate_image_srcset_meta`

*Let plugins pre-filter the image meta to be able to fix inconsistencies in the stored data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$image_meta` | `array` | The image meta data as returned by 'wp_get_attachment_metadata()'.
`$size_array` | `int[]` | {<br>    An array of requested width and height values.<br><br>    @type int $0 The width in pixels.<br>    @type int $1 The height in pixels.<br>}
`$image_src` | `string` | The 'src' of the image.
`$attachment_id` | `int` | The image attachment ID or 0 if not supplied.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1244](../../wordpress/wp-includes/media.php#L1244-L1259)

### `max_srcset_image_width`

*Filters the maximum image width to be included in a 'srcset' attribute.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`2048` |  | 
`$size_array` | `int[]` | {<br>    An array of requested width and height values.<br><br>    @type int $0 The width in pixels.<br>    @type int $1 The height in pixels.<br>}

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1318](../../wordpress/wp-includes/media.php#L1318-L1331)

### `wp_calculate_image_srcset`

*Filters an image's 'srcset' sources.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sources` | `array` | {<br>    One or more arrays of source data to include in the 'srcset'.<br><br>    @type array $width {<br>        @type string $url        The URL of an image source.<br>        @type string $descriptor The descriptor type used in the image candidate string,<br>                                 either 'w' or 'x'.<br>        @type int    $value      The source width if paired with a 'w' descriptor, or a<br>                                 pixel density value if paired with an 'x' descriptor.<br>    }<br>}
`$size_array` | `array` | {<br>    An array of requested width and height values.<br><br>    @type int $0 The width in pixels.<br>    @type int $1 The height in pixels.<br>}
`$image_src` | `string` | The 'src' of the image.
`$image_meta` | `array` | The image meta data as returned by 'wp_get_attachment_metadata()'.
`$attachment_id` | `int` | Image attachment ID or 0.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1392](../../wordpress/wp-includes/media.php#L1392-L1418)

### `wp_calculate_image_sizes`

*Filters the output of 'wp_calculate_image_sizes()'.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sizes` | `string` | A source size value for use in a 'sizes' attribute.
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$image_src` | `string\|null` | The URL to the image file or null.
`$image_meta` | `array\|null` | The image meta data as returned by wp_get_attachment_metadata() or null.
`$attachment_id` | `int` | Image attachment ID of the original image or 0.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1507](../../wordpress/wp-includes/media.php#L1507-L1519)

### `wp_image_file_matches_image_meta`

*Filters whether an image path or URI matches image meta.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$match` | `bool` | Whether the image relative path from the image meta<br>matches the end of the URI or path to the image file.
`$image_location` | `string` | Full path or URI to the tested image file.
`$image_meta` | `array` | The image meta data as returned by 'wp_get_attachment_metadata()'.
`$attachment_id` | `int` | The image attachment ID or 0 if not supplied.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1577](../../wordpress/wp-includes/media.php#L1577-L1588)

### `wp_image_src_get_dimensions`

*Filters the 'wp_image_src_get_dimensions' value.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$dimensions` | `array\|false` | Array with first element being the width<br>and second element being the height, or<br>false if dimensions could not be determined.
`$image_src` | `string` | The image source file.
`$image_meta` | `array` | The image meta data as returned by<br>'wp_get_attachment_metadata()'.
`$attachment_id` | `int` | The image attachment ID. Default 0.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1631](../../wordpress/wp-includes/media.php#L1631-L1644)

### `wp_lazy_loading_enabled`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default` |  | 
`$tag_name` |  | 
`$context` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1746](../../wordpress/wp-includes/media.php#L1746-L1746)

### `wp_img_tag_add_loading_attr`

*Filters the `loading` attribute value to add to an image. Default `lazy`.*

Returning `false` or an empty string will not add the attribute.
Returning `true` will add the default value.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'lazy'` |  | 
`$image` | `string` | The HTML `img` tag to be filtered.
`$context` | `string` | Additional context about how the function was called or where the img tag is.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1872](../../wordpress/wp-includes/media.php#L1872-L1885)

### `wp_img_tag_add_width_and_height_attr`

*Filters whether to add the missing `width` and `height` HTML attributes to the img tag. Default `true`.*

Returning anything else than `true` will not add the attributes.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$image` | `string` | The HTML `img` tag where the attribute should be added.
`$context` | `string` | Additional context about how the function was called or where the img tag is.
`$attachment_id` | `int` | The image attachment ID.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1922](../../wordpress/wp-includes/media.php#L1922-L1934)

### `wp_img_tag_add_srcset_and_sizes_attr`

*Filters whether to add the `srcset` and `sizes` HTML attributes to the img tag. Default `true`.*

Returning anything else than `true` will not add the attributes.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$image` | `string` | The HTML `img` tag where the attribute should be added.
`$context` | `string` | Additional context about how the function was called or where the img tag is.
`$attachment_id` | `int` | The image attachment ID.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1960](../../wordpress/wp-includes/media.php#L1960-L1972)

### `wp_iframe_tag_add_loading_attr`

*Filters the `loading` attribute value to add to an iframe. Default `lazy`.*

Returning `false` or an empty string will not add the attribute.
Returning `true` will add the default value.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'lazy'` |  | 
`$iframe` | `string` | The HTML `iframe` tag to be filtered.
`$context` | `string` | Additional context about how the function was called or where the iframe tag is.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 1992](../../wordpress/wp-includes/media.php#L1992-L2005)

### `img_caption_shortcode`

*Filters the default caption shortcode output.*

If the filtered output isn't empty, it will be used instead of generating
the default caption template.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$attr` | `array` | Attributes of the caption shortcode.
`$content` | `string` | The image element, possibly wrapped in a hyperlink.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2108](../../wordpress/wp-includes/media.php#L2108-L2122)

### `img_caption_shortcode_width`

*Filters the width of an image's caption.*

By default, the caption is 10 pixels greater than the width of the image,
to prevent post content from running up against a floated image.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$width` | `int` | Width of the caption in pixels. To remove this inline style,<br>return zero.
`$atts` | `array` | Attributes of the caption shortcode.
`$content` | `string` | The image element, possibly wrapped in a hyperlink.

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2173](../../wordpress/wp-includes/media.php#L2173-L2188)

### `post_gallery`

*Filters the default gallery shortcode output.*

If the filtered output isn't empty, it will be used instead of generating
the default gallery template.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$attr` | `array` | Attributes of the gallery shortcode.
`$instance` | `int` | Unique numeric ID of this gallery shortcode instance.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | The `$instance` parameter was added.
`2.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2276](../../wordpress/wp-includes/media.php#L2276-L2291)

### `use_default_gallery_style`

*Filters whether to print default gallery styles.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`!$html5` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2402](../../wordpress/wp-includes/media.php#L2402-L2411)

### `gallery_style`

*Filters the default gallery shortcode CSS styles.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$gallery_style . $gallery_div` |  | 

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2438](../../wordpress/wp-includes/media.php#L2438-L2446)

### `post_playlist`

*Filters the playlist output.*

Returning a non-empty value from the filter will short-circuit generation
of the default playlist output, returning the passed value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$attr` | `array` | An array of shortcode attributes.
`$instance` | `int` | Unique numeric ID of this playlist shortcode instance.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | The `$instance` parameter was added.
`3.9.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2617](../../wordpress/wp-includes/media.php#L2617-L2630)

### `wp_mediaelement_fallback`

*Filters the Mediaelement fallback output for no-JS.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`sprintf('<a href="%1$s">%1$s</a>', esc_url($url))` |  | 
`$url` | `string` | Media file URL.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2831](../../wordpress/wp-includes/media.php#L2831-L2839)

### `wp_audio_extensions`

*Filters the list of supported audio formats.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('mp3', 'ogg', 'flac', 'm4a', 'wav')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2850](../../wordpress/wp-includes/media.php#L2850-L2858)

### `wp_get_attachment_id3_keys`

*Filters the editable list of keys to look up data from an attachment's metadata.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$fields` | `array` | Key/value pairs of field keys to labels.
`$attachment` | `\WP_Post` | Attachment object.
`$context` | `string` | The context. Accepts 'edit', 'display'. Default 'display'.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2885](../../wordpress/wp-includes/media.php#L2885-L2894)

### `wp_audio_shortcode_override`

*Filters the default audio shortcode output.*

If the filtered output isn't empty, it will be used instead of generating the default audio template.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$attr` | `array` | Attributes of the shortcode. @see wp_audio_shortcode()
`$content` | `string` | Shortcode content.
`$instance` | `int` | Unique numeric ID of this audio shortcode instance.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2923](../../wordpress/wp-includes/media.php#L2923-L2935)

### `wp_audio_shortcode_library`

*Filters the media library used for the audio shortcode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mediaelement'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 2997](../../wordpress/wp-includes/media.php#L2997-L3004)

### `wp_audio_shortcode_class`

*Filters the class attribute for the audio shortcode output container.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$atts['class']` |  | 
`$atts` | `array` | Array of audio shortcode attributes.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `$atts` parameter was added.
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3011](../../wordpress/wp-includes/media.php#L3011-L3020)

### `wp_audio_shortcode`

*Filters the audio shortcode output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | Audio shortcode HTML output.
`$atts` | `array` | Array of audio shortcode attributes.
`$audio` | `string` | Audio file.
`$post_id` | `int` | Post ID.
`$library` | `string` | Media library used for the audio shortcode.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3073](../../wordpress/wp-includes/media.php#L3073-L3084)

### `wp_video_extensions`

*Filters the list of supported video formats.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('mp4', 'm4v', 'webm', 'ogv', 'flv')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3096](../../wordpress/wp-includes/media.php#L3096-L3104)

### `wp_video_shortcode_override`

*Filters the default video shortcode output.*

If the filtered output isn't empty, it will be used instead of generating
the default video template.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$attr` | `array` | Attributes of the shortcode. @see wp_video_shortcode()
`$content` | `string` | Video shortcode content.
`$instance` | `int` | Unique numeric ID of this video shortcode instance.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3141](../../wordpress/wp-includes/media.php#L3141-L3156)

### `wp_video_shortcode_library`

*Filters the media library used for the video shortcode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mediaelement'` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3246](../../wordpress/wp-includes/media.php#L3246-L3253)

### `wp_video_shortcode_class`

*Filters the class attribute for the video shortcode output container.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$atts['class']` |  | 
`$atts` | `array` | Array of video shortcode attributes.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | The `$atts` parameter was added.
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3278](../../wordpress/wp-includes/media.php#L3278-L3287)

### `wp_video_shortcode`

*Filters the output of the video shortcode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | Video shortcode HTML output.
`$atts` | `array` | Array of video shortcode attributes.
`$video` | `string` | Video file.
`$post_id` | `int` | Post ID.
`$library` | `string` | Media library used for the video shortcode.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3358](../../wordpress/wp-includes/media.php#L3358-L3369)

### `{$adjacent}_image_link`

*Filters the adjacent image link.*

The dynamic portion of the hook name, `$adjacent`, refers to the type of adjacency,
either 'next', or 'previous'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | Adjacent image HTML markup.
`$attachment_id` | `int` | Attachment ID
`$size` | `string\|int[]` | Requested image size. Can be any registered image size name, or<br>an array of width and height values in pixels (in that order).
`$text` | `string` | Link text.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3451](../../wordpress/wp-includes/media.php#L3451-L3465)

### `upload_size_limit`

*Filters the maximum upload size allowed in php.ini.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`min($u_bytes, $p_bytes)` |  | 
`$u_bytes` | `int` | Maximum upload filesize in bytes.
`$p_bytes` | `int` | Maximum size of POST data in bytes.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3647](../../wordpress/wp-includes/media.php#L3647-L3656)

### `wp_image_editors`

*Filters the list of image editing library classes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('WP_Image_Editor_Imagick', 'WP_Image_Editor_GD')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3726](../../wordpress/wp-includes/media.php#L3726-L3734)

### `plupload_default_settings`

*Filters the Plupload default settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$defaults` | `array` | Default Plupload settings array.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3805](../../wordpress/wp-includes/media.php#L3805-L3812)

### `plupload_default_params`

*Filters the Plupload default parameters.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$params` | `array` | Default Plupload parameters array.

**Changelog**

Version | Description
------- | -----------
`3.4.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3818](../../wordpress/wp-includes/media.php#L3818-L3825)

### `image_size_names_choose`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('thumbnail' => __('Thumbnail'), 'medium' => __('Medium'), 'large' => __('Large'), 'full' => __('Full Size'))` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 3998](../../wordpress/wp-includes/media.php#L3998-L4007)

### `image_downsize`

*This filter is documented in wp-includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$attachment->ID` |  | 
`$size` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4018](../../wordpress/wp-includes/media.php#L4018-L4019)

### `wp_prepare_attachment_for_js`

*Filters the attachment data prepared for JavaScript.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | Array of prepared attachment data. @see wp_prepare_attachment_for_js().
`$attachment` | `\WP_Post` | Attachment object.
`$meta` | `array\|false` | Array of attachment meta data, or false if there is none.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4126](../../wordpress/wp-includes/media.php#L4126-L4135)

### `media_upload_tabs`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tabs` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4177](../../wordpress/wp-includes/media.php#L4177-L4178)

### `media_library_show_audio_playlist`

*Allows showing or hiding the "Create Audio Playlist" button in the media library.*

By default, the "Create Audio Playlist" button will always be shown in
the media library.  If this filter returns `null`, a query will be run
to determine whether the media library contains any audio items.  This
was the default behavior prior to version 4.8.0, but this query is
expensive for large media libraries.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.0` | The filter's default value is `true` rather than `null`.
`4.7.4` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4199](../../wordpress/wp-includes/media.php#L4199-L4216)

### `media_library_show_video_playlist`

*Allows showing or hiding the "Create Video Playlist" button in the media library.*

By default, the "Create Video Playlist" button will always be shown in
the media library.  If this filter returns `null`, a query will be run
to determine whether the media library contains any video items.  This
was the default behavior prior to version 4.8.0, but this query is
expensive for large media libraries.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.0` | The filter's default value is `true` rather than `null`.
`4.7.4` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4229](../../wordpress/wp-includes/media.php#L4229-L4246)

### `media_library_months_with_files`

*Allows overriding the list of months displayed in the media library.*

By default (if this filter does not return an array), a query will be
run to determine the months that have media items.  This query can be
expensive for large media libraries, so it may be desirable for sites to
override this behavior.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`4.7.4` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4259](../../wordpress/wp-includes/media.php#L4259-L4275)

### `disable_captions`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4303](../../wordpress/wp-includes/media.php#L4303-L4303)

### `media_view_settings`

*Filters the media view settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$settings` | `array` | List of media view settings.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4485](../../wordpress/wp-includes/media.php#L4485-L4493)

### `media_view_strings`

*Filters the media view strings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$strings` | `string[]` | Array of media view strings keyed by the name they'll be referenced by in JavaScript.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4495](../../wordpress/wp-includes/media.php#L4495-L4503)

### `get_attached_media_args`

*Filters arguments used to retrieve media attached to the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Post query arguments.
`$type` | `string` | Mime type of the desired media.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4559](../../wordpress/wp-includes/media.php#L4559-L4568)

### `get_attached_media`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$children` |  | 
`$type` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4581](../../wordpress/wp-includes/media.php#L4581-L4581)

### `media_embedded_in_content_allowed_types`

*Filters the embedded media types that are allowed to be returned from the content blob.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('audio', 'video', 'object', 'embed', 'iframe')` |  | 

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4596](../../wordpress/wp-includes/media.php#L4596-L4604)

### `get_post_galleries`

*Filters the list of all found galleries in the given post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$galleries` | `array` | Associative array of all found post galleries.
`$post` | `\WP_Post` | Post object.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4684](../../wordpress/wp-includes/media.php#L4684-L4692)

### `get_post_gallery`

*Filters the first-found post gallery.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$gallery` | `array` | The first-found post gallery.
`$post` | `int\|\WP_Post` | Post ID or object.
`$galleries` | `array` | Associative array of all found post galleries.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4708](../../wordpress/wp-includes/media.php#L4708-L4717)

### `attachment_url_to_postid`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_id` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/media.php](../../wordpress/wp-includes/media.php), [line 4837](../../wordpress/wp-includes/media.php#L4837-L4837)

### `https_local_ssl_verify`

*Filters whether SSL should be verified for local HTTP API requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ssl_verify` | `bool` | Whether to verify the SSL connection. Default true.
`$url` | `string` | The request URL.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | The `$url` parameter was added.
`2.8.0` | 

Source: [wordpress/wp-includes/class-wp-http-streams.php](../../wordpress/wp-includes/class-wp-http-streams.php), [line 96](../../wordpress/wp-includes/class-wp-http-streams.php#L96-L105)

### `https_ssl_verify`

*This filter is documented in wp-includes/class-http.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$ssl_verify` |  | 
`$url` |  | 

Source: [wordpress/wp-includes/class-wp-http-streams.php](../../wordpress/wp-includes/class-wp-http-streams.php), [line 107](../../wordpress/wp-includes/class-wp-http-streams.php#L107-L108)

### `use_streams_transport`

*Filters whether streams can be used as a transport for retrieving a URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$args` | `array` | Request arguments.

**Changelog**

Version | Description
------- | -----------
`2.7.0` | 

Source: [wordpress/wp-includes/class-wp-http-streams.php](../../wordpress/wp-includes/class-wp-http-streams.php), [line 450](../../wordpress/wp-includes/class-wp-http-streams.php#L450-L458)

### `customizer_widgets_section_args`

*Filters Customizer widget section arguments for a given sidebar.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$section_args` | `array` | Array of Customizer widget section arguments.
`$section_id` | `string` | Customizer section ID.
`$sidebar_id` | `int\|string` | Sidebar ID.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 456](../../wordpress/wp-includes/class-wp-customize-widgets.php#L456-L465)

### `is_wide_widget_in_customizer`

*Filters whether the given widget is considered "wide".*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_wide` | `bool` | Whether the widget is wide, Default false.
`$widget_id` | `string` | Widget ID.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 581](../../wordpress/wp-includes/class-wp-customize-widgets.php#L581-L589)

### `widget_customizer_setting_args`

*Filters the common arguments supplied when constructing a Customizer setting.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of Customizer setting arguments.
`$id` | `string` | Widget setting ID.

**Changelog**

Version | Description
------- | -----------
`3.9.0` | 

Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 898](../../wordpress/wp-includes/class-wp-customize-widgets.php#L898-L908)

### `option_{$option_name}`

*This filter is documented in wp-includes/option.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$option_name` |  | 

Source: [wordpress/wp-includes/class-wp-customize-widgets.php](../../wordpress/wp-includes/class-wp-customize-widgets.php), [line 2004](../../wordpress/wp-includes/class-wp-customize-widgets.php#L2004-L2005)

### `register_taxonomy_args`

*Filters the arguments for registering a taxonomy.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of arguments for registering a taxonomy.<br>See the register_taxonomy() function for accepted arguments.
`$this->name` |  | 
`(array) $object_type` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-taxonomy.php](../../wordpress/wp-includes/class-wp-taxonomy.php), [line 290](../../wordpress/wp-includes/class-wp-taxonomy.php#L290-L300)

### `rss_update_period`

*Filters how often to update the RSS feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$duration` | `string` | The update period. Accepts 'hourly', 'daily', 'weekly', 'monthly',<br>'yearly'. Default 'hourly'.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/feed-rss2.php](../../wordpress/wp-includes/feed-rss2.php), [line 51](../../wordpress/wp-includes/feed-rss2.php#L51-L59)

### `rss_update_frequency`

*Filters the RSS update frequency.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$frequency` | `string` | An integer passed as a string representing the frequency<br>of RSS updates within the update period. Default '1'.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/feed-rss2.php](../../wordpress/wp-includes/feed-rss2.php), [line 66](../../wordpress/wp-includes/feed-rss2.php#L66-L74)

### `register_post_type_args`

*Filters the arguments for registering a post type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of arguments for registering a post type.<br>See the register_post_type() function for accepted arguments.
`$this->name` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-post-type.php](../../wordpress/wp-includes/class-wp-post-type.php), [line 415](../../wordpress/wp-includes/class-wp-post-type.php#L415-L424)

### `user_has_cap`

*Dynamically filter a user's capabilities.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->allcaps` |  | 
`$caps` | `string[]` | Required primitive capabilities for the requested capability.
`$args` | `array` | {<br>    Arguments that accompany the requested capability check.<br><br>    @type string    $0 Requested capability.<br>    @type int       $1 Concerned user ID.<br>    @type mixed  ...$2 Optional second and further parameters, typically object ID.<br>}
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.7.0` | Added the `$user` parameter.
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-user.php](../../wordpress/wp-includes/class-wp-user.php), [line 765](../../wordpress/wp-includes/class-wp-user.php#L765-L783)

### `role_has_cap`

*Filters which capabilities a role has.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$this->capabilities` |  | 
`$cap` | `string` | Capability name.
`$this->name` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/class-wp-role.php](../../wordpress/wp-includes/class-wp-role.php), [line 84](../../wordpress/wp-includes/class-wp-role.php#L84-L94)

### `list_pages`

*Filters the page title when creating an HTML drop-down list of pages.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | Page title.
`$page` | `\WP_Post` | Page data object.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/class-walker-page-dropdown.php](../../wordpress/wp-includes/class-walker-page-dropdown.php), [line 78](../../wordpress/wp-includes/class-walker-page-dropdown.php#L78-L86)

### `register_block_type_args`

*Filters the arguments for registering a block type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of arguments for registering a block type.
`$this->name` |  | 

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/class-wp-block-type.php](../../wordpress/wp-includes/class-wp-block-type.php), [line 322](../../wordpress/wp-includes/class-wp-block-type.php#L322-L330)

### `image_strip_meta`

*Filters whether to strip metadata from images when they're resized.*

This filter only applies when resizing using the Imagick editor since GD
always strips profiles by default.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$strip_meta` | `bool` | Whether to strip image metadata during resizing. Default true.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/class-wp-image-editor-imagick.php](../../wordpress/wp-includes/class-wp-image-editor-imagick.php), [line 325](../../wordpress/wp-includes/class-wp-image-editor-imagick.php#L325-L335)

### `image_make_intermediate_size`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filename` |  | 

Source: [wordpress/wp-includes/class-wp-image-editor-imagick.php](../../wordpress/wp-includes/class-wp-image-editor-imagick.php), [line 715](../../wordpress/wp-includes/class-wp-image-editor-imagick.php#L715-L715)

### `widget_tag_cloud_args`

*Filters the taxonomy used in the Tag Cloud widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('taxonomy' => $current_taxonomy, 'echo' => false, 'show_count' => $show_count)` |  | 
`$instance` | `array` | Array of settings for the current widget.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$instance` parameter.
`3.0.0` | Added taxonomy drop-down.
`2.8.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php](../../wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php), [line 58](../../wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php#L58-L78)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php](../../wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php), [line 85](../../wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php#L85-L86)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php](../../wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php), [line 95](../../wordpress/wp-includes/widgets/class-wp-widget-tag-cloud.php#L95-L96)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-archives.php](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php), [line 46](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php#L46-L47)

### `widget_archives_dropdown_args`

*Filters the arguments for the Archives widget drop-down.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('type' => 'monthly', 'format' => 'option', 'show_post_count' => $count)` |  | 
`$instance` | `array` | Settings for the current Archives widget instance.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$instance` parameter.
`2.8.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-archives.php](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php), [line 64](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php#L64-L83)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-archives.php](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php), [line 128](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php#L128-L129)

### `widget_archives_args`

*Filters the arguments for the Archives widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('type' => 'monthly', 'show_post_count' => $count)` |  | 
`$instance` | `array` | Array of settings for the current widget.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$instance` parameter.
`2.8.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-archives.php](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php), [line 142](../../wordpress/wp-includes/widgets/class-wp-widget-archives.php#L142-L160)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-meta.php](../../wordpress/wp-includes/widgets/class-wp-widget-meta.php), [line 48](../../wordpress/wp-includes/widgets/class-wp-widget-meta.php#L48-L49)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-meta.php](../../wordpress/wp-includes/widgets/class-wp-widget-meta.php), [line 59](../../wordpress/wp-includes/widgets/class-wp-widget-meta.php#L59-L60)

### `widget_meta_poweredby`

*Filters the "WordPress.org" list item HTML in the Meta widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`sprintf('<li><a href="%1$s">%2$s</a></li>', esc_url(__('https://wordpress.org/')), __('WordPress.org'))` |  | 
`$instance` | `array` | Array of settings for the current widget.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$instance` parameter.
`3.6.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-meta.php](../../wordpress/wp-includes/widgets/class-wp-widget-meta.php), [line 77](../../wordpress/wp-includes/widgets/class-wp-widget-meta.php#L77-L94)

### `widget_{$this->id_base}_instance_schema`

*Filters the media widget instance schema to add additional properties.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$schema` | `array` | Instance schema.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-media.php](../../wordpress/wp-includes/widgets/class-wp-widget-media.php), [line 159](../../wordpress/wp-includes/widgets/class-wp-widget-media.php#L159-L167)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance['title']` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-media.php](../../wordpress/wp-includes/widgets/class-wp-widget-media.php), [line 234](../../wordpress/wp-includes/widgets/class-wp-widget-media.php#L234-L235)

### `widget_{$this->id_base}_instance`

*Filters the media widget instance prior to rendering the media.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance` | `array` | Instance data.
`$args` | `array` | Widget args.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-media.php](../../wordpress/wp-includes/widgets/class-wp-widget-media.php), [line 241](../../wordpress/wp-includes/widgets/class-wp-widget-media.php#L241-L250)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php](../../wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php), [line 51](../../wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php#L51-L52)

### `widget_posts_args`

*Filters the arguments for the Recent Posts widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true)` |  | 
`$instance` | `array` | Array of settings for the current widget.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$instance` parameter.
`3.4.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php](../../wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php), [line 61](../../wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php#L61-L81)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php](../../wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php), [line 98](../../wordpress/wp-includes/widgets/class-wp-widget-recent-posts.php#L98-L99)

### `widget_links_args`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$widget_links_args` |  | 
`$instance` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-links.php](../../wordpress/wp-includes/widgets/class-wp-widget-links.php), [line 80](../../wordpress/wp-includes/widgets/class-wp-widget-links.php#L80-L80)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-search.php](../../wordpress/wp-includes/widgets/class-wp-widget-search.php), [line 45](../../wordpress/wp-includes/widgets/class-wp-widget-search.php#L45-L46)

### `widget_title`

*Filters the widget title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | The widget title. Default 'Pages'.
`$instance` | `array` | Array of settings for the current widget.
`$this->id_base` |  | 

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-pages.php](../../wordpress/wp-includes/widgets/class-wp-widget-pages.php), [line 46](../../wordpress/wp-includes/widgets/class-wp-widget-pages.php#L46-L55)

### `widget_pages_args`

*Filters the arguments for the Pages widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('title_li' => '', 'echo' => 0, 'sort_column' => $sortby, 'exclude' => $exclude)` |  | 
`$instance` | `array` | Array of settings for the current widget.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$instance` parameter.
`2.8.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-pages.php](../../wordpress/wp-includes/widgets/class-wp-widget-pages.php), [line 65](../../wordpress/wp-includes/widgets/class-wp-widget-pages.php#L65-L85)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-pages.php](../../wordpress/wp-includes/widgets/class-wp-widget-pages.php), [line 96](../../wordpress/wp-includes/widgets/class-wp-widget-pages.php#L96-L97)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance['title']` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-custom-html.php](../../wordpress/wp-includes/widgets/class-wp-widget-custom-html.php), [line 132](../../wordpress/wp-includes/widgets/class-wp-widget-custom-html.php#L132-L133)

### `widget_text`

*This filter is documented in wp-includes/widgets/class-wp-widget-text.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance['content']` |  | 
`$simulated_text_widget_instance` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-custom-html.php](../../wordpress/wp-includes/widgets/class-wp-widget-custom-html.php), [line 146](../../wordpress/wp-includes/widgets/class-wp-widget-custom-html.php#L146-L147)

### `widget_custom_html_content`

*Filters the content of the Custom HTML widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | The widget content.
`$instance` | `array` | Array of settings for the current widget.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.1` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-custom-html.php](../../wordpress/wp-includes/widgets/class-wp-widget-custom-html.php), [line 152](../../wordpress/wp-includes/widgets/class-wp-widget-custom-html.php#L152-L161)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-categories.php](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php), [line 50](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php#L50-L51)

### `widget_categories_dropdown_args`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cat_args` |  | 
`$instance` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-categories.php](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php), [line 90](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php#L90-L90)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-categories.php](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php), [line 115](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php#L115-L116)

### `widget_categories_args`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cat_args` |  | 
`$instance` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-categories.php](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php), [line 139](../../wordpress/wp-includes/widgets/class-wp-widget-categories.php#L139-L139)

### `widget_{$this->id_base}_instance_schema`

*This filter is documented in wp-includes/widgets/class-wp-widget-media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$schema` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-media-gallery.php](../../wordpress/wp-includes/widgets/class-wp-widget-media-gallery.php), [line 100](../../wordpress/wp-includes/widgets/class-wp-widget-media-gallery.php#L100-L101)

### `show_recent_comments_widget_style`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php), [line 53](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php#L53-L53)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php), [line 88](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php#L88-L89)

### `widget_comments_args`

*Filters the arguments for the Recent Comments widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('number' => $number, 'status' => 'approve', 'post_status' => 'publish')` |  | 
`$instance` | `array` | Array of settings for the current widget.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | Added the `$instance` parameter.
`3.4.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php), [line 97](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php#L97-L116)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php), [line 129](../../wordpress/wp-includes/widgets/class-wp-widget-recent-comments.php#L129-L130)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php](../../wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php), [line 52](../../wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php#L52-L53)

### `navigation_widgets_format`

*Filters the HTML format of widgets with navigation links.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` | `string` | The type of markup to use in widgets with navigation links.<br>Accepts 'html5', 'xhtml'.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php](../../wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php), [line 63](../../wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php#L63-L71)

### `widget_nav_menu_args`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$nav_menu_args` |  | 
`$nav_menu` |  | 
`$args` |  | 
`$instance` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php](../../wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php), [line 108](../../wordpress/wp-includes/widgets/class-wp-nav-menu-widget.php#L108-L108)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-calendar.php](../../wordpress/wp-includes/widgets/class-wp-widget-calendar.php), [line 52](../../wordpress/wp-includes/widgets/class-wp-widget-calendar.php#L52-L53)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-rss.php](../../wordpress/wp-includes/widgets/class-wp-widget-rss.php), [line 84](../../wordpress/wp-includes/widgets/class-wp-widget-rss.php#L84-L85)

### `navigation_widgets_format`

*This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-rss.php](../../wordpress/wp-includes/widgets/class-wp-widget-rss.php), [line 100](../../wordpress/wp-includes/widgets/class-wp-widget-rss.php#L100-L101)

### `widget_title`

*This filter is documented in wp-includes/widgets/class-wp-widget-pages.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-text.php](../../wordpress/wp-includes/widgets/class-wp-widget-text.php), [line 229](../../wordpress/wp-includes/widgets/class-wp-widget-text.php#L229-L230)

### `widget_text`

*Filters the content of the Text widget.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$text` | `string` | The widget content.
`$instance` | `array` | Array of settings for the current widget.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.1` | The `$widget` param may now be a `WP_Widget_Custom_HTML` object in addition to a `WP_Widget_Text` object.
`4.4.0` | Added the `$widget` parameter.
`2.3.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-text.php](../../wordpress/wp-includes/widgets/class-wp-widget-text.php), [line 269](../../wordpress/wp-includes/widgets/class-wp-widget-text.php#L269-L280)

### `widget_text_content`

*Filters the content of the Text widget to apply changes expected from the visual (TinyMCE) editor.*

By default a subset of the_content filters are applied, including wpautop and wptexturize.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$text` | `string` | The widget content.
`$instance` | `array` | Array of settings for the current widget.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.8.0` | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-text.php](../../wordpress/wp-includes/widgets/class-wp-widget-text.php), [line 284](../../wordpress/wp-includes/widgets/class-wp-widget-text.php#L284-L295)

### `the_editor_content`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$instance['text']` |  | 
`$default_editor` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-text.php](../../wordpress/wp-includes/widgets/class-wp-widget-text.php), [line 472](../../wordpress/wp-includes/widgets/class-wp-widget-text.php#L472-L473)

### `wp_video_shortcode_library`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mediaelement'` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-media-video.php](../../wordpress/wp-includes/widgets/class-wp-widget-media-video.php), [line 176](../../wordpress/wp-includes/widgets/class-wp-widget-media-video.php#L176-L176)

### `wp_audio_shortcode_library`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mediaelement'` |  | 

Source: [wordpress/wp-includes/widgets/class-wp-widget-media-audio.php](../../wordpress/wp-includes/widgets/class-wp-widget-media-audio.php), [line 135](../../wordpress/wp-includes/widgets/class-wp-widget-media-audio.php#L135-L135)

### `rest_{$this->post_type}_query`

*Filters WP_Query arguments when querying users via the REST API.*

The dynamic portion of the hook name, `$this->post_type`, refers to the post type slug.

Possible filter names include:

 - `rest_post_query`
 - `rest_page_query`
 - `rest_attachment_query`

Enables adding extra arguments or setting defaults for a post collection request.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Array of arguments to be passed to WP_Query.
`$request` | `\WP_REST_Request` | The REST API request.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | Moved after the `tax_query` query arg is generated.
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 288](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L288-L309)

### `rest_{$this->post_type}_trashable`

*Filters whether a post is trashable.*

The dynamic portion of the hook name, `$this->post_type`, refers to the post type slug.

Pass false to disable Trash support for the post.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$supports_trash` | `bool` | Whether the post type support trashing.
`$post` | `\WP_Post` | The Post object being considered for trashing support.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 888](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L888-L900)

### `rest_query_var-{$key}`

*Filters the query_vars used in get_items() for the constructed query.*

The dynamic portion of the hook name, `$key`, refers to the query_var key.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `string` | The query_var value.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 988](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L988-L997)

### `rest_pre_insert_{$this->post_type}`

*Filters a post before it is inserted via the REST API.*

The dynamic portion of the hook name, `$this->post_type`, refers to the post type slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_post` | `\stdClass` | An object representing a single post prepared<br>for inserting or updating the database.
`$request` | `\WP_REST_Request` | Request object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 1249](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L1249-L1260)

### `get_the_guid`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->guid` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 1646](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L1646-L1647)

### `the_content`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_content` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 1721](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L1721-L1721)

### `get_the_excerpt`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_excerpt` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 1731](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L1731-L1732)

### `the_excerpt`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$excerpt` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 1734](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L1734-L1735)

### `rest_prepare_{$this->post_type}`

*Filters the post data for a REST API response.*

The dynamic portion of the hook name, `$this->post_type`, refers to the post type slug.

Possible filter names include:

 - `rest_prepare_post`
 - `rest_prepare_page`
 - `rest_prepare_attachment`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$post` | `\WP_Post` | Post object.
`$request` | `\WP_REST_Request` | Request object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 1852](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L1852-L1869)

### `rest_{$this->post_type}_item_schema`

*Filters the post's schema.*

The dynamic portion of the filter, `$this->post_type`, refers to the
post type slug for the controller.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$schema` | `array` | Item schema data.

**Changelog**

Version | Description
------- | -----------
`5.4.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 2460](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L2460-L2470)

### `rest_{$this->post_type}_collection_params`

*Filters collection parameters for the posts controller.*

The dynamic part of the filter `$this->post_type` refers to the post
type slug for the controller.

This filter registers the collection parameter, but does not map the
collection parameter to an internal WP_Query parameter. Use the
`rest_{$this->post_type}_query` filter to set WP_Query parameters.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_params` | `array` | JSON Schema-formatted collection parameters.
`$post_type` | `\WP_Post_Type` | Post type object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php), [line 2783](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php#L2783-L2798)

### `rest_prepare_post_type`

*Filters a post type returned from the REST API.*

Allows modification of the post type data right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$post_type` | `\WP_Post_Type` | The original post type object.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-post-types-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-post-types-controller.php), [line 243](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-post-types-controller.php#L243-L254)

### `plugins_update_check_locales`

*This filter is documented in wp-includes/update.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$installed_locales` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php), [line 363](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php#L363-L364)

### `rest_prepare_plugin`

*Filters plugin data for a REST API response.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$item` | `array` | The plugin item from {@see \get_plugin_data()}.
`$request` | `\WP_REST_Request` | The request object.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php), [line 588](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php#L588-L597)

### `site_health_test_rest_capability_{$check}`

*Filters the capability needed to run a given Site Health check.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_capability` | `string` | The default capability required for this check.
`$check` | `string` | The Site Health check being performed.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-site-health-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-site-health-controller.php), [line 172](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-site-health-controller.php#L172-L180)

### `rest_prepare_status`

*Filters a post status returned from the REST API.*

Allows modification of the status data right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$status` | `object` | The original post status object.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-post-statuses-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-post-statuses-controller.php), [line 270](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-post-statuses-controller.php#L270-L281)

### `rest_prepare_theme`

*Filters theme data returned from the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$theme` | `\WP_Theme` | Theme object used to create response.
`$request` | `\WP_REST_Request` | Request object.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-themes-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-themes-controller.php), [line 314](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-themes-controller.php#L314-L323)

### `rest_themes_collection_params`

*Filters REST API collection parameters for the themes controller.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_params` | `array` | JSON Schema-formatted collection parameters.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-themes-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-themes-controller.php), [line 582](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-themes-controller.php#L582-L589)

### `rest_pre_insert_application_password`

*Filters an application password before it is inserted via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared` | `\stdClass` | An object representing a single application password prepared for inserting or updating the database.
`$request` | `\WP_REST_Request` | Request object.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php), [line 586](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php#L586-L594)

### `rest_prepare_application_password`

*Filters the REST API response for an application password.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$item` | `array` | The application password array.
`$request` | `\WP_REST_Request` | The request object.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php), [line 632](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-application-passwords-controller.php#L632-L641)

### `wp_edited_image_metadata`

*Filters the meta data for the new image created by editing an existing image.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$new_image_meta` | `array` | Meta data for the new image.
`$new_attachment_id` | `int` | Attachment post ID for the new image.
`$attachment_id` | `int` | Attachment post ID for the edited (parent) image.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 650](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L650-L659)

### `the_content`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_content` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 723](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L723-L724)

### `get_the_excerpt`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_excerpt` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 729](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L729-L730)

### `the_excerpt`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$caption` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 732](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L732-L733)

### `rest_prepare_attachment`

*Filters an attachment returned from the REST API.*

Allows modification of the attachment right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$post` | `\WP_Post` | The original attachment post.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php), [line 821](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-attachments-controller.php#L821-L832)

### `rest_prepare_taxonomy`

*Filters a taxonomy returned from the REST API.*

Allows modification of the taxonomy data right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$taxonomy` |  | 
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-taxonomies-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-taxonomies-controller.php), [line 279](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-taxonomies-controller.php#L279-L290)

### `rest_pre_get_setting`

*Filters the value of a setting recognized by the REST API.*

Allow hijacking the setting value and overriding the built-in behavior by returning a
non-null value.  The returned value will be presented as the setting value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$name` | `string` | Setting name (as shown in REST API responses).
`$args` | `array` | Arguments passed to register_setting() for this setting.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-settings-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-settings-controller.php), [line 85](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-settings-controller.php#L85-L99)

### `rest_pre_update_setting`

*Filters whether to preempt a setting value update via the REST API.*

Allows hijacking the setting update logic and overriding the built-in behavior by
returning true.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$name` | `string` | Setting name (as shown in REST API responses).
`$request[$name]` |  | 
`$args` | `array` | Arguments passed to register_setting() for this setting.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-settings-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-settings-controller.php), [line 156](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-settings-controller.php#L156-L170)

### `rest_revision_query`

*This filter is documented in wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 
`$request` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php), [line 276](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php#L276-L277)

### `rest_query_var-{$key}`

*This filter is documented in wp-includes/rest-api/endpoints/class-wp-rest-posts-controller.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php), [line 513](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php#L513-L514)

### `get_the_guid`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->guid` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php), [line 585](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php#L585-L586)

### `the_content`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_content` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php), [line 602](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php#L602-L603)

### `rest_prepare_revision`

*Filters a revision returned from the REST API.*

Allows modification of the revision right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$post` | `\WP_Post` | The original revision object.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php), [line 623](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php#L623-L634)

### `the_excerpt`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$excerpt` |  | 
`$post` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php), [line 825](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-revisions-controller.php#L825-L826)

### `rest_prepare_block_type`

*Filters a block type returned from the REST API.*

Allows modification of the block type data right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$block_type` | `\WP_Block_Type` | The original block type object.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-block-types-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-block-types-controller.php), [line 306](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-block-types-controller.php#L306-L317)

### `rest_block_directory_collection_params`

*Filters REST API collection parameters for the block directory controller.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_params` | `array` | JSON Schema-formatted collection parameters.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-block-directory-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-block-directory-controller.php), [line 315](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-block-directory-controller.php#L315-L322)

### `rest_user_query`

*Filters WP_User_Query arguments when querying users via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_args` | `array` | Array of arguments for WP_User_Query.
`$request` | `\WP_REST_Request` | The REST API request.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 307](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L307-L317)

### `rest_prepare_user`

*Filters user data returned from the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$user` | `\WP_User` | User object used to create response.
`$request` | `\WP_REST_Request` | Request object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 1059](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L1059-L1068)

### `rest_pre_insert_user`

*Filters user data before insertion via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_user` | `object` | User object.
`$request` | `\WP_REST_Request` | Request object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 1160](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L1160-L1168)

### `illegal_user_logins`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 1255](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L1255-L1255)

### `rest_user_collection_params`

*Filters REST API collection parameters for the users controller.*

This filter registers the collection parameter, but does not map the
collection parameter to an internal WP_User_Query parameter.  Use the
`rest_user_query` filter to set WP_User_Query arguments.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_params` | `array` | JSON Schema-formatted collection parameters.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php), [line 1561](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-users-controller.php#L1561-L1572)

### `rest_{$this->taxonomy}_query`

*Filters get_terms() arguments when querying users via the REST API.*

The dynamic portion of the hook name, `$this->taxonomy`, refers to the taxonomy slug.

Enables adding extra arguments or setting defaults for a terms
collection request.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_args` | `array` | Array of arguments to be<br>passed to get_terms().
`$request` | `\WP_REST_Request` | The REST API request.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 235](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L235-L251)

### `rest_pre_insert_{$this->taxonomy}`

*Filters term data before inserting term via the REST API.*

The dynamic portion of the hook name, `$this->taxonomy`, refers to the taxonomy slug.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_term` | `object` | Term object.
`$request` | `\WP_REST_Request` | Request object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 759](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L759-L769)

### `rest_prepare_{$this->taxonomy}`

*Filters the term data for a REST API response.*

The dynamic portion of the hook name, `$this->taxonomy`, refers to the taxonomy slug.

Possible filter names include:

 - `rest_prepare_category`
 - `rest_prepare_post_tag`

Allows modification of the term data right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$item` | `\WP_Term` | The original term object.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 830](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L830-L848)

### `rest_{$this->taxonomy}_collection_params`

*Filters collection parameters for the terms controller.*

The dynamic part of the filter `$this->taxonomy` refers to the taxonomy
slug for the controller.

This filter registers the collection parameter, but does not map the
collection parameter to an internal WP_Term_Query parameter.  Use the
`rest_{$this->taxonomy}_query` filter to set WP_Term_Query parameters.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_params` | `array` | JSON Schema-formatted collection parameters.
`$taxonomy` | `\WP_Taxonomy` | Taxonomy object.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php), [line 1088](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-terms-controller.php#L1088-L1103)

### `rest_comment_query`

*Filters arguments, before passing to WP_Comment_Query, when querying comments via the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_args` | `array` | Array of arguments for WP_Comment_Query.
`$request` | `\WP_REST_Request` | The current request.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 263](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L263-L273)

### `rest_allow_anonymous_comments`

*Filters whether comments can be created via the REST API without authentication.*

Enables creating comments for anonymous users.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$request` | `\WP_REST_Request` | Request used to generate the<br>response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 451](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L451-L463)

### `rest_pre_insert_comment`

*Filters a comment before it is inserted via the REST API.*

Allows modification of the comment right before it is inserted via wp_insert_comment().
Returning a WP_Error value from the filter will short-circuit insertion and allow
skipping further processing.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_comment` | `array\|\WP_Error` | The prepared comment data for wp_insert_comment().
`$request` | `\WP_REST_Request` | Request used to insert the comment.

**Changelog**

Version | Description
------- | -----------
`4.8.0` | `$prepared_comment` can now be a WP_Error to short-circuit insertion.
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 681](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L681-L694)

### `rest_comment_trashable`

*Filters whether a comment can be trashed via the REST API.*

Return false to disable trash support for the comment.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`EMPTY_TRASH_DAYS > 0` |  | 
`$comment` | `\WP_Comment` | The comment object being considered for trashing support.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 957](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L957-L967)

### `comment_text`

*This filter is documented in wp-includes/comment-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$comment->comment_content` |  | 
`$comment` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 1087](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L1087-L1088)

### `rest_prepare_comment`

*Filters a comment returned from the REST API.*

Allows modification of the comment right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$comment` | `\WP_Comment` | The original comment object.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 1122](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L1122-L1133)

### `rest_preprocess_comment`

*Filters a comment added via the REST API after it is prepared for insertion into the database.*

Allows modification of the comment right after it is prepared for the database.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prepared_comment` | `array` | The prepared comment data for `wp_insert_comment`.
`$request` | `\WP_REST_Request` | The current request.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 1353](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L1353-L1363)

### `rest_comment_collection_params`

*Filters REST API collection parameters for the comments controller.*

This filter registers the collection parameter, but does not map the
collection parameter to an internal WP_Comment_Query parameter. Use the
`rest_comment_query` filter to set WP_Comment_Query parameters.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_params` | `array` | JSON Schema-formatted collection parameters.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 1676](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L1676-L1687)

### `allow_empty_comment`

*This filter is documented in wp-includes/comment.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$check` |  | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php), [line 1891](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-comments-controller.php#L1891-L1892)

### `rest_prepare_autosave`

*Filters a revision returned from the REST API.*

Allows modification of the revision right before it is returned.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | The response object.
`$post` | `\WP_Post` | The original revision object.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`5.0.0` | 

Source: [wordpress/wp-includes/rest-api/endpoints/class-wp-rest-autosaves-controller.php](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-autosaves-controller.php), [line 427](../../wordpress/wp-includes/rest-api/endpoints/class-wp-rest-autosaves-controller.php#L427-L438)

### `rest_authentication_errors`

*Filters REST API authentication errors.*

This is used to pass a WP_Error from an authentication method back to
the API.

Authentication methods should check first if they're being used, as
multiple authentication methods can be enabled on a site (cookies,
HTTP basic auth, OAuth). If the authentication method hooked in is
not actually being attempted, null should be returned to indicate
another authentication method should check instead. Similarly,
callbacks should ensure the value is `null` before checking for
errors.

A WP_Error instance can be returned if an error occurs, and this should
match the format used by API methods internally (that is, the `status`
data should be used). A callback can return `true` to indicate that
the authentication method was used, and it succeeded.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 164](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L164-L188)

### `rest_exposed_cors_headers`

*Filters the list of response headers that are exposed to REST API CORS requests.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$expose_headers` | `string[]` | The list of response headers to expose.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 284](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L284-L291)

### `rest_allowed_cors_headers`

*Filters the list of request headers that are allowed for REST API CORS requests.*

The allowed headers are passed to the browser to specify which
headers can be passed to the REST API. By default, we allow the
Content-* headers needed to upload files to the media endpoints.
As well as the Authorization and Nonce headers for allowing authentication.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$allow_headers` | `string[]` | The list of request headers to allow.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 303](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L303-L315)

### `rest_send_nocache_headers`

*Filters whether to send nocache headers on a REST API request.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`is_user_logged_in()` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 319](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L319-L326)

### `rest_enabled`

*Filters whether the REST API is enabled.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(true)` |  | 
`'4.7.0'` |  | 
`'rest_authentication_errors'` |  | 
`sprintf(
    /* translators: %s: rest_authentication_errors */
    __('The REST API can no longer be completely disabled, the %s filter can be used to restrict access to the API, instead.'),
    'rest_authentication_errors'
)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 337](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L337-L356)

### `rest_jsonp_enabled`

*Filters whether JSONP is enabled for the REST API.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 358](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L358-L365)

### `rest_post_dispatch`

*Filters the REST API response.*

Allows modification of the response before returning.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`rest_ensure_response($result)` |  | 
`$this` |  | 
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Applied to embedded responses.
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 423](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L423-L435)

### `rest_pre_serve_request`

*Filters whether the REST API request has already been served.*

Allow sending the request manually - by returning true, the API result
will not be sent to the client.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`false` |  | 
`$result` | `\WP_HTTP_Response` | Result to send to the client. Usually a `WP_REST_Response`.
`$request` | `\WP_REST_Request` | Request used to generate the response.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 449](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L449-L463)

### `rest_pre_echo_response`

*Filters the REST API response.*

Allows modification of the response data after inserting
embedded data (if any) and before echoing the response data.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result` | `array` | Response data to send to the client.
`$this` |  | 
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.8.1` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 474](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L474-L486)

### `rest_post_dispatch`

*This filter is documented in wp-includes/rest-api/class-wp-rest-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`rest_ensure_response($response)` |  | 
`$this` |  | 
`$request` |  | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 698](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L698-L699)

### `rest_envelope_response`

*Filters the enveloped form of a REST API response.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$envelope` | `array` | {<br>    Envelope data.<br><br>    @type array $body    Response data.<br>    @type int   $status  The 3-digit HTTP status code.<br>    @type array $headers Map of header name to header value.<br>}
`$response` | `\WP_REST_Response` | Original response data.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 742](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L742-L756)

### `rest_endpoints`

*Filters the array of available REST API endpoints.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$endpoints` | `array` | The available endpoints. An array of matching regex patterns, each mapped<br>to an array of callbacks for the endpoint. These take the format<br>`'/path/regex' => array( $callback, $bitmask )` or<br>`'/path/regex' => array( array( $callback, $bitmask ).

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 837](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L837-L847)

### `rest_pre_dispatch`

*Filters the pre-calculated result of a REST API dispatch request.*

Allow hijacking the request before dispatching by returning a non-empty. The returned value
will be used to serve the request instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$this` |  | 
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 937](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L937-L950)

### `rest_request_before_callbacks`

*Filters the response before executing any REST API callbacks.*

Allows plugins to perform additional validation after a
request is initialized and matched to a registered route,
but before it is executed.

Note that this filter will not be called for requests that
fail to authenticate or match to a registered route.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response\|\WP_HTTP_Response\|\WP_Error\|mixed` | Result to send to the client.<br>Usually a WP_REST_Response or WP_Error.
`$handler` | `array` | Route handler used for the request.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1085](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1085-L1102)

### `rest_dispatch_request`

*Filters the REST API dispatch request result.*

Allow plugins to override dispatching the request.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$request` | `\WP_REST_Request` | Request used to generate the response.
`$route` | `string` | Route matched for the request.
`$handler` | `array` | Route handler used for the request.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | Added `$route` and `$handler` parameters.
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1120](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1120-L1133)

### `rest_request_after_callbacks`

*Filters the response immediately after executing any REST API
callbacks.*

Allows plugins to perform any needed cleanup, for example,
to undo changes made during the %1$s
filter.

Note that this filter will not be called for requests that
fail to authenticate or match to a registered route.

Note that an endpoint's `permission_callback` can still be
called after this filter - see `rest_send_allow_header()`.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response\|\WP_HTTP_Response\|\WP_Error\|mixed` | Result to send to the client.<br>Usually a WP_REST_Response or WP_Error.
`$handler` | `array` | Route handler used for the request.
`$request` | `\WP_REST_Request` | Request used to generate the response.

**Changelog**

Version | Description
------- | -----------
`4.7.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1143](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1143-L1164)

### `rest_index`

*Filters the REST API root index data.*

This contains the data describing the API. This includes information
about supported authentication schemes, supported namespaces, routes
available on the API, and a small amount of data about the site.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | Response data.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1230](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1230-L1241)

### `rest_namespace_index`

*Filters the REST API namespace index data.*

This typically is just the route data for the namespace, but you can
add any data you'd like here.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `\WP_REST_Response` | Response data.
`$request` | `\WP_REST_Request` | Request data. The namespace is passed as the 'namespace' parameter.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1305](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1305-L1316)

### `rest_endpoints_description`

*Filters the REST API endpoint data.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$data` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1338](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1338-L1345)

### `rest_route_data`

*Filters the publicly-visible data for REST API routes.*

This data is exposed on indexes and can be used by clients or
developers to investigate the site and find out how to use it. It
acts as a form of self-documentation.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$available` | `array[]` | Route data to expose in indexes, keyed by route.
`$routes` | `array` | Internal route data as an associative array.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1348](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1348-L1360)

### `rest_get_max_batch_size`

*Filters the maximum number of REST API requests that can be included in a batch.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`25` |  | 

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1448](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1448-L1455)

### `rest_pre_dispatch`

*This filter is documented in wp-includes/rest-api/class-wp-rest-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`null` |  | 
`$this` |  | 
`$clean_request` |  | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1577](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1577-L1578)

### `rest_post_dispatch`

*This filter is documented in wp-includes/rest-api/class-wp-rest-server.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`rest_ensure_response($result)` |  | 
`$this` |  | 
`$single_request` |  | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-server.php](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php), [line 1605](../../wordpress/wp-includes/rest-api/class-wp-rest-server.php#L1605-L1606)

### `rest_request_parameter_order`

*Filters the parameter priority order for a REST API request.*

The order affects which parameters are checked when using WP_REST_Request::get_param()
and family. This acts similarly to PHP's `request_order` setting.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$order` | `string[]` | Array of types to check, in order of priority.
`$this` | `\WP_REST_Request` | The request object.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-request.php](../../wordpress/wp-includes/rest-api/class-wp-rest-request.php), [line 373](../../wordpress/wp-includes/rest-api/class-wp-rest-request.php#L373-L384)

### `rest_request_from_url`

*Filters the REST API request generated from a URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$request` | `\WP_REST_Request\|false` | Generated request object, or false if URL<br>could not be parsed.
`$url` | `string` | URL the request was generated from.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-request.php](../../wordpress/wp-includes/rest-api/class-wp-rest-request.php), [line 1045](../../wordpress/wp-includes/rest-api/class-wp-rest-request.php#L1045-L1054)

### `rest_term_search_query`

*Filters the query arguments for a REST API search request.*

Enables adding extra arguments or setting defaults for a term search request.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_args` | `array` | Key value array of query var to query value.
`$request` | `\WP_REST_Request` | The request used.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/rest-api/search/class-wp-rest-term-search-handler.php](../../wordpress/wp-includes/rest-api/search/class-wp-rest-term-search-handler.php), [line 68](../../wordpress/wp-includes/rest-api/search/class-wp-rest-term-search-handler.php#L68-L78)

### `rest_post_search_query`

*Filters the query arguments for a REST API search request.*

Enables adding extra arguments or setting defaults for a post search request.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_args` | `array` | Key value array of query var to query value.
`$request` | `\WP_REST_Request` | The request used.

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/rest-api/search/class-wp-rest-post-search-handler.php](../../wordpress/wp-includes/rest-api/search/class-wp-rest-post-search-handler.php), [line 73](../../wordpress/wp-includes/rest-api/search/class-wp-rest-post-search-handler.php#L73-L83)

### `rest_post_format_search_query`

*Filters the query arguments for a REST API search request.*

Enables adding extra arguments or setting defaults for a post format search request.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$query_args` | `array` | Key value array of query var to query value.
`$request` | `\WP_REST_Request` | The request used.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/rest-api/search/class-wp-rest-post-format-search-handler.php](../../wordpress/wp-includes/rest-api/search/class-wp-rest-post-format-search-handler.php), [line 48](../../wordpress/wp-includes/rest-api/search/class-wp-rest-post-format-search-handler.php#L48-L58)

### `rest_response_link_curies`

*Filters extra CURIEs available on REST API responses.*

CURIEs allow a shortened version of URI relations. This allows a more
usable form for custom relations than using the full URI. These work
similarly to how XML namespaces work.

Registered CURIES need to specify a name and URI template. This will
automatically transform URI relations into their shortened version.
The shortened relation follows the format `{name}:{rel}`. `{rel}` in
the URI template will be replaced with the `{rel}` part of the
shortened relation.

For example, a CURIE with name `example` and URI template
`http://w.org/{rel}` would transform a `http://w.org/term` relation
into `example:term`.

Well-behaved clients should expand and normalise these back to their
full URI relation, however some naive clients may not resolve these
correctly, so adding new CURIEs may break backward compatibility.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/rest-api/class-wp-rest-response.php](../../wordpress/wp-includes/rest-api/class-wp-rest-response.php), [line 264](../../wordpress/wp-includes/rest-api/class-wp-rest-response.php#L264-L289)

### `user_search_columns`

*Filters the columns to search in a WP_User_Query search.*

The default columns depend on the search term, and include 'ID', 'user_login',
'user_email', 'user_url', 'user_nicename', and 'display_name'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$search_columns` | `string[]` | Array of column names to be searched.
`$search` | `string` | Text being searched.
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/class-wp-user-query.php](../../wordpress/wp-includes/class-wp-user-query.php), [line 537](../../wordpress/wp-includes/class-wp-user-query.php#L537-L549)

### `users_pre_query`

*Filters the users array before the query takes place.*

Return a non-null value to bypass WordPress' default user queries.

Filtering functions that require pagination information are encouraged to set
the `total_users` property of the WP_User_Query object, passed to the filter
by reference. If WP_User_Query does not perform a database query, it will not
have enough information to generate these values itself.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(null, &$this)` |  | 

**Changelog**

Version | Description
------- | -----------
`5.1.0` | 

Source: [wordpress/wp-includes/class-wp-user-query.php](../../wordpress/wp-includes/class-wp-user-query.php), [line 595](../../wordpress/wp-includes/class-wp-user-query.php#L595-L611)

### `found_users_query`

*Filters SELECT FOUND_ROWS() query for the current WP_User_Query instance.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'SELECT FOUND_ROWS()'` |  | 
`$this` |  | 

**Changelog**

Version | Description
------- | -----------
`5.1.0` | Added the `$this` parameter.
`3.2.0` | 

Source: [wordpress/wp-includes/class-wp-user-query.php](../../wordpress/wp-includes/class-wp-user-query.php), [line 623](../../wordpress/wp-includes/class-wp-user-query.php#L623-L634)

### `recovery_mode_begin_url`

*Filters the URL to begin recovery mode.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | The generated recovery mode begin URL.
`$token` | `string` | The token used to identify the key.
`$key` | `string` | The recovery mode key.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/class-wp-recovery-mode-link-service.php](../../wordpress/wp-includes/class-wp-recovery-mode-link-service.php), [line 118](../../wordpress/wp-includes/class-wp-recovery-mode-link-service.php#L118-L127)

### `script_loader_src`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$src` |  | 
`$handle` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 202](../../wordpress/wp-includes/script-loader.php#L202-L202)

### `wp_editor_settings`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('tinymce' => true)` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 414](../../wordpress/wp-includes/script-loader.php#L414-L415)

### `tiny_mce_plugins`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tinymce_plugins` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 438](../../wordpress/wp-includes/script-loader.php#L438-L439)

### `disable_captions`

*This filter is documented in wp-admin/includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 444](../../wordpress/wp-includes/script-loader.php#L444-L445)

### `mce_buttons`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$toolbar1` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 467](../../wordpress/wp-includes/script-loader.php#L467-L468)

### `mce_buttons_2`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$toolbar2` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 484](../../wordpress/wp-includes/script-loader.php#L484-L485)

### `mce_buttons_3`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 486](../../wordpress/wp-includes/script-loader.php#L486-L487)

### `mce_buttons_4`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 488](../../wordpress/wp-includes/script-loader.php#L488-L489)

### `mce_external_plugins`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 490](../../wordpress/wp-includes/script-loader.php#L490-L491)

### `tiny_mce_before_init`

*This filter is documented in wp-includes/class-wp-editor.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$tinymce_settings` |  | 
`'classic-block'` |  | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 511](../../wordpress/wp-includes/script-loader.php#L511-L512)

### `heartbeat_settings`

*Filters the Heartbeat settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 719](../../wordpress/wp-includes/script-loader.php#L719-L726)

### `mejs_settings`

*Filters the MediaElement configuration settings.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$mejs_settings` | `array` | MediaElement settings array.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 1040](../../wordpress/wp-includes/script-loader.php#L1040-L1047)

### `print_head_scripts`

*Filters whether to print the head scripts.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 1869](../../wordpress/wp-includes/script-loader.php#L1869-L1876)

### `print_footer_scripts`

*Filters whether to print the footer scripts.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 1904](../../wordpress/wp-includes/script-loader.php#L1904-L1911)

### `print_admin_styles`

*Filters whether to print the admin styles.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2048](../../wordpress/wp-includes/script-loader.php#L2048-L2055)

### `print_late_styles`

*Filters whether to print the styles queued too late for the HTML head.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`3.3.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2084](../../wordpress/wp-includes/script-loader.php#L2084-L2091)

### `should_load_block_editor_scripts_and_styles`

*Filters the flag that decides whether or not block editor scripts and
styles are going to be enqueued on the current screen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$is_block_editor_screen` | `bool` | Current value of the flag.

**Changelog**

Version | Description
------- | -----------
`5.6.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2227](../../wordpress/wp-includes/script-loader.php#L2227-L2235)

### `wp_script_attributes`

*Filters attributes to be added to a script tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attributes` | `array` | Key-value pairs representing `<script>` tag attributes.<br>Only the attribute name is added to the `<script>` tag for<br>entries with a boolean value, and that are true.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2381](../../wordpress/wp-includes/script-loader.php#L2381-L2390)

### `wp_inline_script_attributes`

*Filters attributes to be added to a script tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$attributes` | `array` | Key-value pairs representing `<script>` tag attributes.<br>Only the attribute name is added to the `<script>` tag for<br>entries with a boolean value, and that are true.
`$javascript` |  | 

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/script-loader.php](../../wordpress/wp-includes/script-loader.php), [line 2425](../../wordpress/wp-includes/script-loader.php#L2425-L2434)

### `wp_should_replace_insecure_home_url`

*Filters whether WordPress should replace old HTTP URLs to the site with their HTTPS counterpart.*

If a WordPress site had its URL changed from HTTP to HTTPS, by default this will return `true`. This filter can
be used to disable that behavior, e.g. after having replaced URLs manually in the database.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$should_replace_insecure_home_url` | `bool` | Whether insecure HTTP URLs to the site should be replaced.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/https-migration.php](../../wordpress/wp-includes/https-migration.php), [line 27](../../wordpress/wp-includes/https-migration.php#L27-L37)

### `image_make_intermediate_size`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$filename` |  | 

Source: [wordpress/wp-includes/class-wp-image-editor-gd.php](../../wordpress/wp-includes/class-wp-image-editor-gd.php), [line 480](../../wordpress/wp-includes/class-wp-image-editor-gd.php#L480-L480)

### `search_form_args`

*Filters the array of arguments used when generating the search form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | The array of arguments for building the search form.<br>See get_search_form() for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 276](../../wordpress/wp-includes/general-template.php#L276-L284)

### `search_form_format`

*Filters the HTML format of the search form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$format` | `string` | The type of markup to use in the search form.<br>Accepts 'html5', 'xhtml'.
`$args` | `array` | The array of arguments for building the search form.<br>See get_search_form() for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`3.6.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 291](../../wordpress/wp-includes/general-template.php#L291-L302)

### `get_search_form`

*Filters the HTML output of the search form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$form` | `string` | The search form HTML output.
`$args` | `array` | The array of arguments for building the search form.<br>See get_search_form() for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | The `$args` parameter was added.
`2.7.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 341](../../wordpress/wp-includes/general-template.php#L341-L351)

### `loginout`

*Filters the HTML output for the Log In/Log Out link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The HTML link content.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 384](../../wordpress/wp-includes/general-template.php#L384-L391)

### `loginout`

*This filter is documented in wp-includes/general-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 393](../../wordpress/wp-includes/general-template.php#L393-L394)

### `logout_url`

*Filters the logout URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$logout_url` | `string` | The HTML-encoded logout URL.
`$redirect` | `string` | Path to redirect to on logout.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 417](../../wordpress/wp-includes/general-template.php#L417-L425)

### `login_url`

*Filters the login URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$login_url` | `string` | The login URL. Not HTML-encoded.
`$redirect` | `string` | The path to redirect to on login, if supplied.
`$force_reauth` | `bool` | Whether to force reauthorization, even if a cookie is present.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | The `$force_reauth` parameter was added.
`2.8.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 449](../../wordpress/wp-includes/general-template.php#L449-L459)

### `register_url`

*Filters the user registration URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`site_url('wp-login.php?action=register', 'login')` |  | 

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 470](../../wordpress/wp-includes/general-template.php#L470-L477)

### `login_form_defaults`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$defaults` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 540](../../wordpress/wp-includes/general-template.php#L540-L540)

### `login_form_top`

*Filters content to display at the top of the login form.*

The filter evaluates just following the opening form tag element.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$args` | `array` | Array of login form arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 542](../../wordpress/wp-includes/general-template.php#L542-L552)

### `login_form_middle`

*Filters content to display in the middle of the login form.*

The filter evaluates just following the location where the 'login-password'
field is displayed.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$args` | `array` | Array of login form arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 554](../../wordpress/wp-includes/general-template.php#L554-L565)

### `login_form_bottom`

*Filters content to display at the bottom of the login form.*

The filter evaluates just preceding the closing form tag element.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$args` | `array` | Array of login form arguments.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 567](../../wordpress/wp-includes/general-template.php#L567-L577)

### `lostpassword_url`

*Filters the Lost Password URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$lostpassword_url` | `string` | The lost password page URL.
`$redirect` | `string` | The path to redirect to on login.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 632](../../wordpress/wp-includes/general-template.php#L632-L640)

### `register`

*Filters the HTML link to the Registration or Admin page.*

Users are sent to the admin page if logged-in, or the registration page
if enabled and logged-out.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The HTML code for the link to the Registration or Admin page.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 670](../../wordpress/wp-includes/general-template.php#L670-L680)

### `bloginfo_url`

*Filters the URL returned by get_bloginfo().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The URL returned by bloginfo().
`$show` | `string` | Type of information requested.

**Changelog**

Version | Description
------- | -----------
`2.0.5` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 885](../../wordpress/wp-includes/general-template.php#L885-L893)

### `bloginfo`

*Filters the site information returned by get_bloginfo().*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `mixed` | The requested non-URL site information.
`$show` | `string` | Type of information requested.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 895](../../wordpress/wp-includes/general-template.php#L895-L903)

### `get_site_icon_url`

*Filters the site icon URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$url` | `string` | Site icon URL.
`$size` | `int` | Size of the site icon.
`$blog_id` | `int` | ID of the blog to get the site icon for.

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 943](../../wordpress/wp-includes/general-template.php#L943-L952)

### `get_custom_logo_image_attributes`

*Filters the list of custom logo image attributes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$custom_logo_attr` | `array` | Custom logo image attributes.
`$custom_logo_id` | `int` | Custom logo attachment ID.
`$blog_id` | `int` | ID of the blog to get the custom logo for.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1052](../../wordpress/wp-includes/general-template.php#L1052-L1061)

### `get_custom_logo`

*Filters the custom logo output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | Custom logo HTML output.
`$blog_id` | `int` | ID of the blog to get the custom logo for.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Added the `$blog_id` parameter.
`4.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1097](../../wordpress/wp-includes/general-template.php#L1097-L1106)

### `pre_get_document_title`

*Filters the document title before it is generated.*

Passing a non-empty value will short-circuit wp_get_document_title(),
returning that value instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1132](../../wordpress/wp-includes/general-template.php#L1132-L1142)

### `document_title_separator`

*Filters the separator for the document title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'-'` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1214](../../wordpress/wp-includes/general-template.php#L1214-L1221)

### `document_title_parts`

*Filters the parts of the document title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `array` | {<br>    The document title parts.<br><br>    @type string $title   Title of the viewed page.<br>    @type string $page    Optional. Page number if paginated.<br>    @type string $tagline Optional. Site description when on home page.<br>    @type string $site    Optional. Site title when not on home page.<br>}

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1223](../../wordpress/wp-includes/general-template.php#L1223-L1237)

### `wp_title_parts`

*Filters the parts of the page title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`explode($t_sep, $title)` |  | 

**Changelog**

Version | Description
------- | -----------
`4.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1380](../../wordpress/wp-includes/general-template.php#L1380-L1387)

### `wp_title`

*Filters the text of the page title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | Page title.
`$sep` | `string` | Title separator.
`$seplocation` | `string` | Location of the separator ('left' or 'right').

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1397](../../wordpress/wp-includes/general-template.php#L1397-L1406)

### `single_post_title`

*Filters the page title for a single post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_post->post_title` |  | 
`$_post` | `\WP_Post` | The current post.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1439](../../wordpress/wp-includes/general-template.php#L1439-L1447)

### `post_type_archive_title`

*Filters the post type archive title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post_type_obj->labels->name` |  | 
`$post_type` | `string` | Post type.

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1479](../../wordpress/wp-includes/general-template.php#L1479-L1487)

### `single_cat_title`

*Filters the category archive page title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term->name` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.10` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1551](../../wordpress/wp-includes/general-template.php#L1551-L1558)

### `single_tag_title`

*Filters the tag archive page title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term->name` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1560](../../wordpress/wp-includes/general-template.php#L1560-L1567)

### `single_term_title`

*Filters the custom taxonomy archive page title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$term->name` |  | 

**Changelog**

Version | Description
------- | -----------
`3.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1569](../../wordpress/wp-includes/general-template.php#L1569-L1576)

### `get_the_archive_title_prefix`

*Filters the archive title prefix.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$prefix` | `string` | Archive title prefix.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1721](../../wordpress/wp-includes/general-template.php#L1721-L1728)

### `get_the_archive_title`

*Filters the archive title.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` | `string` | Archive title to be displayed.
`$original_title` | `string` | Archive title without prefix.
`$prefix` | `string` | Archive title prefix.

**Changelog**

Version | Description
------- | -----------
`5.5.0` | Added the `$prefix` and `$original_title` parameters.
`4.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1738](../../wordpress/wp-includes/general-template.php#L1738-L1748)

### `get_the_archive_description`

*Filters the archive description.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$description` | `string` | Archive description to be displayed.

**Changelog**

Version | Description
------- | -----------
`4.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1788](../../wordpress/wp-includes/general-template.php#L1788-L1795)

### `get_the_post_type_description`

*Filters the description for a post type archive.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$description` | `string` | The post type description.
`$post_type_obj` | `\WP_Post_Type` | The post type object.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1821](../../wordpress/wp-includes/general-template.php#L1821-L1829)

### `get_archives_link`

*Filters the archive link content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link_html` | `string` | The archive HTML link content.
`$url` | `string` | URL to archive.
`$text` | `string` | Archive text description.
`$format` | `string` | Link format. Can be 'link', 'option', 'html', or custom.
`$before` | `string` | Content to prepend to the description.
`$after` | `string` | Content to append to the description.
`$selected` | `bool` | True if the current page is the selected archive.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | Added the `$selected` parameter.
`4.5.0` | Added the `$url`, `$text`, `$format`, `$before`, and `$after` parameters.
`2.6.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1883](../../wordpress/wp-includes/general-template.php#L1883-L1898)

### `getarchives_where`

*Filters the SQL WHERE clause for retrieving archives.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$sql_where` | `string` | Portion of SQL query containing the WHERE clause.
`$parsed_args` | `array` | An array of default arguments.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1988](../../wordpress/wp-includes/general-template.php#L1988-L1996)

### `getarchives_join`

*Filters the SQL JOIN clause for retrieving archives.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 
`$parsed_args` | `array` | An array of default arguments.

**Changelog**

Version | Description
------- | -----------
`2.2.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 1998](../../wordpress/wp-includes/general-template.php#L1998-L2006)

### `the_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$result->post_title` |  | 
`$result->ID` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2143](../../wordpress/wp-includes/general-template.php#L2143-L2143)

### `get_calendar`

*This filter is documented in wp-includes/general-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cache[$key]` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2200](../../wordpress/wp-includes/general-template.php#L2200-L2201)

### `get_calendar`

*Filters the HTML calendar output.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$calendar_output` | `string` | HTML output of the calendar.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2401](../../wordpress/wp-includes/general-template.php#L2401-L2408)

### `get_calendar`

*This filter is documented in wp-includes/general-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$calendar_output` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2411](../../wordpress/wp-includes/general-template.php#L2411-L2412)

### `the_date`

*Filters the date a post was published for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_date` | `string` | The formatted date string.
`$format` | `string` | PHP date format.
`$before` | `string` | HTML output before the date.
`$after` | `string` | HTML output after the date.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2496](../../wordpress/wp-includes/general-template.php#L2496-L2506)

### `get_the_date`

*Filters the date a post was published.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_date` | `string` | The formatted date.
`$format` | `string` | PHP date format.
`$post` | `int\|\WP_Post` | The post object or ID.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2538](../../wordpress/wp-includes/general-template.php#L2538-L2547)

### `the_modified_date`

*Filters the date a post was last modified for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_modified_date` | `string\|false` | The last modified date or false if no post is found.
`$format` | `string` | PHP date format.
`$before` | `string` | HTML output before the date.
`$after` | `string` | HTML output after the date.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2564](../../wordpress/wp-includes/general-template.php#L2564-L2574)

### `get_the_modified_date`

*Filters the date a post was last modified.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_time` | `string\|int\|false` | The formatted date or false if no post is found.
`$format` | `string` | PHP date format.
`$post` | `\WP_Post\|null` | WP_Post object or null if no post is found.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Added the `$post` parameter.
`2.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2606](../../wordpress/wp-includes/general-template.php#L2606-L2616)

### `the_time`

*Filters the time a post was written for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_time($format)` |  | 
`$format` | `string` | Format to use for retrieving the time the post<br>was written. Accepts 'G', 'U', or PHP date format.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2629](../../wordpress/wp-includes/general-template.php#L2629-L2638)

### `get_the_time`

*Filters the time a post was written.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_time` | `string` | The formatted time.
`$format` | `string` | Format to use for retrieving the time the post<br>was written. Accepts 'G', 'U', or PHP date format.
`$post` | `int\|\WP_Post` | WP_Post object or ID.

**Changelog**

Version | Description
------- | -----------
`1.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2664](../../wordpress/wp-includes/general-template.php#L2664-L2674)

### `get_post_time`

*Filters the localized time a post was written.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$time` | `string` | The formatted time.
`$format` | `string` | Format to use for retrieving the time the post was written.<br>Accepts 'G', 'U', or PHP date format. Default 'U'.
`$gmt` | `bool` | Whether to retrieve the GMT time. Default false.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2721](../../wordpress/wp-includes/general-template.php#L2721-L2731)

### `the_modified_time`

*Filters the localized time a post was last modified, for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_modified_time($format)` |  | 
`$format` | `string` | Format to use for retrieving the time the post<br>was modified. Accepts 'G', 'U', or PHP date format.

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2816](../../wordpress/wp-includes/general-template.php#L2816-L2825)

### `get_the_modified_time`

*Filters the localized time a post was last modified.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_time` | `string\|int\|false` | The formatted time or false if no post is found.
`$format` | `string` | Format to use for retrieving the time the post<br>was modified. Accepts 'G', 'U', or PHP date format.
`$post` | `\WP_Post\|null` | WP_Post object or null if no post is found.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | Added the `$post` parameter.
`2.0.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2852](../../wordpress/wp-includes/general-template.php#L2852-L2863)

### `get_post_modified_time`

*Filters the localized time a post was last modified.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$time` | `string\|int` | Formatted date string or Unix timestamp if `$format` is 'U' or 'G'.
`$format` | `string` | Format to use for retrieving the time the post was modified.<br>Accepts 'G', 'U', or PHP date format. Default 'U'.
`$gmt` | `bool` | Whether to retrieve the GMT time. Default false.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2910](../../wordpress/wp-includes/general-template.php#L2910-L2920)

### `the_weekday`

*Filters the weekday on which the post was written, for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_weekday` | `string` | 

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2941](../../wordpress/wp-includes/general-template.php#L2941-L2948)

### `the_weekday_date`

*Filters the localized date on which the post was written, for display.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$the_weekday_date` | `string` | The weekday on which the post was written.
`$before` | `string` | The HTML to output before the date.
`$after` | `string` | The HTML to output after the date.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 2984](../../wordpress/wp-includes/general-template.php#L2984-L2993)

### `feed_links_show_posts_feed`

*Filters whether to display the posts feed link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3067](../../wordpress/wp-includes/general-template.php#L3067-L3074)

### `feed_links_show_comments_feed`

*Filters whether to display the comments feed link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3078](../../wordpress/wp-includes/general-template.php#L3078-L3085)

### `site_icon_meta_tags`

*Filters the site icon meta tags, so plugins can add their own.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_tags` | `string[]` | Array of Site Icon meta tags.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3242](../../wordpress/wp-includes/general-template.php#L3242-L3249)

### `emoji_svg_url`

*This filter is documented in wp-includes/formatting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'https://s.w.org/images/core/emoji/13.0.0/svg/'` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3281](../../wordpress/wp-includes/general-template.php#L3281-L3282)

### `wp_resource_hints`

*Filters domains and URLs for resource hints of relation type.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$urls` | `array` | URLs to print for resource hints.
`$relation_type` | `string` | The relation type the URLs are printed for, e.g. 'preconnect' or 'prerender'.

**Changelog**

Version | Description
------- | -----------
`4.6.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3287](../../wordpress/wp-includes/general-template.php#L3287-L3295)

### `user_can_richedit`

*Filters whether the user can access the visual editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$wp_rich_edit` | `bool` | Whether the user can access the visual editor.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3436](../../wordpress/wp-includes/general-template.php#L3436-L3443)

### `wp_default_editor`

*Filters which editor should be displayed by default.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$r` | `string` | Which editor should be displayed by default. Either 'tinymce', 'html', or 'test'.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3463](../../wordpress/wp-includes/general-template.php#L3463-L3470)

### `wp_code_editor_settings`

*Filters settings that are passed into the code editor.*

Returning a falsey value will disable the syntax-highlighting code editor.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$settings` | `array` | The array of settings passed to the code editor.<br>A falsey value disables the editor.
`$args` | `array` | {<br>    Args passed when calling `get_code_editor_settings()`.<br><br>    @type string   $type       The MIME type of the file to be edited.<br>    @type string   $file       Filename being edited.<br>    @type WP_Theme $theme      Theme being edited when on theme editor.<br>    @type string   $plugin     Plugin being edited when on plugin editor.<br>    @type array    $codemirror Additional CodeMirror setting overrides.<br>    @type array    $csslint    CSSLint rule overrides.<br>    @type array    $jshint     JSHint rule overrides.<br>    @type array    $htmlhint   JSHint rule overrides.<br>}

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3946](../../wordpress/wp-includes/general-template.php#L3946-L3968)

### `get_search_query`

*Filters the contents of the search query variable.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_query_var('s')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 3984](../../wordpress/wp-includes/general-template.php#L3984-L3991)

### `the_search_query`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_search_query(false)` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4015](../../wordpress/wp-includes/general-template.php#L4015-L4015)

### `language_attributes`

*Filters the language attributes for display in the 'html' tag.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | A space-separated list of language attributes.
`$doctype` | `string` | The type of HTML document (xhtml\|html).

**Changelog**

Version | Description
------- | -----------
`4.3.0` | Added the `$doctype` parameter.
`2.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4048](../../wordpress/wp-includes/general-template.php#L4048-L4057)

### `paginate_links`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4252](../../wordpress/wp-includes/general-template.php#L4252-L4252)

### `paginate_links`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4278](../../wordpress/wp-includes/general-template.php#L4278-L4278)

### `paginate_links`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4302](../../wordpress/wp-includes/general-template.php#L4302-L4302)

### `paginate_links_output`

*Filters the HTML output of paginated links for archives.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$r` | `string` | HTML output.
`$args` | `array` | An array of arguments. See paginate_links()<br>for information on accepted arguments.

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4322](../../wordpress/wp-includes/general-template.php#L4322-L4331)

### `wp_admin_css_uri`

*Filters the URI of a WordPress admin CSS file.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$_file` | `string` | Relative path to the file with query arguments attached.
`$file` | `string` | Relative path to the file, minus its ".css" extension.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4519](../../wordpress/wp-includes/general-template.php#L4519-L4527)

### `wp_admin_css`

*Filters the stylesheet link to the specified CSS file.*

If the site is set to display right-to-left, the RTL stylesheet link
will be used instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$stylesheet_link` | `string` | HTML link element for the stylesheet.
`$file` | `string` | Style handle name or filename (without ".css" extension)<br>relative to wp-admin/. Defaults to 'wp-admin'.

**Changelog**

Version | Description
------- | -----------
`2.3.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4570](../../wordpress/wp-includes/general-template.php#L4570-L4581)

### `wp_admin_css`

*This filter is documented in wp-includes/general-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rtl_stylesheet_link` |  | 
`"{$file}-rtl"` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4589](../../wordpress/wp-includes/general-template.php#L4589-L4590)

### `wp_generator_type`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'xhtml'` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4627](../../wordpress/wp-includes/general-template.php#L4627-L4627)

### `the_generator`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_generator($type)` |  | 
`$type` |  | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4650](../../wordpress/wp-includes/general-template.php#L4650-L4650)

### `get_the_generator_{$type}`

*Filters the HTML for the retrieved generator type.*

The dynamic portion of the hook name, `$type`, refers to the generator type.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$gen` | `string` | The HTML markup output to wp_head().
`$type` | `string` | The type of generator. Accepts 'html', 'xhtml', 'atom',<br>'rss2', 'rdf', 'comment', 'export'.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/general-template.php](../../wordpress/wp-includes/general-template.php), [line 4717](../../wordpress/wp-includes/general-template.php#L4717-L4728)

### `customize_dynamic_partial_args`

*This filter is documented in wp-includes/customize/class-wp-customize-selective-refresh.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` |  | 
`$id` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php), [line 100](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php#L100-L101)

### `customize_dynamic_partial_class`

*This filter is documented in wp-includes/customize/class-wp-customize-selective-refresh.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$class` |  | 
`$id` |  | 
`$args` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php), [line 103](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php#L103-L104)

### `customize_dynamic_partial_args`

*Filters a dynamic partial's constructor arguments.*

For a dynamic partial to be registered, this filter must be employed
to override the default false value with an array of args to pass to
the WP_Customize_Partial constructor.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$partial_args` | `false\|array` | The arguments to the WP_Customize_Partial constructor.
`$partial_id` | `string` | ID for dynamic partial.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php), [line 222](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php#L222-L234)

### `customize_dynamic_partial_class`

*Filters the class used to construct partials.*

Allow non-statically created partials to be constructed with custom WP_Customize_Partial subclass.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$partial_class` | `string` | WP_Customize_Partial or a subclass.
`$partial_id` | `string` | ID for dynamic partial.
`$partial_args` | `array` | The arguments to the WP_Customize_Partial constructor.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php), [line 239](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php#L239-L250)

### `customize_render_partials_response`

*Filters the response from rendering the partials.*

Plugins may use this filter to inject `$scripts` and `$styles`, which are dependencies
for the partials being rendered. The response data will be available to the client via
the `render-partials-response` JS event, so the client can then inject the scripts and
styles into the DOM if they have not already been enqueued there.

If plugins do this, they'll need to take care for any scripts that do `document.write()`
and make sure that these are not injected, or else to override the function to no-op,
or else the page will be destroyed.

Plugins should be aware that `$scripts` and `$styles` may eventually be included by
default in the response.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$response` | `array` | {<br>    Response.<br><br>    @type array $contents Associative array mapping a partial ID its corresponding array of contents<br>                          for the containers requested.<br>    @type array $errors   List of errors triggered during rendering of partials, if `WP_DEBUG_DISPLAY`<br>                          is enabled.<br>}
`$this` |  | 
`$partials` | `array` | Placements' context data for the partials rendered in the request.<br>The array is keyed by partial ID, with each item being an array of<br>the placements' context data.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php), [line 406](../../wordpress/wp-includes/customize/class-wp-customize-selective-refresh.php#L406-L436)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$original_object->post_title` |  | 
`$original_object->ID` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 273](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L273-L274)

### `nav_menu_attr_title`

*This filter is documented in wp-includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->attr_title` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 637](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L637-L638)

### `nav_menu_description`

*This filter is documented in wp-includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_trim_words($post->description, 200)` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 640](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L640-L641)

### `wp_setup_nav_menu_item`

*This filter is documented in wp-includes/nav-menu.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 643](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L643-L644)

### `title_save_pre`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_slash($menu_item_value['title'])` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 716](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L716-L716)

### `excerpt_save_pre`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_slash($menu_item_value['attr_title'])` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 719](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L719-L719)

### `content_save_pre`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`wp_slash($menu_item_value['description'])` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 722](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L722-L722)

### `customize_sanitize_{$this->id}`

*This filter is documented in wp-includes/class-wp-customize-setting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$menu_item_value` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php), [line 736](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-item-setting.php#L736-L737)

### `customize_partial_render`

*Filters partial rendering.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rendered` | `string\|array\|false` | The partial value. Default false.
`$partial` | `\WP_Customize_Partial` | WP_Customize_Setting instance.
`$container_context` | `array` | Optional array of context data associated with<br>the target container.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-partial.php](../../wordpress/wp-includes/customize/class-wp-customize-partial.php), [line 235](../../wordpress/wp-includes/customize/class-wp-customize-partial.php#L235-L245)

### `customize_partial_render_{$partial->id}`

*Filters partial rendering for a specific partial.*

The dynamic portion of the hook name, `$partial->ID` refers to the partial ID.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$rendered` | `string\|array\|false` | The partial value. Default false.
`$partial` | `\WP_Customize_Partial` | WP_Customize_Setting instance.
`$container_context` | `array` | Optional array of context data associated with<br>the target container.

**Changelog**

Version | Description
------- | -----------
`4.5.0` | 

Source: [wordpress/wp-includes/customize/class-wp-customize-partial.php](../../wordpress/wp-includes/customize/class-wp-customize-partial.php), [line 247](../../wordpress/wp-includes/customize/class-wp-customize-partial.php#L247-L259)

### `customize_sanitize_{$this->id}`

*This filter is documented in wp-includes/class-wp-customize-setting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-nav-menu-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-setting.php), [line 443](../../wordpress/wp-includes/customize/class-wp-customize-nav-menu-setting.php#L443-L444)

### `customize_value_{$id_base}`

*This filter is documented in wp-includes/class-wp-customize-setting.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` |  | 
`$this` |  | 

Source: [wordpress/wp-includes/customize/class-wp-customize-custom-css-setting.php](../../wordpress/wp-includes/customize/class-wp-customize-custom-css-setting.php), [line 141](../../wordpress/wp-includes/customize/class-wp-customize-custom-css-setting.php#L141-L142)

### `the_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_title` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 151](../../wordpress/wp-includes/deprecated.php#L151-L151)

### `the_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$post->post_title` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 186](../../wordpress/wp-includes/deprecated.php#L186-L186)

### `link_category`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$cat->name` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 1061](../../wordpress/wp-includes/deprecated.php#L1061-L1061)

### `the_content_rss`

*Filters the post content in the context of an RSS feed.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content` | `string` | Content of the current post.

**Changelog**

Version | Description
------- | -----------
`0.71` | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 1682](../../wordpress/wp-includes/deprecated.php#L1682-L1689)

### `icon_dir`

*This filter is documented in wp-includes/post.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_template_directory() . '/images'` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 1914](../../wordpress/wp-includes/deprecated.php#L1914-L1915)

### `attachment_max_dims`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$max_dims` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 1949](../../wordpress/wp-includes/deprecated.php#L1949-L1949)

### `attachment_icon`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$icon` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 1978](../../wordpress/wp-includes/deprecated.php#L1978-L1978)

### `attachment_innerHTML`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$innerHTML` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2004](../../wordpress/wp-includes/deprecated.php#L2004-L2004)

### `the_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2713](../../wordpress/wp-includes/deprecated.php#L2713-L2713)

### `{$boundary}_post_rel_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2720](../../wordpress/wp-includes/deprecated.php#L2720-L2720)

### `index_rel_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2751](../../wordpress/wp-includes/deprecated.php#L2751-L2751)

### `the_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$post->ID` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2788](../../wordpress/wp-includes/deprecated.php#L2788-L2788)

### `parent_post_rel_link`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 2794](../../wordpress/wp-includes/deprecated.php#L2794-L2794)

### `extra_theme_headers`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 3101](../../wordpress/wp-includes/deprecated.php#L3101-L3101)

### `richedit_pre`

*Filters text returned for the rich text editor.*

This filter is first evaluated, and the value returned, if an empty string
is passed to wp_richedit_pre(). If an empty string is passed, it results
in a break tag and line feed.

If a non-empty string is passed, the filter is evaluated on the wp_richedit_pre()
return after being formatted.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

**Changelog**

Version | Description
------- | -----------
`2.0.0` | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 3583](../../wordpress/wp-includes/deprecated.php#L3583-L3598)

### `richedit_pre`

*This filter is documented in wp-includes/deprecated.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` |  | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 3605](../../wordpress/wp-includes/deprecated.php#L3605-L3606)

### `htmledit_pre`

*Filters the text before it is formatted for the HTML editor.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `string` | The HTML-formatted text.

**Changelog**

Version | Description
------- | -----------
`2.5.0` | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 3628](../../wordpress/wp-includes/deprecated.php#L3628-L3636)

### `shortcut_link`

*Filters the Press This bookmarklet link.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The Press This bookmarklet link.

**Changelog**

Version | Description
------- | -----------
`2.6.0` | 

Source: [wordpress/wp-includes/deprecated.php](../../wordpress/wp-includes/deprecated.php), [line 3936](../../wordpress/wp-includes/deprecated.php#L3936-L3944)

### `the_author`

*Filters the display name of the current post's author.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`is_object($authordata) ? $authordata->display_name : null` |  | 

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/author-template.php](../../wordpress/wp-includes/author-template.php), [line 30](../../wordpress/wp-includes/author-template.php#L30-L37)

### `the_modified_author`

*Filters the display name of the author who last edited the current post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$last_user->display_name` |  | 

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/author-template.php](../../wordpress/wp-includes/author-template.php), [line 97](../../wordpress/wp-includes/author-template.php#L97-L104)

### `get_the_author_{$field}`

*Filters the value of the requested user metadata.*

The filter name is dynamic and depends on the $field parameter of the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$value` | `string` | The value of the metadata.
`$user_id` | `int` | The user ID for the value.
`$original_user_id` | `int\|false` | The original user ID, as passed to the function.

**Changelog**

Version | Description
------- | -----------
`4.3.0` | The `$original_user_id` parameter was added.
`2.8.0` | 

Source: [wordpress/wp-includes/author-template.php](../../wordpress/wp-includes/author-template.php), [line 177](../../wordpress/wp-includes/author-template.php#L177-L189)

### `the_author_{$field}`

*The value of the requested user metadata.*

The filter name is dynamic and depends on the $field parameter of the function.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$author_meta` | `string` | The value of the metadata.
`$user_id` | `int\|false` | The user ID.

**Changelog**

Version | Description
------- | -----------
`2.8.0` | 

Source: [wordpress/wp-includes/author-template.php](../../wordpress/wp-includes/author-template.php), [line 206](../../wordpress/wp-includes/author-template.php#L206-L216)

### `the_author_posts_link`

*Filters the link to the author page of the author of the current post.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | HTML link.

**Changelog**

Version | Description
------- | -----------
`2.9.0` | 

Source: [wordpress/wp-includes/author-template.php](../../wordpress/wp-includes/author-template.php), [line 308](../../wordpress/wp-includes/author-template.php#L308-L315)

### `author_link`

*Filters the URL to the author's page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$link` | `string` | The URL to the author's page.
`$author_id` | `int` | The author's ID.
`$author_nicename` | `string` | The author's nice name.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-includes/author-template.php](../../wordpress/wp-includes/author-template.php), [line 363](../../wordpress/wp-includes/author-template.php#L363-L372)

### `is_multi_author`

*Filters whether the site has more than one author with published posts.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`(bool) $is_multi_author` |  | 

**Changelog**

Version | Description
------- | -----------
`3.2.0` | 

Source: [wordpress/wp-includes/author-template.php](../../wordpress/wp-includes/author-template.php), [line 554](../../wordpress/wp-includes/author-template.php#L554-L561)

### `wp_http_ixr_client_headers`

*Filters the headers collection to be sent to the XML-RPC server.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args['headers']` |  | 

**Changelog**

Version | Description
------- | -----------
`4.4.0` | 

Source: [wordpress/wp-includes/class-wp-http-ixr-client.php](../../wordpress/wp-includes/class-wp-http-ixr-client.php), [line 73](../../wordpress/wp-includes/class-wp-http-ixr-client.php#L73-L80)

### `shake_error_codes`

*Filters the error codes array for shaking the login form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$shake_error_codes` | `array` | Error codes that shake the login form.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 56](../../wordpress/wp-login.php#L56-L63)

### `login_title`

*Filters the title tag content for login page.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$login_title` | `string` | The page title, with extra context added.
`$title` | `string` | The original page title.

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 79](../../wordpress/wp-login.php#L79-L87)

### `login_headerurl`

*Filters link URL of the header logo above login form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$login_header_url` | `string` | Login header logo URL.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 125](../../wordpress/wp-login.php#L125-L132)

### `login_headertitle`

*Filters the title attribute of the header logo above login form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($login_header_title)` |  | 
`'5.2.0'` |  | 
`'login_headertext'` |  | 
`__('Usage of the title attribute on the login logo is not recommended for accessibility reasons. Use the link text instead.')` |  | 

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 136](../../wordpress/wp-login.php#L136-L150)

### `login_headertext`

*Filters the link text of the header logo above the login form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$login_header_text` | `string` | The login header logo link text.

**Changelog**

Version | Description
------- | -----------
`5.2.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 154](../../wordpress/wp-login.php#L154-L161)

### `login_body_class`

*Filters the login page body classes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classes` | `array` | An array of body classes.
`$action` | `string` | The action that brought the visitor to the login page.

**Changelog**

Version | Description
------- | -----------
`3.5.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 183](../../wordpress/wp-login.php#L183-L191)

### `login_message`

*Filters the message to display above the login form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$message` | `string` | Login message text.

**Changelog**

Version | Description
------- | -----------
`2.1.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 211](../../wordpress/wp-login.php#L211-L218)

### `login_errors`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 253](../../wordpress/wp-login.php#L253-L253)

### `login_messages`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$messages` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 264](../../wordpress/wp-login.php#L264-L264)

### `login_site_html_link`

*Filter the "Go to site" link displayed in the login page footer.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html_link` |  | 

**Changelog**

Version | Description
------- | -----------
`5.7.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 296](../../wordpress/wp-login.php#L296-L303)

### `login_link_separator`

*Filters the separator used between login form navigation links.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`' | '` |  | 

**Changelog**

Version | Description
------- | -----------
`4.9.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 443](../../wordpress/wp-login.php#L443-L450)

### `admin_email_remind_interval`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`3 * DAY_IN_SECONDS` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 487](../../wordpress/wp-login.php#L487-L487)

### `admin_email_check_interval`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`6 * MONTH_IN_SECONDS` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 519](../../wordpress/wp-login.php#L519-L519)

### `post_password_expires`

*Filters the life span of the post password cookie.*

By default, the cookie expires 10 days from creation. To turn this
into a session cookie, return 0.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`time() + 10 * DAY_IN_SECONDS` |  | 

**Changelog**

Version | Description
------- | -----------
`3.7.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 639](../../wordpress/wp-login.php#L639-L649)

### `logout_redirect`

*Filters the log out redirect URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_to` | `string` | The redirect destination URL.
`$requested_redirect_to` | `string` | The requested redirect destination URL passed as a parameter.
`$user` | `\WP_User` | The WP_User object for the user that's logging out.

**Changelog**

Version | Description
------- | -----------
`4.2.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 685](../../wordpress/wp-login.php#L685-L694)

### `lostpassword_redirect`

*Filters the URL redirected to after submitting the lostpassword/retrievepassword form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$lostpassword_redirect` | `string` | The redirect destination URL.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 720](../../wordpress/wp-login.php#L720-L727)

### `register`

*This filter is documented in wp-includes/general-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$registration_url` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 780](../../wordpress/wp-login.php#L780-L781)

### `register`

*This filter is documented in wp-includes/general-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$registration_url` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 916](../../wordpress/wp-login.php#L916-L917)

### `wp_signup_location`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`network_site_url('wp-signup.php')` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 936](../../wordpress/wp-login.php#L936-L936)

### `registration_redirect`

*Filters the registration redirect URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$registration_redirect` | `string` | The redirect destination URL.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 968](../../wordpress/wp-login.php#L968-L975)

### `wp_login_errors`

*This action is documented in wp-login.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` |  | 
`$redirect_to` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1045](../../wordpress/wp-login.php#L1045-L1046)

### `login_redirect`

*Filters the login redirect URL.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$redirect_to` | `string` | The redirect destination URL.
`$requested_redirect_to` | `string` | The requested redirect destination URL passed as a parameter.
`$user` | `\WP_User\|\WP_Error` | WP_User object if login was successful, WP_Error object otherwise.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1155](../../wordpress/wp-login.php#L1155-L1164)

### `admin_email_check_interval`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`6 * MONTH_IN_SECONDS` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1199](../../wordpress/wp-login.php#L1199-L1199)

### `wp_login_errors`

*Filters the login page errors.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$errors` | `\WP_Error` | WP Error object.
`$redirect_to` | `string` | Redirect destination URL.

**Changelog**

Version | Description
------- | -----------
`3.6.0` | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1270](../../wordpress/wp-login.php#L1270-L1278)

### `register`

*This filter is documented in wp-includes/general-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$registration_url` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1363](../../wordpress/wp-login.php#L1363-L1364)

### `enable_login_autofocus`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-login.php](../../wordpress/wp-login.php), [line 1401](../../wordpress/wp-login.php#L1401-L1401)

### `twentyseventeen_starter_content`

*Filters Twenty Seventeen array of starter content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$starter_content` | `array` | Array of starter content.

Source: [wordpress/wp-content/themes/twentyseventeen/functions.php](../../wordpress/wp-content/themes/twentyseventeen/functions.php), [line 234](../../wordpress/wp-content/themes/twentyseventeen/functions.php#L234-L241)

### `twentyseventeen_content_width`

*Filters Twenty Seventeen content width of the theme.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$content_width` | `int` | Content width in pixels.

Source: [wordpress/wp-content/themes/twentyseventeen/functions.php](../../wordpress/wp-content/themes/twentyseventeen/functions.php), [line 275](../../wordpress/wp-content/themes/twentyseventeen/functions.php#L275-L282)

### `twentyseventeen_social_links_icons`

*Filters Twenty Seventeen social links icons.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$social_links_icons` | `array` | Array of social links icons.

Source: [wordpress/wp-content/themes/twentyseventeen/inc/icon-functions.php](../../wordpress/wp-content/themes/twentyseventeen/inc/icon-functions.php), [line 215](../../wordpress/wp-content/themes/twentyseventeen/inc/icon-functions.php#L215-L222)

### `twentyseventeen_front_page_sections`

*Filters the number of front page sections in Twenty Seventeen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`4` |  | 

Source: [wordpress/wp-content/themes/twentyseventeen/inc/customizer.php](../../wordpress/wp-content/themes/twentyseventeen/inc/customizer.php), [line 118](../../wordpress/wp-content/themes/twentyseventeen/inc/customizer.php#L118-L125)

### `twentyseventeen_custom_header_args`

*Filters Twenty Seventeen custom-header support arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default-image' => get_parent_theme_file_uri('/assets/images/header.jpg'), 'width' => 2000, 'height' => 1200, 'flex-height' => true, 'video' => true, 'wp-head-callback' => 'twentyseventeen_header_style')` |  | 

Source: [wordpress/wp-content/themes/twentyseventeen/inc/custom-header.php](../../wordpress/wp-content/themes/twentyseventeen/inc/custom-header.php), [line 21](../../wordpress/wp-content/themes/twentyseventeen/inc/custom-header.php#L21-L48)

### `twentyseventeen_custom_colors_saturation`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`50` |  | 

Source: [wordpress/wp-content/themes/twentyseventeen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentyseventeen/inc/color-patterns.php), [line 23](../../wordpress/wp-content/themes/twentyseventeen/inc/color-patterns.php#L23-L23)

### `twentyseventeen_custom_colors_css`

*Filters Twenty Seventeen custom colors CSS.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$css` | `string` | Base theme colors CSS.
`$hue` | `int` | The user's selected color hue.
`$saturation` | `string` | Filtered theme color saturation level.

Source: [wordpress/wp-content/themes/twentyseventeen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentyseventeen/inc/color-patterns.php), [line 570](../../wordpress/wp-content/themes/twentyseventeen/inc/color-patterns.php#L570-L579)

### `twentyseventeen_front_page_sections`

*Filters the number of front page sections in Twenty Seventeen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`4` |  | 

Source: [wordpress/wp-content/themes/twentyseventeen/inc/template-functions.php](../../wordpress/wp-content/themes/twentyseventeen/inc/template-functions.php), [line 78](../../wordpress/wp-content/themes/twentyseventeen/inc/template-functions.php#L78-L85)

### `the_content`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_content()` |  | 

Source: [wordpress/wp-content/themes/twentyseventeen/template-parts/post/content-audio.php](../../wordpress/wp-content/themes/twentyseventeen/template-parts/post/content-audio.php), [line 45](../../wordpress/wp-content/themes/twentyseventeen/template-parts/post/content-audio.php#L45-L45)

### `the_content`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_the_content()` |  | 

Source: [wordpress/wp-content/themes/twentyseventeen/template-parts/post/content-video.php](../../wordpress/wp-content/themes/twentyseventeen/template-parts/post/content-video.php), [line 45](../../wordpress/wp-content/themes/twentyseventeen/template-parts/post/content-video.php#L45-L45)

### `twentyseventeen_front_page_sections`

*Filters the number of front page sections in Twenty Seventeen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`4` |  | 

Source: [wordpress/wp-content/themes/twentyseventeen/front-page.php](../../wordpress/wp-content/themes/twentyseventeen/front-page.php), [line 36](../../wordpress/wp-content/themes/twentyseventeen/front-page.php#L36-L43)

### `twentysixteen_content_width`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`840` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/functions.php](../../wordpress/wp-content/themes/twentysixteen/functions.php), [line 236](../../wordpress/wp-content/themes/twentysixteen/functions.php#L236-L236)

### `twentysixteen_custom_background_args`

*Filters the arguments used when adding 'custom-background' support in Twenty Sixteen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default-color' => $default_background_color)` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/inc/customizer.php](../../wordpress/wp-content/themes/twentysixteen/inc/customizer.php), [line 24](../../wordpress/wp-content/themes/twentysixteen/inc/customizer.php#L24-L40)

### `twentysixteen_custom_header_args`

*Filters the arguments used when adding 'custom-header' support in Twenty Sixteen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default-text-color' => $default_text_color, 'width' => 1200, 'height' => 280, 'flex-height' => true, 'wp-head-callback' => 'twentysixteen_header_style')` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/inc/customizer.php](../../wordpress/wp-content/themes/twentysixteen/inc/customizer.php), [line 45](../../wordpress/wp-content/themes/twentysixteen/inc/customizer.php#L45-L70)

### `twentysixteen_color_schemes`

*Filters the color schemes registered for use with Twenty Sixteen.*

The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default' => array('label' => __('Default', 'twentysixteen'), 'colors' => array('#1a1a1a', '#ffffff', '#007acc', '#1a1a1a', '#686868')), 'dark' => array('label' => __('Dark', 'twentysixteen'), 'colors' => array('#262626', '#1a1a1a', '#9adffd', '#e5e5e5', '#c1c1c1')), 'gray' => array('label' => __('Gray', 'twentysixteen'), 'colors' => array('#616a73', '#4d545c', '#c7c7c7', '#f2f2f2', '#f2f2f2')), 'red' => array('label' => __('Red', 'twentysixteen'), 'colors' => array('#ffffff', '#ff675f', '#640c1f', '#402b30', '#402b30')), 'yellow' => array('label' => __('Yellow', 'twentysixteen'), 'colors' => array('#3b3721', '#ffef8e', '#774e24', '#3b3721', '#5b4d3e')))` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/inc/customizer.php](../../wordpress/wp-content/themes/twentysixteen/inc/customizer.php), [line 293](../../wordpress/wp-content/themes/twentysixteen/inc/customizer.php#L293-L367)

### `twentysixteen_author_avatar_size`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`49` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/inc/template-tags.php](../../wordpress/wp-content/themes/twentysixteen/inc/template-tags.php), [line 22](../../wordpress/wp-content/themes/twentysixteen/inc/template-tags.php#L22-L22)

### `twentysixteen_custom_header_sizes`

*Filters the default twentysixteen custom header sizes attribute.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'(max-width: 709px) 85vw, (max-width: 909px) 81vw, (max-width: 1362px) 88vw, 1200px'` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/header.php](../../wordpress/wp-content/themes/twentysixteen/header.php), [line 87](../../wordpress/wp-content/themes/twentysixteen/header.php#L87-L96)

### `twentysixteen_author_bio_avatar_size`

*Filters the Twenty Sixteen author bio avatar size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`42` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/template-parts/biography.php](../../wordpress/wp-content/themes/twentysixteen/template-parts/biography.php), [line 14](../../wordpress/wp-content/themes/twentysixteen/template-parts/biography.php#L14-L21)

### `twentysixteen_attachment_size`

*Filters the default twentysixteen image attachment size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'large'` |  | 

Source: [wordpress/wp-content/themes/twentysixteen/image.php](../../wordpress/wp-content/themes/twentysixteen/image.php), [line 38](../../wordpress/wp-content/themes/twentysixteen/image.php#L38-L45)

### `twentyeleven_header_image_width`

*Filters the Twenty Eleven default header image width.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`1000` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/functions.php](../../wordpress/wp-content/themes/twentyeleven/functions.php), [line 176](../../wordpress/wp-content/themes/twentyeleven/functions.php#L176-L183)

### `twentyeleven_header_image_height`

*Filters the Twenty Eleven default header image height.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`288` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/functions.php](../../wordpress/wp-content/themes/twentyeleven/functions.php), [line 184](../../wordpress/wp-content/themes/twentyeleven/functions.php#L184-L191)

### `the_permalink`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_permalink()` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/functions.php](../../wordpress/wp-content/themes/twentyeleven/functions.php), [line 633](../../wordpress/wp-content/themes/twentyeleven/functions.php#L633-L633)

### `category_archive_meta`

*Filters the default Twenty Eleven category description.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'<div class="category-archive-meta">' . $category_description . '</div>'` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/category.php](../../wordpress/wp-content/themes/twentyeleven/category.php), [line 28](../../wordpress/wp-content/themes/twentyeleven/category.php#L28-L35)

### `twentyeleven_author_bio_avatar_size`

*This filter is documented in author.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`68` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/content-single.php](../../wordpress/wp-content/themes/twentyeleven/content-single.php), [line 73](../../wordpress/wp-content/themes/twentyeleven/content-single.php#L73-L74)

### `widget_title`

*This filter is documented in wp-includes/default-widgets.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`empty($instance['title']) ? __('Ephemera', 'twentyeleven') : $instance['title']` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/inc/widgets.php](../../wordpress/wp-content/themes/twentyeleven/inc/widgets.php), [line 73](../../wordpress/wp-content/themes/twentyeleven/inc/widgets.php#L73-L74)

### `twentyeleven_color_schemes`

*Filters the Twenty Eleven color scheme options.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$color_scheme_options` | `array` | An associative array of color scheme options.

Source: [wordpress/wp-content/themes/twentyeleven/inc/theme-options.php](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php), [line 164](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php#L164-L171)

### `twentyeleven_layouts`

*Filters the Twenty Eleven layout options.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$layout_options` | `array` | An associative array of layout options.

Source: [wordpress/wp-content/themes/twentyeleven/inc/theme-options.php](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php), [line 198](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php#L198-L205)

### `twentyeleven_default_theme_options`

*Filters the Twenty Eleven default options.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$default_theme_options` | `array` | An array of default theme options.

Source: [wordpress/wp-content/themes/twentyeleven/inc/theme-options.php](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php), [line 226](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php#L226-L233)

### `twentyeleven_theme_options_validate`

*Filters the Twenty Eleven sanitized form input array.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$output` | `array` | An array of sanitized form output.
`$input` | `array` | An array of un-sanitized form input.
`$defaults` | `array` | An array of default theme options.

Source: [wordpress/wp-content/themes/twentyeleven/inc/theme-options.php](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php), [line 400](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php#L400-L409)

### `twentyeleven_layout_classes`

*Filters the Twenty Eleven layout body classes.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$classes` | `array` | An array of body classes.
`$current_layout` | `string` | The current theme layout.

Source: [wordpress/wp-content/themes/twentyeleven/inc/theme-options.php](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php), [line 510](../../wordpress/wp-content/themes/twentyeleven/inc/theme-options.php#L510-L518)

### `twentyeleven_status_avatar`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`65` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/content-status.php](../../wordpress/wp-content/themes/twentyeleven/content-status.php), [line 44](../../wordpress/wp-content/themes/twentyeleven/content-status.php#L44-L44)

### `tag_archive_meta`

*Filters the default Twenty Eleven tag description.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'<div class="tag-archive-meta">' . $tag_description . '</div>'` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/tag.php](../../wordpress/wp-content/themes/twentyeleven/tag.php), [line 28](../../wordpress/wp-content/themes/twentyeleven/tag.php#L28-L35)

### `twentyeleven_author_bio_avatar_size`

*Filters the Twenty Eleven author bio avatar size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`60` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/author.php](../../wordpress/wp-content/themes/twentyeleven/author.php), [line 55](../../wordpress/wp-content/themes/twentyeleven/author.php#L55-L62)

### `twentyeleven_attachment_size`

*Filters the Twenty Eleven default attachment size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`848` |  | 

Source: [wordpress/wp-content/themes/twentyeleven/image.php](../../wordpress/wp-content/themes/twentyeleven/image.php), [line 95](../../wordpress/wp-content/themes/twentyeleven/image.php#L95-L102)

### `twentythirteen_attachment_size`

*Filters the image attachment size to use.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(724, 724)` |  | 

Source: [wordpress/wp-content/themes/twentythirteen/functions.php](../../wordpress/wp-content/themes/twentythirteen/functions.php), [line 554](../../wordpress/wp-content/themes/twentythirteen/functions.php#L554-L564)

### `the_permalink`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_permalink()` |  | 

Source: [wordpress/wp-content/themes/twentythirteen/functions.php](../../wordpress/wp-content/themes/twentythirteen/functions.php), [line 630](../../wordpress/wp-content/themes/twentythirteen/functions.php#L630-L630)

### `twentythirteen_author_bio_avatar_size`

*Filters the author bio avatar size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`74` |  | 

Source: [wordpress/wp-content/themes/twentythirteen/author-bio.php](../../wordpress/wp-content/themes/twentythirteen/author-bio.php), [line 14](../../wordpress/wp-content/themes/twentythirteen/author-bio.php#L14-L21)

### `twentynineteen_content_width`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`640` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/functions.php](../../wordpress/wp-content/themes/twentynineteen/functions.php), [line 242](../../wordpress/wp-content/themes/twentynineteen/functions.php#L242-L242)

### `twentynineteen_can_show_post_thumbnail`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`!post_password_required() && !is_attachment() && has_post_thumbnail()` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/inc/helper-functions.php](../../wordpress/wp-content/themes/twentynineteen/inc/helper-functions.php), [line 14](../../wordpress/wp-content/themes/twentynineteen/inc/helper-functions.php#L14-L14)

### `twentynineteen_custom_colors_saturation`

*Filters Twenty Nineteen default saturation level.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`100` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php), [line 20](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php#L20-L27)

### `twentynineteen_custom_colors_saturation_selection`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`50` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php), [line 37](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php#L37-L37)

### `twentynineteen_custom_colors_lightness`

*Filters Twenty Nineteen default lightness level.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`33` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php), [line 40](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php#L40-L47)

### `twentynineteen_custom_colors_lightness_hover`

*Filters Twenty Nineteen default hover lightness level.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`23` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php), [line 50](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php#L50-L57)

### `twentynineteen_custom_colors_lightness_selection`

*Filters Twenty Nineteen default selection lightness level.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`90` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php), [line 60](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php#L60-L67)

### `twentynineteen_custom_colors_css`

*Filters Twenty Nineteen custom colors CSS.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$theme_css` |  | 
`$primary_color` | `int` | The user's selected color hue.
`$saturation` | `string` | Filtered theme color saturation level.

Source: [wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php), [line 261](../../wordpress/wp-content/themes/twentynineteen/inc/color-patterns.php#L261-L270)

### `twentynineteen_attachment_size`

*Filters the default twentynineteen image attachment size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'full'` |  | 

Source: [wordpress/wp-content/themes/twentynineteen/image.php](../../wordpress/wp-content/themes/twentynineteen/image.php), [line 32](../../wordpress/wp-content/themes/twentynineteen/image.php#L32-L39)

### `twentyfifteen_custom_background_args`

*Filters Twenty Fifteen custom-background support arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default-color' => $default_color, 'default-attachment' => 'fixed')` |  | 

Source: [wordpress/wp-content/themes/twentyfifteen/functions.php](../../wordpress/wp-content/themes/twentyfifteen/functions.php), [line 150](../../wordpress/wp-content/themes/twentyfifteen/functions.php#L150-L168)

### `twentyfifteen_color_schemes`

*Filters the color schemes registered for use with Twenty Fifteen.*

The default schemes include 'default', 'dark', 'yellow', 'pink', 'purple', and 'blue'.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default' => array('label' => __('Default', 'twentyfifteen'), 'colors' => array('#f1f1f1', '#ffffff', '#ffffff', '#333333', '#333333', '#f7f7f7')), 'dark' => array('label' => __('Dark', 'twentyfifteen'), 'colors' => array('#111111', '#202020', '#202020', '#bebebe', '#bebebe', '#1b1b1b')), 'yellow' => array('label' => __('Yellow', 'twentyfifteen'), 'colors' => array('#f4ca16', '#ffdf00', '#ffffff', '#111111', '#111111', '#f1f1f1')), 'pink' => array('label' => __('Pink', 'twentyfifteen'), 'colors' => array('#ffe5d1', '#e53b51', '#ffffff', '#352712', '#ffffff', '#f1f1f1')), 'purple' => array('label' => __('Purple', 'twentyfifteen'), 'colors' => array('#674970', '#2e2256', '#ffffff', '#2e2256', '#ffffff', '#f1f1f1')), 'blue' => array('label' => __('Blue', 'twentyfifteen'), 'colors' => array('#e9f2f9', '#55c3dc', '#ffffff', '#22313f', '#ffffff', '#f1f1f1')))` |  | 

Source: [wordpress/wp-content/themes/twentyfifteen/inc/customizer.php](../../wordpress/wp-content/themes/twentyfifteen/inc/customizer.php), [line 159](../../wordpress/wp-content/themes/twentyfifteen/inc/customizer.php#L159-L250)

### `twentyfifteen_custom_header_args`

*Filters Twenty Fifteen custom-header support arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default-text-color' => $default_text_color, 'width' => 954, 'height' => 1300, 'wp-head-callback' => 'twentyfifteen_header_style')` |  | 

Source: [wordpress/wp-content/themes/twentyfifteen/inc/custom-header.php](../../wordpress/wp-content/themes/twentyfifteen/inc/custom-header.php), [line 21](../../wordpress/wp-content/themes/twentyfifteen/inc/custom-header.php#L21-L44)

### `the_permalink`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_permalink()` |  | 

Source: [wordpress/wp-content/themes/twentyfifteen/inc/template-tags.php](../../wordpress/wp-content/themes/twentyfifteen/inc/template-tags.php), [line 235](../../wordpress/wp-content/themes/twentyfifteen/inc/template-tags.php#L235-L235)

### `twentyfifteen_author_bio_avatar_size`

*Filters the author bio avatar size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`56` |  | 

Source: [wordpress/wp-content/themes/twentyfifteen/author-bio.php](../../wordpress/wp-content/themes/twentyfifteen/author-bio.php), [line 15](../../wordpress/wp-content/themes/twentyfifteen/author-bio.php#L15-L22)

### `twentyfifteen_attachment_size`

*Filters the default Twenty Fifteen image attachment size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'large'` |  | 

Source: [wordpress/wp-content/themes/twentyfifteen/image.php](../../wordpress/wp-content/themes/twentyfifteen/image.php), [line 37](../../wordpress/wp-content/themes/twentyfifteen/image.php#L37-L44)

### `twenty_twenty_one_content_width`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`750` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/functions.php](../../wordpress/wp-content/themes/twentytwentyone/functions.php), [line 385](../../wordpress/wp-content/themes/twentytwentyone/functions.php#L385-L385)

### `twentytwentyone_html_classes`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`''` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/functions.php](../../wordpress/wp-content/themes/twentytwentyone/functions.php), [line 606](../../wordpress/wp-content/themes/twentytwentyone/functions.php#L606-L606)

### `twenty_twenty_one_starter_content`

*Filters the array of starter content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$starter_content` | `array` | Array of starter content.

Source: [wordpress/wp-content/themes/twentytwentyone/inc/starter-content.php](../../wordpress/wp-content/themes/twentytwentyone/inc/starter-content.php), [line 176](../../wordpress/wp-content/themes/twentytwentyone/inc/starter-content.php#L176-L183)

### `twenty_twenty_one_can_show_post_thumbnail`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`!post_password_required() && !is_attachment() && has_post_thumbnail()` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php), [line 109](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php#L109-L112)

### `twenty_twenty_one_get_localized_font_family_types`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(
    // Arabic.
    'ar' => array('Tahoma', 'Arial', 'sans-serif'),
    'ary' => array('Tahoma', 'Arial', 'sans-serif'),
    'azb' => array('Tahoma', 'Arial', 'sans-serif'),
    'ckb' => array('Tahoma', 'Arial', 'sans-serif'),
    'fa-IR' => array('Tahoma', 'Arial', 'sans-serif'),
    'haz' => array('Tahoma', 'Arial', 'sans-serif'),
    'ps' => array('Tahoma', 'Arial', 'sans-serif'),
    // Chinese Simplified (China) - Noto Sans SC.
    'zh-CN' => array('\'PingFang SC\'', '\'Helvetica Neue\'', '\'Microsoft YaHei New\'', '\'STHeiti Light\'', 'sans-serif'),
    // Chinese Traditional (Taiwan) - Noto Sans TC.
    'zh-TW' => array('\'PingFang TC\'', '\'Helvetica Neue\'', '\'Microsoft YaHei New\'', '\'STHeiti Light\'', 'sans-serif'),
    // Chinese (Hong Kong) - Noto Sans HK.
    'zh-HK' => array('\'PingFang HK\'', '\'Helvetica Neue\'', '\'Microsoft YaHei New\'', '\'STHeiti Light\'', 'sans-serif'),
    // Cyrillic.
    'bel' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'bg-BG' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'kk' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'mk-MK' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'mn' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'ru-RU' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'sah' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'sr-RS' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'tt-RU' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'uk' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    // Devanagari.
    'bn-BD' => array('Arial', 'sans-serif'),
    'hi-IN' => array('Arial', 'sans-serif'),
    'mr' => array('Arial', 'sans-serif'),
    'ne-NP' => array('Arial', 'sans-serif'),
    // Greek.
    'el' => array('\'Helvetica Neue\', Helvetica, Arial, sans-serif'),
    // Gujarati.
    'gu' => array('Arial', 'sans-serif'),
    // Hebrew.
    'he-IL' => array('\'Arial Hebrew\'', 'Arial', 'sans-serif'),
    // Japanese.
    'ja' => array('sans-serif'),
    // Korean.
    'ko-KR' => array('\'Apple SD Gothic Neo\'', '\'Malgun Gothic\'', '\'Nanum Gothic\'', 'Dotum', 'sans-serif'),
    // Thai.
    'th' => array('\'Sukhumvit Set\'', '\'Helvetica Neue\'', 'Helvetica', 'Arial', 'sans-serif'),
    // Vietnamese.
    'vi' => array('\'Libre Franklin\'', 'sans-serif'),
)` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php), [line 223](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php#L223-L285)

### `twenty_twenty_one_get_localized_font_family_elements`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('front-end' => array('body', 'input', 'textarea', 'button', '.button', '.faux-button', '.wp-block-button__link', '.wp-block-file__button', '.has-drop-cap:not(:focus)::first-letter', '.has-drop-cap:not(:focus)::first-letter', '.entry-content .wp-block-archives', '.entry-content .wp-block-categories', '.entry-content .wp-block-cover-image', '.entry-content .wp-block-latest-comments', '.entry-content .wp-block-latest-posts', '.entry-content .wp-block-pullquote', '.entry-content .wp-block-quote.is-large', '.entry-content .wp-block-quote.is-style-large', '.entry-content .wp-block-archives *', '.entry-content .wp-block-categories *', '.entry-content .wp-block-latest-posts *', '.entry-content .wp-block-latest-comments *', '.entry-content p', '.entry-content ol', '.entry-content ul', '.entry-content dl', '.entry-content dt', '.entry-content cite', '.entry-content figcaption', '.entry-content .wp-caption-text', '.comment-content p', '.comment-content ol', '.comment-content ul', '.comment-content dl', '.comment-content dt', '.comment-content cite', '.comment-content figcaption', '.comment-content .wp-caption-text', '.widget_text p', '.widget_text ol', '.widget_text ul', '.widget_text dl', '.widget_text dt', '.widget-content .rssSummary', '.widget-content cite', '.widget-content figcaption', '.widget-content .wp-caption-text'), 'block-editor' => array('.editor-styles-wrapper > *', '.editor-styles-wrapper p', '.editor-styles-wrapper ol', '.editor-styles-wrapper ul', '.editor-styles-wrapper dl', '.editor-styles-wrapper dt', '.editor-post-title__block .editor-post-title__input', '.editor-styles-wrapper .wp-block h1', '.editor-styles-wrapper .wp-block h2', '.editor-styles-wrapper .wp-block h3', '.editor-styles-wrapper .wp-block h4', '.editor-styles-wrapper .wp-block h5', '.editor-styles-wrapper .wp-block h6', '.editor-styles-wrapper .has-drop-cap:not(:focus)::first-letter', '.editor-styles-wrapper cite', '.editor-styles-wrapper figcaption', '.editor-styles-wrapper .wp-caption-text'), 'classic-editor' => array('body#tinymce.wp-editor', 'body#tinymce.wp-editor p', 'body#tinymce.wp-editor ol', 'body#tinymce.wp-editor ul', 'body#tinymce.wp-editor dl', 'body#tinymce.wp-editor dt', 'body#tinymce.wp-editor figcaption', 'body#tinymce.wp-editor .wp-caption-text', 'body#tinymce.wp-editor .wp-caption-dd', 'body#tinymce.wp-editor cite', 'body#tinymce.wp-editor table'))` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php), [line 293](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php#L293-L300)

### `the_content`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$blocks_content` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php), [line 379](../../wordpress/wp-content/themes/twentytwentyone/inc/template-functions.php#L379-L379)

### `twenty_twenty_one_svg_icons_{$group}`

*Filters Twenty Twenty-Ones's array of icons.*

The dynamic portion of the hook name, `$group`, refers to
the name of the group of icons, either "ui" or "social".

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$arr` | `array` | Array of icons.

Source: [wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php](../../wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php), [line 171](../../wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php#L171-L181)

### `twenty_twenty_one_social_icons_map`

*Filters Twenty Twenty-Ones's array of domain mappings for social icons.*

By default, each Icon ID is matched against a .com TLD. To override this behavior,
specify all the domains it covers (including the .com TLD too, if applicable).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::$social_icons_map` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php](../../wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php), [line 214](../../wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php#L214-L224)

### `twenty_twenty_one_svg_icons_social`

*Filters Twenty Twenty-One's array of social icons.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::$social_icons` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php](../../wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php), [line 226](../../wordpress/wp-content/themes/twentytwentyone/classes/class-twenty-twenty-one-svg-icons.php#L226-L233)

### `twenty_twenty_one_attachment_size`

*Filter the default image attachment size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'full'` |  | 

Source: [wordpress/wp-content/themes/twentytwentyone/image.php](../../wordpress/wp-content/themes/twentytwentyone/image.php), [line 24](../../wordpress/wp-content/themes/twentytwentyone/image.php#L24-L29)

### `twentyfourteen_custom_background_args`

*Filters Twenty Fourteen custom-background support arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default-color' => 'f5f5f5')` |  | 

Source: [wordpress/wp-content/themes/twentyfourteen/functions.php](../../wordpress/wp-content/themes/twentyfourteen/functions.php), [line 173](../../wordpress/wp-content/themes/twentyfourteen/functions.php#L173-L189)

### `twentyfourteen_get_featured_posts`

*Filters the featured posts to return in Twenty Fourteen.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-content/themes/twentyfourteen/functions.php](../../wordpress/wp-content/themes/twentyfourteen/functions.php), [line 230](../../wordpress/wp-content/themes/twentyfourteen/functions.php#L230-L237)

### `twentyfourteen_attachment_size`

*Filters the default Twenty Fourteen attachment size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(810, 810)` |  | 

Source: [wordpress/wp-content/themes/twentyfourteen/functions.php](../../wordpress/wp-content/themes/twentyfourteen/functions.php), [line 427](../../wordpress/wp-content/themes/twentyfourteen/functions.php#L427-L439)

### `wp_audio_shortcode_library`

*This filter is documented in wp-includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mediaelement'` |  | 

Source: [wordpress/wp-content/themes/twentyfourteen/inc/widgets.php](../../wordpress/wp-content/themes/twentyfourteen/inc/widgets.php), [line 54](../../wordpress/wp-content/themes/twentyfourteen/inc/widgets.php#L54-L55)

### `wp_video_shortcode_library`

*This filter is documented in wp-includes/media.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`'mediaelement'` |  | 

Source: [wordpress/wp-content/themes/twentyfourteen/inc/widgets.php](../../wordpress/wp-content/themes/twentyfourteen/inc/widgets.php), [line 56](../../wordpress/wp-content/themes/twentyfourteen/inc/widgets.php#L56-L57)

### `widget_title`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$title` |  | 
`$instance` |  | 
`$this->id_base` |  | 

Source: [wordpress/wp-content/themes/twentyfourteen/inc/widgets.php](../../wordpress/wp-content/themes/twentyfourteen/inc/widgets.php), [line 114](../../wordpress/wp-content/themes/twentyfourteen/inc/widgets.php#L114-L114)

### `twentyfourteen_custom_header_args`

*Filters Twenty Fourteen custom-header support arguments.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('default-text-color' => 'fff', 'width' => 1260, 'height' => 240, 'flex-height' => true, 'wp-head-callback' => 'twentyfourteen_header_style', 'admin-head-callback' => 'twentyfourteen_admin_header_style', 'admin-preview-callback' => 'twentyfourteen_admin_header_image')` |  | 

Source: [wordpress/wp-content/themes/twentyfourteen/inc/custom-header.php](../../wordpress/wp-content/themes/twentyfourteen/inc/custom-header.php), [line 22](../../wordpress/wp-content/themes/twentyfourteen/inc/custom-header.php#L22-L51)

### `twentytwelve_status_avatar`

*Filters the status avatar size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`48` |  | 

Source: [wordpress/wp-content/themes/twentytwelve/content-status.php](../../wordpress/wp-content/themes/twentytwelve/content-status.php), [line 21](../../wordpress/wp-content/themes/twentytwelve/content-status.php#L21-L28)

### `twentytwelve_author_bio_avatar_size`

*This filter is documented in author.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`68` |  | 

Source: [wordpress/wp-content/themes/twentytwelve/content.php](../../wordpress/wp-content/themes/twentytwelve/content.php), [line 68](../../wordpress/wp-content/themes/twentytwelve/content.php#L68-L69)

### `twentytwelve_author_bio_avatar_size`

*Filters the author bio avatar size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`68` |  | 

Source: [wordpress/wp-content/themes/twentytwelve/author.php](../../wordpress/wp-content/themes/twentytwelve/author.php), [line 59](../../wordpress/wp-content/themes/twentytwelve/author.php#L59-L66)

### `twentytwelve_attachment_size`

*Filters the image attachment size to use.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(960, 960)` |  | 

Source: [wordpress/wp-content/themes/twentytwelve/image.php](../../wordpress/wp-content/themes/twentytwelve/image.php), [line 95](../../wordpress/wp-content/themes/twentytwelve/image.php#L95-L105)

### `twentyten_header_image_width`

*Filters the Twenty Ten default header image width.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`940` |  | 

Source: [wordpress/wp-content/themes/twentyten/functions.php](../../wordpress/wp-content/themes/twentyten/functions.php), [line 159](../../wordpress/wp-content/themes/twentyten/functions.php#L159-L166)

### `twentyten_header_image_height`

*Filters the Twenty Ten defaul header image height.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`198` |  | 

Source: [wordpress/wp-content/themes/twentyten/functions.php](../../wordpress/wp-content/themes/twentyten/functions.php), [line 167](../../wordpress/wp-content/themes/twentyten/functions.php#L167-L174)

### `twentyten_author_bio_avatar_size`

*This filter is documented in author.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`60` |  | 

Source: [wordpress/wp-content/themes/twentyten/loop-single.php](../../wordpress/wp-content/themes/twentyten/loop-single.php), [line 52](../../wordpress/wp-content/themes/twentyten/loop-single.php#L52-L53)

### `twentyten_attachment_size`

*Filters the Twenty Ten default attachment width.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`900` |  | 

Source: [wordpress/wp-content/themes/twentyten/loop-attachment.php](../../wordpress/wp-content/themes/twentyten/loop-attachment.php), [line 125](../../wordpress/wp-content/themes/twentyten/loop-attachment.php#L125-L132)

### `twentyten_attachment_height`

*Filters the Twenty Ten default attachment height.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`900` |  | 

Source: [wordpress/wp-content/themes/twentyten/loop-attachment.php](../../wordpress/wp-content/themes/twentyten/loop-attachment.php), [line 133](../../wordpress/wp-content/themes/twentyten/loop-attachment.php#L133-L140)

### `twentyten_author_bio_avatar_size`

*Filters the Twenty Ten author bio avatar size.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`60` |  | 

Source: [wordpress/wp-content/themes/twentyten/author.php](../../wordpress/wp-content/themes/twentyten/author.php), [line 43](../../wordpress/wp-content/themes/twentyten/author.php#L43-L50)

### `twentytwenty_get_elements_array`

*Filters Twenty Twenty theme elements*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$elements` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/functions.php](../../wordpress/wp-content/themes/twentytwenty/functions.php), [line 752](../../wordpress/wp-content/themes/twentytwenty/functions.php#L752-L759)

### `twentytwenty_site_logo_args`

*Filters the arguments for `twentytwenty_site_logo()`.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | Parsed arguments.
`$defaults` | `array` | Function's default arguments.

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 50](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L50-L56)

### `twentytwenty_site_logo`

*Filters the arguments for `twentytwenty_site_logo()`.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | Compiled HTML based on our arguments.
`$args` | `array` | Parsed arguments.
`$classname` | `string` | Class name based on current view, home or single.
`$contents` | `string` | HTML for site title or logo.

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 70](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L70-L78)

### `twentytwenty_site_description`

*Filters the HTML for the site description.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$html` | `string` | The HTML to display.
`$description` | `string` | Site description via `bloginfo()`.
`$wrapper` | `string` | The format used in case you want to reuse it in a `sprintf()`.

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 105](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L105-L114)

### `twentytwenty_disallowed_post_types_for_meta_output`

*Filters post types array.*

This filter can be used to hide post meta information of post, page or custom post type
registered by child themes or plugins.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('page')` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 236](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L236-L246)

### `twentytwenty_post_meta_location_single_top`

*Filters post meta info visibility.*

Use this filter to hide post meta information like Author, Post date, Comments, Is sticky status.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('author', 'post-date', 'comments', 'sticky')` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 258](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L258-L280)

### `twentytwenty_post_meta_location_single_bottom`

*Filters post tags visibility.*

Use this filter to hide post tags.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('tags')` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 286](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L286-L302)

### `twentytwenty_get_the_archive_title_regex`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('pattern' => '/(\\A[^\\:]+\\:)/', 'replacement' => '<span class="color-accent">$1</span>')` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 732](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L732-L738)

### `twentytwenty_toggle_duration`

*Filters the animation duration/speed used usually for submenu toggles.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`250` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/inc/template-tags.php](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php), [line 762](../../wordpress/wp-content/themes/twentytwenty/inc/template-tags.php#L762-L769)

### `twentytwenty_starter_content`

*Filters Twenty Twenty array of starter content.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$starter_content` | `array` | Array of starter content.

Source: [wordpress/wp-content/themes/twentytwenty/inc/starter-content.php](../../wordpress/wp-content/themes/twentytwenty/inc/starter-content.php), [line 209](../../wordpress/wp-content/themes/twentytwenty/inc/starter-content.php#L209-L216)

### `page_css_class`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$css_class` |  | 
`$page` |  | 
`$depth` |  | 
`$args` |  | 
`$current_page` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php), [line 65](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php#L65-L65)

### `page_menu_link_attributes`

*This filter is documented in wp-includes/class-walker-page.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$atts` |  | 
`$page` |  | 
`$depth` |  | 
`$args` |  | 
`$current_page` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php), [line 80](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php#L80-L81)

### `the_title`

*This filter is documented in wp-includes/post-template.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$page->post_title` |  | 
`$page->ID` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php), [line 128](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-walker-page.php#L128-L129)

### `twentytwenty_svg_icons_{$group}`

*Filters Twenty Twenty's array of icons.*

The dynamic portion of the hook name, `$group`, refers to
the name of the group of icons, either "ui" or "social".

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$arr` | `array` | Array of icons.

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php), [line 33](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php#L33-L43)

### `twentytwenty_svg_icon_color`

*Filters an SVG icon's color.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$color` | `string` | The icon color.
`$icon` | `string` | The icon name.
`$group` | `string` | The icon group.

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php), [line 45](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php#L45-L54)

### `twentytwenty_social_icons_map`

*Filters Twenty Twenty's array of domain mappings for social icons.*

By default, each Icon ID is matched against a .com TLD. To override this behavior,
specify all the domains it covers (including the .com TLD too, if applicable).

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::$social_icons_map` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php), [line 79](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php#L79-L89)

### `twentytwenty_svg_icons_social`

*Filters Twenty Twenty's array of social icons.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`self::$social_icons` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php), [line 91](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-svg-icons.php#L91-L98)

### `twentytwenty_customize_opacity_range`

*Filters the input attributes for opacity*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('min' => 0, 'max' => 90, 'step' => 5)` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-customize.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-customize.php), [line 505](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-customize.php#L505-L523)

### `twentytwenty_get_localized_font_family_types`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array(
    // Arabic.
    'ar' => array('Tahoma', 'Arial', 'sans-serif'),
    'ary' => array('Tahoma', 'Arial', 'sans-serif'),
    'azb' => array('Tahoma', 'Arial', 'sans-serif'),
    'ckb' => array('Tahoma', 'Arial', 'sans-serif'),
    'fa-IR' => array('Tahoma', 'Arial', 'sans-serif'),
    'haz' => array('Tahoma', 'Arial', 'sans-serif'),
    'ps' => array('Tahoma', 'Arial', 'sans-serif'),
    // Chinese Simplified (China) - Noto Sans SC.
    'zh-CN' => array('\'PingFang SC\'', '\'Helvetica Neue\'', '\'Microsoft YaHei New\'', '\'STHeiti Light\'', 'sans-serif'),
    // Chinese Traditional (Taiwan) - Noto Sans TC.
    'zh-TW' => array('\'PingFang TC\'', '\'Helvetica Neue\'', '\'Microsoft YaHei New\'', '\'STHeiti Light\'', 'sans-serif'),
    // Chinese (Hong Kong) - Noto Sans HK.
    'zh-HK' => array('\'PingFang HK\'', '\'Helvetica Neue\'', '\'Microsoft YaHei New\'', '\'STHeiti Light\'', 'sans-serif'),
    // Cyrillic.
    'bel' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'bg-BG' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'kk' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'mk-MK' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'mn' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'ru-RU' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'sah' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'sr-RS' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'tt-RU' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    'uk' => array('\'Helvetica Neue\'', 'Helvetica', '\'Segoe UI\'', 'Arial', 'sans-serif'),
    // Devanagari.
    'bn-BD' => array('Arial', 'sans-serif'),
    'hi-IN' => array('Arial', 'sans-serif'),
    'mr' => array('Arial', 'sans-serif'),
    'ne-NP' => array('Arial', 'sans-serif'),
    // Greek.
    'el' => array('\'Helvetica Neue\', Helvetica, Arial, sans-serif'),
    // Gujarati.
    'gu' => array('Arial', 'sans-serif'),
    // Hebrew.
    'he-IL' => array('\'Arial Hebrew\'', 'Arial', 'sans-serif'),
    // Japanese.
    'ja' => array('sans-serif'),
    // Korean.
    'ko-KR' => array('\'Apple SD Gothic Neo\'', '\'Malgun Gothic\'', '\'Nanum Gothic\'', 'Dotum', 'sans-serif'),
    // Thai.
    'th' => array('\'Sukhumvit Set\'', '\'Helvetica Neue\'', 'Helvetica', 'Arial', 'sans-serif'),
    // Vietnamese.
    'vi' => array('\'Libre Franklin\'', 'sans-serif'),
)` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-non-latin-languages.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-non-latin-languages.php), [line 32](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-non-latin-languages.php#L32-L94)

### `twentytwenty_get_localized_font_family_elements`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array('front-end' => array('body', 'input', 'textarea', 'button', '.button', '.faux-button', '.wp-block-button__link', '.wp-block-file__button', '.has-drop-cap:not(:focus)::first-letter', '.has-drop-cap:not(:focus)::first-letter', '.entry-content .wp-block-archives', '.entry-content .wp-block-categories', '.entry-content .wp-block-cover-image', '.entry-content .wp-block-latest-comments', '.entry-content .wp-block-latest-posts', '.entry-content .wp-block-pullquote', '.entry-content .wp-block-quote.is-large', '.entry-content .wp-block-quote.is-style-large', '.entry-content .wp-block-archives *', '.entry-content .wp-block-categories *', '.entry-content .wp-block-latest-posts *', '.entry-content .wp-block-latest-comments *', '.entry-content p', '.entry-content ol', '.entry-content ul', '.entry-content dl', '.entry-content dt', '.entry-content cite', '.entry-content figcaption', '.entry-content .wp-caption-text', '.comment-content p', '.comment-content ol', '.comment-content ul', '.comment-content dl', '.comment-content dt', '.comment-content cite', '.comment-content figcaption', '.comment-content .wp-caption-text', '.widget_text p', '.widget_text ol', '.widget_text ul', '.widget_text dl', '.widget_text dt', '.widget-content .rssSummary', '.widget-content cite', '.widget-content figcaption', '.widget-content .wp-caption-text'), 'block-editor' => array('.editor-styles-wrapper > *', '.editor-styles-wrapper p', '.editor-styles-wrapper ol', '.editor-styles-wrapper ul', '.editor-styles-wrapper dl', '.editor-styles-wrapper dt', '.editor-post-title__block .editor-post-title__input', '.editor-styles-wrapper .wp-block h1', '.editor-styles-wrapper .wp-block h2', '.editor-styles-wrapper .wp-block h3', '.editor-styles-wrapper .wp-block h4', '.editor-styles-wrapper .wp-block h5', '.editor-styles-wrapper .wp-block h6', '.editor-styles-wrapper .has-drop-cap:not(:focus)::first-letter', '.editor-styles-wrapper cite', '.editor-styles-wrapper figcaption', '.editor-styles-wrapper .wp-caption-text'), 'classic-editor' => array('body#tinymce.wp-editor', 'body#tinymce.wp-editor p', 'body#tinymce.wp-editor ol', 'body#tinymce.wp-editor ul', 'body#tinymce.wp-editor dl', 'body#tinymce.wp-editor dt', 'body#tinymce.wp-editor figcaption', 'body#tinymce.wp-editor .wp-caption-text', 'body#tinymce.wp-editor .wp-caption-dd', 'body#tinymce.wp-editor cite', 'body#tinymce.wp-editor table'))` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-non-latin-languages.php](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-non-latin-languages.php), [line 102](../../wordpress/wp-content/themes/twentytwenty/classes/class-twentytwenty-non-latin-languages.php#L102-L109)

### `twentytwenty_show_categories_in_entry_header`

*Allow child themes and plugins to filter the display of the categories in the entry header.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/template-parts/entry-header.php](../../wordpress/wp-content/themes/twentytwenty/template-parts/entry-header.php), [line 23](../../wordpress/wp-content/themes/twentytwenty/template-parts/entry-header.php#L23-L30)

### `twentytwenty_show_categories_in_entry_header`

*Allow child themes and plugins to filter the display of the categories in the article header.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`true` |  | 

Source: [wordpress/wp-content/themes/twentytwenty/template-parts/content-cover.php](../../wordpress/wp-content/themes/twentytwenty/template-parts/content-cover.php), [line 57](../../wordpress/wp-content/themes/twentytwenty/template-parts/content-cover.php#L57-L64)

### `signup_another_blog_init`

*Filters the default site sign-up variables.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$signup_defaults` | `array` | {<br>    An array of default site sign-up variables.<br><br>    @type string   $blogname   The site blogname.<br>    @type string   $blog_title The site title.<br>    @type WP_Error $errors     A WP_Error object possibly containing 'blogname' or 'blog_title' errors.<br>}

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 322](../../wordpress/wp-signup.php#L322-L335)

### `signup_create_blog_meta`

*Filters the new site meta variables.*

Use the %1$s filter instead.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array($blog_meta_defaults)` |  | 
`'3.0.0'` |  | 
`'add_signup_meta'` |  | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 450](../../wordpress/wp-signup.php#L450-L460)

### `add_signup_meta`

*Filters the new default site meta variables.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$meta_defaults` |  | 

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 462](../../wordpress/wp-signup.php#L462-L474)

### `signup_user_init`

*Filters the default user variables used on the user sign-up form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$signup_user_defaults` | `array` | {<br>    An array of default user variables.<br><br>    @type string   $user_name  The user username.<br>    @type string   $user_email The user email address.<br>    @type WP_Error $errors     A WP_Error object with possible errors relevant to the sign-up user.<br>}

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 573](../../wordpress/wp-signup.php#L573-L586)

### `add_signup_meta`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`array()` |  | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 650](../../wordpress/wp-signup.php#L650-L650)

### `signup_blog_init`

*Filters the default site creation variables for the site sign-up form.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$signup_blog_defaults` | `array` | {<br>    An array of default site creation variables.<br><br>    @type string   $user_name  The user username.<br>    @type string   $user_email The user email address.<br>    @type string   $blogname   The blogname.<br>    @type string   $blog_title The title of the site.<br>    @type WP_Error $errors     A WP_Error object with possible errors relevant to new site creation variables.<br>}

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 709](../../wordpress/wp-signup.php#L709-L724)

### `add_signup_meta`

*This filter is documented in wp-signup.php*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$signup_meta` |  | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 801](../../wordpress/wp-signup.php#L801-L802)

### `signup_get_available_languages`

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`get_available_languages()` |  | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 879](../../wordpress/wp-signup.php#L879-L879)

### `wpmu_active_signup`

*Filters the type of site sign-up.*

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$active_signup` | `string` | String that returns registration type. The value can be<br>'all', 'none', 'blog', or 'user'.

**Changelog**

Version | Description
------- | -----------
`3.0.0` | 

Source: [wordpress/wp-signup.php](../../wordpress/wp-signup.php), [line 893](../../wordpress/wp-signup.php#L893-L901)


<p align="center"><a href="https://github.com/pronamic/wp-documentor"><img src="https://cdn.jsdelivr.net/gh/pronamic/wp-documentor@main/logos/pronamic-wp-documentor.svgo-min.svg" alt="Pronamic WordPress Documentor" width="32" height="32"></a><br><em>Generated by <a href="https://github.com/pronamic/wp-documentor">Pronamic WordPress Documentor</a> <code>1.2.0</code></em><p>

